(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    605115,      10984]*)
(*NotebookOutlinePosition[    606127,      11020]*)
(*  CellTagsIndexPosition[    606049,      11014]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["10.2  Bilinear Transformations - Mobius \
Transformations",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tAnother important class of elementary mappings was studied by ",
  StyleBox[ButtonBox["August Ferdinand M\[ODoubleDot]bius",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Mobius.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " (1790-1868).  These mappings are conveniently expressed as the quotient \
of two linear expressions and are commonly known as linear fractional or \
bilinear transformations.  They arise naturally in mapping problems involving \
the function  arctan(z).  In this section, we show how they are used to map a \
disk one-to-one and onto a half-plane.  \n\n\tLet  ",
  Cell[BoxData[
      RowBox[{"a", ",", "b", ",", "c", ",", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "d"}]}]]],
  "  denote four complex constants with the restriction that ",
  Cell[BoxData[
      \(a\ d \[NotEqual] b\ c\)]],
  ".  Then the function\n\n",
  StyleBox["(10-13)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(a\ z\  + \ b\)\/\(c\ z\  + \ d\)\)\)]],
  "\n\nis called  a bilinear transformation, a ",
  StyleBox[ButtonBox["M\[ODoubleDot]bius transformation",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/MoebiusTransformation.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ", or a ",
  StyleBox[ButtonBox["linear fractional transformation",
    ButtonData:>{
      URL[ 
      "http://mathworld.wolfram.com/LinearFractionalTransformation.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  ".   \nIf the expression for ",
  StyleBox["S(z)",
    FontFamily->"Courier New"],
  " in Equation ",
  StyleBox["(10-13)",
    FontColor->RGBColor[0, 0, 1]],
  " is multiplied through by the quantity  ",
  Cell[BoxData[
      \(c\ z\  + \ d\)]],
  ",  then the resulting expression has the bilinear form  ",
  Cell[BoxData[
      \(c\ w\ z\  - \ a\ z\  + \ d\ w\  - \ b\  = \ 0\)]],
  ".  \nWe collect terms involving ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " and write  ",
  Cell[BoxData[
      \(z \((c\ w\  - a\ )\)\  = \ \(-d\)\ w\  + \ b\)]],
  ".  Then, for values of  ",
  Cell[BoxData[
      \(w \[NotEqual] a\/c\)]],
  "  the inverse transformation is given by\n\n",
  StyleBox["(10-14)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(z = \(\(S\^\(-1\)\) \((w)\) = \(\(-d\)\ w\  + \ b\)\/\(c\ w\  - \ a\)\
\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe can extend  ",
  Cell[BoxData[
      \(S \((z)\)\ \ and\ \ \(S\^\(-1\)\) \((w)\)\)]],
  "  to mappings in the extended complex plane.  The value  ",
  Cell[BoxData[
      \(S \((\[Infinity])\)\)]],
  "  should be chosen to equal the limit of ",
  Cell[BoxData[
      \(S \((z)\)\)]],
  "  as  ",
  Cell[BoxData[
      \(z \[Rule] \[Infinity]\)]],
  ".  Therefore we define\n\n\t\t\t\t",
  Cell[BoxData[
      \(S \((\[Infinity])\)\  = \ \(lim\+\(z\  \[Rule] \ \[Infinity]\)\ \ S \
\((z)\)\  = \ \(lim\+\(z\  \[Rule] \ \[Infinity]\)\ \ \(a\ \  + \ b\/z\)\/\(c\
\ \  + \ d\/z\)\  = \ \ a\/c\)\)\)]],
  ",  \n\nand the inverse is  ",
  Cell[BoxData[
      \(\(S\^\(-1\)\) \((a\/c)\)\  = \ \[Infinity]\)]],
  ".  Similarly, the value  ",
  Cell[BoxData[
      \(\(S\^\(-1\)\) \((\[Infinity])\)\)]],
  "  is obtained by \n\n\t\t\t\t",
  Cell[BoxData[
      \(\(S\^\(-1\)\) \((\[Infinity])\)\  = \ \(lim\+\(w \[Rule] \ \
\[Infinity]\)\ \ \(S\^\(-1\)\) \((w)\)\  = \ 
          lim\+\(w\  \[Rule] \ \[Infinity]\)\ \ \(\(-d\)\  + b\/w\)\/\(c\  - \
a\/w\)\  \[Equal] \ \ \(-\ d\)\/c\)\)]],
  ",\n\nand the inverse is  ",
  Cell[BoxData[
      \(S \((\(-\ d\)\/c)\)\  = \ \[Infinity]\)]],
  ".  With these extensions we conclude that the transformation  ",
  Cell[BoxData[
      \(w = S \((z)\)\)]],
  "  is a one-to-one mapping of the extended complex z-plane onto the \
extended complex ",
  StyleBox["w",
    FontFamily->"Courier New"],
  "-plane.  "
}], "Text"],

Cell[TextData[{
  "\tWe now show that a bilinear transformation carries the class of circles \
and lines onto itself.  If ",
  StyleBox["S(z)",
    FontFamily->"Courier New"],
  " is an arbitrary bilinear transformation given by Equation ",
  StyleBox["(10-13)",
    FontColor->RGBColor[0, 0, 1]],
  " and  ",
  Cell[BoxData[
      \(c = 0\)]],
  ",  then ",
  StyleBox["S(z)",
    FontFamily->"Courier New"],
  "  reduces to a linear transformation, which carries lines onto lines and \
circles onto circles.  If  ",
  Cell[BoxData[
      \(c \[NotEqual] 0\)]],
  ",  then we can write ",
  StyleBox["S(z)",
    FontFamily->"Courier New"],
  " in the form  \n\n",
  StyleBox["(10-15)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[{
      \(\(\(S \((z)\)\ \  = \ \(a\ z\  + \ b\)\/\(c\ z\  + \ d\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(c\ \((a\ z\  + \ 
                  b)\)\)\/\(c\ \((c\ z + d)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(a\ c\ z\  + \ 
              b\ c\)\/\(c\ \((c\ z + d)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(a\ c\ z\ \  + \ 
              a\ d\  - \ a\ d\  + \ 
              b\ c\)\/\(c\ \((c\ z + d)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(a\ \((c\ z + d)\)\  - \ 
              a\ d\  + \ 
              b\ c\)\/\(c\ \((c\ z + d)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(a\/c\  + \ \(\(b\ c\  - \ 
                  a\ d\)\/c\) 1\/\(c\ z\  + \ d\)\)\)\)}]],
  "   "
}], "Text"],

Cell[TextData[{
  "\tThe condition  ",
  Cell[BoxData[
      \(a\ d\  \[NotEqual] \ b\ c\)]],
  "  precludes the possibility that ",
  StyleBox["S(z)",
    FontFamily->"Courier New"],
  " reduces to a constant.  Equation ",
  StyleBox["(10-15)",
    FontColor->RGBColor[0, 0, 1]],
  " indicates that ",
  StyleBox["S(z)",
    FontFamily->"Courier New"],
  " can be considered as a composition of functions.  \nIt is a linear \
mapping  ",
  Cell[BoxData[
      \(\[Xi]\  = \ c\ z\  + \ d\)]],
  ",  followed by the reciprocal transformation  ",
  Cell[BoxData[
      \(Z\  = \ 1\/\[Xi]\)]],
  ",  followed by  ",
  Cell[BoxData[
      \(w\  = \ a\/c\  + \ \(\(b\ c\  - \ a\ d\)\/c\) Z\)]],
  ".  In Chapter 2 we showed that each function in this composition maps the \
class of circles and lines onto itself; it follows that the bilinear \
transformation ",
  StyleBox["S(z)",
    FontFamily->"Courier New"],
  " has this property.  A half-plane can be considered to be a family of \
parallel lines and a disk as a family of circles.  Therefore we conclude that \
a bilinear transformation maps the class of half-planes and disks onto \
itself.  Example 10.3 illustrates this idea."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 10.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(\[ImaginaryI]\ \((1\  - \ z)\)\)\/\(1\  + \ z\)\)\
\)],
    AspectRatioFixed->True],
  "  maps the unit disk  ",
  Cell[BoxData[
      \(D : \(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  "  one-to-one and onto the upper half-plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009D0000[b000`400?l0
0000o`00003oo`3ooooo0?oooeH0oooo003o0?ooool0ooooEP3oool00?l0
ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0ooooEP3o
ool009H0oooo00<000000?ooo`3oool0o`3ooonl0?ooo`00UP3oool00`00
0000oooo0?ooo`1l0?ooo`800000:`3oool4000002X0oooo1@00001C0?oo
o`D00000:@3oool4000002/0oooo0P00000]0?ooo`00UP3oool20?l007`0
oooo00@000000?ooo`3oool00000:P3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0[0?ooo`040000003oool0oooo000002`0oooo002E0?oo
o`@0o`00O@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0:`3oool00940
oooo0`000?l60?l000D0003oK`3oool4000000D0oooo00<000000?ooo`3o
ool08P3oool4000000@0oooo00<000000?ooo`3oool08`3oool4000000@0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0:P3oool008X0oooo
1`000?l30?ooo`H0o`001@3oool50000og00oooo00@000000?ooo`3oool0
0000:P3oool010000000oooo0?ooo`00000/0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool0:@3oool010000000oooo0?ooo`00000Z
0?ooo`040000003oool0oooo000002`0oooo00250?ooo`D0003o2`3oool4
0?l000/0oooo0`000?m^0?ooo`800000;03oool2000002`0oooo0P00001F
0?ooo`800000;03oool2000002`0oooo0P00000]0?ooo`00P@3oool40000
oa40oooo0P3o000?0?ooo`@0003oo`3ooonZ0?ooo`00O@3oool40000o`80
oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo00@0003oo`3ooonV0?ooo`00N`3oool20000o`L0oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00@0oooo0`000?oo0?oooj<0oooo001i0?ooo`80003o2@3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00l0oooo00<0
003o0?ooo`3oool01`3oool30000ool0ooooX03oool007L0oooo0P000?l<
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0:0?ooo`80003o]`3oool20?l002`0oooo0P00o`0/
0?ooo`80003oI@3oool4000001l0oooo001e0?ooo`80003o3P3oool00`00
0?l0oooo0?ooo`0:0?ooo`/0o`002`3oool00`000?l0oooo0?ooo`0<0?oo
o`80003o]03oool40?l002X0oooo1000o`0Z0?ooo`@0003oH`3oool01000
0000oooo0?ooo`00000P0?ooo`00L`3oool20000oa00oooo00<0003o0?oo
o`3oool00`3oool70?l000@0oooo00<0o`000?ooo`3oool0103oool80?l0
00<0oooo00<0003o0?ooo`3oool03P3oool20000oeP0oooo>P000?l00`3o
0000003o0000o`0L0000o`H0o`0040000?l00`3o0000003o0000o`0;0000
o`80o`0020000?l6003o00T0003o00<0o`000000o`000?l02`000?l00`3o
0000003o0000o`0b0000o`030?l000000?l0003o03P0003o2@3oool01000
0000oooo0?ooo`00000P0?ooo`00LP3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3o0000o`000080o`002`3oool00`3o0000oooo0?ooo`0<0?oo
o`80o`0000<0003o0?ooo`3oool04@3oool00`3o0000003o0?ooo`1E0?oo
o`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool0403oool00`00
0000oooo0?ooo`090?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool0203oool60?l000L0oooo0P000?l70?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00H00?l00`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo0P000?l60?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool60000o`X0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo
0100oooo00<0003o0?ooo`3oool0603oool00`000000oooo0?ooo`060?oo
o`80000000<0oooo000000000000803oool00700oooo0P000?l00`3o0000
oooo0?ooo`0?0?ooo`80o`0000<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0>0?ooo`030000o`3o0000o`000100oooo00<0o`000?ooo`3o
ool00P000?mD0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3o
ool0403oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool02@3oool40?l000T0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?ooo`3oool4003o
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`@0003o2`3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0H0?ooo`030000003oool0oooo02/0oooo001^0?ooo`80
003o0`3oool00`3o0000oooo0?ooo`0:0?ooo`@0o`000P3oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o
ool00`3o000<0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0K03oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool02P3oool20?l000X0oooo00<0003o0?ooo`3o
ool00P3oool;0?l000030000o`3o0000o`0000X0o`0000<0003o0?l0003o
00000P3o0002003o00D0o`0000<0003o0?l0003o00002@3o00000`000?l0
o`000?l000020?l000<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`070?ooo`80003o303oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool0AP3oool006d0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`070?ooo`80o`00
1`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool0103oool20?l000X0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`1[0?ooo`030000o`3oool0oooo01d0oooo
00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00@0oooo103o00000`000?l0o`000?l000020?l000<0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`/0o`0000<0003o0?l0003o0000
103o00040?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo04H0oooo
001/0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool30?l000T0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00H0oooo0P3o00070?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0JP3oool00`000?l0oooo0?oo
o`0M0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool02@3o
ool90?l000@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`T0o`002@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo01d0oooo00<0003o0?ooo`3oool0AP3oool006X0oooo0P000?l9
0?ooo`040?l0003oool0oooo0?ooo`80o`00303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0203o
ool20?l000D0oooo00<0o`000?ooo`3oool01`3oool20000of/0oooo00<0
003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0080oooo1`3o00020?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0003o00@0003o00<0o`000000o`000?l02@000?l00`3o0000003o0000
o`090000o`030?l000000?l0003o0080003o00<0oooo0000o`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool00P3oool70?l00080oooo00<0003o0?ooo`3oool0403o
ool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo04H0oooo001Y
0?ooo`030000o`3oool0oooo00T0oooo00@0o`000?ooo`3o0000o`003P3o
ool00`000?l0oooo0?ooo`080?ooo`@0003o00<0o`000000o`000?l00`00
0?l90?ooo`030000o`3oool0oooo00/0oooo0P3o00020?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool0J03oool00`000?l0oooo0?oo
o`0L0?ooo`030?l0003oool0oooo00l0oooo00<0o`000000o`3o00000`3o
00090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0000o`060000o`D0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`D0003o0`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool02@3oool20?l000040000o`3o0000o`000?l000l0oooo
00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`160?ooo`00J03o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00h0oooo00@0
003o0?ooo`3oool0oooo1`000?l40?ooo`030?l0003oool0oooo00<0oooo
20000?l00`3oool0003o0?ooo`0>0?ooo`<0o`003@3oool00`000?l0oooo
0?ooo`1W0?ooo`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool0
2P3oool50?l00080oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo0080oooo10000?l00`3o0000003o
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`040000
o`3oool0oooo0?ooo`<0003o00<0o`000000o`000?l00P000?l40?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02`3oool010000?l0
oooo0?ooo`3oool50?l000X0oooo00<0o`000?ooo`3oool0703oool00`00
0?l0oooo0?ooo`170?ooo`00IP3oool20000o``0oooo0`3o000@0?ooo`@0
003o2`3oool00`3o0000oooo0?ooo`0;0?ooo`<0003o3`3oool30?l000d0
oooo00<0003o0?ooo`3oool0IP3oool00`000?l0oooo0?ooo`0L0?ooo`03
0?l0003oool0oooo00H0oooo103o00070?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool01@3oool70000o`@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
o`0000<0003o0?l0003o0000203o00000`000?l0o`000?l000020?l00003
0?ooo`3o0000oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`020?ooo`L0003o1`3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00L0oooo103o00060?ooo`030?l0003oool0oooo01`0
oooo00<0003o0?ooo`3oool0A`3oool006D0oooo00<0003o0?ooo`3oool0
2P3oool20?l000<0oooo00<0o`000?ooo`3oool02`3oool20000o`030?oo
o`000?l0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`030000o`/0oooo00@0o`000?ooo`3oool0oooo0P3o000<0?ooo`03
0000o`3oool0oooo06D0oooo00<0003o0?ooo`3oool0703oool0103o0000
oooo0?ooo`3oool50?l000/0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`050000o`<0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3o0000o`0000L0o`000`3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool60?l00080oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0003o00<0oooo0?l0
003oool0303oool00`000?l0oooo0?ooo`0;0?ooo`D0o`0000<0oooo0?l0
003oool07@3oool00`000?l0oooo0?ooo`170?ooo`00I03oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool01`3oool30000o`<0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00<0oooo0P000?l90?ooo`03
0?l0003oool0oooo00<0oooo0P3o000;0?ooo`030000o`3oool0oooo06@0
oooo00<0003o0?ooo`3oool06`3oool50?l00100oooo00<0003o0?ooo`3o
ool02P3oool010000?l0o`000000o`000?l80?ooo`030000o`3oool0oooo
00D0oooo00@0o`000?ooo`3oool0oooo0`3o00000`3oool0003o0?ooo`04
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00P3oool20?l000040000o`3o0000o`000?l000<0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`040000o`3o
0000003o0000o`/0oooo00<0003o0?ooo`3oool0403oool50?l001/0oooo
00<0003o0?ooo`3oool0A`3oool006<0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo0`00
0?l60?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`050?ooo`80003o1P3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00T0oooo0P000?mT0?ooo`030000o`3o
ool0oooo01L0oooo103o00020?ooo`030?l0003oool0oooo0100oooo00<0
003o0?ooo`3oool01`3oool30000o`80oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`050?ooo`@0o`00103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`D0o`001P3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00<0003o1`3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0080oooo103o
000G0?ooo`030000o`3oool0oooo04L0oooo001R0?ooo`030000o`3oool0
003o00X0oooo00<0o`000?ooo`3oool01`3oool0103o0000oooo0?ooo`3o
ool20000o`X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00L0oooo0P000?l40?ooo`030?l0003o
ool0oooo00L0oooo00<0o`000?ooo`3oool0203oool20000ofD0oooo00<0
003o0?ooo`3oool04P3oool40?l000H0oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`020?ooo`@0003o1@3oool00`3o0000oooo0?oo
o`070?ooo`040000o`3oool0oooo0?ooo`@0o`0000<0oooo0?l0003oool0
1@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00T0003o
00<0o`000000o`000?l01`000?l00`3oool0o`000?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o00000`3oool0003o
0?ooo`0:0?ooo`030?l0003oool0oooo00<0oooo10000?l30?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool01P3oool50?l00180oooo
00<0003o0?ooo`3oool0A`3oool00680oooo00@0003o0?ooo`3oool0003o
1`3oool20?l000/0oooo00<0o`000000o`000?l0303oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
2@3oool20000o`030?ooo`3o0000oooo00X0oooo0P3o00070?ooo`040000
o`3oool0oooo0000of@0oooo00<0003o0?ooo`3oool03P3oool40?l000X0
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0000o`020000o`T0
oooo00<0o`000?ooo`3oool01`3oool0103o0000003o0?l0003o00050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`000?l00`3o
0000003o0000o`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o0000003o
00<0003o00<0oooo0000o`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`040?l000000?l0o`000?l000P0oooo00<0o`000?ooo`3oool0203oool4
0000oa<0oooo00<0o`000?ooo`3oool02`3oool40?l000h0oooo00<0003o
0?ooo`3oool0A`3oool00640oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00X0oooo00<0003o0?l0
003oool03@3oool00`000?l0oooo0?ooo`070?ooo`L0o`002P3oool00`00
0?l0oooo0?ooo`0;0?ooo`030000o`3o0000oooo00`0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
0640oooo00<0003o0?ooo`3oool02P3oool40?l000h0oooo00<0o`000?oo
o`3oool0403oool30000o``0oooo00<0o`000?ooo`3oool0103oool30?l0
00030?ooo`000?l0oooo00H0oooo00<0o`000?ooo`3oool0103oool30000
o`<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`<0003o1@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo0080o`001P3oool00`3o0000oooo0?ooo`0:0?oo
o`@0003o403oool00`3o0000oooo0?ooo`0@0?ooo`@0o`002@3oool00`00
0?l0oooo0?ooo`180?ooo`00H03oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool02@3oool20000o`80
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`060?l000<0
oooo00@0o`000?ooo`3oool0oooo203o00000`3oool0003o0?ooo`0=0?oo
o`040?l0003oool0003o0000o``0oooo00D0o`000?ooo`3oool0oooo0000
o`060?ooo`030000o`3oool0oooo0600oooo00<0003o0?ooo`3oool01P3o
ool40?l001<0oooo00<0o`000?ooo`3oool03@3oool20000o`80oooo00<0
003o0?ooo`3oool02P3oool0103o0000oooo0?ooo`3oool30?l000@0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030000o`030?oo
o`000?l0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0003o00<0003o
00<0oooo0?l0003oool01P3oool00`000?l0oooo0?ooo`020?ooo`<0o`00
0P3oool00`3o0000oooo0?ooo`0;0?ooo`040000o`3oool0oooo0?ooo`80
003o3P3oool00`3o0000oooo0?ooo`0D0?ooo`@0o`001@3oool00`000?l0
oooo0?ooo`180?ooo`00G`3oool00`000?l0oooo0?ooo`050?ooo`040000
o`3oool0oooo0?l000/0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0:0?ooo`80o`0000<0003o0?l0003o00002@3oool00`3o0000
oooo0?ooo`090?ooo`030?l000000?l0o`0000d0oooo00D0o`000?ooo`3o
ool0oooo0000o`0<0?ooo`030?l0003oool0003o00P0oooo00<0003o0?oo
o`3oool0G`3oool00`000?l0oooo0?ooo`020?ooo`@0o`005`3oool00`3o
0000oooo0?ooo`0:0?ooo`<0003o103oool00`000?l0oooo0?ooo`0;0?oo
o`<0o`001`3oool00`000?l0oooo0?ooo`050?ooo`040000o`3o0000003o
0000o`@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool0103oool00`3o0000003o0000o`050?ooo`030000o`3oool0
oooo00H0oooo0`3o000=0?ooo`030000o`3oool0oooo00<0oooo0`000?l;
0?ooo`030?l0003oool0oooo01P0oooo103o00000`3oool0003o0?ooo`19
0?ooo`00GP3oool00`000?l0oooo0?ooo`070?ooo`030000o`3o0000oooo
00X0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`070?oo
o`80o`000P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3o00000P3o00090?ooo`030?l0003oool0oooo
00<0oooo0P000?l;0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool0G`3oool00`000?l0o`000?l000020?l001/0oooo00<0o`000?oo
o`3oool0203oool20000o`L0oooo00<0003o0?ooo`3oool02@3oool30?l0
00X0oooo00<0003o0?ooo`3oool010000?l00`3oool0o`000?ooo`050?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o00000P3o00000`00
0?l0o`000?l000080?l000060000o`3o0000o`000?l0003oool0o`001@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080003o0`3o
ool00`000?l0oooo0?ooo`080?ooo`80o`002`3oool00`000?l0oooo0?oo
o`070?ooo`80003o203oool00`3o0000oooo0?ooo`0M0?ooo`040000o`3o
0000o`000?l004P0oooo001M0?ooo`030000o`3oool0oooo00P0oooo00<0
o`000000o`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00@0oooo0P3o00050?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`030?ooo`80o`001P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?l0003oool02@3oool00`000?l0oooo0?ooo`1L0?ooo`<0o`0000<0
003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`050?ooo`80003o2P3o
ool00`000?l0oooo0?ooo`060?ooo`80o`000`3oool00`3o0000oooo0?oo
o`070?ooo`<0003o1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0o`0000@0o`00103oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00@0003o0?ooo`3oool0oooo1P3o00000`3oool0003o
0?ooo`040?ooo`030?l0003oool0oooo00<0oooo0`000?l:0?ooo`030?l0
003oool0oooo0080o`002@3oool00`000?l0oooo0?ooo`090?ooo`<0003o
1@3oool00`3o0000oooo0?ooo`0M0?ooo`040000o`3oool0oooo0?ooo`<0
o`00A@3oool005`0oooo00<0003o0?ooo`3oool0203oool0103o0000oooo
0?ooo`000?l70?ooo`80003o2@3oool00`3o0000oooo0?ooo`020?ooo`80
o`001`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool01@3oool20?l000@0oooo00<0o`000?ooo`3o
ool01`3oool20000o`H0oooo00@0003o0?ooo`3oool0o`002P3oool00`00
0?l0oooo0?ooo`1G0?ooo`@0o`000`3oool00`000?l0oooo0?ooo`0M0?oo
o`030?l0003oool0oooo0080oooo0`000?l<0?ooo`030000o`3oool0oooo
00@0oooo0P3o00050?ooo`030?l0003oool0oooo00H0oooo0`000?l70?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?l0003oool00`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo0000o`050?ooo`030?l0003oool0oooo0080oooo00<0003o
0?l0003o0000103oool00`3o0000oooo0?ooo`050?ooo`80003o2@3oool0
0`3o0000oooo0?ooo`020?ooo`80o`001`3oool00`000?l0oooo0?ooo`0<
0?ooo`<0003o0P3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0
oooo00@0oooo0`3o00120?ooo`00G03oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0:0?ooo`040?l0003oool0o`000?l000T0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00L0oooo0P3o00000`3oool0o`000?ooo`0;0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo05<0oooo0`3o00070?ooo`030000o`3oool0
oooo01d0oooo00<0o`000?ooo`3oool00P000?l@0?ooo`040000o`3oool0
oooo0?ooo`80o`00203oool00`3o0000oooo0?ooo`040?ooo`040000o`3o
ool0oooo0000o`P0oooo00<0o`000?ooo`3oool00`3o00000`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?l000030?ooo`3o0000oooo00L0
oooo00@0003o0?ooo`000?l0003o1P3oool00`3o0000oooo0?ooo`050?oo
o`80o`00103oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3o0000oooo
01l0oooo00<0003o0?ooo`3oool01`3oool20?l00400oooo001K0?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool20000o`80
oooo00<0003o0?ooo`3oool02`3oool20?l000/0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00X0
oooo0P3o000=0?ooo`040000o`3oool0oooo0000o`H0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`1@0?ooo`<0o`002`3oool00`00
0?l0oooo0?ooo`0M0?ooo`030?l000000?l0oooo0180oooo00<0003o0?l0
003o00002`3oool0103o0000oooo0?ooo`3oool20000o`@0oooo00<0003o
0?ooo`3oool01@3oool30?l000<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool00`3oool20?l000L0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00L0oooo0P3o
00000`3oool0003o0?ooo`0C0?ooo`030?l000000?l0003o01d0oooo00<0
003o0?ooo`3oool02P3oool30?l003d0oooo001J0?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool20000o``0oooo0P3o0000
0`3oool0o`000?ooo`0:0?ooo`030000o`3oool0oooo00H0oooo0P000?l0
0`3o0000003o0000o`080?ooo`030000o`3oool0oooo00X0oooo00@0o`00
0?ooo`3o0000o`00303oool20000o`P0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`1;0?ooo`@0o`003P3oool00`000?l0oooo0?oo
o`0K0?ooo`80003o00<0o`000?ooo`3oool04@3oool00`3o0000003o0?oo
o`0<0?ooo`040?l0003oool0003o0000o`H0oooo00<0003o0?ooo`3oool0
103oool30?l000D0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`070000o`030?l000000?l0003o00D0003o00<0oooo0?l0003oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`040?l0003oool0o`000?l000D0
oooo00<0003o0?ooo`3oool00`3oool20000o`80oooo00<0o`000?ooo`3o
ool02P3oool00`3o0000003o0?ooo`0B0?ooo`040?l0003oool0oooo0?oo
o`80003o6`3oool00`000?l0oooo0?ooo`0=0?ooo`<0o`00>P3oool005T0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`80
003o2`3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool01P000?l20?ooo`030?l0003oool0oooo00L0
003o00<0oooo0000o`3oool02P3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo04L0oooo0`3o000B0?ooo`03
0000o`3oool0oooo01T0oooo0P000?l30?ooo`030?l0003oool0oooo00l0
oooo00@0o`000?ooo`3oool0003o3@3oool00`3o0000oooo0?ooo`070?oo
o`040000o`3oool0oooo0?ooo`80o`000P3oool00`3o0000oooo0?ooo`03
0?ooo`040000o`3oool0oooo0?ooo`80003o00D0o`000000o`3oool0oooo
0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`000?l0
o`000?ooo`030?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3o
ool0oooo0?l000030?ooo`030000o`3oool0oooo00H0oooo0P000?l00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0o`000180oooo00<0o`000?oo
o`3oool00`3oool20000oaP0oooo00<0003o0?ooo`3oool04@3oool30?l0
03L0oooo001H0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool01`3oool010000?l0oooo0?ooo`000?l90?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool0203oool30000o`P0oooo00<0o`000?oo
o`3oool01`3oool20000o`X0oooo00<0o`000?ooo`3oool0103oool20?l0
00P0oooo00<0003o0?ooo`000?l02@3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo04@0oooo0`3o000F0?ooo`030000o`3oool0oooo
01H0oooo0P000?l60?ooo`030?l0003oool0oooo00`0oooo0P3o00030?oo
o`030000o`3oool0oooo00T0oooo0P000?l00`3o0000oooo0?ooo`080?oo
o`030000o`3o0000o`0000@0oooo00<0o`000?ooo`3oool0103oool30000
o`80oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0
oooo0?ooo`000?l00`3oool01P3o0000oooo0000o`000?l0oooo0000o`D0
oooo00<0o`000?ooo`3oool00`3oool20?l000030?ooo`000?l0oooo00P0
oooo00<0o`000000o`3oool02`3oool00`000?l0oooo0?ooo`020?l000l0
oooo00<0o`000?ooo`3oool01P3oool20000oaH0oooo00<0003o0?ooo`3o
ool0503oool30?l003@0oooo001H0?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0003o00H0
oooo0P3o00070?ooo`030?l0003oool0oooo00@0oooo0`000?l00`3oool0
003o0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`00
0?l00`000?l60?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3o
ool0103oool01@000?l0oooo0?ooo`3oool0003o00T0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`110?ooo`80o`006@3oool00`00
0?l0oooo0?ooo`0D0?ooo`80003o203oool00`3o0000oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01`3oool01@00
0?l0oooo0?ooo`3oool0o`0000P0oooo00<0o`000000o`3oool01P3oool0
103o0000oooo0?ooo`3oool30000o`@0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool0103o0000
oooo0?ooo`3oool30000o`@0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo0080003o2@3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00`0oooo00<0o`000?oo
o`3oool0203oool20000oa<0oooo00<0003o0?ooo`3oool0603oool20?l0
0380oooo001G0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`020?ooo`80
003o103oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool00`3oool30000o`80oooo00<0o`000?ooo`3o
ool0203oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3o0000oooo03h0oooo0`3o000L0?ooo`030000o`3oool0oooo0180
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`80
o`001`3oool00`000?l0oooo0?ooo`050?ooo`80003o1@3oool00`3o0000
oooo0?ooo`040?ooo`040?l0003oool0oooo0000o`H0oooo00@0o`000?oo
o`3oool0003o0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`030000o`3o
ool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`80003o
00<0oooo0?l0003oool01P3oool010000?l0oooo0?l0003o00060?ooo`03
0?l0003oool0oooo00<0oooo0P000?l70?ooo`030000o`3oool0oooo00@0
oooo0P3o000;0?ooo`030?l0003oool0oooo00/0oooo0P000?lA0?ooo`03
0000o`3oool0oooo01X0oooo0`3o000_0?ooo`00E`3oool00`000?l0o`00
0?l000070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1@3oool010000?l0oooo0?ooo`3o000;0?ooo`040?l0003oool0003o0000
o`L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00H0oooo0P000?l00`3o0000oooo0?ooo`090?oo
o`040?l0003oool0oooo0000o`L0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`050?ooo`030?l000000?l0oooo03`0oooo0P3o000P
0?ooo`030000o`3oool0oooo00l0oooo0P000?l<0?ooo`030?l0003oool0
oooo00H0oooo0P3o000:0?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o0000003o0?ooo`03
0?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
o`030?ooo`040?l0003oool0oooo0000o`<0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o0000oooo00D0oooo
00<0003o0?ooo`3oool00P3oool20?l000<0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00d0oooo00<0003o0?ooo`3oool07P3oool20?l002d0oooo
001F0?ooo`040000o`3oool0oooo0?ooo`80o`00103oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o0000
303oool00`3o0000003o0?ooo`080?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0
00000?l0003o00/0oooo00<0o`000?ooo`000?l0203oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo0080oooo0P3o00000`3oool0003o
0?ooo`1N0?ooo`030000o`3oool0oooo00d0oooo0P000?l?0?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`020000o`T0oooo00<0o`000?ooo`3oool00P3o00060?ooo`030000
o`3oool0oooo0080oooo0P000?l00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo00D0o`000?ooo`3oool0o`000000o`060?l00005
0000o`3o0000oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0003o00@0oooo00<0003o0?ooo`3oool01@3oool0103o
0000oooo0?ooo`3o00090?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0203oool20?l000L0oooo00<0o`000?ooo`3oool03`3oool2
0000o`d0oooo00<0003o0?ooo`3oool0C@3oool005H0oooo00<0003o0?oo
o`3oool00`3oool20?l000030?ooo`3o0000oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`000?l0oooo0?ooo`090?ooo`80003o00<0oooo0?l0
003oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01`3oool0103o0000oooo0?ooo`000?l;
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`020?l000@0oooo00<0003o0?ooo`3oool0G@3oool0
0`000?l0oooo0?ooo`0:0?ooo`80003o4P3oool0103o0000oooo0?ooo`3o
ool20?l000l0oooo0P000?l<0?ooo`80o`002@3oool010000?l0oooo0000
o`000?l30?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0
oooo0`3o00000`3oool0003o0?ooo`020?ooo`050?l0003oool0oooo0000
o`3oool00`3o00030?ooo`030000o`3oool0oooo0080oooo00@0o`000?oo
o`3oool0oooo0P000?l00`3oool0003o0?ooo`080?ooo`80o`002`3oool4
0000o`d0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0CP3oool0
05D0oooo00<0003o0?ooo`3oool01P3oool20?l000T0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0000o`090?ooo`050000o`3oool0oooo
0?ooo`3o00002P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00H0oooo0P000?l00`3oool0o`000?ooo`08
0?ooo`030000o`3oool0oooo00L0oooo0P3o00060?ooo`030000o`3oool0
oooo05h0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0B
0?ooo`040?l0003oool0oooo0?l00140oooo0P000?l<0?ooo`80o`002P3o
ool00`000?l0oooo0?ooo`040?ooo`060?l0003oool0oooo0?ooo`000?l0
oooo103o00020?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool01P00
0?l0oooo0?ooo`3o0000oooo0?l00080oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`030?ooo`80003o2@3oool20?l000`0oooo0P00
0?l?0?ooo`80o`000`3oool00`3o0000oooo0?ooo`0C0?ooo`80003o2@3o
ool00`000?l0oooo0?ooo`1>0?ooo`00E@3oool00`000?l0oooo0?ooo`06
0?ooo`<0o`001`3oool00`000?l0oooo0?ooo`070?ooo`050?l0003oool0
oooo0?ooo`000?l01`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?l0003o00003@3o00000`3oool0003o0?oo
o`070?ooo`030?l0003oool0oooo00@0oooo0P000?l50?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`050?ooo`80o`00203oool00`000?l0oooo0?ooo`1M0?ooo`030000o`3o
ool0oooo00H0oooo0P000?lF0?ooo`80o`004@3oool010000?l0oooo0?oo
o`000?l:0?ooo`040?l0003oool0oooo0?l000P0oooo00<0003o0?ooo`00
0?l01@3oool01P3o0000oooo0?ooo`3oool0o`000000o`<0oooo00D0o`00
0?ooo`3oool0oooo0000o`020?ooo`030?l0003oool0003o00<0oooo00D0
o`000?ooo`3oool0o`000000o`040?ooo`030?l0003oool0oooo00@0oooo
0P000?l80?ooo`040?l0003oool0oooo0?l000X0oooo00@0003o0?ooo`3o
ool0003o403oool00`3o0000oooo0?l0000H0?ooo`80003o1P3oool00`00
0?l0oooo0?ooo`1?0?ooo`00E@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo0080o`00103oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool20000o`L0
oooo00<0o`000?ooo`3oool00`3oool30?l000030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool010000?l0o`000?l0003o00060?oo
o`030?l0003oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo0000o`06
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool2
0?l00080oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1N
0?ooo`030000o`3oool0oooo00<0oooo0P000?lH0?ooo`80o`00403oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0
oooo0000o`H0oooo00D0o`000?ooo`3o0000oooo0000o`040?ooo`040?l0
003oool0oooo0000o`80oooo00<0o`000?ooo`000?l00P3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3o0000o`000080oooo00<0o`000?ooo`3o
ool00`3oool010000?l0oooo0?ooo`000?l60?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool0
003o0100oooo0P3o000J0?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool0C`3oool005@0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`030?ooo`040?l0003oool0oooo0000o`T0oooo00<0o`00
0?ooo`3oool01@3oool010000?l0oooo0?ooo`000?l90?ooo`040?l0003o
ool0oooo0?ooo`80o`000`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00@0003o0?ooo`3oool0oooo0P3o00030?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`000?l0203oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo0080o`00103oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo05h0oooo00<0003o0?ooo`3o
ool00P000?lI0?ooo`040?l0003oool0oooo0?l000h0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00<0oooo0P3o00030?ooo`050000o`3oool0oooo
0?ooo`3o00000P3oool01P000?l0oooo0?ooo`3o0000oooo0000o`80oooo
00D0o`000?ooo`3oool0oooo0000o`030?ooo`80o`001@3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0303oool0103o0000oooo0?ooo`3o000J0?oo
o`80003o0P3oool00`000?l0oooo0?ooo`1@0?ooo`00E03oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`00
0?l02@3oool00`3o0000oooo0?ooo`060?ooo`80003o2`3oool00`3o0000
oooo0?l000050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`030?ooo`040?l0003oool0oooo0?l0
00/0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3o0000oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`1N0?ooo`<0003o6@3oool20?l000@0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool01@3oool20?l00080oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80o`00103oool01000
0?l0oooo0?ooo`3o00020?ooo`080000o`3oool0oooo0?l0003oool0003o
0?ooo`3o00030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
00000`3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0o`000?l0
00L0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`0I0?ooo`030000o`3oool0003o0580oooo001C0?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool20?l000P0
oooo00<0o`000?ooo`3oool01`3oool20000o`/0oooo0P3o00070?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`80o`002`3oool00`000?l0oooo0000o`090?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo05d0oooo0P000?lI0?ooo`03
0?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`050000o`3oool0oooo0?ooo`3o00002P3oool00`3o
0000003o0?ooo`060?ooo`040000o`3oool0o`000?l00080oooo0P3o0003
0?ooo`0=0000o`3oool0oooo0?l0003oool0003o0?ooo`000?l0o`000?oo
o`000?l0oooo0?l000020?ooo`030000o`3oool0oooo0080oooo00L0o`00
0?ooo`3oool0oooo0?l0003oool0003o00L0oooo00<0003o0?l0003oool0
2@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo01T0oooo0P000?mB0?ooo`00D`3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3o
00060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool00P00
0?l70?ooo`80o`0000<0oooo0?l0003oool01P3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool0103o0000oooo0?l0003o00080?ooo`050000o`3oool0oooo0?ooo`00
0?l02@3oool00`3o0000oooo0?ooo`030?ooo`80o`0000<0oooo0000o`3o
ool01`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo05/0
oooo0P000?l00`3oool0003o0?ooo`0G0?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0:0?ooo`03
0000o`3oool0o`0000/0oooo00<0003o0?l0003o00001`3oool20000o`D0
oooo00@0o`000?ooo`3oool0003o0P3oool00`3o0000003o0000o`020000
o`050?l000000?l0003o0000o`3o00000P3oool01@000?l0oooo0?ooo`3o
ool0o`0000D0oooo00<0003o0?ooo`3oool01@3oool20?l000030000o`3o
ool0oooo00T0oooo00@0o`000?ooo`3oool0003o2`3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
5`3oool00`000?l0oooo0?ooo`020000oe00oooo001B0?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`020?ooo`80o`000`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00D0
o`000?ooo`3oool0oooo0?l000060?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`020?l000<0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo05T0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0D0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`0<0?ooo`80003o2P3oool01@000?l0oooo
0?ooo`3oool0o`0000H0oooo00<0o`000?ooo`000?l01@3oool00`3o0000
oooo0?ooo`030000o`090?l0003oool0003o0?ooo`3o0000003o0?ooo`3o
0000oooo0080003o0P3oool20?l000D0oooo00<0003o0?l0003oool01@3o
ool01@3o0000oooo0?ooo`3oool0003o00/0oooo0P000?l<0?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0203oool20?l001H0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1=0?ooo`00DP3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?l000080?ooo`030000o`3o
ool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool20?l000<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`070?ooo`<0o`001P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0E`3oool20000o`D0oooo
00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool0103o0000oooo
0?ooo`000?l80?ooo`030000o`3oool0oooo00<0oooo0P3o00030?ooo`05
0?l0003oool0oooo0?ooo`000?l01@3oool03P3o0000oooo0000o`000?l0
oooo0?l0003oool0003o0?ooo`3o0000003o0?ooo`3o0000oooo0`000?l0
0`3o0000oooo0?ooo`030?ooo`80003o0P3oool0103o0000oooo0?ooo`3o
ool20?l000@0oooo00<0003o0?ooo`3oool01`3oool20000o`030?ooo`3o
0000oooo00`0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`0:0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`1<0?ooo`00D@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool2
0?l000L0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?l00007
0?ooo`030?l0003oool0oooo00@0oooo1P000?l00`3o0000003o0000o`05
0000o`H0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0000o`08
0?ooo`030000o`3oool0oooo00H0oooo0P3o00080?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`1E
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool0303oool0103o0000oooo0?ooo`3oool20000o`H0oooo00<0
003o0?ooo`3oool01@3oool0103o0000oooo0?ooo`3o00040?ooo`030000
o`3oool0oooo00<0oooo00d0o`000?ooo`3oool0003o0?l0003oool0003o
0?ooo`3o0000003o0?l0003oool0003o0080oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo0?l000L0
oooo00<0003o0?ooo`3oool0103oool20000o`@0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00`0
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`060?ooo`80
003oC03oool00540oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00@0o`000?ooo`3o0000
o`001@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00H0
oooo00@0o`000?ooo`3oool0oooo10000?l50?ooo`030?l0003oool0oooo
00@0oooo0`000?l30?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`80o`0000<0oooo0?l0
003oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0E03oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool03P3oool0103o
0000oooo0?ooo`000?l>0?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`<0o`001@3oool2
0000o`80oooo00<0003o0?ooo`3o00000P3oool020000?l0o`000?ooo`00
0?l0o`000?ooo`3o0000003o0P3oool00`3o0000oooo0000o`020?ooo`80
003o1P3oool20?l000P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00`0oooo00@0003o0?ooo`3o
ool0o`00403oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00T0oooo00<0003o0?ooo`3oool0B@3oool00540oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo00@0o`000?ooo`3oool0oooo0P3o00020?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`000?l0203oool00`3o0000003o0000o`040?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool01000
0?l0oooo0?ooo`3oool20000o`030?ooo`3o0000oooo00L0oooo00<0003o
0?ooo`3o00002@3oool010000?l0oooo0?ooo`3oool20?l000@0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0DP3oool20000o``0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0@0?ooo`80o`003P3o
ool00`3o0000oooo0?ooo`060?ooo`80003o0P3oool00`000?l0oooo0?oo
o`080?ooo`<0o`001P3oool20000o`<0oooo00H0o`000?ooo`000?l0o`00
0?ooo`000?l20?l000040?ooo`000?l0oooo0?l000<0oooo0P000?l60?oo
o`<0o`002P3oool00`000?l0oooo0?ooo`020000o`P0oooo00<0o`000?oo
o`3oool0303oool20?l00180oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo04P0oooo001A0?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0o`000000o`3o
ool02@3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0003o0?l0
003oool01@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000003o0?ooo`060?oo
o`050000o`3oool0oooo0?ooo`3o0000203oool010000?l0oooo0?l0003o
00060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0540oooo00<0
003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3o0000303oool00`3o0000oooo0?oo
o`090?ooo`<0003o2P3oool00`3o0000oooo0?ooo`040?l000<0oooo0`00
0?l20?ooo`050?l0003oool0003o0?l000000?l00P3o00000`000?l0oooo
0?l000020?ooo`<0003o103oool30?l00080oooo00<0o`000?ooo`3oool0
203oool30000o`X0oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo
0000o`0C0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`170?ooo`00D03oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`80o`00203oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`00
1@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l60?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool20?l000T0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0CP3oool20000oa40
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0080o`002P3oool00`3o0000oooo0?ooo`0:0?ooo`04
0000o`3oool0003o0000o`L0oooo00<0o`000?ooo`3oool01@3oool20?l0
00040?ooo`000?l0000000000080003o00<000000?l0003oool00P000?l0
1@3o0000003o0?ooo`3o0000oooo0080003o0P3oool20000o`<0o`001P3o
ool00`3o0000oooo0?ooo`050?ooo`@0003o303oool00`3o0000oooo0?oo
o`080?ooo`80o`000`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?oo
o`160?ooo`00D03oool20000o`L0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool00P3o00050?ooo`030?l0003oool0oooo00@0oooo00D0003o
0?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo00<0oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo00<0oooo
00D0o`000?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0000o`090?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo04d0oooo00<0003o0?ooo`3o
ool04P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool00`3oool20?l000L0oooo00<0o`000?ooo`3o
ool02`3oool010000?l0oooo0?ooo`3oool20000o`D0oooo00<0o`000?oo
o`3oool01`3oool60?l00080003o1@3o00000`000?l0o`000?l000060?l0
00T0oooo00<0o`000?ooo`3oool00`3oool20000o`<0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`050?ooo`80o`001@3oool00`00
0?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool04@3oool20000odH0oooo001@0?ooo`030000o`3oool0003o0080
003o0`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`05
0?l0003oool0oooo0?ooo`3o0000203oool00`000?l0oooo0000o`050?oo
o`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool0
10000?l0oooo0?ooo`000?l70?ooo`040?l0003oool0oooo0?ooo`80o`00
0`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool0103o0000oooo0?ooo`3oool40000odd0
oooo0P000?lF0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`060?ooo`80o`001@3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00@0oooo10000?l00`3oool0
o`000?ooo`080?ooo`050000o`3oool0oooo0?ooo`0000000P3oool00`00
0?l0o`000000o`030?l00080003o1P3oool00`000?l0oooo0?ooo`080?oo
o`030?l000000?l0003o0080003o1P3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00<0oooo0P3o00080?ooo`030000o`3oool0oooo
0180oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0D0?oo
o`030000o`3oool0oooo04<0oooo001@0?ooo`030000o`3oool0oooo0080
oooo1P000?l60?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`030?ooo`<0o`002P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool0103oool20000o`T0oooo0`3o00060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?oo
o`H0003o0`3oool00`000?l0oooo0?ooo`1:0?ooo`030000o`3oool0oooo
01L0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo00T0oooo0P3o00020?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool0203ooolB0000o`<0o`000P000?l30?l0
0180003o2P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
0080o`002P3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`120?oo
o`00D03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0
003o0P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool20?l000P0oooo00<0003o0?ooo`00
0?l01P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o0000o`0000D0
o`0000<0003o0?l0003oool00P3oool00`3o0000oooo0?ooo`040?ooo`80
003o00<0oooo0000o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`030000o`80oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`180?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00/0
oooo0`3o000<0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool0203oool01@000?l0oooo0?ooo`3oool000000080o`0000<0oooo0000
o`3oool00P3o00020000o`030?ooo`3o0000o`0000@0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00X0oooo0`3o000=0?ooo`030000o`3oool0oooo0180oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo
0440oooo001?0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool00`3oool30000o`L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo0080o`001@3oool01@000?l0
oooo0?ooo`3oool0003o00H0oooo103o00001@000?l0oooo0?ooo`3oool0
o`0000<0oooo00H0003o0?ooo`3o0000o`000?ooo`3o00050?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool20?l000030?oo
o`3o0000oooo00L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`<0003o1@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo04L0oooo00<0003o0?ooo`3oool06`3oool010000?l0oooo
0?ooo`3o000D0?ooo`030000o`3oool0oooo00d0oooo0`3o000;0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool20000o`<0
o`000P3oool020000?l0oooo0?l000000?l0o`000000o`3o0000003o0P3o
ool30?l00080003o2P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00T0oooo0`3o000?0?ooo`030000o`3oool0oooo0180oooo00@0
o`000?ooo`3oool0003o703oool00`000?l0oooo0?ooo`100?ooo`00C`3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo1P00
0?l20?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`020?ooo`80o`000`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo
0000o`030?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool20?l000@0
oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3oool20?l0
00<0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0003o00H0003o203oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo04H0oooo00<0003o0?ooo`3oool07@3oool00`00
0?l0o`000?ooo`0C0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool0103o00070?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool01`3oool30?l000<0oooo0P000?l0203oool0o`000?ooo`000?l0
o`000000o`3o0000oooo0P000?l30?ooo`<0o`002@3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00D0oooo103o00020?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool04`3oool00`3o0000003o
0?ooo`0M0?ooo`80003o@03oool004l0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo0`00
0?l70?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0000o`060?ooo`070000o`3oool0oooo0?ooo`3o0000
oooo0?l000030?ooo`040000o`3oool0oooo0?l00080oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?l000020?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?l0003o00001P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00@0oooo0`000?l70?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`150?oo
o`030000o`3oool0oooo01l0oooo00<0003o0?ooo`3oool04P3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00@0oooo0`3o00040?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool01@3oool20?l0
0080oooo00@0003o0?ooo`3oool0003o0P3oool0203o0000oooo0000o`3o
ool0o`000000o`3oool0o`000P3oool010000?l0oooo0?ooo`000?l20?oo
o`80o`001`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
0080oooo0`3o00060?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool04P3oool00`000?l0o`000?ooo`0O0?ooo`030000o`3oool0oooo
03d0oooo001>0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0003o0080
003o103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo0P3o00070?ooo`80003o00@0o`000?ooo`3oool0o`000`3oool01000
0?l0oooo0?ooo`3o00020?ooo`050000o`3oool0oooo0?ooo`3o00000`3o
ool00`3o0000003o0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool010000?l0oooo0?ooo`3oool30000o`030?oo
o`3o0000oooo00L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo04<0oooo00<0003o0?ooo`3oool0
7`3oool00`3o0000oooo0000o`0B0?ooo`030000o`3oool0oooo00l0oooo
00<0o`000?ooo`3oool01`3oool70?l000T0oooo203o00040?ooo`030000
o`3oool0003o00<0oooo00P0o`000?ooo`000?l0oooo0?l0003oool0003o
0?l000<0oooo00<0003o0?ooo`000?l0103oool80?l000T0oooo1`3o0009
0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0403oool0
10000?l0oooo0?ooo`3o000P0?ooo`030000o`3oool0oooo03`0oooo001>
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo10000?l8
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3o0005
0?ooo`030?l0003oool0003o00<0oooo00@0o`000?ooo`3oool0003o0P3o
ool0103o0000oooo0?ooo`000?l20?ooo`030?l0003oool0oooo0080oooo
00<0003o0?l0003o00001@3oool20?l000030?ooo`000?l0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool40000o`D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0O0?ooo`040?l0
003oool0oooo0?ooo`80003o403oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02P3o000<0?ooo`07
0000o`3oool0oooo0?ooo`3o0000oooo0000o`020?ooo`050?l0003oool0
003o0?ooo`3o00000`3oool00`000?l0oooo0?ooo`0:0?ooo`X0o`000`3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool03P3oool20000o`@0oooo00<0o`000?ooo`3oool07P3o
ool00`000?l0oooo0?ooo`0k0?ooo`00CP3oool00`000?l0000000000003
00000080oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo1P000?l30?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool00P3oool20?l00080oooo00D0o`00
0?ooo`3oool0oooo0000o`030?ooo`060?l0003oool0oooo0000o`3oool0
o`000P3oool010000?l0oooo0?ooo`3o00030?ooo`040000o`3oool0oooo
0?l000<0oooo0P3o00030?ooo`030000o`3oool0oooo00H0oooo00@0o`00
0?ooo`3oool0oooo1@000?l80?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`0300000000
0?l0000000800000@03oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`080?ooo`050000o`3oool0003o0?ooo`3o0000
0P3oool01P000?l0oooo0?ooo`3o0000oooo0000o`80oooo00D0o`000?oo
o`000?l0oooo0000o`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo00`0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0N
0?ooo`030000o`3oool0oooo03X0oooo001>0?ooo`040000o`3oool0oooo
000000@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool3
0000o`L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?l00004
0?ooo`040000o`3oool0oooo0?l00080oooo00P0003o0?ooo`3o0000003o
0?ooo`000?l0oooo0?l000<0oooo00<0003o0?ooo`3oool00P3oool30?l0
00H0oooo00<0003o0?ooo`3oool01@3oool0103o0000003o0000o`000?l5
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0000003oool0@03oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0
oooo00H0oooo0P000?l<0?ooo`030000o`3oool0oooo00l0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00H0oooo0P000?l30?ooo`050?l0003oool0oooo0?ooo`000?l00P3o
ool00`3o0000oooo0000o`030?ooo`040?l0003oool0oooo0?ooo`80003o
203oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0:0?ooo`80003o
203oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo03T0oooo
001>0?ooo`040000o`3oool0oooo000000@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool0103o0000003o0000o`000?l40?ooo`03
0000o`3oool0oooo00H0oooo0P3o00050?ooo`050000o`3oool0oooo0?l0
003oool00P000?l01P3o0000003o0000o`000?l0oooo0?l00080oooo00<0
003o0?ooo`3oool00P3oool20?l000P0oooo00<0003o0?ooo`3oool00`3o
ool30000o`P0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l000000?ooo`0o0?ooo`030000o`3oool0oooo0200oooo00<0
o`000?ooo`3oool0203oool20000o`T0oooo00<0003o0?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0103oool20000o`@0oooo00<0o`000?ooo`000?l00P00
0?l30?ooo`040?l0003oool0003o0?ooo`80003o00<0oooo0?l0003oool0
0`3oool30000o`D0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
1`3oool20000o`/0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo
0?ooo`0h0?ooo`00B@3oool4000000050?ooo`000?l0oooo0?ooo`000000
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`040?l0
003oool0oooo0?ooo`<0003o00<0oooo0000o`3oool01`3oool0103o0000
oooo0?l0003o00040?ooo`0>0000o`3oool0o`000000o`3oool0003o0?l0
003oool0003o0?ooo`3o0000003o0?ooo`000?l40?ooo`040?l0003oool0
oooo0?l000P0oooo00<0003o0?ooo`000?l00P000?l30?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`0m0?ooo`030000o`3oool0oooo0200oooo00<0
o`000?ooo`3oool02`3oool20000o`L0oooo00<0003o0?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool00P3oool20000o`D0oooo00<0o`000?ooo`3oool00P3o
ool40000o`040?l000000?l0003o0000o`@0oooo00<0o`000?ooo`3oool0
103oool20000o`<0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
1@3oool20000o`d0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo
0?ooo`0g0?ooo`00CP3oool010000?l0oooo0?ooo`0000040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
103oool60000o`<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`090000o`3oool0o`000?ooo`000?l0o`000?ooo`000?l0
o`000080oooo00@0003o0?ooo`3oool0oooo0P3o00030?ooo`030?l0003o
ool0oooo0080oooo1P000?l60?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0l0?ooo`030000o`3oool0oooo0200oooo00<0o`000?ooo`3oool03P3o
ool30000o`<0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`000?l00P00
0?l60?ooo`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo
0?l000020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
1P3oool20000o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0080oooo
0P000?l@0?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0
=P3oool004h0oooo00@0003o0?ooo`0000000000103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool00`3oool30000o`030?l0003oool0oooo00<0oooo
0P3o00020000o`0:0?ooo`000?l0oooo0?l000000?l0o`000?ooo`000?l0
o`000?ooo`<0003o0P3o00060?ooo`040?l000000?l0003o0000o`@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<000000000o`3oool0
?03oool00`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo0180oooo
0P000?l00`3oool0003o0?ooo`0A0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool20000o`T0oooo00<0o`000?ooo`3oool0
0`3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`070?ooo`80003o3@3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool00P000?lB0?ooo`030?l0003oool0oooo0240oooo00<0003o0?ooo`3o
ool0=@3oool004h0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01P3oool30000o`D0oooo0P3o00020?ooo`080000
o`3o0000oooo0?l000000?l0o`000?ooo`000?l20?ooo`030?l000000?l0
oooo00@0oooo0`000?l70?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo03X0oooo00<0003o0?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`0D0?ooo`80003o4@3oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00P0oooo0`000?l00`3oool0o`000?ooo`07
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0000o`020000o`X0oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0?0?ooo`<0003o5@3oool00`3o0000oooo0?oo
o`0Q0?ooo`030000o`3oool0oooo03@0oooo001>0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00@0o`00
0?ooo`3oool0oooo1P000?l01@3oool0o`000?l000000?l0oooo0080o`00
00@0003o0?l000000?l0oooo0P3o00000`3oool0003o0000o`040000o`80
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool2003o03/0oooo00<0003o0?ooo`3oool08@3oool00`3o0000
oooo0?ooo`0E0?ooo`030000o`3oool0003o0080003o3P3oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00D0oooo0`000?l50?ooo`03
0?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l01P3oool00`3o
0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo0`000?l70?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool40000
oaL0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`0d0?oo
o`00CP3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo10000?l00`3oool0
o`000000o`030?l000030000o`3o0000o`0000@0003o1`3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`@0
0?l01`3oool2000000030?ooo`000000000002d0oooo00<0003o0?ooo`3o
ool08@3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo0080
oooo0`000?l;0?ooo`030?l0003oool0oooo00h0oooo00@0003o0?ooo`3o
ool0oooo0`000?l90?ooo`030?l0003oool0oooo0080oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo00H0oooo0`000?l30?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool02@3oool40000o`<0oooo00<0003o0?oo
o`3oool05@3oool00`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo
03<0oooo001>0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool010000?l0
oooo0?ooo`3oool50000o`040?l000000?l0003o0000o`<0oooo0P000?l6
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo0080oooo1P00o`070?ooo`030000003oool0000002d0oooo00<0003o
0?ooo`3oool08P3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0
oooo00D0oooo10000?l70?ooo`030?l0003oool0oooo00h0oooo00@0003o
0?ooo`000?l0003o303oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00P3o
000<0?ooo`@0003o403oool00`3o0000oooo0?ooo`050?ooo`@0003o1`3o
ool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo0240oooo00<0
003o0?ooo`3oool0<P3oool004X0oooo100000170?l000030000o`3o0000
o`0004@0o`001P00o`02000000H0oooo00<000000?ooo`3oool0:`3oool0
0`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo01L0oooo00<0003o
0?ooo`3oool02@3oool90000o`H0oooo2`000?l?0?ooo`040?l0003oool0
oooo0?l000L0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00H0oooo0P3o000A0?ooo`X0003o1P3o
ool90000o``0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?oo
o`0R0?ooo`030000o`3oool0oooo0340oooo001>0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool70000o`030?l000000?l0o`000080o`001@000?l7
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00<0oooo1000o`070?ooo`80000000<0oooo000000000000:P3oool0
0`000?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo01H0oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0000o`060000o`P0oooo00<0003o
0?ooo`3oool03`3oool20?l000L0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`060?ooo`L0003o00<0oooo
0?l0003oool04P3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0
oooo0280oooo00<0003o0?ooo`3oool0<03oool004h0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`<0003o0P3oool20?l000060000o`3o0000003o
0000o`3o0000oooo0P3o00020?ooo`<0003o1@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo0P3o00070?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo0P00o`0f0?ooo`030000o`3o
ool0oooo02<0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03@3o
ool30?l000L0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o00003`3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3o
ool0oooo02l0oooo001>0?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3oool0oooo0`00
0?l20?ooo`070000o`3o0000o`000?ooo`000?l0o`000?ooo`020000o`07
0?l000000?l0003o0?ooo`3o0000oooo0000o`020?ooo`<0003o0P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo03<0oooo00<0003o0?ooo`3oool0903oool0
0`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0<0?ooo`050?l0003oool0
oooo0?ooo`3o00001@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo0?oo
o`3oool0o`0000h0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0
8`3oool00`000?l0oooo0?ooo`0^0?ooo`00CP3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`<0003o103o
ool20?l000060000o`3oool0003o0?ooo`3o0000oooo0P000?l01@3oool0
o`000?ooo`000?l0oooo0080o`001@3oool30000o`L0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0<P3oool00`00
0?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?oo
o`3oool04P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool00`3oool20?l000<0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo
0?ooo`80o`001@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00l0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0G
0?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0;@3oool0
04h0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`000?l01@000?l00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
0080003o00P0oooo0?l0003oool0003o0?l0003oool0003o0?l00080oooo
0P000?l00`3oool0o`000?l000050?ooo`030?l000000?l0003o00@0003o
00<0oooo0000o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
<@3oool00`000?l0oooo0?ooo`0U0?ooo`030?l0003oool0oooo01L0oooo
00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool01P3oool20?l000030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool010000?l0oooo
0?ooo`3o00080?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo01L0
oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`0/0?ooo`00
CP3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool30000o`H0oooo
00@0o`000?ooo`3oool0oooo0P3o00030?ooo`80003o00T0oooo0?l0003o
ool0003o0?l0003oool0003o0?ooo`3o00000`000?l30?ooo`050?l0003o
ool0oooo0?ooo`3o00001`3oool30000o`H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo0340oooo00<0o`000?ooo`3oool0903oool00`3o0000oooo
0?ooo`0H0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0
403oool00`000?l0oooo0?ooo`070?ooo`80o`002`3oool00`000?l0o`00
0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?l0003oool0
2@3oool20?l000T0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo
0?ooo`0B0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0
903oool00`3o0000oooo0?ooo`0[0?ooo`00CP3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00@0
o`000?ooo`3oool0oooo0`000?l00`3oool0003o0?ooo`070?ooo`<0o`00
103oool02@000?l0oooo0?ooo`3o0000003o0?ooo`000?l0o`000?ooo`02
0000o`050?l0003oool0oooo0?ooo`000?l00`3oool30?l000P0oooo00<0
003o0?ooo`3oool00`000?l30?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0b0?ooo`80o`00903oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3o
ool0oooo01<0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0103o
00030?ooo`040?l0003oool0oooo0?ooo`@0o`0000<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0100oooo
00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0
003oool0oooo0280oooo0P3o000^0?ooo`00CP3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo1P00
0?l40?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`3o
ool01P000?l0oooo0?ooo`3oool0o`000?ooo`80003o00H0o`000000o`00
0?l0003o0?ooo`3o00030?ooo`030000o`3oool0oooo0080oooo0P3o0007
0?ooo`030000o`3oool0oooo00<0oooo1@000?l60?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0=@3oool0
0`3o0000oooo0?ooo`0Q0?ooo`030?l0003oool0oooo01L0oooo00<0003o
0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`04
0?ooo`L0o`001@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0C
0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0803oool0
0`3o0000oooo0?ooo`0^0?ooo`00CP3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0003o0P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo0P3o00000`3o
ool0o`000?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool0
0`000?l0oooo0?l000020?ooo`030000o`3oool0o`0000@0oooo00@0003o
0?ooo`3oool0o`000P3oool20?l000D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`030000o`80oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0f0?ooo`030?l0003o
ool0oooo01l0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?oo
o`0C0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0C0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool07`3o
ool00`3o0000oooo0?ooo`0_0?ooo`00CP3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`<0003o1P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo0080o`000`3oool01@3o0000oooo0?ooo`3o
ool0003o0080oooo00@0o`000?ooo`3oool0003o0P3oool0103o0000oooo
0?ooo`000?l20?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool00`3o
0000oooo0?ooo`020?ooo`80o`000P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00<0oooo0`000?l80?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo03L0oooo0P3o000O0?ooo`030?l0003oool0oooo
01P0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0B0?oo
o`030000o`3oool0oooo0080o`003P3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0303oool20?l0
0080oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0C0?oo
o`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0703oool20?l0
0380oooo001>0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080
oooo10000?l80?ooo`030?l0003oool0oooo00H0oooo00<0003o0?l0003o
00001P3oool00`3o0000oooo0000o`030?ooo`040?l0003oool0oooo0000
o`80oooo00@0o`000?ooo`3oool0003o0`3oool01P3o0000oooo0?ooo`3o
ool0003o0?l000L0oooo00<0o`000?ooo`000?l01`3oool00`3o0000oooo
0?ooo`060?ooo`@0003o103oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0i0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0
6@3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo01<0oooo
00<0003o0?l0003oool03P3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0000o`0D0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0
6@3oool00`3o0000oooo0?ooo`0K0?ooo`030?l0003oool0oooo0380oooo
001>0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`D0003o103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo00<0o`000000o`3oool01P3o
ool20000o`040?l0003oool0oooo0?l000<0oooo00@0003o0?ooo`3oool0
o`000P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0o`000000
o`3oool01`3oool20?l000L0oooo00<0o`000?ooo`3oool01P3oool01000
0?l0oooo0?ooo`3oool60000o`H0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo03X0oooo0P3o000K
0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool0503oool0
0`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`0D
0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool06@3oool2
0?l003D0oooo001?0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool010000?l0oooo0?ooo`3oool30000o`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`80o`0000<0oooo0000o`3oool01@3oool010000?l0oooo0?ooo`3o
ool30?l00080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`070000
o`3oool0oooo0?ooo`3o0000oooo0?l000020?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool00P3o00040?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0000o`020000
o`<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo03`0oooo0P3o000H0?ooo`030?l0003oool0oooo
01X0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0@0?oo
o`80o`0000<0oooo0000o`3oool03@3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool03P3oool00`00
0?l0o`000?l0000B0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?oo
o`3oool06P3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0003oool0oooo
03D0oooo001?0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool40000o`@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`040?l0003oool0oooo0?ooo`80o`00103oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo0P3o00020?oo
o`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`03
0?l000@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`80o`000P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool00`3oool40000o`L0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0n0?ooo`030?l0003oool0
oooo01D0oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0D
0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0<0?ooo`040000o`3oool0
oooo0?ooo`80o`00403oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3o
ool0oooo01T0oooo00<0o`000?ooo`3oool05@3oool20?l003P0oooo001?
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool3
0000o`L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`040?l0003oool0oooo0?l000H0oooo00D0003o0?ooo`3oool0oooo
0000o`060?ooo`050?l0003oool0o`000?l000000?l00`3oool01@3o0000
oooo0?ooo`3oool0003o0080o`000P3oool00`3o0000oooo0?ooo`030?oo
o`050000o`3oool0oooo0?ooo`000?l01`3oool20?l000T0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`<0003o1@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo03l0oooo0P3o000D
0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool0503oool0
0`3o0000oooo0?ooo`0=0?ooo`80o`001@3oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00@0oooo0P3o000>
0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool06P3oool0
0`3o0000oooo0?ooo`0B0?ooo`80o`00>P3oool004l0oooo00<0003o0?oo
o`3oool01P3oool60000o`80oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo0P3o00080?oo
o`030000o`3oool0003o00H0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0o`000?l000060?l000050000o`3oool0oooo0?ooo`3o00001P3oool3
0000o`T0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0oooo1P00
0?l70?ooo`030000o`3oool0oooo0480oooo0P3o000B0?ooo`030?l0003o
ool0oooo01X0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00/0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?oo
o`0J0?ooo`030?l0003oool0oooo0140oooo00<0o`000?ooo`3oool0>P3o
ool00500oooo00<0003o0?ooo`3oool00P3oool30000o`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00@0oooo0P3o000:0?ooo`80003o1@3oool0
0`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo0P00
0?l80?ooo`040?l0003oool0o`000?l000H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`000?l00P000?l40?ooo`030000o`3oool0oooo04@0oooo
0P3o000?0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool0
5P3oool00`3o0000oooo0?ooo`090?ooo`80o`002P3oool00`000?l0oooo
0?ooo`080?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo
0P3o000:0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0
6P3oool00`3o0000oooo0?ooo`0?0?ooo`80o`00?@3oool00500oooo00<0
003o0?ooo`000?l00P000?l30?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`040000o`3o
ool0oooo0?ooo`<0o`000P3oool00`3o0000oooo0?ooo`060?ooo`040000
o`3oool0oooo0000o`@0oooo00<0o`000?ooo`3oool00`3oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`020?ooo`040000o`3oool0oooo0000o`L0oooo00@0o`00
0?ooo`3oool0oooo0P3o00030?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo0080oooo0P000?l20?ooo`030000o`3oool0oooo04H0oooo00<0
o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3o
ool0oooo01H0oooo00<0o`000?ooo`3oool01`3oool20?l000d0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0<0?ooo`80o`00203oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3o
ool0oooo01/0oooo00<0o`000?ooo`3oool0303oool20?l003l0oooo001@
0?ooo`80003o1`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0o`000?l00006
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool0
10000?l0oooo0?ooo`3o00050?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo0P3o00000`3oool0003o0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`<0003oB@3oool20?l000`0oooo00<0o`000?ooo`3oool0
6`3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo00D0oooo
0P3o000@0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool03`3oool20?l000H0oooo00<0o`000?ooo`3oool0
5P3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo00X0oooo
0P3o00110?ooo`00D03oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0o`0000D0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000000o`000?l01P3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00H0oooo0P3o00070?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo04X0oooo0P3o00090?ooo`030?l0003o
ool0oooo01`0oooo00<0003o0?ooo`3oool05`3oool0103o0000oooo0?oo
o`3oool30?l001<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0B0?ooo`80o`000`3oool00`3o0000oooo
0?ooo`0G0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool0
203oool20?l004<0oooo001A0?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`000?l02@3oool0103o0000oooo0?oo
o`000?l80?ooo`030?l000000?l0oooo00@0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool01`3oool010000?l0oooo0?ooo`3o00080?ooo`04
0000o`3oool0oooo0?l000D0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool0C03oool30?l000H0oooo00<0o`000?ooo`3oool0703oool00`00
0?l0oooo0?ooo`0G0?ooo`040?l0003oool0o`000?l001L0oooo0P000?l3
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool0
1@000?l0oooo0?ooo`3oool0003o01L0oooo0P3o00000`3oool0o`000?oo
o`0H0?ooo`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool0103o
ool30?l004D0oooo001A0?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo0080oooo0P3o00030?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0000o`3oool01`3oool00`3o0000oooo0?ooo`030000o`030?ooo`000?l0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0000o`02
0000o`030?ooo`3o0000oooo00P0oooo00<0003o0?l0003oool0203oool0
10000?l0oooo0?ooo`3oool20?l000<0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool0D03oool40?l00080oooo00<0o`000?ooo`3oool0703o
ool00`000?l0oooo0?ooo`0F0?ooo`<0o`006`3oool00`000?l0oooo0000
o`0@0?ooo`030?l0003oool0oooo00d0oooo00@0003o0?ooo`3oool0003o
6P3oool30?l001P0oooo00<0003o0?ooo`3oool0703oool0103o0000oooo
0?ooo`3oool30?l004P0oooo001A0?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`040?l0
003oool0o`000?l000H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
o`000?ooo`070?ooo`030?l0003oool0oooo00<0oooo0`000?l40?ooo`03
0?l0003oool0oooo00<0oooo0`000?l50?ooo`030?l0003oool0oooo00H0
oooo00<0o`000000o`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0o`0000T0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo05@0oooo0`3o000N0?ooo`03
0000o`3oool0oooo0180oooo103o00020?ooo`030?l0003oool0oooo01X0
oooo0P000?l@0?ooo`030?l0003oool0oooo00h0oooo0P000?lK0?ooo`03
0?l0003oool0oooo00@0o`00503oool00`000?l0oooo0?ooo`0M0?ooo`<0
o`00B`3oool00540oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo0P3o00080?ooo`030000
o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0o`001P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0003o00<0003o00<0o`000000o`00
0?l00`000?l00`3oool0003o0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00@0o`000?ooo`3oool0003o1`3oool00`000?l0oooo0?ooo`050?oo
o`80o`00203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool0E@3oool00`3o0000oooo0?l000020?l0
01/0oooo00<0003o0?ooo`3oool03P3oool40?l000H0oooo00<0o`000?oo
o`3oool06P3oool010000?l0oooo0000o`000?l>0?ooo`030?l0003oool0
oooo00/0oooo0`000?l00`3oool0003o0?ooo`0J0?ooo`030?l0003oool0
oooo00@0oooo103o000@0?ooo`030000o`3oool0oooo01T0oooo1@3o001=
0?ooo`00DP3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?l000090?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool0103o
0000oooo0?l0003o00060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1F0?ooo`030?l0003oool0
oooo0080oooo0`3o000H0?ooo`030000o`3oool0oooo00T0oooo1@3o000:
0?ooo`030?l0003oool0oooo01X0oooo00@0003o0?ooo`3oool0oooo0`00
0?l20?ooo`@000001@3oool00`3o0000oooo0?ooo`090?ooo`80003o103o
ool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo00T0oooo1@3o
000;0?ooo`030000o`3oool0oooo01H0oooo0`3o00040?ooo`030?l0003o
ool0oooo04/0oooo001B0?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`80o`000P3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool20?l00080oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo00@0oooo00D0003o0?ooo`3oool0oooo0000o`090?ooo`040?l0003o
ool0oooo0?ooo`80o`000`3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0E@3oool00`3o0000oooo
0?ooo`060?ooo`L0o`004@3oool00`000?l0oooo0?ooo`050?ooo`@0o`00
403oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo00D0oooo
0P000?l00`000000oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
10000?l70?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0
3P3oool40?l000L0oooo00<0003o0?ooo`3oool0403oool60?l000P0oooo
00<0o`000?ooo`3oool0BP3oool005<0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0080o`001@3o
ool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo0000o`T0oooo
00<0o`000?ooo`3o00001`3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool0103o0000oooo
0?l0003o00070?ooo`040000o`3oool0oooo0000o`T0oooo00<0o`000?oo
o`3oool0103oool20?l000030?ooo`000?l0oooo00L0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`1E0?ooo`030?l0003oool0oooo
00d0oooo6@3o000D0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?oo
o`3oool0203oool90000o`030?l000000?l0003o00D0003o2`3oool00`00
0?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo0180oooo6P3o000>0?oo
o`030?l0003oool0oooo04X0oooo001C0?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool20?l000P0oooo00<0o`000?ooo`3o
ool01`3oool20000o`/0oooo0P3o00060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`80
o`002P3oool00`000?l0oooo0000o`090?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo05H0oooo00<0o`000?ooo`3oool07P3oool00`000?l0
oooo0?ooo`0J0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3o
ool02`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0J0?ooo`03
0000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0BP3oool005@0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0003o00T0oooo00<0o`000?ooo`3oool01P3oool20000o`/0oooo
00@0o`000?ooo`3o0000o`00103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool20?l00003
0?ooo`3o0000oooo00X0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3o0000o`0000H0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`1F0?ooo`030?l0003oool0oooo01h0
oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0E0?ooo`03
0000o`3oool0oooo00T0oooo00@000000?ooo`3oool000001@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?oo
o`3oool06P3oool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo
04X0oooo001D0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool00P3oool20?l00080oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`050?ooo`040000o`3oool0oooo0000o`T0oooo00<0o`000?oo
o`3oool00P3oool20?l00080oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`040000o`3oool0oooo0?ooo`80o`000`3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0003o00L0oooo00<0o`00
0?ooo`3oool01`3oool010000?l0oooo0?ooo`3oool20?l000<0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`1F0?ooo`030?l0003o
ool0oooo01l0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?oo
o`0C0?ooo`030000o`3oool0oooo00/0oooo0P0000060?ooo`030?l0003o
ool0oooo0180oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?oo
o`0K0?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0BP3o
ool005D0oooo00<0003o0?ooo`3oool01P3oool0103o0000oooo0?l0003o
00050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool20?l000030000o`3o0000oooo00D0oooo00<0
o`000?ooo`3oool0103oool20?l000030000o`3o0000o`0000H0oooo00<0
o`000?ooo`3oool01@3oool20000o`<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00@0
o`000?ooo`3oool0o`00203oool00`000?l0oooo0?ooo`1F0?ooo`030?l0
003oool0oooo01l0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo
0?ooo`0B0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0
4`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo01X0oooo
00<0003o0?ooo`3oool0803oool00`3o0000oooo0?ooo`190?ooo`00E@3o
ool00`000?l0oooo0?ooo`060?ooo`80o`00203oool00`000?l0oooo0?oo
o`070?ooo`050?l0003oool0oooo0?ooo`000?l01P3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o0000
303o00020?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`3o
00002P3oool00`000?l0oooo0?ooo`050?ooo`80o`00203oool00`000?l0
oooo0?ooo`1G0?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3o
ool06`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo01@0
oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool0803oool00`3o0000
oooo0?ooo`190?ooo`00EP3oool00`000?l0oooo0?ooo`040?ooo`<0o`00
2@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0003o00P0oooo
0P000?l30?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo
00@0o`000?ooo`3oool0oooo0P000?l80?ooo`80003o00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`070?ooo`<0o`001P3oool00`000?l0
oooo0?ooo`1G0?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3o
ool0703oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo01D0
oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool0803oool00`3o0000
oooo0?ooo`190?ooo`00EP3oool00`000?l0oooo0?ooo`020?ooo`80o`00
0`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo
00<0003o0?ooo`3oool02@3oool20000o`030?ooo`3o0000oooo00P0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00L0oooo00<0o`000000o`000?l02`3oool00`3o0000003o
0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00@0o`000?ooo`3oool0
oooo0P3o00030?ooo`030000o`3oool0oooo05P0oooo00<0o`000?ooo`3o
ool0803oool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0E0?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0703oool00`000?l0
oooo0?ooo`0P0?ooo`030?l0003oool0oooo04T0oooo001G0?ooo`040000
o`3oool0o`000?l000D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0o`0000`0oooo00<0o`000000o`3o
ool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0o`000?ooo`0;0?ooo`04
0?l0003oool0oooo0000o`L0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`040?ooo`040?l0003oool0oooo0000oeX0oooo00<0o`00
0?ooo`3oool0803oool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0E
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool07@3oool0
0`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo04T0oooo001G0?oo
o`80o`00203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00@0oooo00D0003o0?ooo`3oool0oooo0?l0000:0?ooo`030?l0003oool0
oooo00<0003o1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool0103oool20000o`80oooo00<0o`00
0?ooo`3oool01`3oool20?l000@0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo0P3o001K
0?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool07P3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01H0oooo00<0o`00
0?ooo`3oool05P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo01h0oooo00<0003o0?ooo`3oool0803oool00`3o0000oooo0?ooo`19
0?ooo`00F03oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool00`3oool20000
o`<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00D0003o0?oo
o`3oool0oooo0000o`0:0?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool0F03oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0
oooo01h0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0G
0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo0280oooo00<0o`00
0?ooo`3oool0B03oool005T0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`080?ooo`040000o`3oool0oooo0000o`L0oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`@0003o2@3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0003o00<0003o1P3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00@0003o
0?ooo`3oool0003o2@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo05T0oooo00<0o`000?ooo`3oool08P3oool00`000?l0oooo0?oo
o`0O0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool05`3o
ool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003o
ool0oooo04P0oooo001I0?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool0203oool20000o`T0oooo0P3o00050?ooo`030?l0003oool0
oooo00T0oooo0`000?l70?ooo`030?l0003oool0oooo00D0oooo10000?l;
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02@3oool2
0000o`T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`1I
0?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool0803oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo01P0oooo00<0o`00
0?ooo`3oool0603oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo0200oooo00<0003o0?ooo`3oool08P3oool00`3o0000oooo0?ooo`18
0?ooo`00FP3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo0P000?l;0?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool0
10000?l0oooo0?ooo`3oool70000o`030?l000000?l0003o00D0003o0`3o
ool00`000?l0oooo0?ooo`0:0?ooo`040?l0003oool0o`000?l000`0oooo
0P000?l80?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
FP3oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0240oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0
003oool0oooo01T0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo0280oooo00<0o`000?ooo`3oool0
B03oool005/0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`050?ooo`040000o`3oool0oooo0000o`/0oooo00@0o`000?ooo`3oool0
o`002`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02P3oool20?l000d0oooo00@0003o0?ooo`3o
ool0003o1`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
05/0oooo00<0o`000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0R0?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool06P3oool00`3o
0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool08P3oool00`000?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo
04L0oooo001K0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00T0
oooo0P3o000<0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0:0?ooo`80o`00303oool01@000?l0
oooo0?ooo`3oool0003o00H0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`1K0?ooo`030?l0003oool0oooo02@0oooo00<0003o0?oo
o`3oool08P3oool01@3o0000oooo0?ooo`3oool0003o01d0oooo00<0o`00
0?ooo`3oool06P3oool01@000?l0oooo0?ooo`3oool0o`0002@0oooo00<0
003o0?ooo`3oool0903oool00`3o0000oooo0?ooo`170?ooo`00G03oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`040?l0003oool0
o`000?l000X0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00L0oooo0P3o00000`3oool0o`000?oo
o`090?ooo`80003o1@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0F`3oool00`3o0000oooo0?oo
o`0T0?ooo`030000o`3oool0oooo02<0oooo00<0o`000?ooo`000?l07P3o
ool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0o`0002D0oooo00<0
003o0?ooo`3oool0903oool00`3o0000oooo0?ooo`170?ooo`00G@3oool0
0`000?l0oooo0?ooo`070?ooo`040?l0003oool0oooo0000o`P0oooo0P00
0?l80?ooo`040?l0003oool0oooo0?ooo`<0o`001`3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
1@3oool20?l000@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`040000o`3oool0oooo0?l000X0oooo00<0003o0?ooo`3o
ool0G03oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo02<0
oooo00<0o`000000o`3oool07@3oool00`3o0000oooo0?ooo`0L0?ooo`03
0000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool0903oool00`3o0000
oooo0?ooo`170?ooo`00GP3oool00`000?l0oooo0?ooo`070?ooo`030?l0
00000?l0oooo00X0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`<0o`00103oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool00P3oool30?l000L0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`030000
o`3oool0o`0000T0oooo00<0003o0?ooo`3oool0G@3oool00`3o0000oooo
0?ooo`0U0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?l0003oool0
7@3oool00`3o0000oooo0?ooo`0K0?ooo`030?l000000?l0oooo02D0oooo
00<0003o0?ooo`3oool0903oool00`3o0000oooo0?ooo`170?ooo`00GP3o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3o0000o`0000/0oooo0P00
0?l40?ooo`030?l0003oool0oooo00P0oooo0`3o00000`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00X0oooo00@0003o0?l0003o0000o`00
2P3oool00`3o0000oooo0?ooo`020?ooo`80003o303oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo05h0oooo00<0o`000?ooo`3oool0
9@3oool00`000?l0oooo0?ooo`0R0?ooo`030000o`3oool0oooo0080o`00
703oool00`3o0000oooo0?ooo`0I0?ooo`80o`000P3oool00`000?l0oooo
0?ooo`0R0?ooo`030000o`3oool0oooo02D0oooo00<0o`000?ooo`3oool0
A`3oool005l0oooo00<0003o0?ooo`3oool01@3oool01@000?l0oooo0?oo
o`3oool0o`0000`0oooo00@0003o0?ooo`3oool0o`003P3oool00`000?l0
o`000?l000090?ooo`030?l0003oool0oooo00L0oooo0`3o00000`000?l0
oooo0?ooo`0<0?ooo`040?l0003oool0oooo0000o``0oooo0P3o00000`3o
ool0003o0?ooo`060?ooo`030000o`3oool0oooo05l0oooo00<0o`000?oo
o`3oool09P3oool00`000?l0oooo0?ooo`0P0?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0H0?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool08@3oool00`00
0?l0oooo0?ooo`0U0?ooo`030?l0003oool0oooo04L0oooo001P0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0:0?ooo`80003o00<0o`000?ooo`3oool02`3oool010000?l0
oooo0?ooo`3ooolC0?l000<0oooo00<0003o0?ooo`3oool0303oool00`3o
0000003o0000o`0<0?ooo`030?l0003oool0oooo0080oooo0P000?l40?oo
o`030000o`3oool0oooo0600oooo00<0o`000?ooo`3oool09P3oool00`00
0?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0603oool00`3o0000oooo0?ooo`0F0?ooo`80o`001`3oool00`00
0?l0oooo0?ooo`0O0?ooo`030000o`3oool0oooo02H0oooo00<0o`000?oo
o`3oool0A`3oool00640oooo00D0003o0?ooo`3oool0oooo0000o`070?oo
o`030?l0003oool0oooo00X0oooo00<0o`000000o`3oool0303oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool02`3oool00`000?l0o`000?ooo`0;0?ooo`030?l0003oool0oooo
00D0oooo00D0003o0?ooo`3oool0oooo0000o`1R0?ooo`030?l0003oool0
oooo02H0oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo0?ooo`07
0?ooo`80o`00603oool00`3o0000oooo0?ooo`0D0?ooo`80o`002P3oool0
0`000?l0oooo0?ooo`0N0?ooo`030000o`3oool0oooo02H0oooo00<0o`00
0?ooo`3oool0A`3oool00680oooo00<0003o0?ooo`000?l02@3oool00`3o
0000oooo0?ooo`090?ooo`040?l0003oool0003o0000o`/0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00T0oooo0P000?l00`3oool0o`000?ooo`090?ooo`80o`002@3oool0
0`000?l0oooo0000o`1S0?ooo`030?l0003oool0oooo02L0oooo00<0003o
0?ooo`3oool07@3oool00`000?l0oooo0?ooo`090?ooo`@0o`00503oool0
0`3o0000oooo0?ooo`0B0?ooo`80o`00303oool00`000?l0oooo0?ooo`0N
0?ooo`030000o`3oool0oooo02H0oooo00<0o`000?ooo`3oool0A`3oool0
06<0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool01`3oool20000o`@0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0680oooo00<0o`000?oo
o`3oool09`3oool00`000?l0oooo0?ooo`0L0?ooo`030000o`3oool0oooo
00h0oooo0`3o000A0?ooo`030?l0003oool0oooo0100oooo0P3o000?0?oo
o`030000o`3oool0oooo01`0oooo00<0003o0?ooo`3oool09`3oool00`3o
0000oooo0?ooo`170?ooo`00I03oool00`000?l0oooo0?ooo`090?ooo`80
o`001P3oool00`3o0000oooo0?ooo`040?ooo`80003o1`3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool01@3oool20000o`L0oooo00<0o`000?ooo`3oool00`3oool20?l000`0
oooo00<0003o0?ooo`3oool0H`3oool00`3o0000oooo0?ooo`0W0?ooo`03
0000o`3oool0oooo01/0oooo00<0003o0?ooo`3oool04P3oool20?l000l0
oooo00<0o`000?ooo`3oool03@3oool30?l00180oooo00<0003o0?ooo`3o
ool06`3oool00`000?l0oooo0?ooo`0W0?ooo`030?l0003oool0oooo04L0
oooo001U0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`070?ooo`<0003o103oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
0`3oool20000o`T0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo06@0oooo00<0o`000?ooo`3oool0
:03oool00`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0oooo01D0oooo
0P3o000=0?ooo`030?l0003oool0oooo00P0oooo1@3o000F0?ooo`030000
o`3oool0oooo01X0oooo00<0003o0?ooo`3oool09`3oool00`3o0000oooo
0?ooo`170?ooo`00IP3oool00`000?l0oooo0?ooo`0:0?ooo`050?l0003o
ool0oooo0?ooo`3o0000303oool40000o`h0oooo00<0o`000?ooo`3oool0
303oool50000o``0oooo00@0o`000?ooo`3oool0o`003@3oool00`000?l0
oooo0?ooo`1U0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3o
ool0603oool00`000?l0oooo0?ooo`0H0?ooo`L0o`001P3oool00`3o0000
oooo0?ooo`020?ooo`H0o`00703oool00`000?l0oooo0?ooo`0H0?ooo`03
0000o`3oool0oooo02P0oooo00<0o`000?ooo`3oool0A`3oool006L0oooo
00<0003o0?ooo`3oool02P3oool30?l00100oooo10000?l;0?ooo`030?l0
003oool0oooo00T0oooo10000?l@0?ooo`<0o`00303oool20000ofP0oooo
00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0G0?ooo`030000
o`3oool0oooo01l0oooo2`3o000R0?ooo`030000o`3oool0oooo01P0oooo
00<0003o0?ooo`3oool0:03oool00`3o0000oooo0?ooo`170?ooo`00J03o
ool00`000?l0oooo0?ooo`0;0?ooo`80o`003`3oool010000?l0oooo0?oo
o`3oool;0000o`030?l000000?l0003o00T0003o0`3oool00`000?l0oooo
0?ooo`0>0?ooo`80o`00303oool00`000?l0oooo0?ooo`1X0?ooo`030?l0
003oool0oooo02T0oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo
0?ooo`0V0?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0
5P3oool00`000?l0oooo0?ooo`0Y0?ooo`030?l0003oool0oooo04L0oooo
001Y0?ooo`80003o2P3oool00`3o0000oooo0?ooo`020?l000d0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo00/0oooo0P3o00000`3oool0o`000?ooo`0:0?ooo`030000o`3o
ool0oooo06T0oooo00<0o`000?ooo`3oool0:P3oool00`000?l0oooo0?oo
o`0D0?ooo`030000o`3oool0oooo02L0oooo00<0o`000?ooo`3oool09P3o
ool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo02T0oooo00<0
o`000?ooo`3oool0A`3oool006/0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`020?ooo`80o`002`3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0203oool3
0?l000@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`1Z
0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`0X0?ooo`030?l0003oool0oooo02L0oooo00<0003o
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0
oooo04L0oooo001/0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool20?l000T0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00H0oooo0P3o00070?oo
o`030?l0003oool0oooo00D0oooo0P000?m]0?ooo`030?l0003oool0oooo
02/0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0Y0?oo
o`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0[0?ooo`030?l0003oool0oooo04L0oooo001]0?ooo`80
003o103oool00`3o0000oooo0?ooo`080?ooo`80o`001P3oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o
ool00P3oool30?l000X0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`1]0?ooo`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0oooo02T0
oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0[0?ooo`03
0?l0003oool0oooo04L0oooo001_0?ooo`050000o`3oool0oooo0?ooo`3o
0000303oool20?l000@0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0>0?ooo`030000o`3oool0o`000080o`003P3oool00`3o0000
oooo0?ooo`020000og00oooo00<0o`000?ooo`3oool0;03oool00`000?l0
oooo0?ooo`0>0?ooo`030000o`3oool0oooo02/0oooo00<0o`000?ooo`3o
ool0:P3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo02`0
oooo00<0o`000?ooo`3oool0A`3oool00700oooo0P000?l00`3o0000oooo
0?ooo`0=0?ooo`@0o`0000<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3o0000oooo0100oooo00<0o`000000o`000?l0
LP3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo00`0oooo
00<0003o0?ooo`3oool0;03oool00`3o0000oooo0?ooo`0[0?ooo`80003o
3@3oool00`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0oooo04L0oooo
001b0?ooo`030?l0003oool0oooo0100oooo00<0003o0?l0003o00000P3o
000<0?ooo`030?l0003oool0oooo00X0oooo103o00000`3oool0003o0?oo
o`0@0?ooo`030000o`3o0000oooo0780oooo00<0o`000?ooo`3oool0;P3o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo02d0oooo00<0
o`000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo02d0oooo00<0o`000?ooo`3oool0A`3oool007<0oooo0P000?l@
0?ooo`030000o`3oool0oooo0080oooo6@3o00050?ooo`030000o`3oool0
oooo00d0oooo0P000?me0?ooo`030?l0003oool0oooo02h0oooo00<0003o
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0
oooo02h0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0^
0?ooo`030?l0003oool0oooo04L0oooo001e0?ooo`80003o3P3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?oo
o`3oool02`3oool20000ogL0oooo00<0o`000?ooo`3oool0;`3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo02l0oooo00<0o`000?oo
o`3oool0;`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
02l0oooo00<0o`000?ooo`3oool0A`3oool007L0oooo0P000?l;0?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool03`3oool00`000?l0
oooo0?ooo`090?ooo`80003oN@3oool00`3o0000oooo0?ooo`0`0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0<03oool00`3o0000
oooo0?ooo`0`0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool0<03oool00`3o0000oooo0?ooo`170?ooo`00N@3oool20000o`T0oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00L0oooo0P000?mk0?ooo`030?l0003oool0oooo0300oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0a0?ooo`030?l0
003oool0oooo0340oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0`0?ooo`030?l0003oool0oooo04L0oooo001k0?ooo`@0003o1@3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00l0oooo00<0
003o0?ooo`3oool0103oool30000ogh0oooo00<0o`000?ooo`3oool0<03o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0380oooo00<0
o`000?ooo`3oool0<P3oool01@000?l0oooo0?ooo`3oool0003o03<0oooo
00<0o`000?ooo`3oool0A`3oool007l0oooo1@000?lB0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`000?l00`000?n10?ooo`030?l0003o
ool0oooo0340oooo00@0003o0?ooo`000?l0003o=@3oool00`3o0000oooo
0?ooo`0c0?ooo`030000o`3oool0003o03<0oooo00<0o`000?ooo`3oool0
B03oool008<0oooo0P000?l:0?ooo`D000000P3oool20000oa40oooo0P00
0?n50?ooo`030?l0003oool0oooo0380oooo00<0003o0?ooo`3oool0=@3o
ool00`3o0000oooo0?ooo`0d0?ooo`80003o<`3oool00`3o0000oooo0?oo
o`180?ooo`00Q@3oool30000o`T0oooo00@000000?ooo`3oool0oooo1000
0?l90?ooo`L0003oQ`3oool00`3o0000oooo0?ooo`0a0?ooo`80003o;`3o
ool2000000H0oooo00<0o`000?ooo`3oool0=03oool00`000?l0oooo0000
o`0b0?ooo`030?l0003oool0oooo04P0oooo00280?oooaX0003oSP3oool0
0`3o0000oooo0?ooo`0_0?ooo`80003o0P3oool00`000?l0oooo0?ooo`0[
0?ooo`040000003oool0oooo000000D0oooo00<0o`000?ooo`3oool0<`3o
ool01@000?l0oooo0?ooo`3oool0003o0340oooo00<0o`000?ooo`3oool0
B03oool00940oooo00<000000?ooo`3oool01P000?nF0?ooo`030?l0003o
ool0oooo02h0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0/0?ooo`030000003oool0oooo00@0oooo00<0o`000000003oool0<P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02h0oooo00<0
o`000?ooo`3oool0B03oool00940oooo00@000000?ooo`3oool0oooo1000
0?on0?ooo`030000003oool0oooo0;X0oooo002@0?ooo`800000103oool2
0000oo`0oooo00@000000?ooo`3oool00000_03oool009H0oooo00<00000
0?ooo`3oool0o03oool200000;d0oooo003o0?ooool0ooooEP3oool00?l0
ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0ooooEP3o
ool00?l0ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo002D0?ooo`80
0000o`3ooono0?ooo`00U@3oool00`000000oooo0?ooo`3o0?oookd0oooo
002F0?ooo`030000003oool0oooo0?l0oooo103oool200000;H0oooo002E
0?ooo`030000003oool000000?l0oooo1@3oool200000;H0oooo002D0?oo
o`040000003oool0oooo00000?l0oooo103oool010000000oooo0?ooo`00
002e0?ooo`00T`3oool3000000030?ooo`00000000000?l0oooo0P3oool2
00000080oooo0P00002d0?ooo`00o`3ooooo0?oooeH0oooo003o0?ooool0
ooooEP3oool00?l0ooooo`3ooomF0?ooo`00o`3ooooo0?oooeH0oooo0000
\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{596, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  We first consider the unit circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z\)\(|\)\) = 1\)]],
  ",  which forms the boundary of the disk and find its image in the w plane. \
 \nIf we write  ",
  Cell[BoxData[
      \(S \((z)\) = \(\(-\[ImaginaryI]\)\ z\  + \ \[ImaginaryI]\)\/\(z\  + \ \
1\)\)],
    AspectRatioFixed->True],
  ",  then we see that  ",
  Cell[BoxData[
      \(a = \(-\[ImaginaryI]\)\)]],
  ",  ",
  Cell[BoxData[
      \(b = \[ImaginaryI]\)]],
  ",  ",
  Cell[BoxData[
      \(c = 1\)]],
  ", and ",
  Cell[BoxData[
      \(d = 1\)]],
  ".  \nUsing Equation ",
  StyleBox["(10-14)",
    FontColor->RGBColor[0, 0, 1]],
  ", we find that the inverse is given by\n\n\t\t\t\n",
  StyleBox["(10-16)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(z\ \  = \ \ \(\(S\^\(-1\)\) \((w)\)\ \  = \ \ \(\(\(-d\)\ w\  + \ b\)\
\/\(c\ w\  - \ a\)\ \  = \ \ \(\(\(-\((1)\)\)\ w\  + \ \
\((\[ImaginaryI])\)\)\/\(\((1)\)\ w\  - \ \ \((\(-\[ImaginaryI]\))\)\)\ \  = \
\ \ \(\(-\ w\)\  + \ \[ImaginaryI]\)\/\(w\  + \ \[ImaginaryI]\)\)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "If  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = 1\)]],
  ",  then Equation ",
  StyleBox["(10-16)",
    FontColor->RGBColor[0, 0, 1]],
  " implies that the images of points on the unit circle satisfy ",
  Cell[BoxData[
      \(\(\(|\)\(\(\(-\ 
                  w\)\  + \ \[ImaginaryI]\)\/\(w\  + \ \[ImaginaryI]\)\)\(|\)\
\) = 1\)]],
  " which yields the equation  \n\n",
  StyleBox["(10-17)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(\(\(|\)\(w\  + \ \[ImaginaryI]\)\(|\)\)\  = \ \(\(|\)\(\(-\ 
              w\)\  + \ \[ImaginaryI]\)\(|\)\)\)]],
  ".  \n"
}], "Text"],

Cell[TextData[{
  "Squaring both sides of Equation ",
  StyleBox["(10-17)",
    FontColor->RGBColor[0, 0, 1]],
  ", we obtain\n\n\t\t\t   ",
  Cell[BoxData[
      \(\(\(|\)\(u + \[ImaginaryI]\ v\  + \ \[ImaginaryI]\)\(|\)\)\ \  = \ \ \
\(\(|\)\(\(-\ u\) - \[ImaginaryI]\ v\  + \ \[ImaginaryI]\)\(|\)\)\)]],
  "   \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(u + \[ImaginaryI]\ \((1 + 
                  v)\)\)\( | \^2\)\)\  = \ \ \(\(|\)\(\(-\ 
              u\) + \ \[ImaginaryI] \((1 - v)\)\)\( | \^2\)\)\)]],
  "   \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(u\^2 + \((1 + v)\)\^2\ \  = \ \ \((\(-\ u\))\)\^2 + \ \((1 - v)\)\
\^2\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\(\(u\^2 + \((1 + v)\)\^2\ \  = \ \ u\^2 + \ \((1 - v)\)\^2\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \(\(\((1 + v)\)\^2\ \  = \ \ \((1 - v)\)\^2\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \(\(1 + 2\ v + v\^2\  = \ \ 1 - 2\ v + 
          v\^2\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(4\ v\ \  = \ \ 0\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ v\ \  = \ \ 0\)}]],
  "     \n\nwhich is the equation of the ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " axis in the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane.  "
}], "Text"],

Cell[TextData[{
  "\tThe circle ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " divides the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane into two portions, and its image is the u axis, which divides the \
",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane into two portions.  The image of the point  ",
  Cell[BoxData[
      \(z = 0\)]],
  "  is  ",
  Cell[BoxData[
      \(w = \(S \((0)\) = \[ImaginaryI]\)\)]],
  ",  so we expect that the interior of the circle ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is mapped onto the portion of the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane that lies above the ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " axis.  To show that this outcome is true, we let  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ".  Then Equation ",
  StyleBox["(10-16)",
    FontColor->RGBColor[0, 0, 1]],
  " implies that the image values must satisfy the inequality  ",
  Cell[BoxData[
      \(\(\(|\)\(\(-\ 
            w\)\  + \ \[ImaginaryI]\)\(|\)\(\ \)\(\(<\)\(\ \)\(\(|\)\(w\  + \ \
\[ImaginaryI]\)\(|\)\)\)\)\)]],
  ",  which we write as  \n\n\t\t\t",
  Cell[BoxData[
      \(d\_1\  = \ \(\(\(|\)\(w\  - \ \[ImaginaryI]\)\(|\)\(\ \)\(\(<\)\(\ \)\
\(\(|\)\(w\  - \((\(-\ \[ImaginaryI]\))\)\)\(|\)\)\)\)\  = \ d\_2\)\)]],
  " .  "
}], "Text"],

Cell[TextData[{
  "\tIf we interpret ",
  Cell[BoxData[
      \(d\_1\)]],
  " as the distance from  ",
  Cell[BoxData[
      RowBox[{"w", "  ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "\[ImaginaryI]"}]]],
  "  and ",
  Cell[BoxData[
      \(d\_2\)]],
  " as the distance from  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"w", "  ", 
          StyleBox["to",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], " ", "-", "\[ImaginaryI]"}]]],
  ",  then a geometric argument shows that the image point w must lie in the \
upper half-plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  ",  as shown in Figure 10.5.  As ",
  StyleBox["S(z)",
    FontFamily->"Courier New"],
  " is one-to-one and onto in the extended complex plane, it follows that ",
  StyleBox["S(z)",
    FontFamily->"Courier New"],
  " maps the disk onto the half-plane. "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 10.5",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/mobiustranformation/\
MobiusTranformationFigures/mat1005.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The image  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  "  under  ",
  Cell[BoxData[
      \(w\  = \ \(\[ImaginaryI]\ \((1\  - \ z)\)\)\/\(1\  + \ z\)\)],
    AspectRatioFixed->True],
  ",  the points \n\t\t\t",
  Cell[BoxData[
      \(z\_1 = \(-\[ImaginaryI]\), \ z\_2 = 1, \ z\_3 = \[ImaginaryI]\)]],
  "  are mapped onto the points  ",
  Cell[BoxData[
      \(w\_1 = \(-1\), \ \ w\_2 = 0, \ \ w\_3 = 1\)]],
  ",  respectively."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(S \((z)\) = \ \(\[ImaginaryI]\ \((1\  - \ z)\)\)\/\(1\  + \ z\)\)],
    AspectRatioFixed->True],
  "."
}], "Text"],

Cell[BoxData[{
    \(z = 0; \ Remove[z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[eqn, Iden, solset, S, w, z];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(S[z_]\  = \ \(\[ImaginaryI]\ \((1 - z)\)\)\/\(1 + z\);\)\ \), "\n", 
    \(\(Print["\<S(z) = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["To show  S(z)  is one-to-one, find the inverse function.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(eqn = w \[Equal] S[z];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ Solve[eqn, z];\)\ \), "\[IndentingNewLine]", 
    \(\(S1[w_] = 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn];\)\ \), "\n", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<z = \!\(S\^\(-1\)\)[w] = \>\"", 
        S1[w]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Check out the inverse function.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<w = S(z) = \>", S[z]];\)\ \), "\n", 
    \(\(Print[\*"\"\<z = \!\(S\^\(-1\)\)[w] = \>\"", S1[w]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\^\(-1\)\)[S[z]] = \>\"", S1[S[z]], "\< = \>", 
        Together[S1[S[z]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<S[\!\(S\^\(-1\)\)[w]] = \>\"", S[S1[w]], "\< = \>", 
        Together[S[S1[w]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Consider the unit circle C: |z| = 1.  Since  ",
  Cell[BoxData[
      \(z = \(\(S\^\(-1\)\) \((w)\) = \(\[ImaginaryI]\  - \ w\)\/\(\
\[ImaginaryI]\  + \ w\)\)\)]],
  ",  the image of these points will satisfy  ",
  Cell[BoxData[
      \(\(\(\ \)\(\(\(|\)\(w + \[ImaginaryI]\)\(|\)\) = \(\(|\)\(w + \
\[ImaginaryI]\)\(|\)\)\)\)\)]],
  ".  \nSquare both sides of the above equation and obtain ",
  Cell[BoxData[
      \(\(\(|\)\(u + \[ImaginaryI]\ v + \[ImaginaryI]\)\( | \^2\)\) = \(\(|\)\
\(\(-u\) - \[ImaginaryI]\ v + \[ImaginaryI]\)\( | \^2\)\)\)]],
  "  which can be simplified."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(eqn = 
        u\^2 + \((v + 1)\)\^2 == 
          u\^2 + \((\(-v\) + 1)\)\^2;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[Simplify[eqn]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
The circle  C  divides the z-plane into two portions, and its image, v = 0, \
is the u-axis which divides the w-plane into two portions. The image of a \
point interior to  C  will determine which half plane is the image of the \
unit disk.  For example\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(Print["\<S[0] = \>", S[0]];\)\(\ \)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[TextData[{
  "Therefore, the image of the unit disk ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  " is the upper half plane ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  ".  \n\nTo visualize that  S(z)  is onto we will consider a graph. The \
graph is not conclusive, but it appears to confirm our suspicion."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, Iden, z];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(S[
          z_]\  = \(\(\ \)\(\[ImaginaryI]\ \((1 - z)\)\)\)\/\(1 + z\);\)\ \), \
"\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(graph1 = 
        PolarMap[
          Iden, {0.000005, 0.999995, 0.11111}, {0, 2  \[Pi], \[Pi]\/12}, 
          PlotRange \[Rule] {{\(-1.05\), 1.05}, {\(-1.05\), 
                1.05}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 1, 
                1], Range[1, 1, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Red, Blue}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The disk |z| < 1.\>"];\)\ \), "\n", 
    \(\(graph2 = 
        PolarMap[
          S\ \ \ , {0.000005, 0.999995, 0.11111}, {0, 2  \[Pi], \[Pi]\/12}, 
          Ticks \[Rule] {Range[\(-3\), 3, 1], Range[0, 3, 1]}, 
          AspectRatio \[Rule] 1\/2, 
          PlotRange \[Rule] {{\(-3\), 3}, {0, 
                3}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Red, Blue}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image half-plane Im[w] > 0,\>"];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the transformation  ",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(\[ImaginaryI]\ \((1\  - \ z)\)\)\/\(1\  + \ z\)\)\
\)],
    AspectRatioFixed->True],
  "  maps the unit disk ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  " one-to-one and onto the upper half plane ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(set\  = \ \ {{0, \(-1\)}, {1, 0}, {0, 
            1}};\)\ \), "\[IndentingNewLine]", 
    \(\(zdots = 
        Graphics[{{Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Green, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{\(-1\), 0}, {0, 0}, {1, 
            0}};\)\ \), "\[IndentingNewLine]", 
    \(\(wdots = 
        Graphics[{{Red, PointSize[0.023], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Green, PointSize[0.023], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.023], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph1, zdots];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph2, wdots];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<w = S[\>", z, "\<] = \>", 
        S[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<   S[\>", \(-\[ImaginaryI]\), "\<] = \>", 
        S[\(-\[ImaginaryI]\)]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<    S[\>", 1, "\<] = \>", 
        S[1]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<    S[\>", \[ImaginaryI], "\<] = \>", 
        S[\[ImaginaryI]]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tThe general formula for a bilinear transformation (Equation ",
  StyleBox["(10-13)",
    FontColor->RGBColor[0, 0, 1]],
  ") appears to involve four independent coefficients:  ",
  Cell[BoxData[
      RowBox[{"a", ",", "b", ",", "c", ",", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", "d"}]}]]],
  ".  But as ",
  StyleBox["S(z)",
    FontFamily->"Courier New"],
  " is not identically constant, either  ",
  Cell[BoxData[
      \(a \[NotEqual] 0\)]],
  "  or  ",
  Cell[BoxData[
      \(c \[NotEqual] 0\)]],
  ",  we can express the transformation with three unknown coefficients and \
write either \n\n\t\t\t",
  Cell[BoxData[
      \(S \((z)\)\ \  = \ \(z\  + \ b\/a\)\/\(c\/a\ z\  + \ d\/a\)\)]],
  "     or     ",
  Cell[BoxData[
      \(S \((z)\)\ \  = \ \(a\/c\ z\  + \ b\/c\)\/\(z\  + \ d\/c\)\)]],
  ",  \n\nrespectively.  Doing so permits us to determine a unique a bilinear \
transformation if three distinct image values  ",
  Cell[BoxData[
      \(S \((z\_1)\) = w\_1\)]],
  ",   ",
  Cell[BoxData[
      \(S \((z\_2)\) = w\_2\)]],
  ", and  ",
  Cell[BoxData[
      \(S \((z\_3)\) = w\_3\)]],
  "  are specified.  To determine such a mapping, we can conveniently use an \
implicit formula involving ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["w",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 10.3 (The Implicit Formula).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " There exists a unique bilinear transformation that maps three distinct \
points ",
  Cell[BoxData[
      RowBox[{\(z\_1\), ",", \(z\_2\), ",", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", \(z\_3\)}]}]]],
  "  onto three distinct points ",
  Cell[BoxData[
      RowBox[{\(w\_1\), ",", \(w\_2\), ",", 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", \(w\_3\)}]}]]],
  ", respectively.  An implicit formula for the mapping is given by the \
equation    \n\n",
  StyleBox["(10-18)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      \(\(\((z\  - \ z\_1)\)\ \((z\_2\  - \ z\_3)\)\)\/\(\((z\  - \ z\_3)\) \
\((z\_2\  - \ z\_1)\)\)\  = \ \(\((w\  - \ w\_1)\)\ \((w\_2\  - \ w\_3)\)\)\/\
\(\((w\  - \ w\_3)\) \((w\_2\  - \ w\_1)\)\(\ \)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 10.3 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Construct the bilinear transformation  ",
  StyleBox["w = S(z)",
    FontFamily->"Courier New"],
  "  that maps the points  ",
  Cell[BoxData[
      \(z\_1 = \(-\[ImaginaryI]\), \ z\_2 = 1, \ z\_3 = \[ImaginaryI]\)]],
  "  onto the points  ",
  Cell[BoxData[
      \(w\_1 = \(-1\), \ \ w\_2 = 0, \ \ w\_3 = 1\)]],
  ",  respectively."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008/0000[b000`400?l0
0000o`00003oo`3ooooo0?ooobh0oooo003o0?ooool0oooo;P3oool00?l0
ooooo`3oool^0?ooo`00o`3ooooo0?ooobh0oooo003o0?ooool0oooo;P3o
ool00?l0oooo@@3oool00`3o0000oooo0?ooo`0^0?ooo`030000003oool0
oooo02l0oooo00<0o`000?ooo`3oool0QP3oool00?l0oooo@03oool20?l0
0300oooo00<000000?ooo`3oool0;P3oool00`3o0000oooo0?l000270?oo
o`00o`3ooolo0?ooo`040?l0003oool0oooo0?l002l0oooo00<000000?oo
o`3oool0;@3oool01@3o0000oooo0?ooo`3oool0o`0008H0oooo003o0?oo
ocd0oooo0P3o00030?ooo`030?l0003oool0oooo02d0oooo00<000000?oo
o`3oool0;@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
08<0oooo003o0?oooc/0oooo0P3o00060?ooo`030?l0003oool0oooo02`0
oooo00<000000?ooo`3oool0;03oool00`3o0000oooo0?ooo`040?ooo`80
o`00P`3oool00?l0oooo>P3oool00`3o0000oooo0000o`070?ooo`030?l0
00000?l0oooo02/0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0o`000880oooo003o0?ooocT0oooo00@0
o`000?ooo`3oool0003o1`3oool00`000?l0o`000?ooo`0[0?ooo`030000
003oool0oooo02X0oooo00<0o`000000o`3oool01@3oool01@000?l0oooo
0?ooo`3oool0o`000840oooo003o0?ooocL0oooo0P3o00040?ooo`030000
o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`00:`3oool00`000000
oooo0?ooo`0Y0?ooo`040?l0003oool0oooo0000o`D0oooo00<0003o0?oo
o`3oool00P3oool20?l007l0oooo003o0?ooocD0oooo0P3o00070?ooo`03
0000o`3oool0oooo0080003o103oool00`3o0000oooo0?ooo`0X0?ooo`03
0000003oool0oooo02P0oooo00<0o`000?ooo`3oool00P3oool20000o`80
oooo00<0003o0?ooo`3oool01@3oool30?l007`0oooo003o0?oooc<0oooo
0P3o00000`3oool0o`000?ooo`070?ooo`80003o1`3oool20?l002P0oooo
00<000000?ooo`3oool09`3oool00`3o0000oooo0?ooo`050?ooo`80003o
2@3oool0103o0000oooo0?l0003o001j0?ooo`00o`3ooolb0?ooo`050?l0
003oool0oooo0?ooo`3o0000203oool20000o`P0oooo0P3o000W0?ooo`03
0000003oool0oooo02H0oooo00<0o`000?ooo`3oool01P3oool20000o`P0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`1g0?ooo`00
o`3oool`0?ooo`80o`001@3oool00`3o0000oooo0?ooo`040?ooo`<0003o
1`3oool0103o0000oooo0?ooo`3o000V0?ooo`030000003oool0oooo02D0
oooo00<0o`000?ooo`3o00001`3oool010000?l0oooo0000o`000?l50?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0MP3oool00?l0
oooo;P3oool20?l000P0oooo00<0o`000?ooo`3oool00P3oool01@000?l0
oooo0?ooo`3oool0003o00H0oooo00D0o`000?ooo`3oool0oooo0?l0000U
0?ooo`030000003oool0oooo02@0oooo00D0o`000?ooo`3oool0oooo0?l0
00050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`050?ooo`<0o`00M@3oool007P0oooo00<00000
0?ooo`3oool0[`3oool30?l000030?ooo`000?l0oooo00P0oooo00@0o`00
0?ooo`3oool0003o1@3oool010000?l0oooo0?ooo`3oool20?l000D0oooo
00<0o`000?ooo`3oool08P3oool00`000000oooo0?ooo`0S0?ooo`030?l0
003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`04
0000o`3oool0oooo0?l000P0oooo00<0003o0?ooo`3oool00`3o001b0?oo
o`00N03oool00`000000oooo0?ooo`1k0?ooo`D00000;@3oool20?l000@0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0000o`070?ooo`80
003o00<0o`000?ooo`3oool01P3oool00`3o0000003o0?ooo`0Q0?ooo`03
0000003oool0oooo0240oooo00<0003o0?l0003oool01P3oool00`3o0000
oooo0000o`080?ooo`030000o`3o0000oooo00P0oooo00<0003o0?ooo`3o
ool00`3oool20?l002l0oooo1@00000l0?ooo`00N03oool00`000000oooo
0?ooo`1m0?ooo`030000003oool0oooo02/0oooo0P3o00070?ooo`030000
o`3oool0oooo00H0oooo0P000?l:0?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?l0003o00008@3oool00`000000oooo0?ooo`0O0?ooo`80o`00
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0
00000?l0oooo00L0oooo00<0003o0?ooo`3oool01P3oool20?l002l0oooo
00<000000?ooo`3oool0?03oool007P0oooo00<000000?ooo`3oool0O@3o
ool00`000000oooo0?ooo`0Y0?ooo`80o`002@3oool00`000?l0oooo0?oo
o`040?ooo`80003o00<0oooo0?l0003oool0203oool00`3o0000oooo0000
o`070?ooo`040000o`3oool0oooo0?l00200oooo00<000000?ooo`3oool0
7P3oool01@3o0000oooo0?ooo`3oool0003o00L0oooo00<0003o0?ooo`3o
0000203oool0103o0000oooo0000o`000?l60?ooo`030000o`3oool0oooo
00L0oooo0P3o000^0?ooo`030000003oool0oooo03`0oooo001c0?ooo`@0
00000`3o001f0?ooo`@00000103oool00`000000oooo0?ooo`0V0?ooo`<0
o`0000<0oooo0?l0003oool02@3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool0103o0000
oooo0?ooo`000?l60?ooo`030000o`3oool0oooo0080oooo0P3o000N0?oo
o`030000003oool0oooo01`0oooo0P3o00040?ooo`030000o`3oool0oooo
00@0oooo00D0003o0?ooo`3oool0oooo0?l000060?ooo`030?l0003oool0
oooo0080oooo0P000?l30?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3o00000P3o000[0?ooo`030000003oool0oooo03`0oooo001e0?oo
o`030000003o0000o`0000<0o`00O@3oool00`000000oooo0?ooo`0S0?oo
o`<0o`001@3oool00`3o0000oooo0?ooo`080?ooo`040000o`3oool0oooo
0000o`H0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool3
0?l001/0oooo00<000000?ooo`3oool06P3oool20?l000L0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?ooo`00
0?l90?ooo`030?l0003oool0oooo00<0oooo103o000W0?ooo`030000003o
ool0oooo03`0oooo001e0?ooo`030000003o0000o`0003L0o`00B03oool2
00000280oooo0`3o00080?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`000?l0203oool01@3o0000oooo0?ooo`3oool0o`0000H0oooo00@0
003o0?ooo`3oool0003o203oool00`3o0000oooo0?ooo`020?l001T0oooo
00<000000?ooo`3oool0603oool20?l000030?ooo`3o0000oooo00L0oooo
00@0003o0?ooo`3oool0003o1`3oool0103o0000oooo0?ooo`3o00090?oo
o`80003o2P3oool00`3o0000oooo0?ooo`070?ooo`<0o`008`3oool20000
03h0oooo001]0?ooo`@00000103oool00`000000o`000?l000030?l000@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`1V0?ooo`@0o`0000<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`070?ooo`80003o2P3oool00`3o0000
oooo0?l000080?ooo`<0003o203oool00`3o0000oooo0?ooo`020?ooo`80
o`005`3oool00`000000oooo0?ooo`0E0?ooo`<0o`00103oool00`3o0000
oooo0?ooo`060?ooo`80003o2@3oool20?l000/0oooo0P000?l90?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3o00000P3o001P0?ooo`00
M@3oool00`000000oooo0?l000020?l000D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`1R0?ooo`@0o`001@3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00D0oooo0P000?l00`3oool0003o0?ooo`0:0?ooo`030?l0
003oool0oooo00P0oooo0`000?l60?ooo`030?l0003oool0oooo00D0oooo
00<0o`000000o`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030?l0
00000?l0oooo00H0oooo00<0o`000?ooo`3oool01@3oool30000o`T0oooo
0P3o000:0?ooo`030000o`3oool0oooo0080003o1P3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo0080oooo103o001L0?ooo`00M03o
ool200000080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo05h0oooo103o00090?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool00P3oool20000o`@0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?l000080?ooo`050000o`3oool0oooo0?ooo`000?l0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0o`0000<0o`00
4@3oool00`000000oooo0?ooo`0@0?ooo`<0o`0000<0oooo0000o`3oool0
1`3oool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`00
0?l01`3oool0103o0000oooo0?ooo`3o00090?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00L0oooo103o001H0?ooo`00N03oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0FP3oool40?l00003
0?ooo`3o0000oooo00/0oooo00<0003o0?ooo`3oool0203oool01@3o0000
oooo0?ooo`3oool0003o00L0oooo00<0003o0?ooo`3oool01@3oool01@3o
0000oooo0?ooo`3oool0o`0000H0oooo00<0003o0?ooo`3oool00`3oool0
1@000?l0oooo0?ooo`3oool0o`0000P0oooo00<0003o0?ooo`3oool00`3o
ool40?l000d0oooo00<000000?ooo`3oool0303oool40?l000D0oooo00<0
003o0?ooo`3oool01@3oool0103o0000oooo0?ooo`3oool20000o`@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo
0?ooo`3oool0o`0000/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?l000030?l005@0oooo001h0?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`130?ooo`<0o`002`3oool90?l000D0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0
00000?l0003o00T0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
103oool20000o`030?ooo`3o0000oooo00L0oooo00<0003o0?ooo`3oool0
1@3oool0103o0000oooo0?l0003o000:0?ooo`<00?l0203oool50?l00003
0?ooo`3o0000oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
003o0000o`070?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0
oooo0P000?l00`3oool0o`000?ooo`090?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool00`3oool90?l000/0oooo0`000?lS0?ooo`@0
00005P3oool007P0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo02/0oooo5`00000?0?l00080000000<0003o000000000000
2P0000000`3o000000000000000:000000030000o`000000000000L00000
0P000?l;000000030000o`00000000000080000000<0o`00000000000000
1@0000001@3o00000000000000000000003o00T0000000<0o`000000o`00
00001P0000000`000?l0000000000005000000030?l00000000000000080
0000103o00000`000?l0o`000?l000020?l000D00?l01@3o00000`000?l0
o`0000000005000000030?l000000000000000H0000000<0003o00000000
00001@0000000`3o0000000000000007000000050000o`00000000000000
003o0000200000001@3o00000000000000000000003o00/000000P000?l:
000000030000o`000000000000T0000000<0o`000000000000002`000000
0`000?l000000?l000090?l000D0003o5`00000:0?ooo`040000003oool0
oooo000001L0oooo001h0?ooocL0003oA03oool50?l000`0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00D0oooo0P000?l20?ooo`030?l0003oool0oooo00T0oooo00@0003o
0?ooo`3o0000o`002@3oool00`3o0000oooo0000o`090?ooo`030?l0003o
ool0oooo0080003o1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool5003o00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00<0oooo0P000?l00`3oool0o`000?ooo`080?ooo`030000o`3o
ool0o`0000X0oooo00<0o`000?ooo`000?l02`3oool00`3o0000oooo0?oo
o`020000o`L0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00T0oooo1@000?lQ0?ooo`040000003o
ool0oooo000001L0oooo001h0?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`120?ooo`D0o`00303oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool00`3o
ool20000o`@0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3o0000oooo00P0oooo00<0o`000?ooo`3oool00P3o
ool20000o`80oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00<0oooo1@00o`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool010000?l0oooo0?oo
o`3oool20000o`@0oooo00<0o`000?ooo`3oool01P3oool00`3o0000003o
0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0
0P3oool20000o`D0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00T0oooo1@000?lP0?ooo`800000
00<0oooo0000000000005`3oool007P0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo04<0oooo0`3o000=0?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool01@000?l0oooo0?oo
o`3oool0003o00L0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0000o`0:0?ooo`040000o`3oool0oooo0?l000L0oooo00<0o`000?ooo`3o
ool01@3oool30000o`P0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`040?ooo`<00?l01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo0`000?l60?ooo`030?l0003oool0oooo00D0
oooo00@0o`000?ooo`3oool0003o2P3oool010000?l0oooo0?l0003o0009
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02`3oool30000ocd0oooo001h0?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`140?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?oo
o`040000o`3oool0003o0000o`T0oooo00<0o`000?ooo`3oool01P3oool0
1@3o0000oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00L0oooo0P00
0?l70?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool20000o`T0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00L0oooo0P000?l00`3oool0003o0?ooo`0;0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0l0?ooo`00N03oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0A03oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool02P3oool20000o`/0oooo00<0o`00
0?ooo`3oool0103oool20?l000D0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`80o`000`3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00@0003o0P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo0`000?l2
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool20?l000D0oooo00<0o`000?ooo`3oool02@3oool3
0000o`/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo03`0oooo001h0?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`140?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`070?oo
o`<0003o00<0oooo0000o`3oool02`3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`060?ooo`<0o`002P3oool00`000?l0oooo0?ooo`040?oo
o`80003o00<0o`000000o`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool20000
o`040?l000000?l0003o0000o`D0oooo00<0003o0?ooo`3oool01`3oool0
103o0000oooo0?l0003o00070?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0o`0000`0oooo
00<0003o0?ooo`3oool00`000?l80?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0l0?ooo`00N03o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0A03o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0103oool20000o`@0oooo00<0003o0?ooo`3oool02`3o
ool0103o0000oooo0?ooo`3o000:0?ooo`050000o`3oool0oooo0?ooo`00
0?l02`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`000?l00P000?l40?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`80
003o0P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3o00003@3oool00`000?l0
oooo0?ooo`030?ooo`80003o1P3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0?03oool007P0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo04@0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo0080oooo0P000?l70?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3o0000303oool00`000?l0oooo0000o`0;0?ooo`040?l0
003oool0o`000?l000L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`030?ooo`T0003o0`3oool0103o0000oooo0?ooo`3oool:0000
o`@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?oo
o`80o`002`3oool010000?l0oooo0?ooo`000?l<0?ooo`80o`00303oool0
0`000?l0oooo0?ooo`060?ooo`80003o0`3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0?03oool0
07P0oooo=`3o00160?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool0303oool0103o0000oooo0000o`000?l90?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0:
0?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00P3o
ool30000o`030?l000000?l0003o0080003o103oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0103o
ool20?l00080oooo00<0o`000?ooo`3oool02@3oool20000o`d0oooo0P3o
000<0?ooo`030000o`3oool0oooo00P0oooo0P000?l00`3oool0o`000?oo
o`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0?03o
ool007P0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo04D0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`<0003o303oool00`000?l0oooo0?ooo`080?ooo`80o`0000<0oooo
0?l0003oool02`3oool00`000?l0oooo0000o`0:0?ooo`030?l0003oool0
oooo00<0oooo0P3o00030?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo0080oooo0P3o00040?ooo`030?l0003oool0
oooo00P0oooo0`000?l<0?ooo`040?l0003oool0oooo0?l000X0oooo00<0
003o0?ooo`3oool02`3oool30000o``0oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0l0?ooo`00N03oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0A@3oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00D0oooo1@000?l20?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00T0oooo00@0003o0?ooo`3oool0003o203o
ool00`3o0000oooo0?ooo`060?ooo`80o`0000<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00@0003o0?ooo`3o0000o`001`3oool00`3o0000oooo
0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l02P3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`040000o`P0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0l0?ooo`00N03oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0A@3oool00`3o0000oooo
0?ooo`0=0?ooo`040000o`3oool0oooo0?ooo`@0003o1`3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00@0oooo0P3o00060?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00P0oooo00<0003o0?l0003o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000000o`3o00002@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`040?ooo`80o`001P3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00@0oooo10000?l30?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0?03oool007P0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo04D0oooo
00<0o`000?ooo`3oool03@3oool010000?l0oooo0000o`000?l<0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo0P000?l60?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?l000020?l000D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`030?ooo`<0o`000P3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo0P3o00040?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0203oool20000o`030?ooo`000?l0oooo00l0oooo00<0o`000?ooo`3o
ool0?03oool007P0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo04D0oooo00<0o`000?ooo`3oool02`3oool40000o`h0oooo
00<0o`000?ooo`3oool0303oool010000?l0oooo0?l0003o000;0?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool20000o`80
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`030?ooo`D0
o`002P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?l000020?l000D0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`020000o`T0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`090?ooo`80
o`0000<0oooo0000o`3oool03@3oool00`3o0000oooo0?ooo`0;0?ooo`@0
003o3P3oool00`3o0000oooo0?ooo`0l0?ooo`00N03oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0A@3oool00`3o0000oooo
0?ooo`060?ooo`D0003o0`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo0P3o000>0?ooo`040?l0003oool0oooo0000o``0
oooo00<0003o0?ooo`3o00002`3oool00`000?l0oooo0?ooo`070?ooo`<0
o`00203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01P3oool30?l000T0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0000o`0<0?ooo`050000o`3oool0oooo0?oo
o`3o00003P3oool00`3o0000003o0?ooo`0=0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool01@000?l90?ooo`030?l0003oool0oooo
03`0oooo001h0?ooocL0003oA`3oool0103o0000oooo0?ooo`3oool50000
o`P0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0:0?oo
o`030?l0003oool0003o00l0oooo00<0o`000000o`3oool03@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool00`3o00040?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`<0o`0000<0oooo0?l0
003oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3o00003`3oool00`000?l0o`000?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool01P3oool60000
o`<0oooo00<0o`000?ooo`3oool0?03oool007P0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo04D0oooo10000?l=0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool02@3oool01@3o0000
oooo0?ooo`3oool0003o00h0oooo00<0003o0?ooo`3oool0303oool0103o
0000oooo0000o`000?l90?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool0103oool40?l000030000o`3o0000oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0o`000?l000030?l000@0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`80003o00<0oooo
0?l0003oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0
oooo0080o`002`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo0`000?lo0?ooo`00N03oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool0A@3oool00`3o0000oooo0?ooo`0?0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo00<0003o0?oo
o`3o00003@3oool0103o0000oooo0?ooo`3oool20000o`H0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
o`000140o`0000<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00@0oooo0P000?l30?ooo`030?l0003oool0
oooo00/0oooo00<0o`000?ooo`000?l03P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo03d0oooo001h0?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`150?oo
o`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`050?ooo`80o`001P3oool00`000?l0oooo0?ooo`0:0?oo
o`040000o`3oool0oooo0?l000/0oooo00<0o`000?ooo`3oool0103oool2
0000o`@0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00@0003o
0?ooo`3oool0oooo0P000?l60?ooo`030?l0003oool0oooo00X0oooo00@0
o`000?ooo`3oool0003o303oool00`000?l0oooo0?ooo`040?ooo`80o`00
1`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00l0oooo
00<0o`000?ooo`3oool0?@3oool007P0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo04D0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0080oooo0P3o
00090?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo0P00
0?l00`3oool0003o0?ooo`0:0?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool010000?l0oooo0?oo
o`000?l90?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo
0P3o00040?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`0m0?ooo`00N03oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0AP3oool00`3o0000oooo0?oo
o`0?0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool00P3o
000;0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0103o
ool20?l000L0oooo00<0o`000?ooo`3oool02@3oool20000o`X0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`090?ooo`80003o2`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0:0?ooo`80o`000P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?ooo`3oool0?@3oool007P0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo04H0oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0=0?ooo`<0o`003P3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0:0?ooo`040000o`3oool0
003o0000o`P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`070?ooo`<0003o3@3oool00`3o0000oooo0?oo
o`030?ooo`80o`00203oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo00`0oooo0P3o000?0?ooo`030000o`3oool0oooo0100oooo00<0
o`000?ooo`3oool0?@3oool007P0oooo=`3o00180?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool02`3oool20?l000030?ooo`3o0000
oooo00l0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`09
0?ooo`050?l0003oool0oooo0?ooo`3o00003@3oool010000?l0oooo0?oo
o`3oool30000o`D0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`040?ooo`<0003o0P3oool00`000?l0oooo
0?ooo`0<0?ooo`050?l0003oool0oooo0?ooo`3o00002`3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00h0oooo0`3o000=0?ooo`03
0000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0?@3oool007P0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo04H0oooo
00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`090?ooo`80o`00
103oool00`3o0000oooo0?ooo`0>0?ooo`050000o`3oool0oooo0?ooo`00
0?l03@3oool20?l000030?ooo`3o0000oooo00/0oooo00<0003o0?ooo`3o
ool01@3oool30000o`030?ooo`3o0000oooo00X0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0
oooo00@0o`000?ooo`3oool0oooo0P000?l60?ooo`030000o`3oool0oooo
00/0oooo00@0o`000?ooo`3oool0o`003@3oool01@000?l0oooo0?ooo`3o
ool0003o0100oooo00@0o`000?ooo`3oool0oooo0P3o000;0?ooo`030000
o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0?P3oool007P0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo04H0oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`060?ooo`80o`001P3o
ool00`3o0000oooo0?ooo`0?0?ooo`<0003o403oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?l0003oool02P3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool02@3oool0103o0000oooo0000o`000?l80?ooo`030000
o`3oool0oooo00`0oooo0P3o000?0?ooo`030000o`3oool0003o0100oooo
00<0o`000?ooo`3oool0103oool20?l000P0oooo00<0003o0?ooo`3oool0
403oool00`3o0000oooo0?ooo`0n0?ooo`00N03oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0AP3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo00@0oooo0P3o00090?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool03`3oool0103o0000oooo0?l0
003o000:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000000o`000?l0
2@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0203oool00`000?l0o`000000o`0;0?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3o0000403oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0003oool0oooo00H0oooo0P3o00060?ooo`030000
o`3oool0oooo0100oooo00<0o`000?ooo`3oool0?P3oool007P0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo04L0oooo00<0
o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00T0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0000
o`0?0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`090?ooo`040?l0003oool0oooo0?ooo`L0003o
0P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool01`000?l00`3oool0o`000?ooo`0;0?ooo`030000
o`3oool0oooo00P0oooo0P3o00020?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`000?l03`3oool00`3o0000oooo0?ooo`090?ooo`80o`00
103oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo03h0oooo
001h0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`170?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool00P3o
000=0?ooo`030?l0003oool0oooo00/0oooo00D0003o0?ooo`3oool0oooo
0000o`0=0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00P0oooo
10000?l90?ooo`030?l0003oool0oooo00L0oooo1@000?l90?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool01@3oool20?l000D0oooo
00<0o`000?ooo`3oool02`3oool010000?l0oooo0?ooo`3oool20000o``0
oooo00<0o`000?ooo`3oool0303oool20?l00080oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0n0?ooo`00N03oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0A`3oool00`3o0000oooo
0?ooo`0@0?ooo`<0o`00403oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`060?ooo`80o`00103oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`000?l020000?l00`3o0000003o
0000o`070000o`80oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo0P3o00080?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00l0oooo0`3o000A0?ooo`030?l0
003oool0oooo03l0oooo001h0?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`170?ooo`030?l0003oool0oooo00d0oooo0`3o
00000`3oool0003o0?ooo`0@0?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00T0oooo00D0o`000?ooo`3oool0oooo0000o`0=0?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2`3oool01@000?l0oooo0?ooo`3oool0o`0000X0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0403oool010000?l0oooo0?l0003o000?0?oo
o`030?l0003oool0oooo03l0oooo001h0?ooocL0003oBP3oool00`3o0000
oooo0?ooo`090?ooo`<0o`00103oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo00D0oooo0P000?l90?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool02P3oool20?l000030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0:0?ooo`040000o`3oool0o`000?l000`0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`020?oo
o`<0o`00303oool00`3o0000oooo0?ooo`0o0?ooo`00N03oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0B03oool00`3o0000
oooo0?ooo`060?ooo`<0o`00203oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool02P3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00d0oooo00<0003o0?l0003o
ool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00X0oooo00<0o`000000o`3oool03P3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00D0
oooo0`3o00080?ooo`030?l0003oool0oooo0400oooo001h0?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`180?ooo`030?l0
003oool0oooo00<0oooo0`3o000;0?ooo`030000o`3oool0oooo0100oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<0?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`020?l000X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`070?ooo`80o`0000<0oooo0000o`3oool0
3`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00`0oooo
0P000?l30?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
2@3oool30?l000D0oooo00<0o`000?ooo`3oool0@03oool007P0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo04P0oooo00<0
o`000?ooo`3oool00`3o000?0?ooo`030000o`3oool0oooo0100oooo00@0
o`000?ooo`000?l0003o403oool010000?l0oooo0?ooo`3o000@0?ooo`03
0000o`3oool0oooo0080oooo0`3o00060?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool01@3oool20?l000@0
oooo00<0003o0?ooo`3oool03@3oool01@3o0000oooo0?ooo`3oool0003o
0140oooo0P000?l00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
00`0oooo0`3o00020?ooo`030?l0003oool0oooo0400oooo001h0?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`190?ooo`80
o`004P3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0003o0?ooo`3o00003`3oool00`000?l0oooo0?ooo`060?ooo`80
o`00103oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00<0oooo0P3o00060?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`000?l04`3oool00`3o0000003o0?ooo`0A0?ooo`03
0000o`3oool0oooo0100oooo0P3o00130?ooo`00N03oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0B@3oool00`3o0000oooo
0?ooo`0B0?ooo`030000o`3oool0oooo00h0oooo0P000?l00`3oool0o`00
0?ooo`0B0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
203oool40?l000d0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o0000
0P3o00090?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
4P3oool00`3o0000oooo0000o`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool0@@3oool007P0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo04T0oooo00<0o`000?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`0<0?ooo`80003o0`3oool00`3o0000oooo0?oo
o`0@0?ooo`030?l0003oool0003o00h0oooo00<0003o0?ooo`3oool0303o
ool20?l000`0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00/0oooo0P3o000=0?ooo`030000o`3o
ool0oooo00`0oooo00<0003o0?ooo`3o00004P3oool0103o0000oooo0?oo
o`3oool20000o`h0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo
0?ooo`110?ooo`00N03ooolg0?l004`0oooo00<0o`000?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool03P3oool0103o0000oooo0?ooo`3oool20000o``0oooo
00<0003o0?ooo`3oool0303oool0103o0000oooo0?l0003o000:0?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`090?ooo`<0o`003P3oool00`000?l0oooo0?ooo`0:0?ooo`80
003o0`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0480oooo001h0?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`1:0?ooo`030?l0003oool0oooo0180oooo
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00`0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`080?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
0P3oool30?l000L0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00@0oooo103o00030?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00d0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0180oooo
00<0o`000?ooo`3oool0@P3oool007P0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo04/0oooo00<0o`000?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`050?ooo`D0o`000P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool0103o00070?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool01`3o
ool20000o`T0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?oo
o`120?ooo`00N03oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0B`3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo0P000?l60?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool02P3oool20?l000030000o`3o0000
o`0000@0o`001P3oool00`3o0000oooo0?ooo`040?ooo`L0o`0000<0003o
0?l0003o0000303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00@0oooo0P000?l:0?ooo`030?l0003oool0oooo00T0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo01<0oooo00<0o`000?ooo`3oool0@P3oool007P0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo04/0oooo00<0o`000?oo
o`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00@0oooo3@3o00070?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool01`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`130?oo
o`00N03oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0C03oool00`3o0000oooo0?ooo`0C0?ooo`040000o`3oool0oooo0?oo
o`80003o403oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo
00`0oooo0P000?l20?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo0080003o3`3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo00h0oooo0P000?l30?ooo`030000o`3oool0oooo
01<0oooo00<0o`000?ooo`3oool0@`3oool007P0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool010000?l0
oooo0?ooo`3oool2000000030?l000000000000004`0oooo00<0o`000?oo
o`3oool04`3oool010000?l0oooo0000o`000?lC0?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool03`3oool20000oa00oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=
0?ooo`80003o4P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0
oooo0140oooo0`000?lF0?ooo`030?l0003oool0oooo04<0oooo001h0?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`1<0?oo
o`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0503oool01@3o
0000oooo0?ooo`3oool0o`0001<0oooo0`000?l=0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool2
0000o`030?ooo`000?l0oooo0180oooo00D0o`000?ooo`3oool0oooo0?l0
000F0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0A03o
ool007P0oooo=`000?m?0?ooo`030?l0003oool0oooo0140oooo0P000?l0
0`3oool0003o0?ooo`0E0?ooo`030?l0003oool0o`0001<0oooo00@0003o
0?ooo`3oool0oooo0P000?l;0?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool02@3oool20000o`<0oooo00<0
003o0?ooo`3oool04P3oool00`3o0000oooo0?l0000F0?ooo`040000o`3o
ool0003o0000oa<0oooo00<0o`000?ooo`3oool0A03oool007P0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo04d0oooo00<0
o`000?ooo`3oool03`3oool20000o`<0oooo00<0003o0?ooo`3oool05@3o
ool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00<0oooo0P00
0?l90?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool01`3oool20000o`H0oooo00<0003o0?ooo`3oool04P3o
ool00`3o0000oooo0?ooo`0E0?ooo`040000o`3oool0oooo0?ooo`80003o
4@3oool00`3o0000oooo0?ooo`140?ooo`00N03oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0CP3oool00`3o0000oooo0?oo
o`0<0?ooo`80003o1P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003o
ool0o`000180oooo00<0003o0?ooo`3oool01P3oool20000o`L0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`040?ooo`80003o203oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0o`0001D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo04D0oooo001h0?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00P3oool00`000000o`000?ooo`1?0?ooo`030?l0003oool0
oooo00X0oooo0P000?l80?ooo`030000o`3oool0oooo0180oooo00D0o`00
0?ooo`3oool0oooo0?l0000A0?ooo`030000o`3oool0oooo00P0oooo0`00
0?l30?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool00P3oool20000o`/0oooo00<0003o0?ooo`3oool03`3o
ool01@3o0000oooo0?ooo`3oool0o`0001<0oooo00<0003o0?ooo`3oool0
1P3oool20000o`d0oooo00<0o`000?ooo`3oool0A@3oool007P0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo04l0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00`0oooo0P000?l00`3oool0o`000?oo
o`0>0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0=0?ooo`040?l0003oool0003o0000o`h0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool0203oool20000o`X0oooo
00<0o`000?ooo`3oool0AP3oool007P0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`020?ooo`<00?l0203oool2000000030?ooo`000000000004<0oooo00<0
o`000?ooo`3oool01P3oool20000o`d0oooo00<0003o0?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`040?ooo`80o`00303oool00`000?l0oooo0?oo
o`0?0?ooo`030000o`3o0000003o00h0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo00<0
003o0?l000000?l0403oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0;0?ooo`80003o203oool00`3o0000oooo0?ooo`160?ooo`00N03oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`040000o`3oool0oooo0?ooo`D00?l0203oool00`000000oooo0000
00150?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0@0?ooo`040?l0003o
ool0003o0000o``0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo0P000?l00`3oool0o`00
0?ooo`0A0?ooo`030000o`3oool0oooo00T0oooo0P3o00080?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo04L0oooo001c0?ooo`D00000=03o
0005003o00@000001@3oool00`000000oooo0?ooo`140?ooo`030?l0003o
ool0oooo0080oooo0P000?lA0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo0100oooo00<0o`000?ooo`3oool00P3oool40000o`L0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo00D0oooo10000?l40?ooo`030?l0003oool0oooo0100oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool0403oool20000o`@0oooo00<0
o`000?ooo`3oool0A`3oool007P0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?ooo`3o
ool5003o00L0oooo0P0000000`3oool00000000000150?ooo`040?l0003o
ool0003o0000oa@0oooo00<0003o0?ooo`3oool02@3oool20?l000d0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo00H0oooo1@000?l20?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`050000o`P0oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0B0?ooo`80003o00<0oooo0?l0003oool0B@3oool007P0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`020?ooo`<00?l0DP3oool20000oaL0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0<0?ooo`D0003o3@3oool00`3o0000oooo0?ooo`0=0?ooo`@0003o3P3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo01D0oooo0P000?m:0?ooo`00N03oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0DP3oool00`3o0000oooo0?ooo`0F
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0403oool2
0?l000<0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00H0003o1`3oool00`3o0000oooo0?ooo`05
0?ooo`P0003o00<0oooo0000o`3oool03`3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo01H0oooo00<0o`00
0?ooo`3oool0B@3oool007P0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo0580oooo00<0o`000?ooo`3oool05`3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo01<0oooo00@0o`000?oo
o`3oool0003o4P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo00H0oooo1`000?l00`3o0000003o0000o`050000o`T0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0080o`004`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo01L0oooo00<0o`000?ooo`3oool0B@3oool007P0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo05<0oooo00<0o`000?oo
o`3oool05`3oool01@000?l0oooo0?ooo`3oool0o`0001L0oooo00<0o`00
0000o`3oool04P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0?
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?l0003oool05@3oool2
0?l000<0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`1:
0?ooo`00N03oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0D`3oool00`3o0000oooo0?ooo`0G0?ooo`040000o`3oool0oooo
0?l001P0oooo00<0003o0?l0003o00004@3oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0100oooo00<0o`00
0000o`3oool0603oool00`3o0000oooo0000o`0J0?ooo`030?l0003oool0
oooo04X0oooo001h0?ooocL0003oEP3oool00`3o0000oooo0?ooo`0G0?oo
o`030000o`3o0000oooo01P0oooo00@0003o0?ooo`3oool0o`00403oool0
0`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo00d0oooo0P3o00020?ooo`030000o`3oool0oooo01L0oooo00<0o`00
0000o`3oool0603oool00`3o0000oooo0?ooo`1;0?ooo`00N03oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0E03oool00`3o
0000oooo0?ooo`0G0?ooo`030?l000000?l0oooo01L0oooo00<0003o0?oo
o`3oool00P3oool20?l000d0oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`0;0?ooo`80o`00103oool00`00
0?l0oooo0?ooo`0G0?ooo`030000o`3o0000oooo01P0oooo00<0o`000?oo
o`3oool0B`3oool007P0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo05D0oooo00<0o`000?ooo`3oool05@3oool0103o0000
oooo0?ooo`000?lF0?ooo`030000o`3oool0oooo00D0oooo0P3o000;0?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool02@3oool20?l000L0oooo00<0003o0?ooo`3oool05@3oool01000
0?l0oooo0?ooo`3o000G0?ooo`030?l0003oool0oooo04`0oooo001h0?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`1F0?oo
o`030?l0003oool0oooo0180oooo0P3o00040?ooo`030000o`3oool0oooo
01<0oooo00<0003o0?ooo`3oool01`3oool20?l000P0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00l0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`060?oo
o`80o`002@3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool04`3oool00`3o0000oooo0?ooo`1=0?oo
o`00N03oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0EP3oool00`3o0000oooo0?ooo`0A0?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0:0?ooo`80
o`001P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo00@0oooo0P3o000<0?ooo`030000o`3oool0oooo0180
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0B0?ooo`03
0?l0003oool0oooo04d0oooo001h0?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`1G0?ooo`030?l0003oool0oooo00l0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00d0oooo0P3o00040?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo00l0oooo00<0o`000?ooo`3oool00P3oool20?l000l0oooo
00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo0100oooo00<0o`000?ooo`3oool0CP3oool007P0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo05P0oooo00<0
o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00d0oooo00<0003o0?ooo`3oool0403oool20?l000030?ooo`3o
0000oooo0180oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0100oooo00@0o`000?ooo`3o0000o`00
4P3oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`1?0?ooo`00N03o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0F03o
ool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0B0?ooo`80o`004`3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0100oooo00<0
003o0?ooo`3oool0403oool20?l001@0oooo00<0003o0?ooo`3oool0303o
ool20000o``0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?oo
o`1?0?ooo`00N03ooolg0?l005/0oooo00<0o`000?ooo`3oool02@3oool2
0?l000l0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0D
0?ooo`<0o`004@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool03P3oool30?l001H0oooo00<0003o
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`80o`00303oool0
0`3o0000oooo0?ooo`1@0?ooo`00N03oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool0F@3oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0203oool00`00
0?l0oooo0?ooo`0D0?ooo`040?l0003oool0oooo0?ooo`80o`003`3oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool0303oool20?l000<0oooo00<0o`000?ooo`3oool0503oool0
0`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0100oooo00<0o`00
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`1@0?ooo`00N03oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0FP3oool00`3o
0000oooo0?ooo`060?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo
00<0oooo1@3o00090?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`070?ooo`@0o`001@3oool00`3o
0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool04P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
0540oooo001h0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`1K0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool0503oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01D0
oooo00<0o`000?ooo`3oool0203oool50?l000@0oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0080
oooo1@3o000:0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0D0?ooo`80o`001P3oool00`3o0000
oooo0?ooo`1B0?ooo`00N03oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0F`3oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo01H0oooo0P000?l40?ooo`030000o`3oool0oooo01D0oooo
00<0o`000?ooo`3oool03P3oool30?l000030?ooo`000?l0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?l000020?l000l0oooo
00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo01L0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`1B0?ooo`00N03oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0G03oool00`3o0000oooo0?ooo`020?l001/0oooo00@0
003o0?ooo`3oool0003o603oool00`3o0000oooo0?ooo`0A0?ooo`040?l0
00000?l0o`000?l00100oooo00<0o`000?ooo`3oool03@3oool40?l00003
0000o`3o0000oooo0180oooo00<0o`000?ooo`3oool05@3oool00`000?l0
oooo0?ooo`020000oa/0oooo00D0o`000?ooo`3oool0oooo0?l0001E0?oo
o`00N03oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0G@3oool20?l001h0oooo00<0003o0?ooo`000?l0603oool00`3o0000
oooo0?ooo`0B0?ooo`030000o`3oool0oooo00T0o`001`3oool00`3o0000
oooo0?ooo`070?ooo`H0o`00103oool00`000?l0oooo0?ooo`0B0?ooo`03
0?l0003oool0oooo01D0oooo00<0003o0?ooo`000?l07P3oool30?l005H0
oooo001h0?ooocL0003oG`3oool00`3o0000oooo0?ooo`0N0?ooo`80003o
5`3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00X0oooo
4@3o000:0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0
5@3oool00`000?l0oooo0?ooo`0N0?ooo`80o`00EP3oool007P0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo05h0oooo00<0
o`000?ooo`3oool0703oool010000?l0oooo0?ooo`000?lF0?ooo`030?l0
003oool0oooo0180oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0
4`3oool20000o`030?ooo`000?l0oooo01d0oooo00<0o`000?ooo`3oool0
EP3oool007P0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo05l0oooo00<0o`000?ooo`3oool06`3oool01@000?l0oooo0?oo
o`3oool0003o01@0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0
4`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`1F0?ooo`00N03o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0H03o
ool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo00<0oooo0P00
0?lB0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool04P3o
ool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo01<0oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo01X0oooo00<0o`000?ooo`3oool0E`3oool007P0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0640oooo00<0o`00
0?ooo`3oool05`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0B
0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0503oool0
0`3o0000oooo0?ooo`0=0?ooo`80003o1`3oool00`000?l0oooo0?ooo`0H
0?ooo`030?l0003oool0oooo05P0oooo001h0?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`1Q0?ooo`030?l0003oool0oooo
01L0oooo00<0003o0?ooo`3oool01`3oool20000o`h0oooo00<0o`000?oo
o`3oool04`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo
0180oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool05P3oool00`3o
0000oooo0?ooo`1I0?ooo`00N03oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0HP3oool00`3o0000oooo0?ooo`0E0?ooo`03
0000o`3oool0oooo00X0oooo0P000?l;0?ooo`030?l0003oool0oooo01@0
oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0B0?ooo`03
0000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool02P3oool20000o``0
oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`1J0?ooo`00
N03ooolg0?l006D0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo
0?ooo`0=0?ooo`80003o2@3oool00`3o0000oooo0?ooo`0D0?ooo`030000
o`3oool0oooo0180oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo
0?ooo`0D0?ooo`030?l0003oool0oooo00L0oooo0P000?l?0?ooo`030000
o`3oool0oooo0180oooo00<0o`000?ooo`3oool0F`3oool007P0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo06@0oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?oo
o`0C0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0503o
ool00`3o0000oooo0?ooo`050?ooo`80003o4P3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo05/0oooo001h0?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`1U0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool04P3oool20000o`D0oooo00<0o`00
0?ooo`3oool0503oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0
oooo01<0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`02
0?ooo`80003o503oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo05`0oooo001h0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`1V0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool05@3oool20000o`80oooo00<0o`000?ooo`3oool05@3oool00`00
0?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?oo
o`3oool05@3oool00`3o0000oooo0?ooo`020000oaL0oooo00<0003o0?oo
o`3oool03P3oool00`3o0000oooo0?ooo`1M0?ooo`00N03oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0IP3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo01P0oooo0P000?l00`3o0000
oooo0?ooo`0E0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3o
ool0503oool00`000?l0oooo0?ooo`0E0?ooo`030?l000000?l0oooo01T0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`1N0?ooo`00
N03oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
I`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo01X0oooo
00<0o`000000o`000?l05P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0
003oool0oooo01@0oooo00<0003o0?ooo`3oool04`3oool20000o`030?l0
003oool0oooo01X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`1O0?ooo`00N03oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0J03oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo01/0oooo00<0o`000?ooo`3oool00P000?lD0?ooo`030000o`3o
ool0oooo01<0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?oo
o`0A0?ooo`80003o0`3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0H03oool007P0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo06T0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0
oooo00<0oooo0`000?l@0?ooo`030000o`3oool0oooo01@0oooo00<0o`00
0?ooo`3oool0503oool00`000?l0oooo0?ooo`0?0?ooo`80003o1@3oool0
0`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool0H@3oool007P0oooo=`000?m/0?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`060?oo
o`<0003o3@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo
01@0oooo00<0003o0?ooo`3oool0303oool30000o`L0oooo00<0o`000?oo
o`3oool0703oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
0680oooo001h0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`1[0?ooo`80o`00103oool00`000?l0oooo0?ooo`0K0?ooo`03
0?l0003oool0oooo00X0oooo10000?l90?ooo`030000o`3oool0oooo01@0
oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`070?ooo`@0
003o2`3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0H`3oool007P0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo06d0oooo00@0o`000?ooo`3oool0
003o7P3oool00`3o0000oooo0?ooo`0>0?ooo`<0003o1P3oool00`000?l0
oooo0?ooo`0D0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3o
ool0103oool30000o`l0oooo00<0o`000?ooo`3oool0703oool00`000?l0
oooo0?ooo`020?l006H0oooo001h0?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`1^0?ooo`030?l0003oool0003o01d0oooo
00<0o`000?ooo`3oool04P3oool40000o`030?ooo`000?l0oooo01H0oooo
00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`040000oa<0oooo
00<0o`000?ooo`3oool0703oool00`000?l0o`000?ooo`1W0?ooo`00N03o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0K`3o
ool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo01H0oooo1000
0?lE0?ooo`030?l0003oool0oooo01@0oooo10000?lG0?ooo`030?l0003o
ool0oooo01`0oooo00<0o`000000o`3oool0I`3oool007P0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0700oooo0P3o000K
0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool010000?lA
0?ooo`030?l0003oool0oooo0100oooo10000?l00`3oool0003o0?ooo`0H
0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0J03oool0
07P0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0780oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?ooo`0G0?oo
o`030000o`3oool0oooo00D0oooo1`000?l:0?ooo`030?l0003oool0oooo
00T0oooo1`000?l50?ooo`030000o`3oool0oooo01P0oooo00<0o`000?oo
o`3oool06@3oool00`3o0000oooo0?ooo`1Y0?ooo`00N03ooolg0?l007D0
oooo00<0o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`0H0?ooo`03
0000o`3oool0oooo00`0oooo2P000?l00`3o0000003o0000o`090000o`d0
oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0H0?ooo`03
0?l0003oool0oooo06X0oooo001h0?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`1d0?ooo`80o`005P3oool00`3o0000oooo
0?ooo`0H0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool0
5P3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo01H0oooo
00<0o`000?ooo`3oool0J`3oool007P0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo07H0oooo00<0o`000?ooo`3oool04P3o
ool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01H0oooo00<0
o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003o
ool0oooo01@0oooo0P3o001^0?ooo`00N03oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0M`3oool00`3o0000oooo0?ooo`0A
0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool05`3oool0
0`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01T0oooo00<0o`00
0?ooo`3oool04P3oool00`3o0000oooo0?ooo`1^0?ooo`00N03oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0N03oool00`3o
0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?oo
o`3oool05`3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo
01P0oooo00<0o`000?ooo`3oool0403oool20?l00740oooo001h0?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`1i0?ooo`80
o`003`3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01L0
oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0I0?ooo`03
0?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0L@3oool007P0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo07/0oooo
00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0J0?ooo`030000
o`3oool0oooo01L0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo
0?ooo`0J0?ooo`030?l0003oool0oooo00/0oooo0P3o001d0?ooo`00N03o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0O03o
ool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01X0oooo00<0
003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3o
ool0oooo01T0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?oo
o`1d0?ooo`00N03ooolg0000ogl0oooo0P3o00090?ooo`030?l0003oool0
oooo01X0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3oool01`3oool2
0?l007L0oooo001h0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`1o0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?oo
o`3oool06P3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo
01P0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo07L0oooo001h0?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`200?ooo`80o`001@3oool00`3o0000
oooo0?ooo`0K0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3o
ool06@3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo00<0
oooo0P3o001j0?ooo`00N03oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0PP3oool20?l000<0oooo00<0o`000?ooo`3oool0
6`3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo01T0oooo
00<0003o0?ooo`3oool06`3oool01@3o0000oooo0?ooo`3oool0o`0007`0
oooo001h0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`240?ooo`<0o`007@3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0
003oool0oooo01T0oooo00<0003o0?ooo`3oool06`3oool0103o0000oooo
0?l0003o001m0?ooo`00L`3oool4000000<0003o1@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo08H0oooo0P3o000L0?ooo`030000o`3oool0oooo01T0oooo
00<0o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0J0?ooo`80o`00
O`3oool007D0oooo00<000000000o`000?l00`000?l40?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0R03oool20?l001X0oooo00<0003o0?ooo`3oool06@3o
ool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo01P0oooo0P3o
00210?ooo`00M@3oool00`000000003o0000o`030000oc@0o`00S03oool2
0?l001P0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0J
0?ooo`030000o`3oool0oooo01H0oooo0P3o00230?ooo`00M@3oool00`00
0000003o0000o`030000ol80oooo0P3o000F0?ooo`030000o`3oool0oooo
01T0oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0C0?oo
o`<0o`00Q@3oool007D0oooo00<000000?ooo`000?l00P000?o50?ooo`80
o`004`3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo01/0
oooo00<0003o0?ooo`3oool0403oool20?l008P0oooo001d0?ooo`800000
0P3oool00`000000oooo0?ooo`360?ooo`<0o`00403oool00`000?l0oooo
0?ooo`0J0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool0
3P3oool20?l008X0oooo001h0?ooo`030000003oool0oooo0<T0oooo0`3o
000=0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3oool06`3o
ool00`000?l0oooo0?ooo`0<0?ooo`80o`00S03oool007P0oooo00<00000
0?ooo`3oool0c03oool30?l000X0oooo00<0003o0?ooo`3oool06P3oool0
0`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00T0oooo0`3o002>
0?ooo`00N03oool00`000000oooo0?ooo`3?0?ooo`<0o`001`3oool00`00
0?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?oo
o`3oool01P3oool30?l00940oooo003o0?ooodh0oooo0`3o00030?ooo`03
0000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool0703oool010000?l0
oooo0?ooo`3oool40?l009@0oooo003o0?oooe40oooo0`3o00000`000?l0
oooo0?ooo`0K0?ooo`030?l0003oool0oooo01`0oooo00@0003o0?l0003o
0000o`00V03oool00?l0ooooE03oool00`000?l0o`000?l000020?l001T0
oooo00<0o`000?ooo`3oool05`3oool50?l000030000o`3oool0oooo09T0
oooo001f0?ooo`800000h03oool50?l000`0oooo1@0000030?ooo`030?l0
003oool0oooo0140oooo1P3o002Q0?ooo`00M`3oool00`000000oooo0?oo
o`3S0?ooo`D0o`002@3oool00`000000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00`0oooo1@3o002W0?ooo`00N03oool00`000000oooo0?ooo`3W
0?oooah0o`00[03oool007L0oooo00<000000?ooo`000000l@3oool00`00
0000oooo0?ooo`2n0?ooo`00MP3oool010000000oooo0?ooo`00003a0?oo
o`030000003oool0oooo0;h0oooo001e0?ooo`<0000000<0oooo00000000
0000k`3oool200000<00oooo003o0?ooool0oooo;P3oool00?l0ooooo`3o
ool^0?ooo`00o`3ooooo0?ooobh0oooo003o0?ooool0oooo;P3oool00?l0
ooooo`3oool^0?ooo`00o`3ooooo0?ooobh0oooo003o0?ooool0oooo;P3o
ool00?l0ooooo`3oool^0?ooo`00o`3ooooo0?ooobh0oooo003o0?ooog40
oooo0P00002j0?ooo`00o`3oooma0?ooo`800000^P3oool00?l0ooooL03o
ool010000000oooo0?ooo`00002i0?ooo`00o`3ooom_0?ooo`8000000P3o
ool200000;P0oooo003o0?ooool0oooo;P3oool00?l0ooooo`3oool^0?oo
o`00o`3ooooo0?ooobh0oooo003o0?ooool0oooo;P3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{556, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  We use the implicit formula, Equation ",
  StyleBox["(10-18)",
    FontColor->RGBColor[0, 0, 1]],
  ", and write  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\((z\  - \ \((\(-\[ImaginaryI]\))\))\)\ \((1\  - \ \[ImaginaryI])\)\
\)\/\(\(\ \)\(\((z\  - \ \[ImaginaryI])\) \((1\  - \ \
\((\(-\[ImaginaryI]\))\))\)\)\)\  = \ \(\((w\  - \ \((\(-1\))\))\)\ \((0\  - \
\ 1)\)\)\/\(\((w\  - \ 1)\) \((0\  - \ \((\(-1\))\))\)\(\ \)\)\)]],
  " \n\n\t\t\t",
  Cell[BoxData[
      \(\(\((z\  + \ \[ImaginaryI])\)\ \((1\  - \ \[ImaginaryI])\)\)\/\(\((z\ \
 - \ \[ImaginaryI])\) \((1\  + \ \[ImaginaryI])\)\)\  = \ \(\((w\  + \ 1)\) \
\((0\  - \ 1)\)\)\/\(\((w\  - \ 1)\) \((0\  + \ 1)\)\)\)]],
  " \n\n\t\t\t",
  Cell[BoxData[
      \(\(\((z\  + \ \[ImaginaryI])\)\ \((1\  - \ \[ImaginaryI])\)\)\/\(\((z\ \
 - \ \[ImaginaryI])\) \((1\  + \ \[ImaginaryI])\)\)\  = \ \(\(\ \ \)\(w\  + \ \
1\)\)\/\(\(-\ w\)\  + \ 1\)\)]],
  ".   "
}], "Text"],

Cell[TextData[{
  "Expanding this equation, collecting terms involving w and zw on the left \
and then simplify.\n\n\t\t\t",
  Cell[BoxData[
      \(\((z\  - \ \[ImaginaryI])\) \((1\  + \ \[ImaginaryI])\) \((w\  + \ 
              1)\)\ \  = \ \ \(\((z\  + \ \[ImaginaryI])\)\(\ \)\((1\  - \ \
\[ImaginaryI])\) \((\(-\ w\)\  + \ 1)\)\(\ \)\)\)]],
  "  \n\n\n\t\t\t",
  Cell[BoxData[{
      \(\((1 + \ \[ImaginaryI])\) z\ w\  + \ \((1 - \ \[ImaginaryI])\) 
          w + \((1 + \ \[ImaginaryI])\) z\  + \ \ \((1 - \ \[ImaginaryI])\)\),
     "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \)\(\[IndentingNewLine]\)\(\((\(-1\) + \ \[ImaginaryI])\) 
            z\ w\  + \ \((\(-1\) - \ \[ImaginaryI])\) 
            w + \((1 - \ \[ImaginaryI])\) 
            z\  + \ \ \((1 + \ \[ImaginaryI])\)\)\)\)}]],
  "   \n\n\n\t\t\t",
  Cell[BoxData[{
      \(z\ w + \ \[ImaginaryI]\ z\ w\  + \ w - \ \[ImaginaryI]\ w + 
        z + \ \[ImaginaryI]\ z\  + 1 - \ \[ImaginaryI]\ \ \), 
    "\[IndentingNewLine]", 
      \(\(\(=\)\(\[IndentingNewLine]\)\(\ \)\(\(-z\)\ w + \ \[ImaginaryI]\ z\ \
w\  - w - \ \[ImaginaryI]\ w + z - \ \[ImaginaryI]\ z\  + \ 
          1 + \ \[ImaginaryI]\)\)\)}]],
  "  \n\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(2\ z\ w\  + \ 2\ w\ \  = \ \ \(-2\)\ \[ImaginaryI]\ z\  + \ 
          2  \[ImaginaryI]\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \(\(z\ w\  + \ 
          w\ \  = \ \ \(-\ \[ImaginaryI]\)\ z\  + \ \[ImaginaryI]\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ w \((1 + z)\)\ \  = \ \ \[ImaginaryI] \((1 - z)\)\)}]],
  "    "
}], "Text"],

Cell[TextData[{
  "Therefore the desired bilinear transformation is  \n\n\t\t\t",
  Cell[BoxData[
      \(w\ \  = \ \ \(S \((z)\)\ \  = \ \ \(\[ImaginaryI]\ \((1\  - \ \
z)\)\)\/\(1\  + \ z\)\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the three points and their images and solve for  w = S(z).  \
\>", "Text"],

Cell[BoxData[{
    \(w = \(z = 0\); \ Remove[w, z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[formula, solset, S];\)\ \), "\n", 
    \(\(formula\  = \ \(\((z - z\_1)\)\ \((z\_2 - z\_3)\)\)\/\(\(\ \)\(\((z - \
z\_3)\) \((z\_2 - z\_1)\)\)\) \[Equal] \(\((w - w\_1)\)\ \((w\_2 - \
w\_3)\)\)\/\(\(\((w - w\_3)\) \((w\_2 - w\_1)\)\)\(\ \)\);\)\ \), "\n", 
    \(\(Print[formula];\)\ \), "\n", 
    \(\(z\_1\  = \ \(-\[ImaginaryI]\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(z\_2\  = \ 1;\)\ \ \), "\[IndentingNewLine]", 
    \(\(z\_3\  = \ \[ImaginaryI];\)\ \ \ \), "\n", 
    \(\(w\_1\  = \ \(-1\);\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(w\_2\  = \ 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\_3\  = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute the values\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,      \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,      \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,      \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,      \!\(w\_3\) = \>\"", 
        w\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[formula];\)\ \), "\n", 
    \(\(solset\  = \ Solve[formula, w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S(z) = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Check our work and by looking at the images of  ",
  Cell[BoxData[
      \(z\_1, \ z\_2, \ z\_3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,      \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,      \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,      \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,      \!\(w\_3\) = \>\"", w\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<S[\!\(z\_1\)] = \>\"", 
        S[z\_1], \*"\"\<,   S[\!\(z\_2\)] = \>\"", 
        S[z\_2], \*"\"\<,   S[\!\(z\_3\)] = \>\"", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
To visualize the mapping  w = S(z)  we will consider a graph. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, Iden, wplane, z, zplane];\)\ \), "\n", 
    \(\(Iden[z_] = z;\)\ \), "\n", 
    \(\(S[
          z_] = \(-\(\(\[ImaginaryI]\ \((\(-1\) + z)\)\)\/\(1 + 
                z\)\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{0, \(-1\)}, {1, 0}, {0, 
            1}};\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(zdots = 
        Graphics[{{Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Green, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{\(-1\), 0}, {0, 0}, {1, 
            0}};\)\ \), "\[IndentingNewLine]", 
    \(\(wdots = 
        Graphics[{{Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Green, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(zplane = 
        CartesianMap[
          Iden, {0, 1, 0.125}, {\(-1\), 1, 
            0.125}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.1\), 
                1.1}, {\(-1.1\), 1.1}}, 
          AspectRatio \[Rule] 
            2, \[IndentingNewLine]Ticks \[Rule] {Range[0, 1, 1], 
              Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Red, Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(wplane = 
        CartesianMap[
          S, {0, 1, 0.125}, {\(-1\), 1, 
            0.125}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1.2\), 
                1.2}, {\(-0.2\), 1.0}}, 
          AspectRatio \[Rule] 
            1\/2, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 1, 1], 
              Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Red, Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[zplane, zdots, 
        PlotRange \[Rule] {{\(-0.1\), 1.1}, {\(-1.1\), 1.1}}, 
        AspectRatio \[Rule] 
          2, \[IndentingNewLine]Ticks \[Rule] {Range[0, 1, 1], 
            Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The points \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<, \!\(z\_2\) = \>\"", z\_2, \*"\"\<, \!\(z\_3\) = \>\"", 
        z\_3, "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<in the z-plane.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[wplane, 
        wdots, \[IndentingNewLine]PlotRange \[Rule] {{\(-1.2\), 
              1.2}, {\(-0.2\), 1.0}}, 
        AspectRatio \[Rule] 
          1\/2, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 1, 1], 
            Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The images \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<, \!\(w\_2\) = \>\"", w\_2, \*"\"\<, \!\(w\_3\) = \>\"", 
        w\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping w = S[z] = \>"\ , 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", z\_1, "\<] = \>", 
        S[z\_1], \[IndentingNewLine]"\<,   S[\>", z\_2, "\<] = \>", 
        S[z\_2], \[IndentingNewLine]"\<,   S[\>", z\_3, "\<] = \>", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(Clear[Iden, z];\)\ \), "\n", 
    \(\(Iden[z_]\  = \ z;\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(zplane = 
        PolarMap[
          Iden, {0.000005, 0.999995, 0.11111}, {0, 2  \[Pi], \[Pi]\/12}, 
          PlotRange \[Rule] {{\(-1.05\), 1.05}, {\(-1.05\), 
                1.05}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 1, 
                1], Range[1, 1, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Red, Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \ \ \), "\n", 
    \(\(wplane = 
        PolarMap[
          S\ \ \ , {0.000005, 0.999995, 0.11111}, {0, 2  \[Pi], \[Pi]\/12}, 
          Ticks \[Rule] {Range[\(-3\), 3, 1], Range[0, 3, 1]}, 
          AspectRatio \[Rule] 1\/2, 
          PlotRange \[Rule] {{\(-3\), 3}, {0, 
                3}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Red, Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[zplane, zdots, 
        PlotRange \[Rule] {{\(-1.05\), 1.05}, {\(-1.05\), 
              1.05}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 1, 1], 
            Range[1, 1, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The points \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<, \!\(z\_2\) = \>\"", z\_2, \*"\"\<, \!\(z\_3\) = \>\"", 
        z\_3, "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<in the z-plane.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[wplane, 
        wdots, \[IndentingNewLine]PlotRange \[Rule] {{\(-1.2\), 
              1.2}, {\(-0.2\), 1.0}}, 
        AspectRatio \[Rule] 
          1\/2, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 1, 1], 
            Range[\(-1\), 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The images \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<, \!\(w\_2\) = \>\"", w\_2, \*"\"\<, \!\(w\_3\) = \>\"", 
        w\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping w = S[z] = \>"\ , 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", z\_1, "\<] = \>", 
        S[z\_1], \[IndentingNewLine]"\<,   S[\>", z\_2, "\<] = \>", 
        S[z\_2], \[IndentingNewLine]"\<,   S[\>", z\_3, "\<] = \>", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the bilinear transformation  ",
  StyleBox["w = S(z)",
    FontFamily->"Courier New"],
  "  that maps the points  ",
  Cell[BoxData[
      \(z\_1 = \(-2\), \ \ z\_2 = \(-1\) - \[ImaginaryI], \ \ z\_3 = 0\)]],
  "  onto the points  ",
  Cell[BoxData[
      \(w\_1 = \(-1\), \ \ w\_2 = 0, \ \ w\_3 = 1\)]],
  ",  respectively."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007>0000[b000`400?l0
0000o`00003oo`3oooo?0?ooo`00o`3oooo?0?ooo`00o`3oooo?0?ooo`00
o`3oooo?0?ooo`00o`3oooo?0?ooo`00oP3oool00`000000oooo0?ooo`1Y
0?ooo`030000003oool0oooo0640oooo003n0?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool0H@3oool00?h0oooo00<000000?ooo`3o
ool0J@3oool00`000000oooo0?ooo`1Q0?ooo`00oP3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo0640oooo003n0?ooo`030000003o
ool0oooo06T0oooo00<000000?ooo`3oool0H@3oool00;T0oooo0P00o`0m
0?ooo`D0000000<0oooo0000003oool0JP3oool00`000000oooo0?ooo`1Q
0?ooo`00^03oool4003o03h0oooo00D000000?ooo`3oool0oooo0000001[
0?ooo`030000003oool0oooo0640oooo001d0?oood<0003o1P00o`120000
o`030000003oool0oooo06P0oooo00<000000?ooo`3oool0H@3oool007@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`H00?l01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool00P3oool4000000050?l0003oool0oooo0?oo
o`0000000`3oool00`000?l0oooo0?ooo`1Y0?ooo`030000003oool0oooo
0640oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool4003o00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00D0o`000?ooo`3o
ool0oooo000000030?ooo`030000o`3oool0oooo06T0oooo00<000000?oo
o`3oool0H@3oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`80
0?l01`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`02000000<0oooo00<0003o0?ooo`3oool0J@3oool00`000000
oooo0?ooo`1Q0?ooo`00M03oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo06T0oooo
00<000000?ooo`3oool0H@3oool007@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`1Y0?ooo`030000003oool0oooo0640oooo001d0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0D03oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0
oooo01L0oooo00<0003o0?ooo`3oool0A`3oool007@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`1>0?ooo`<0003o603oool00`000000oooo0?ooo`0F0?oo
o`030000o`3oool0003o04P0oooo001d0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0C@3oool01@3o0000oooo0?ooo`3oool0003o01L0oooo00<000000?oo
o`3oool05@3oool01@000?l0oooo0?ooo`3oool0o`0004L0oooo001d0?oo
oh/0o`00;@3oool5000001`0oooo00<0003o0?l0003oool00`3oool00`00
0?l0oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00L0003o0?oo
o`3oool0oooo0?l0003oool0003o0200oooo1@00000Q0?ooo`00M03oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo02d0oooo00<000000?ooo`3oool06@3oool3
0000o`80oooo00H0o`000?ooo`3o0000o`000?ooo`000?lE0?ooo`030000
003oool0oooo01<0oooo00H0003o0?ooo`3o0000o`000?ooo`3o00020?oo
o`<0003o7`3oool00`000000oooo0?ooo`0Q0?ooo`00M03oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo02d0oooo00<000000?ooo`3oool05`3oool20000o`03
0?ooo`000?l0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0003o0000
oad0oooo00<000000?ooo`3oool08@3oool007@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0U0?ooo`@00000103oool00`000000oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo0080oooo00H0003o0?ooo`3oool0o`000?ooo`3o0002
0?ooo`030000o`3oool0003o01<0oooo00<000000?ooo`3oool04@3oool0
0`000?l0oooo0000o`020?ooo`030?l0003oool0o`000080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0J0?ooo`030000003oool0
oooo0240oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0D0?ooo`80003o00<0oooo0?l0003oool00`3oool00`00
0?l0o`000?ooo`020?ooo`030?l0003oool0003o0080oooo00<0003o0?l0
003oool0403oool00`000000oooo0?ooo`0?0?ooo`030?l000000?l0oooo
0080oooo00<0003o0?l0003oool00P3oool00`3o0000oooo0000o`030?oo
o`040?l0003oool0003o0000oaX0oooo00<000000?ooo`3oool08@3oool0
07@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`0/0?ooo`8000004`3oool30000
o`<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`050?l0003oool0oooo0?ooo`3o00000P000?l@0?ooo`030000003oool0
oooo00h0oooo0P000?l01@3o0000oooo0?ooo`3oool0o`0000D0oooo00<0
003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`3oool30000oaH0oooo
0P00000S0?ooo`00M03oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo03h0oooo0`00
0?l00`3oool0003o0?ooo`040?ooo`060?l0003oool0o`000?l0003oool0
003o0`3oool00`000?l0oooo0?l000020?ooo`030?l0003oool0oooo0080
003o3P3oool00`000000oooo0?ooo`0<0?ooo`80003o0`3oool01@3o0000
oooo0?l0003oool0003o00<0oooo00H0003o0?ooo`3o0000o`000?ooo`3o
00050?ooo`030000o`3oool0003o00<0003o=`3oool007@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0Y0?ooo`80o`003`3oool30000o`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00P3oool20?l000@0oooo00<0003o
0?ooo`000?l00`3oool20?l000<0oooo00<0003o0?ooo`000?l00P000?l;
0?ooo`800?l02P3oool40000o`@0oooo0P3o00030?ooo`030000o`3oool0
003o00@0oooo0P3o00040?ooo`030000o`3oool0oooo00<0oooo00@0o`00
0000o`000?l0003o3`3oool20000ob<0oooo001d0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0:03oool40?l000/0oooo0`000?l30?ooo`030?l0003oool0
oooo00<0oooo00L0003o0?ooo`3oool0oooo0?l0003oool0o`0000D0oooo
00<0003o0?ooo`3oool00`3oool20?l00080oooo00<0003o0?ooo`3oool0
0P3oool20000o`P0oooo1000o`070?ooo`80003o00D0o`000?ooo`3oool0
oooo0000o`020?ooo`<0o`00103oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0o`0000<0oooo00<0003o0?ooo`3oool00`3oool0103o0000
oooo0?ooo`3oool30000o`/0oooo10000?lB0?ooo`@00000303oool007@0
ooooR`000?lO0?ooo`@0003o00<0o`000?ooo`3oool00`3oool60?l000@0
oooo00<0o`000?ooo`000?l010000?l60?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?l0003o00000`3oool01`3o0000oooo0?ooo`3oool0003o
0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3o0000003o00@0oooo00<0
o`000?ooo`3oool010000?l30?ooo`H00?l000<0oooo0000o`000?l00`00
0?l20?ooo`030?l0003oool0oooo0080oooo00D0003o0?l0003oool0oooo
0?l000030?ooo`040000o`3oool0003o0000o`<0oooo00<0o`000?ooo`3o
ool00P3o00000`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo1@000?l00`3oool0o`000?ooo`030?ooo`H0003o1@3oool00`3o0000
003o0000o`020000o`H0oooo00@000000?ooo`3oool000003@3oool007@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0M0?ooo`@0000000<0o`000000o`00
0?l00`000?l60?l000@0003o00<0o`000000o`000000100000000`000?l0
000000000003000000030?l00000000000000080000000<0o`000000o`00
000010000000103o00000000000000000?l3000000030000o`000000o`00
00@000000P3o0003000000050?l0000000000000000000000?l00P000003
0000o`H00?l000D0003o00000000000000000000o`04000000030?l00000
000000000080o`00100000000`3o000000000000o`04000000030000o`00
0000o`0000D0000000<0003o0?l0000000000`0000000`3o000000000000
0004000000030000o`00000000000080000000<0003o0?l000000?l03P00
0?l00`3o0000000000000002000000H0oooo00@000000?ooo`3oool00000
3@3oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003o
ool0oooo00@0oooo103o00050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?l00080oooo00<0
003o0?ooo`3oool00`3oool00`3o0000003o0?ooo`040?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3o00040?ooo`050000o`3o
ool0oooo0?ooo`3o00000P3oool4003o00030?ooo`3o0000oooo00<0oooo
00@0003o0?ooo`3oool0oooo0`3o00020?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo0080o`000P3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool40000o`H0
oooo00<0o`000?ooo`3oool01`3oool2000000030?ooo`000000000000d0
oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo
0?ooo`050?ooo`80o`001P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00<0oooo0P3o00050?ooo`060000o`3oool0oooo0?ooo`00
0?l0oooo0P3o00030?ooo`030?l0003oool0003o00<0oooo00<0003o0?oo
o`3oool00P3oool30?l00080oooo00D0003o0?ooo`3oool0oooo0?l00003
0?ooo`800?l00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00<0o`000`3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`3o0000
103oool00`3o0000oooo0000o`030?ooo`030000o`3oool0oooo00<0oooo
0P3o00060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool20000o`L0oooo00<0o`000?ooo`3oool06@3oool007@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`040000o`3o
ool0oooo0?ooo`<0o`001P3oool010000?l0oooo0000o`000?l40?ooo`03
0?l0003oool0o`0000<0oooo0`000?l40?ooo`040?l0003oool0oooo0?oo
o`@0o`000P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00@0o`00
0?ooo`3oool0oooo103o00020?ooo`030?l0003oool0oooo0080oooo0`00
0?l30?ooo`040?l0003oool0oooo0?l000<0oooo0P000?l00`3oool0003o
0?ooo`050?ooo`<0o`00103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0I0?ooo`00M03oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0240oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00@0003o0?ooo`3o0000o`000`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool20000o`<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0>0?l000030?ooo`000?l0oooo00<0oooo00@0o`000?ooo`3oool0
oooo0P000?l60?ooo`80o`001P3oool00`000?l0oooo0?ooo`040?ooo`04
0?l0003oool0oooo0?ooo`80o`0000<0oooo0000o`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0603oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0Q0?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`030?ooo`80o`0000<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0003o00H0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020000o`030?l0003oool0oooo00<0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`030?l000000?l0
003o0080oooo00<0003o0?ooo`3oool00`3oool20?l000D0oooo00<0003o
0?ooo`000?l0103oool00`3o0000oooo0?ooo`040?ooo`040?l000000?l0
o`000?l000@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo01P0oooo001d0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0803oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3o00000`3o00020?ooo`030000o`3oool0
oooo00@0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3o00000`3oool00`000?l0oooo0?oo
o`030?ooo`80003o103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo0P000?l50?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool01@3o
0000oooo0?ooo`3oool0003o00<0oooo00D0003o0?ooo`3oool0oooo0?l0
00060?ooo`040000o`3oool0oooo0?ooo`<0o`0000<0oooo0?l0003oool0
1P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo01P0oooo
001d0?oooh/0o`008P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo0080oooo1@3o00060?ooo`030000o`3oool0oooo00@0oooo00@0
o`000?ooo`3oool0003o1@3oool010000?l0oooo0?ooo`3o00030?ooo`80
o`0000<0003o0?ooo`3oool0103oool01P3o0000oooo0000o`000?l0oooo
0000o`@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00H0003o0?ooo`000?l0003o0?oo
o`3o00060?ooo`030000o`3o0000o`0000@0oooo00<0o`000?ooo`000?l0
1@3oool00`000?l0oooo0?l000070?ooo`030000o`3oool0oooo00@0oooo
1@3o00040?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
603oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0P0?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?l0003o00000P3o00040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000003o0?oo
o`060?ooo`030000o`3o0000oooo00D0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`D0003o00<0oooo0?l0003oool00`3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0003o00@0003o103o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
o`000000o`3oool01P3oool00`000?l0o`000?ooo`050?ooo`030000o`3o
ool0oooo00H0oooo00@0o`000?ooo`3oool0oooo103o00000`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo01P0oooo001d0?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool07@3oool=0?l000030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`80003o00<0
oooo0?l0003oool01P3oool00`000?l0oooo0?ooo`040?ooo`040000o`3o
ool0o`000?l000<0oooo00<0o`000?ooo`3oool00`3oool010000?l0oooo
0?ooo`3oool=0000o`<0oooo00<0003o0?ooo`3oool00`3oool0103o0000
oooo0?ooo`3oool20?l000030?ooo`000?l0oooo00@0oooo00<0003o0?l0
003oool01P3oool0103o0000oooo0000o`000?l40?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0o`000?l0000;
0?l001L0oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0803oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`020000o`@0oooo00<0o`000?oo
o`3oool00`3oool00`3o0000oooo0000o`040?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3o0000103oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80003o00<0oooo
0000o`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool0603oool007@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`80003o1`3oool01@3o
0000oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0000
o`050?ooo`80o`001@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo0P3o00050?ooo`040000o`3o
ool0oooo0000o`@0oooo00D0o`000?ooo`3oool0oooo0?l000070?ooo`80
003o203oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0603oool007@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0P0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`030?ooo`80003o00<0oooo0000o`3oool0
1`3oool00`3o0000oooo0?l000050?ooo`<0003o1P3oool00`3o0000oooo
0?l000020?l00080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?l000030?ooo`3o0000oooo00D0oooo
0P000?l60?ooo`030?l0003oool0o`0000P0oooo00@0003o0?ooo`000?l0
003o1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0603oool007@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0Q0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1P3oool0103o0000oooo0?ooo`3oool20000o`<0oooo00<0003o0?ooo`3o
ool01P3oool20?l000P0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`030?ooo`@0o`000`3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0oooo103o00040?oo
o`030?l0003oool0oooo00@0oooo0P000?l70?ooo`030?l0003oool0oooo
00L0oooo00@0003o0?ooo`3oool0oooo0P000?l30?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0H
0?ooo`00M03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo0240oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l000000?l0003o
00H0oooo00<0003o0?ooo`3oool0103oool30?l000L0oooo00@0003o0?oo
o`000?l0003o0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00L0o`000P3oool010000?l0oooo0?ooo`3oool60?l00080oooo00<0
003o0?ooo`3oool0103oool0103o0000oooo0?ooo`3oool20000o`80oooo
00<0003o0?ooo`3oool0103oool30?l000H0oooo00<0003o0?ooo`3oool0
103oool20000o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`0H0?ooo`00M03oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo0240oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3o0000oooo00L0oooo00<0003o0?ooo`3oool00`3o
ool01@3o0000oooo0?ooo`3oool0o`0000D0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?l000070?ooo`030000o`3oool0oooo00<0oooo
00@0o`000?ooo`3oool0oooo1P3o00020?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool0103o0000oooo0?ooo`000?l40?oo
o`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l00005
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000000o`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo01P0oooo001d0?oo
oh/0003o8`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00<0oooo0`000?l20?ooo`030?l0003oool0oooo00H0oooo00D0003o0?oo
o`3oool0oooo0?l000050?ooo`050?l0003oool0oooo0?ooo`000?l01P3o
ool20000o`H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`050?ooo`80003o1P3oool01@000?l0oooo0?oo
o`3oool0o`0000D0oooo00D0o`000?ooo`3oool0oooo0000o`080?ooo`03
0?l0003oool0oooo00<0003o103oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo01T0oooo001d0?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
8@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0003o0080003o
1@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o0000o`0000L0oooo
00<0o`000?ooo`000?l01`3oool0103o0000oooo0000o`000?l40?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00P3oool20000o`030?l0003oool0oooo00H0oooo00<0003o0?l0003o
00001`3oool20?l000030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool00`3oool30000o`030?ooo`000?l0oooo00T0oooo00<0o`000?ooo`3o
ool06@3oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0Q0?ooo`030?l0
003oool0oooo00L0oooo0`000?l90?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`040?l0
003oool0oooo0?ooo`80003o00<0oooo0000o`3oool01P3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`020000o`<0oooo00<0o`000?ooo`3o
ool01@3oool00`3o0000003o0?ooo`080?ooo`030000o`3o0000oooo00L0
oooo00<0o`000?ooo`3oool01`3oool30000o`T0oooo00<0o`000?ooo`3o
ool06@3oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0Q0?ooo`030?l0
003oool0oooo00L0003o00<0oooo0000o`3oool02@3oool00`3o0000oooo
0?ooo`040?ooo`80o`0000<0oooo0000o`3oool0203oool00`000?l0o`00
0?l000050?ooo`030?l0003oool0oooo00@0oooo0`000?l50?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`80003o1@3oool00`3o0000oooo0?ooo`040?ooo`040?l0
003oool0oooo0000o`P0oooo00@0003o0?ooo`3o0000o`001P3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0003o0P3oool00`3o
0000oooo0?ooo`0I0?ooo`00M03oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0200
oooo00@0003o0?l000000?l0003o2@3oool00`000?l0oooo0?ooo`080?oo
o`040?l0003oool0oooo0?ooo`80o`00103oool00`000?l0oooo0?ooo`05
0?ooo`040000o`3oool0oooo0?ooo`80o`000`3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0003o00<0003o00<0oooo0?l0003oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0003o00D0003o1`3o
ool0103o0000oooo0?ooo`3oool20?l000@0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`020?ooo`80o`000`3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00L0oooo0P000?l00`3o0000003o
0?ooo`0I0?ooo`00M03oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo01d0oooo0`00
0?l00`3oool0o`000?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3o00001`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3o0000203oool00`000?l0oooo0?oo
o`030?oooa40003o1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0o`0000L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0o`0000/0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0000o`020000oaL0oooo001d0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool08@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00P0oooo0P3o00090?ooo`050000o`3oool0oooo0?ooo`000?l0203o
ool20?l000L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`80o`00203oool01@000?l0oooo0?oo
o`3oool0003o00T0oooo0P3o000:0?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool06@3oool007@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0R0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01`3o
ool30?l000X0oooo00<0003o0?ooo`000?l02@3oool30?l000H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`030?ooo`<0o`002@3oool00`000?l0oooo0000o`0:0?ooo`<0o`002@3o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo01T0oooo001d
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool08P3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3oool0o`002`3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0080o`00103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`040000o`3o
ool0oooo0?ooo`80o`000P3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00T0oooo00@0o`000?ooo`3oool0o`00203oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo01X0oooo001d0?oooh/0o`00
903oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0003o00P0oooo00<0o`000?ooo`3oool00`3oool20?l00080oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo
0?l0003o00050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`00
0?l02@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0J0?ooo`00
M03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo0280oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`020?ooo`80o`001P3oool00`3o0000oooo
0?ooo`050?ooo`040000o`3oool0oooo0?ooo`80003o1@3oool00`3o0000
oooo0?ooo`060?ooo`80o`001`3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool20?l000P0
oooo00<0o`000?ooo`3oool00`3oool20000o`<0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`030?ooo`80o`00103oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo01X0oooo001d0?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool08`3oool00`3o0000oooo0?ooo`0:0?ooo`040000
o`3oool0o`000?l000P0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool01`3oool010000?l0o`000?l0003o00040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?oo
o`<0o`0000<0oooo0000o`3oool01`3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`060?ooo`80o`0000<0oooo0000o`3oool0303oool00`3o
0000oooo0?ooo`0J0?ooo`00M03oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo02<0
oooo00<0o`000?ooo`3oool02@3oool00`3o0000003o0?l0000;0?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool010000?l0
oooo0?ooo`3o00090?ooo`030000o`3oool0oooo0080oooo1@3o00070?oo
o`030000o`3oool0oooo00@0oooo1P3o00040?ooo`030000o`3oool0oooo
00L0oooo00@0o`000?ooo`3oool0003o203oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00T0oooo00<0o`000000o`3o00002`3oool0
0`3o0000oooo0?ooo`0K0?ooo`00M03oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
02<0oooo00<0o`000?ooo`3oool01`3oool20?l00080oooo00<0003o0?oo
o`3oool02P3oool0103o0000oooo0?ooo`000?l:0?ooo`80003o00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
o`0000d0o`000P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`000?l02P3oool01@000?l0oooo0?ooo`3o
ool0o`0000/0oooo00<0003o0?ooo`3oool00P3o00090?ooo`030?l0003o
ool0oooo01/0oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool08`3oool0
0`3o0000oooo0?ooo`040?ooo`<0o`00103oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0003o00`0oooo00<0o`000000o`000?l01`3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo0P000?l<0?ooo`030000o`3oool0o`0000`0oooo00<0003o
0?ooo`3oool00P3oool30?l000H0oooo00<0o`000?ooo`3oool06`3oool0
07@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo
00<0o`00203oool00`000?l0oooo0?ooo`090?ooo`030000o`3o0000oooo
00/0oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
10000?l0oooo0?ooo`3o000<0?ooo`030?l000000?l0oooo00X0oooo00<0
003o0?ooo`3oool01P3oool30?l000<0oooo00<0o`000?ooo`3oool06`3o
ool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0T0?ooo`<0o`002`3oool0
0`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo0?l000X0oooo00<0
o`000?ooo`3oool00`3oool20000o`<0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`80003o103o
ool00`3o0000oooo0?ooo`080?ooo`040?l0003oool0oooo0000o`X0oooo
00<0003o0?ooo`3oool02@3oool30?l001h0oooo001d0?oooh/0003o903o
ool30?l000h0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01@3o
ool20000o`030?ooo`000?l0oooo00P0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`000?l00P000?l60?ooo`030?l0003oool0oooo00L0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00`0oooo0`3o000L0?ooo`00M03oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo01l0oooo0`3o00030?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`80o`001P3oool0
0`3o0000oooo0?ooo`080?ooo`<0003o1`3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool3
0000o`X0oooo00<0o`000?ooo`3oool0103oool20?l000H0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0;0?ooo`040?l0003oool0
oooo0?ooo`<0o`006@3oool007@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0M
0?ooo`80o`001P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool00`000?l4
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`020?ooo`<0003o0P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0103oool20?l001L0oooo001d0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool09P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
0080003o2`3oool0103o0000oooo0?ooo`3o000;0?ooo`030000o`3oool0
oooo00@0oooo0`000?l00`3oool0o`000?ooo`080?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`000?l00P000?l60?ooo`030000o`3oool0
oooo00T0oooo00@0o`000?ooo`3oool0o`002`3oool20000o`<0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0M0?ooo`00M03oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo02H0oooo00<0o`000?ooo`3oool03@3oool2
0000o`h0oooo00<0o`000?ooo`3o00002`3oool00`000?l0oooo0?ooo`07
0?ooo`<0003o203oool00`000?l0oooo0?ooo`060?ooo`<0003o2@3oool0
0`000?l0oooo0?ooo`0:0?ooo`80o`003P3oool00`000?l0oooo0000o`0>
0?ooo`030?l0003oool0oooo01h0oooo001d0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool09P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00h0oooo0P3o000;0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`000?l040000?l00`3oool0o`000?ooo`0:0?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo01h0oooo001d0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool09`3oool00`3o0000oooo0?ooo`0:0?ooo`80003o00<0oooo0000o`3o
ool03@3oool0103o0000oooo0?ooo`3o000:0?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool20?l0
00030?ooo`3o0000oooo00d0oooo00@0003o0?ooo`000?l0003o303oool0
0`3o0000oooo0?ooo`0O0?ooo`00M03oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
02L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00/0oooo00D0o`000?ooo`3oool0oooo0?l00008
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo01l0oooo001d0?ooo`030000o`0000000000
008000000`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`000000000000<000000`3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool00`3oool20?l000H0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0803oool007@0
ooooR`3o000[0?ooo`030?l0003oool0oooo00@0oooo0P000?l80?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool20?l000<0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`020?ooo`80o`00203oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00D0oooo0P000?l70?ooo`030?l0003oool0oooo0200
oooo001d0?ooo`030000o`3oool0000000D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool010000?l0oooo
0?ooo`0000050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0:@3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`090?ooo`80o`0000<0oooo0000o`3o
ool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool010000?l0oooo0?l0003o000:0?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0240oooo001_0?ooo`@0
000000D0oooo0000o`3oool0oooo000000040?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`050?ooo`040?l0003oool0oooo0?ooo`@0000000D0oooo
0000o`3oool0oooo000000050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0:P3o
ool00`3o0000oooo0?ooo`020000o`d0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00T0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00T0oooo0P3o000=0?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool02P3oool20000o`<0oooo00<0o`000?ooo`3oool08@3o
ool007@0oooo00D0003o0000003oool0oooo000000030?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00@0
003o0?ooo`3oool000001@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo02X0oooo
00<0o`000000o`000?l0403oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?l0003o00002@3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
1`3oool20?l000030?ooo`000?l0oooo00d0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0=0?ooo`80003o00<0o`000?ooo`3oool0
8P3oool007@0oooo00@0003o0?ooo`0000000000103oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`040000
o`3oool00000000000D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0Y0?ooo`80
003o00<0o`000?ooo`3oool0403oool010000?l0oooo0?ooo`3o000>0?oo
o`040000o`3oool0oooo0?ooo`<0o`001P3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool3
0?l000<0oooo00<0003o0?ooo`3oool03@3oool0103o0000oooo0?ooo`00
0?lB0?ooo`030?l000000?l0oooo0280oooo001d0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool09`3oool20000o`<0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0o`000?ooo`0>0?ooo`030000o`3oool0oooo00@0oooo103o0002
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?l000030?l000L0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000003o0000o`0B0?ooo`030?l0003oool0oooo0080003o8@3oool0
07<0oooo0P3o00070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`80003o9`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0100oooo00<0o`000000o`000?l03@3oool00`000?l0oooo0?ooo`090?oo
o`<0o`002`3oool00`000?l0oooo0?ooo`070?ooo`D0o`002`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030000o`3o0000oooo0140oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0N0?ooo`00LP3oool40?l000H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo10000?l:0?ooo`80
000000<0oooo0000000000005@3oool20000o`L0oooo00<0o`000?ooo`3o
ool03P3oool01@3o0000oooo0?ooo`3oool0003o00/0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?l0000D0?l000<0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`040000o`3oool0oooo
0?l00140oooo00<0o`000?ooo`3oool0103oool20000oah0oooo001a0?oo
o`H0o`001@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool60000
o`X0oooo00<000000?ooo`000000503oool20000o`X0oooo00<0o`000?oo
o`3oool0303oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00P0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool03@3oool00`3o0000oooo0?ooo`070?ooo`80003o703oool006d0
oooo100000060?l008/0003o100000070?ooo`030000003oool0oooo0140
oooo0P000?l<0?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool01`3oool20000o`H0
oooo00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`80
003o6P3oool00780oooo103o00060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`040?ooo`@0003o2P3oool2000000030?ooo`000000000000l0oooo
0P000?l?0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0
303oool20000oaP0oooo001c0?ooo`80o`001`3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool20000oah0oooo00<0003o0?ooo`3oool0403o
ool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00<0oooo0P000?l;0?ooo`030?l0003o
ool0oooo00P0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0E0?ooo`00M03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0300oooo00<0o`00
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`020000o`h0oooo00<0o`000?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`0X0?ooo`00M03oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
0340oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0=0?oo
o`80003o00<0oooo0000o`3oool03P3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0000o`0A0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool0:@3oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0b0?ooo`03
0?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0403oool20000o`l0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo02X0oooo001d0?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0<`3oool0103o0000oooo0?ooo`3o000C0?ooo`04
0000o`3oool0003o0000o``0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo0`000?lD0?oo
o`040?l0003oool0oooo0?l002d0oooo001d0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool07@3oool00`000?l0oooo0?ooo`0D0?ooo`80o`00503oool01000
0?l0oooo0?ooo`3oool20000o`X0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00P0oooo0P000?l3
0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3o00005@3oool0
0`000?l0oooo0?ooo`0E0?ooo`00M03ooon;0?l001l0oooo00<0003o0?oo
o`3oool0503oool20?l001<0oooo00<0003o0?ooo`3oool0103oool30000
o`L0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00H0oooo0P000?l50?ooo`030000o`3oool0oooo
01<0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0F0?oo
o`00M03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo01h0oooo00<0003o0?ooo`3o
ool04P3oool00`3o0000oooo0?l0000C0?ooo`030000o`3oool0oooo00L0
oooo10000?l20?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool03@3oool0103o0000oooo0?ooo`3oool40000o`P0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?l0000D0?ooo`030000o`3oool0oooo
01H0oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool07P3oool00`000?l0
oooo0?ooo`0A0?ooo`050?l0003oool0oooo0?ooo`3o00004@3oool00`00
0?l0oooo0?ooo`0<0?ooo`80003o00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0=0?ooo`@0003o303oool00`000?l0oooo0?ooo`0@0?oo
o`050?l0003oool0oooo0?ooo`3o00004P3oool00`000?l0oooo0?ooo`0G
0?ooo`00M03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo01l0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool03P3oool60000o`<0oooo1@0000020?oo
o`030000o`3oool0oooo00X0oooo0`000?l00`3o0000oooo0?ooo`0>0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo01L0oooo001d0?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo00<0oooo2@000?l00`3oool0
003o0?ooo`0;0000o`<0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0H0?ooo`00M03oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo0200oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`090?ooo`030000003oool0oooo00D0003o
3P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00X0oooo
0P3o00090?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
603oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0P0?ooo`030000o`3o
ool0oooo00X0oooo0P3o000;0?ooo`80o`002P3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`80o`002`3o
ool00`000?l0oooo0?ooo`0I0?ooo`00M03oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo0240oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0=
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo01T0oooo001d0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool08P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00l0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0@0?oo
o`030?l0003oool0oooo00P0oooo0P0000040?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0J0?ooo`00M03ooon;0000ob@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`0A0?ooo`80o`001@3oool00`000?l0
oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00<0
oooo0P3o000C0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool06P3oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0S0?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0503oool01@3o0000oooo
0?ooo`3oool0003o01<0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo0100oooo00D0003o0?ooo`3o
ool0oooo0?l0000F0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool06`3oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0T0?ooo`03
0000o`3oool0oooo0080o`00603oool20?l000030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3o0000603oool20?l00080
oooo00<0003o0?ooo`3oool0703oool007@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0U0?ooo`030000o`3o0000oooo01X0oooo00<0003o0?l0003oool0
4P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo
00<0o`000?ooo`3oool04@3oool20?l001/0oooo00<0o`000?ooo`000?l0
7P3oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3o
ool0oooo01X0oooo00@0003o0?ooo`3o0000o`004@3oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0
3P3oool20?l000030?ooo`000?l0oooo01/0oooo00<0003o0?ooo`3oool0
7@3oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0T0?ooo`030?l0003o
ool0003o01X0oooo00<0003o0?ooo`3oool00P3oool20?l000l0oooo00<0
o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo00`0oooo0P3o00040?ooo`030000o`3oool0oooo01P0oooo00<0
003o0?ooo`3o00007P3oool007@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0R
0?ooo`80o`000`3oool00`000?l0oooo0?ooo`0F0?ooo`030000o`3oool0
oooo00D0oooo0P3o000=0?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo0?ooo`0:0?ooo`80o`001`3oool0
0`000?l0oooo0?ooo`0F0?ooo`040000o`3oool0oooo0?ooo`80o`00703o
ool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`07
0?ooo`80o`002P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool0203oool20?l000T0oooo00<0003o
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo01T0oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0803oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo01@0oooo00<0003o0?oo
o`3oool02P3oool20?l000P0oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00D0oooo0P3o000<0?oo
o`030000o`3oool0oooo01@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0H0?ooo`00M03ooon;0?l00200oooo0P3o00090?ooo`03
0000o`3oool0oooo0180oooo00<0003o0?ooo`3oool03@3oool30?l000D0
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`04
0?l0003oool0oooo0?ooo`@0o`003`3oool00`000?l0oooo0?ooo`0B0?oo
o`030000o`3oool0oooo00L0oooo0P3o000H0?ooo`00M03oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0100oooo0`3o00000`3oool0
o`000?ooo`0B0?ooo`030000o`3oool0oooo0140oooo103o000C0?ooo`03
0000o`3oool0oooo0140oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0E0?ooo`00M03oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo02/0oooo
00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0D0?ooo`@0o`00
4@3oool00`000?l0oooo0?ooo`0?0?ooo`<0o`005`3oool00`000?l0oooo
0?ooo`0?0?ooo`030000o`3oool0oooo02<0oooo001d0?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0;03oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo01H0oooo00<0o`000?ooo`3oool00`3o000>0?ooo`030000o`3o
ool0oooo00`0oooo0`3o00030?ooo`030?l0003oool0oooo01D0oooo00<0
003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0T0?ooo`00M03oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo02d0oooo0P000?l=0?ooo`030000o`3oool0
oooo01D0oooo00<0o`000?ooo`3oool0103oool90?l000D0oooo00<0003o
0?ooo`3oool0103oool80?l000H0oooo00<0o`000?ooo`3oool05@3oool0
0`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo02D0oooo001d0?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`090?oo
o`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool03@3oool<0?l0
00h0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0:0?oo
o`030000o`3oool0oooo02H0oooo001d0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0<03oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01L0
oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0B0?ooo`03
0?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool0203oool00`000?l0
oooo0?ooo`0W0?ooo`00M03oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0340oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0
003oool0oooo01<0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo
0?ooo`0G0?ooo`030000o`3oool0oooo00D0oooo0P000?lZ0?ooo`00M03o
oon;0000oc@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`0G0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool04`3o
ool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0:P3oool007@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0c
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0603oool0
0`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01<0oooo00<0o`00
0?ooo`3oool0603oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo02/0oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0=03oool01000
0?l0oooo0?ooo`000?lJ0?ooo`030?l0003oool0oooo01@0oooo00<0003o
0?ooo`3oool0503oool00`3o0000oooo0?ooo`0H0?ooo`040000o`3oool0
oooo0000obh0oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0=@3oool0
0`000?l0oooo0000o`0J0?ooo`030?l0003oool0oooo01@0oooo00<0003o
0?ooo`3oool0503oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0
003o02l0oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0=P3oool00`00
0?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?oo
o`3oool0503oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo
02h0oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0=@3oool010000?l0
oooo0000o`000?lH0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?oo
o`3oool05@3oool00`3o0000oooo0?ooo`0F0?ooo`80003o00<0oooo0000
o`3oool0;P3oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0d0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool05@3oool00`3o0000
oooo0?ooo`0E0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02`0
oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0=03oool00`000?l0oooo
0?ooo`030?ooo`80003o5@3oool00`3o0000oooo0?ooo`0E0?ooo`030000
o`3oool0oooo01D0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo02`0oooo001d0?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`060?ooo`80003o4P3o
ool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01H0oooo00<0
o`000?ooo`3oool04@3oool20000o`L0oooo00<0003o0?ooo`3oool0:`3o
ool007@0ooooR`3o000d0?ooo`030000o`3oool0oooo00T0oooo00<0003o
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0
oooo01H0oooo00<0o`000?ooo`3oool03`3oool20000o`X0oooo00<0003o
0?ooo`3oool0:P3oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0a0?oo
o`030000o`3oool0oooo00/0oooo0P000?l>0?ooo`030?l0003oool0oooo
01L0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0<0?oo
o`80003o3@3oool00`000?l0oooo0?ooo`0Y0?ooo`00M03oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo0300oooo00<0003o0?ooo`3oool03P3oool20000o``0
oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0G0?ooo`03
0?l0003oool0oooo00X0oooo0P000?l@0?ooo`030000o`3oool0oooo02P0
oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0<03oool00`000?l0oooo
0?ooo`0@0?ooo`80003o2P3oool00`3o0000oooo0?ooo`0G0?ooo`030000
o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0203oool20000oa80oooo
00<0003o0?ooo`3oool0:03oool007@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0_0?ooo`030000o`3oool0oooo01<0oooo0P000?l70?ooo`030?l0003o
ool0oooo01P0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?oo
o`040?ooo`<0003o5@3oool00`000?l0oooo0?ooo`0W0?ooo`00M03oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo02h0oooo00<0003o0?ooo`3oool05P3oool2
0000o`D0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0H
0?ooo`030?l0003oool0oooo0080oooo0P000?lI0?ooo`030000o`3oool0
oooo02H0oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0;@3oool00`00
0?l0oooo0?ooo`0I0?ooo`<0003o0P3oool00`3o0000oooo0?ooo`0H0?oo
o`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool00P000?lL0?oo
o`030000o`3oool0oooo02D0oooo001d0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0;03oool00`000?l0oooo0?ooo`0M0?ooo`80003o6`3oool00`000?l0
oooo0?ooo`0H0?ooo`<0003o7`3oool00`000?l0oooo0?ooo`0T0?ooo`00
M03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo02`0oooo00<0003o0?ooo`3oool0
7P3oool0103o0000003o0000o`000?lH0?ooo`030000o`3oool0oooo01H0
oooo0P000?l00`3oool0o`000?ooo`0O0?ooo`030000o`3oool0oooo02@0
oooo001d0?oooh/0003o;@3oool00`000?l0oooo0?ooo`0O0?ooo`040?l0
003oool0oooo0?ooo`D0003o4`3oool00`000?l0oooo0?ooo`0C0?ooo`<0
003o0`3oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo02<0
oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0:P3oool00`000?l0oooo
0?ooo`0O0?ooo`030?l0003oool0oooo00L0oooo10000?l?0?ooo`030000
o`3oool0oooo00h0oooo1@000?l70?ooo`030?l0003oool0oooo01l0oooo
00<0003o0?ooo`3oool08P3oool007@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0M0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0803o
ool00`3o0000oooo0?ooo`0;0?ooo`H0003o2@3oool00`000?l0oooo0?oo
o`070?ooo`L0003o303oool00`3o0000oooo0?ooo`0P0?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool05@3oool007@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool08@3oool00`3o0000oooo0?ooo`0A0?oooa<0003o4`3oool0
0`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool05P3oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0O0?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool08@3oool00`3o
0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?oo
o`3oool08@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
01L0oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0803oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo0280oooo00<0o`000?ooo`3o
ool06`3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo0280
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0H0?ooo`00
M03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo0200oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo01`0oooo
00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0R0?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool0603oool007@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0Q0?ooo`040?l0003oool0oooo0000obD0oooo
00<0o`000?ooo`3oool0703oool00`000?l0oooo0?ooo`0L0?ooo`030?l0
003oool0oooo02<0oooo00@0003o0?ooo`3oool0o`006`3oool007@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`0R0?ooo`030?l000000?l0oooo02D0oooo
00<0o`000?ooo`3oool0703oool00`000?l0oooo0?ooo`0L0?ooo`030?l0
003oool0oooo02<0oooo00<0003o0?ooo`3o0000703oool007@0ooooR`3o
000U0?ooo`030?l0003oool0oooo02<0oooo00<0o`000?ooo`3oool07@3o
ool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo02<0oooo00<0
o`000?ooo`3oool06`3oool007@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0R
0?ooo`030000o`3oool0o`0002@0oooo00<0o`000?ooo`3oool07@3oool0
0`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo0280oooo00<0o`00
0?ooo`000?l0703oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0Q0?oo
o`050000o`3oool0oooo0?ooo`3o00008`3oool00`3o0000oooo0?ooo`0M
0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool0803oool2
0?l000<0oooo00<0003o0?ooo`3oool06@3oool007@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0P0?ooo`030000o`3oool0oooo00<0oooo0P3o000P0?oo
o`030?l0003oool0oooo01h0oooo00<0003o0?ooo`3oool07P3oool00`3o
0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0603oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0O0?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool07@3oool00`3o0000
oooo0?ooo`0N0?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3o
ool07@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo01L0
oooo001d0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool07P3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool0
7`3oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo01/0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0F0?ooo`00M03o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0000
0004000000030?ooo`000?l0oooo01h0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0J0?ooo`030?l0003oool0oooo01l0oooo00<0
003o0?ooo`3oool07`3oool00`3o0000oooo0?ooo`0I0?ooo`80o`00303o
ool00`000?l0oooo0?ooo`0E0?ooo`00M03oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0000000<0oooo00<0
003o0?ooo`3oool0:`3oool20?l001X0oooo00<0o`000?ooo`3oool07`3o
ool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo01P0oooo00<0
o`000?ooo`3oool0903oool007@0ooooR`000?l00`000000oooo0?ooo`0/
0?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool0803oool0
0`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo01H0oooo00<0o`00
0?ooo`3oool09@3oool00?X0oooo00D000000?ooo`3oool0oooo0000000`
0?ooo`030?l0003oool0oooo01D0oooo00<0o`000?ooo`3oool0803oool0
0`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo01@0oooo0P3o000X
0?ooo`00nP3oool01@000000oooo0?ooo`3oool000000340oooo0P3o000E
0?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0803oool0
0`3o0000oooo0?ooo`0C0?ooo`030?l0003oool0oooo02P0oooo003i0?oo
o`8000000`3oool00`000000oooo0?ooo`0a0?ooo`80o`004P3oool00`3o
0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0240oooo00<0o`000?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0Y0?ooo`00oP3oool00`000000
oooo0?ooo`0c0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?ooo`3o
ool08@3oool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003oool0oooo00l0
oooo0P3o000/0?ooo`00oP3oool00`000000oooo0?ooo`0d0?ooo`80o`00
3`3oool00`3o0000oooo0?ooo`0J0?ooo`@000000`3oool00`000?l0oooo
0?ooo`0Q0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0
;03oool00?h0oooo00<000000?ooo`3oool0=P3oool20?l000`0oooo00<0
o`000?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`030000o`3o
ool0oooo0280oooo00<0o`000?ooo`3oool02`3oool20?l002l0oooo003n
0?ooo`030000003oool0oooo03P0oooo00<0o`000?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<0003o
0000003oool08P3oool00`3o0000oooo0?ooo`090?ooo`80o`00<@3oool0
0?l0ooooIP3oool00`000000oooo0?ooo`1V0?ooo`00o`3ooomT0?ooo`04
0000003oool0oooo000006L0oooo003o0?ooofD0oooo0P00001X0?ooo`00
o`3oooo?0?ooo`00o`3oooo?0?ooo`00o`3oooo?0?ooo`00o03oool20000
0=00oooo003m0?ooo`030000003oool0oooo0<h0oooo003n0?ooo`030000
003oool0oooo06P0oooo0P00001S0?ooo`00o@3oool00`000000oooo0000
001Y0?ooo`800000H`3oool00?`0oooo00@000000?ooo`3oool00000J03o
ool010000000oooo0?ooo`00001R0?ooo`00n`3oool3000000030?ooo`00
0000000006H0oooo0P0000020?ooo`800000H@3oool00?l0ooooc`3oool0
0?l0ooooc`3oool00?l0ooooc`3oool00?l0ooooc`3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{462, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  Again, we use the implicit formula, Equation ",
  StyleBox["(10-18)",
    FontColor->RGBColor[0, 0, 1]],
  ", and write  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\((z\  - \ \((\(-2\))\))\)\ \((\((\(-1\) - \[ImaginaryI])\)\  - \ \
0)\)\)\/\(\((z\  - \ 0)\) \((\((\(-1\) - \[ImaginaryI])\)\  - \ \((\(-2\))\))\
\)\)\  = \ \(\((w\  - \ \((\(-1\))\))\)\ \((0\  - 1)\)\)\/\(\((w\  - 1)\) \
\((0\  - \ \((\(-1\))\))\)\(\ \)\)\)]],
  "  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\((z\  + 2)\)\ \((\(-1\) - \[ImaginaryI])\)\)\/\(\((z\ )\) \
\((\(-1\) - \[ImaginaryI]\  + 2)\)\)\  = \ \(\((w\  + \ 1)\)\ \
\((\(-1\))\)\)\/\(\((w\  - \ 1)\) \((1)\)\(\ \)\)\)]],
  "  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(\(z\)\(\ \)\(+\)\(\ \)\(2\)\(\ \)\)\/\(\(z\)\(\ \)\)\) \(\(-1\)\  \
- \ \[ImaginaryI]\)\/\(1\  - \ \[ImaginaryI]\)\ \  = \ \(\(1\)\(\ \)\(+\)\(\ \
\)\(w\)\(\ \)\)\/\(\(1\)\(\ \)\(-\)\(\ \)\(w\)\(\ \ \)\)\)]],
  "    "
}], "Text"],

Cell[TextData[{
  "Using the fact that  ",
  Cell[BoxData[
      \(\(\(-1\)\  - \ \[ImaginaryI]\)\/\(1\  - \ \[ImaginaryI]\)\ \  = \ 
        1\/\[ImaginaryI]\)]],
  ",  we rewrite this equation as  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(z\)\(\ \)\(+\)\(\ \)\(2\)\(\ \)\)\/\(\(\[ImaginaryI]\)\(\ \)\(z\)\
\(\ \)\)\  = \ \(\(1\)\(\ \)\(+\)\(\ \)\(w\)\(\ \)\)\/\(\(1\)\(\ \)\(-\)\(\ \
\)\(w\)\(\ \ \)\)\)]],
  ".    "
}], "Text"],

Cell[TextData[{
  "We now expand the equation and obtain  \n\n\t\t\t",
  Cell[BoxData[{
      \(\ \ \ \(\(\((z\  + \ 2)\) \((1\  - \ 
              w)\)\ \ \  = \ \ \ \[ImaginaryI]\ z\ \((1\  + \ 
              w\ )\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\(\(z\  + \ 2\  - \ z\ w\  - \ 
          2\ w\ \ \  = \ \ \ \[ImaginaryI]\ z\  + \ \[ImaginaryI]\ z\ w\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(z\  - \ \[ImaginaryI]\ z\  + \ 
          2\ \ \ \  = \ \ \ z\ w\ \  + \ \[ImaginaryI]\ z\ w\  + \ 
          2\ w\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \(\(\((1 - \[ImaginaryI])\) z\  + \ 
          2\ \ \  = \ \ \ w \((z + \[ImaginaryI]\ z\  + \ 
              2\ )\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \((1 - \[ImaginaryI])\)\ z\  + \ 
          2\ \ \  = \ \ \ \(\(w\) \((\((1\  + \[ImaginaryI])\) z\  + \ 
              2)\)\(\ \)\)\)}]],
  "  \n\nwhich can be solved for w in terms of z, giving the desired solution \
 \n \n\t\t\t",
  Cell[BoxData[
      \(w\  = \ \(S \((z)\)\  = \ \(\((1 - \[ImaginaryI])\) z\  + \ \
2\)\/\(\((1 + \[ImaginaryI])\) z\  + \ 2\)\)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the three points and their images and solve for  w = S(z).  \
\>", "Text"],

Cell[BoxData[{
    \(w = \(z = 0\); \ Remove[w, z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[formula, solset, S];\)\ \), "\n", 
    \(\(formula\  = \ \(\((z - z\_1)\)\ \((z\_2 - z\_3)\)\)\/\(\(\ \)\(\((z - \
z\_3)\) \((z\_2 - z\_1)\)\)\) \[Equal] \(\((w - w\_1)\)\ \((w\_2 - \
w\_3)\)\)\/\(\(\((w - w\_3)\) \((w\_2 - w\_1)\)\)\(\ \)\);\)\ \), "\n", 
    \(\(Print[formula];\)\ \), "\n", 
    \(\(z\_1\  = \ \(-2\);\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(z\_2\  = \ \(-1\) - \[ImaginaryI];\)\ \ \), "\[IndentingNewLine]", 
    \(\(z\_3\  = \ 0;\)\ \), "\n", 
    \(\(w\_1\  = \ \(-1\);\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(w\_2\  = \ 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\_3\  = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute the values\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,      \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,      \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,      \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,      \!\(w\_3\) = \>\"", 
        w\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[formula];\)\ \), "\n", 
    \(\(solset\  = \ Solve[formula, w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S(z) = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "This is equivalent to the formula  ",
  Cell[BoxData[
      \(S \((z)\) = \(\((1 - \[ImaginaryI])\) z\ \  + \ \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\ \  + \ \ 2\)\)]],
  ",  and can be verified by a computation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[
        S[z], "\< = \>", \(\((1 - \[ImaginaryI])\) z\  + \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\  + \ 2\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[S[z], "\< = \>", 
        Simplify[\(\((1 - \[ImaginaryI])\) z\  + \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\  + \ 2\)]];\)\ \), "\n", 
    \(\(Print["\<Are they equal ?  \>", 
        S[z]\  \[Equal] \ 
          Simplify[\(\((1 - \[ImaginaryI])\) z\  + \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\  + \ 2\)]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Check our work and look at the images of  ",
  Cell[BoxData[
      \(z\_1, \ z\_2, \ z\_3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,    \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,  \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,    \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,      \!\(w\_3\) = \>\"", w\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<S[\!\(z\_1\)] = \>\"", 
        S[z\_1], \*"\"\<, S[\!\(z\_2\)] = \>\"", 
        S[z\_2], \*"\"\<,   S[\!\(z\_3\)] = \>\"", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
To visualize the mapping  w = S(z)  we will consider a graph. \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, Iden, wplane, z, zplane];\)\ \), "\n", 
    \(\(Iden[z_] = z;\)\ \), "\n", 
    \(\(S[
          z_] = \(-\(\(\[ImaginaryI]\ \((\((1 + \[ImaginaryI])\) + 
                    z)\)\)\/\(\((1 - \[ImaginaryI])\) + 
                z\)\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{\(-2\), 0}, {\(-1\), \(-1\)}, {0, 
            0}};\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(zdots = 
        Graphics[{{Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Green, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{\(-1\), 0}, {0, 0}, {1, 
            0}};\)\ \), "\[IndentingNewLine]", 
    \(\(wdots = 
        Graphics[{{Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Green, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(zplane = 
        CartesianMap[
          Iden, {\(-2\), 0, 0.125}, {\(-1\), 1, 
            0.125}, \[IndentingNewLine]PlotRange \[Rule] {{\(-2.1\), 
                0.1}, {\(-1.1\), 1.1}}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-2\), 0, 1], 
              Range[\(-1\), 1, 
                1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(wplane = 
        CartesianMap[
          S, {\(-2\), 0, 0.125}, {\(-1\), 1, 
            0.125}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1.2\), 
                1.2}, {\(-0.4\), 2.0}}, 
          AspectRatio \[Rule] 
            1, \[IndentingNewLine]Ticks \[Rule] {Range[\(-1\), 1, 1], 
              Range[\(-1\), 2, 
                1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[zplane, zdots, 
        PlotRange \[Rule] {{\(-2.1\), 0.1}, {\(-1.1\), 
              1.1}}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-2\), 0, 1], 
            Range[\(-1\), 1, 
              1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The points \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<, \!\(z\_2\) = \>\"", z\_2, \*"\"\<, \!\(z\_3\) = \>\"", 
        z\_3, "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<in the z-plane.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[wplane, wdots, 
        PlotRange \[Rule] {{\(-1.2\), 1.2}, {\(-0.4\), 
              2.0}}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], 
            Range[\(-1\), 2, 
              1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The image points \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<, \!\(w\_2\) = \>\"", w\_2, \*"\"\<, \!\(w\_3\) = \>\"", 
        w\_3, "\<,\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping w = S[z] = \>"\ , 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", z\_1, "\<] = \>", 
        S[z\_1], \[IndentingNewLine]"\<,   S[\>", z\_2, "\<] = \>", 
        S[z\_2], \[IndentingNewLine]"\<,   S[\>", z\_3, "\<] = \>", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\tWe let ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " be a region in the z plane that is bounded by either a circle or a \
straight line ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ".  We further let ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(z\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", \(z\_3\)}]}]]],
  " be three distinct points that lie on ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " and have the property that an observer moving along ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " from ",
  Cell[BoxData[
      RowBox[{\(z\_1\), 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(z\_3\)}]]],
  " through ",
  Cell[BoxData[
      \(z\_2\)]],
  " finds the region ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " to be on the left.  If ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a circle and ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " is the interior of ",
  StyleBox["C",
    FontFamily->"Courier New"],
  ", then we say that ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is positively oriented.  Conversely, the ordered triple ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{\(z\_1\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(z\_2\), 
          StyleBox[",",
            FontFamily->"Times New Roman"], \(z\_3\)}], ")"}]]],
  " uniquely determines a region that lies to the left of ",
  StyleBox["C",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe let ",
  StyleBox["G",
    FontFamily->"Courier New"],
  " be a region in the w plane that is bounded by either a circle of a \
straight line ",
  StyleBox["K",
    FontFamily->"Courier New"],
  ".  We further let ",
  Cell[BoxData[
      RowBox[{\(w\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(w\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", \(w\_3\)}]}]]],
  " be three distinct points that lie on ",
  StyleBox["K",
    FontFamily->"Courier New"],
  " such that an observer moving along ",
  StyleBox["K",
    FontFamily->"Courier New"],
  " from ",
  Cell[BoxData[
      RowBox[{\(w\_1\), 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(w\_3\)}]]],
  " through ",
  Cell[BoxData[
      \(w\_2\)]],
  " finds the region ",
  StyleBox["G",
    FontFamily->"Courier New"],
  " to be on the left.  Because a bilinear transformation is a conformal \
mapping that maps the class of circles and straight lines onto itself, we can \
use the implicit formula to construct a bilinear transformation ",
  Cell[BoxData[
      \(w = S \((z)\)\)],
    AspectRatioFixed->True],
  " that is a one-to-one mapping of ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " onto ",
  StyleBox["G",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 10.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  the mapping  ",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(\((1 - \[ImaginaryI])\) z\ \  + \ \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\ \  + \ \ 2\)\)\)],
    AspectRatioFixed->True],
  "  maps the disk  ",
  Cell[BoxData[
      \(D : \ \(\(|\)\(z + 1\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  one-to-one and onto the upper half plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009>0000[b000`400?l0
0000o`00003oo`3ooooo0?oooe00oooo003o0?ooool0ooooD03oool00?l0
ooooo`3ooom@0?ooo`00o`3ooooo0?oooe00oooo003o0?ooool0ooooD03o
ool00?l0ooooo`3ooom@0?ooo`00g`3oool00`000000oooo0?ooo`0c0?oo
o`800000:`3oool4000002X0oooo1@00001C0?ooo`D00000:@3oool40000
02/0oooo0P00000W0?ooo`00UP3oool2003o04L0oooo00<000000?ooo`3o
ool0<P3oool010000000oooo0?ooo`00000Z0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo02/0oooo00@000000?ooo`3oool000009P3oool0
09D0oooo1000o`0o0?ooo`D000000P3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0U0?ooo`00U03oool6003o0400
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0/0?ooo`@0
00001@3oool00`000000oooo0?ooo`0R0?ooo`@00000103oool00`000000
oooo0?ooo`0S0?ooo`@00000103oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0T0?ooo`00S`3oool50000o`H00?l01@000?lk0?ooo`030000
003oool0oooo0080oooo0P00000c0?ooo`040000003oool0oooo000002X0
oooo00@000000?ooo`3oool00000;03oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo02T0oooo00@000000?ooo`3oool00000:P3oool0
10000000oooo0?ooo`00000V0?ooo`00Q`3oool80000o`H0oooo1000o`06
0?ooo`P0003o:`3oool4000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0c0?ooo`800000;03oool2000002`0oooo0P00001F
0?ooo`800000;03oool2000002`0oooo0P00000W0?ooo`00Q03oool30000
o`l0oooo0P00o`0?0?ooo`<0003o<03oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0?l0ooooK@3oool00840oooo10000?lA0?ooo`03
0?l0003oool0oooo0100oooo0`000?l]0?ooo`800000103oool00`000000
oooo0?ooo`3o0?ooofd0oooo001m0?ooo`@0003o0`3oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0003oool0oooo00l0oooo00@0003o0?ooo`3oool0
oooo0`000?l`0?ooo`030000003oool0oooo0?l0ooooK@3oool007/0oooo
0P000?l70?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`040?ooo`<0003o;@3oool00`000000oooo
0?ooo`3o0?ooofd0oooo001i0?ooo`80003o2@3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool01`3o
ool30000obX0oooo00<000000?ooo`3oool0S03oool20?l002`0oooo0P00
o`0[0?ooo`80003oIP3oool4000001T0oooo001g0?ooo`80003o303oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool02`3oool20000obP0oooo00<000000?ooo`3oool0R`3oool4
0?l002X0oooo1000o`0Y0?ooo`@0003oI03oool010000000oooo0?ooo`00
000J0?ooo`00M@3oool20000o`h0oooo00<0003o0?ooo`3oool0203oool>
0?l000T0oooo00<0003o0?ooo`3oool03@3oool20000obH0oooo00<00000
0?ooo`3oool0<@3ooolj0000o`030?l000000?l0003o01`0003o1P3o000@
0000o`030?l000000?l0003o00/0003o0P3o00080000o`H00?l02@000?l0
0`3o0000003o0000o`0;0000o`030?l000000?l0003o0380003o00<0o`00
0000o`000?l0>0000?l90?ooo`040000003oool0oooo000001X0oooo001c
0?ooo`80003o403oool010000?l0oooo0?ooo`3oool70?l000H0oooo00<0
o`000?ooo`3oool01@3oool70?l00080oooo00<0003o0?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0603oool00`000?l0oooo0?ooo`0@0?ooo`030000003o
ool0oooo00T0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`080?ooo`H0o`001`3oool20000o`L0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01P00o`030?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool20000o`H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`040?ooo`H0003o2`3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo0P00
00000`3oool000000000000J0?ooo`00LP3oool00`3o0000oooo0?ooo`0@
0?ooo`040?l000000?l0o`000?l000d0oooo00<0o`000?ooo`3oool0303o
ool20?l000030000o`3o0000oooo0100oooo00<0o`000000o`3oool08P3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01P0oooo00<0
003o0?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool02@3oool40?l000T0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?oo
o`3oool4003o00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`@0003o303oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`3oool0
403oool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo02D0oooo
001`0?ooo`80003o00<0oooo0?l0003oool03P3oool20?l000030?ooo`00
0?l0oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?l0
00030?l000`0oooo00<0o`000?ooo`3oool00P000?lQ0?ooo`030000003o
ool0oooo04`0oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo00X0oooo0P3o000:0?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3o00000`000?l0o`000?l0
000:0?l000030000o`3o0000o`000080o`000P00o`050?l000030000o`3o
0000o`0000T0o`0000<0003o0?l0003o00002@3o00050?ooo`030000o`3o
ool0oooo00H0oooo0P000?l=0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0703oool00`000?l0oooo0?ooo`100?ooo`00KP3oool2
0000o`@0oooo00<0o`000?ooo`3oool02@3oool30?l000<0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00<0oooo0P3o000:0?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool07P3oool00`000000oooo0?ooo`1<0?ooo`030000o`3oool0
oooo01d0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00<0oooo1@3o00000`000?l0o`000?l00008
0?l000D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool01@3oool0103o0000oooo0?ooo`3oool40?l000030000o`3o
0000o`0000<0o`001@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool0703oool00`000?l0oooo0?oo
o`100?ooo`00K@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00L0oooo0P3o00070?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`80o`001`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo01d0oooo00<00000
0?ooo`3oool0C03oool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool0203oool90?l000D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`T0o`002P3oool0
0`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01d0oooo00<0003o
0?ooo`3oool0@03oool006`0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`030?ooo`<0o`002@3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0203oool20?l0
00D0oooo00<0o`000?ooo`3oool01@3oool20000oad0oooo00<000000?oo
o`3oool0C@3oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo
0100oooo00@0003o0?ooo`3oool0oooo1`3o00030?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0003o00<0o`000000o`000?l02@000?l0
0`3o0000003o0000o`090000o`030?l000000?l0003o00@0003o1P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00@0o`00
0?ooo`3oool0oooo1P3o00040?ooo`030000o`3oool0oooo0100oooo00<0
o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`100?ooo`00J`3oool0
0`000?l0oooo0?ooo`070?ooo`040?l0003oool0oooo0?ooo`80o`00303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool02P3oool20?l00080oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0J0?ooo`030000003oool0oooo04d0oooo00<0
003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0>0?ooo`80o`0000@0
003o0?l0003o0000o`002P3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?l000000?l020000?l40?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool50000o`80oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00L0oooo103o00000`000?l0o`00
0?ooo`0@0?ooo`030?l0003oool0oooo01d0oooo00<0003o0?ooo`3oool0
@03oool006T0oooo0P000?l;0?ooo`<0o`003P3oool00`000?l0oooo0?oo
o`070?ooo`D0003o00<0o`000000o`000?l010000?l80?ooo`030000o`3o
ool0oooo00d0oooo0P3o000<0?ooo`030000o`3oool0oooo01T0oooo00<0
00000?ooo`3oool0C@3oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003o
ool0oooo00T0oooo1@3o00030?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool01`3oool010000?l0oooo0?ooo`3oool40000o`030?oo
o`3o0000oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00P3oool20000o`030?l000000?l0003o0080003o
103oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3o0000103o000<0?ooo`030?l0003oool0oooo01`0oooo
00<0003o0?ooo`3oool0@@3oool006P0oooo00<0003o0?ooo`3oool02`3o
ool20?l000l0oooo00@0003o0?ooo`3oool0oooo1P000?l50?ooo`030?l0
003oool0oooo00@0oooo1P000?l20?ooo`030000o`3oool0oooo00h0oooo
0P3o000<0?ooo`80003o6@3oool00`000000oooo0?ooo`1=0?ooo`030000
o`3oool0oooo01`0oooo00<0o`000?ooo`3oool01@3oool40?l000P0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`060?ooo`D0003o
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3o00000`3o00000`000?l0o`000?l000080?l000030000
o`3o0000o`000080o`0000<0oooo0?l0003oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo0080oooo1`000?l70?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool01@3oool50?l000L0oooo
00<0o`000?ooo`3oool0703oool00`000?l0oooo0?ooo`110?ooo`00I`3o
ool00`000?l0oooo0?ooo`0:0?ooo`80o`0000<0oooo0?l0003oool03@3o
ool50000o`/0oooo00<0o`000?ooo`3oool02P3oool40000o`h0oooo00<0
o`000?ooo`3oool00P3o000<0?ooo`030000o`3oool0oooo01H0oooo00<0
00000?ooo`3oool0C@3oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003o
ool0oooo00D0o`00303oool00`000?l0oooo0?ooo`0;0?ooo`040?l0003o
ool0oooo0?ooo`D0003o0P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3o00040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`020?ooo`H0o`000P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@000?l20?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool50?l00080oooo
00<0o`000?ooo`3oool0703oool00`000?l0oooo0?ooo`110?ooo`00IP3o
ool00`000?l0oooo0?ooo`090?ooo`80o`00103oool00`3o0000oooo0?oo
o`080?ooo`<0003o0P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool00`000?l;0?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`0E0?ooo`030000003oool0oooo04d0oooo00<0003o0?ooo`3oool06P3o
ool50?l00140oooo00<0003o0?ooo`3oool02`3oool0103o0000003o0000
o`000?l70?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3o00000`000?l0o`000?ooo`030?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool20?l000030000
o`3o0000o`0000@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`80003o00<0o`000000o`3oool02`3oool00`000?l0oooo
0?ooo`0?0?ooo`D0o`00703oool00`000?l0oooo0?ooo`110?ooo`00I@3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool01P3oool20000o`D0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00<0oooo0P00
0?l80?ooo`030?l0003oool0oooo00@0oooo0P3o000;0?ooo`030000o`3o
ool0oooo01@0oooo00<000000?ooo`3oool0C@3oool00`000?l0oooo0?oo
o`0F0?ooo`@0o`000`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo00L0oooo10000?l00`3oool0o`000?ooo`080?ooo`030000o`3o
ool0oooo00D0oooo0`3o00050?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`040000o`3oool0oooo0?ooo`D0o`001`3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0003o0080003o203oool00`000?l0oooo
0?ooo`0A0?ooo`040?l0003oool0oooo0?ooo`@0o`00603oool00`000?l0
oooo0?ooo`110?ooo`00H`3oool20000o`/0oooo00<0o`000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`030?ooo`80003o1`3oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
1@3oool20000o`H0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3oool0
CP3oool00`000?l0oooo0?ooo`0@0?ooo`D0o`001`3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0080oooo10000?l50?ooo`030?l0
003oool0oooo00L0oooo00@0003o0?ooo`3oool0oooo103o00000`3oool0
o`000?ooo`050?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3o
ool0oooo20000?l00`3o0000003o0000o`060000o`80oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0o`00
00<0o`000P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
0080oooo0`000?l50?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool01@3oool50?l001<0oooo00<0003o0?ooo`3oool0@@3oool006<0
oooo0P000?l:0?ooo`030?l0003oool0oooo00L0oooo00@0o`000?ooo`3o
ool0oooo0P000?l:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`070?ooo`80003o0`3oool00`3o
0000oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`000?l0503oool00`000000oooo0?ooo`1>0?ooo`030000o`3oool0oooo
00`0oooo103o000<0?ooo`030?l0003oool0oooo0140oooo1@000?l90?oo
o`030?l0003oool0oooo00L0oooo00@0o`000000o`3o0000o`001@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0003o00<0003o00@0o`00
0000o`000?l0003o0P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo0080oooo00@0003o0?ooo`3oool0oooo0P000?l0103o0000003o
0000o`000?l20?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool00`3oool20?l000030000o`3o0000oooo00P0oooo00<0o`000?ooo`3o
ool01P3oool30000o`80oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0:0?ooo`D0o`003P3oool00`000?l0oooo0?ooo`110?ooo`00
HP3oool010000?l0oooo0?ooo`000?l70?ooo`80o`002`3oool00`3o0000
003o0000o`0<0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`090?ooo`80003o00<0oooo0?l0003o
ool02P3oool20?l000H0oooo00D0003o0?ooo`3oool0oooo0000o`0C0?oo
o`030000003oool0oooo04h0oooo00<0003o0?ooo`3oool0203oool40?l0
0100oooo00<0o`000?ooo`3oool0403oool20000o`d0oooo00<0o`000?oo
o`3oool0103oool30?l000030?ooo`000?l0oooo00H0oooo00<0o`000?oo
o`3oool00`3oool30000o`@0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`<0003o1P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0o`000080o`001P3oool00`3o
0000oooo0?ooo`090?ooo`<0003o4P3oool00`3o0000oooo0?ooo`0@0?oo
o`@0o`002@3oool00`000?l0oooo0?ooo`120?ooo`00H@3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0o`000?ooo`0=0?ooo`030000o`3oool0oooo00D0
oooo2`3o00080?ooo`030000o`3oool0oooo00/0oooo00<0o`000000o`3o
ool0303oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0403oool00`000000oooo0?ooo`1>0?ooo`03
0000o`3oool0oooo00<0oooo1@3o000E0?ooo`030?l0003oool0oooo00`0
oooo0`000?l20?ooo`030000o`3oool0oooo00X0oooo00@0o`000?ooo`3o
ool0oooo0`3o00040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`000?l00P000?l20?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?oo
o`@0003o0`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
0080oooo0`3o00020?ooo`030?l0003oool0oooo00/0oooo00@0003o0?oo
o`000?l0003o403oool00`3o0000oooo0?ooo`0D0?ooo`@0o`001@3oool0
0`000?l0oooo0?ooo`120?ooo`00H03oool00`000?l0oooo0?ooo`040?oo
o`050000o`3oool0oooo0?ooo`3o00002`3oool20000o`80oooo00<0o`00
0?ooo`3oool0303oool00`000?l0o`000?l000040?l000D0oooo00<0o`00
0?ooo`3oool00`3oool60?l000030?ooo`000?l0oooo00`0oooo00<0o`00
0?ooo`3oool00P000?l<0?ooo`040?l0003oool0oooo0000o`L0oooo00<0
003o0?ooo`3oool03`3oool00`000000oooo0?ooo`1>0?ooo`030000o`3o
ool0o`0000<0o`006P3oool00`3o0000oooo0?ooo`0:0?ooo`80003o1@3o
ool00`000?l0oooo0?ooo`0;0?ooo`<0o`001`3oool00`000?l0oooo0?oo
o`040?ooo`80003o00<0o`000000o`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80003o00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`<0o`003@3o
ool010000?l0oooo0?ooo`3oool30000o`d0oooo00<0o`000?ooo`3oool0
603oool40?l000030?ooo`000?l0oooo04<0oooo001O0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3o00002`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00T0oooo0P3o00000`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo00<0o`000000o`3o0000303o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00X0oooo00<0
o`000000o`3oool0203oool00`000?l0oooo0?ooo`0>0?ooo`030000003o
ool0oooo04`0oooo0P3o00000`000?l0o`000?ooo`0M0?ooo`030?l0003o
ool0oooo00P0oooo0P000?l70?ooo`030000o`3oool0oooo00X0oooo0P3o
000:0?ooo`040000o`3oool0oooo0?ooo`80003o0P3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo1@3o00000`000?l0o`00
0?l000080?l000060000o`3o0000o`000?l0003oool0o`001@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l000000?l0003o0080003o0`3oool00`00
0?l0oooo0?ooo`080?ooo`80o`002`3oool00`000?l0oooo0?ooo`050?oo
o`<0003o2@3oool00`3o0000oooo0?ooo`0M0?ooo`040000o`3o0000o`00
0?l00480oooo001N0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00H0oooo0`3o00020?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?l000020?l000P0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`090?ooo`030000o`3o0000oooo
00P0oooo00<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`190?oo
o`<0o`000`3oool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo
00@0oooo0`000?l:0?ooo`030000o`3oool0oooo00L0oooo0P3o00020?oo
o`030?l0003oool0oooo00L0oooo00@0003o0?ooo`000?l0003o103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0o`0000<0o`001@3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00@0003o
0?ooo`3oool0oooo1P3o00000`3oool0003o0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo0`000?l:0?ooo`030?l0003oool0oooo0080o`002@3o
ool00`000?l0oooo0?ooo`080?ooo`<0003o1P3oool00`3o0000oooo0?oo
o`0M0?ooo`040000o`3oool0oooo0?ooo`<0o`00?`3oool005h0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0000o`090?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool30?l000H0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00<0oooo0P3o00060?ooo`030?l0003oool0oooo00D0oooo0P00
0?l80?ooo`040000o`3oool0oooo0?l000T0oooo00<0003o0?ooo`3oool0
3@3oool00`000000oooo0?ooo`160?ooo`<0o`001P3oool00`000?l0oooo
0?ooo`0M0?ooo`030?l0003oool0oooo0080oooo0P000?l=0?ooo`030000
o`3oool0oooo00D0oooo0P3o00040?ooo`030?l0003oool0oooo00L0oooo
0P000?l70?ooo`030?l0003oool0oooo00<0oooo00<0o`000000o`3o0000
103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
00D0o`000?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo0080
oooo00<0003o0?l0003oool0103oool00`3o0000oooo0?ooo`050?ooo`80
003o2@3oool00`3o0000oooo0?ooo`020?ooo`80o`001`3oool00`000?l0
oooo0?ooo`0;0?ooo`80003o103oool00`3o0000oooo0?ooo`0M0?ooo`03
0000o`3oool0oooo00@0oooo0P3o000m0?ooo`00G@3oool00`000?l0oooo
0?ooo`070?ooo`050?l0003oool0oooo0?ooo`000?l01P3oool20000o`T0
oooo00<0o`000?ooo`3oool00P3o00090?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`050?ooo`80
o`000`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00D0
oooo00D0003o0?ooo`3oool0oooo0?l000090?ooo`030000o`3oool0oooo
00`0oooo00<000000?ooo`3oool0@`3oool30?l000T0oooo00<0003o0?oo
o`3oool07@3oool00`3o0000oooo0?ooo`020000oa00oooo00<0003o0?oo
o`3oool00P3oool20?l000L0oooo00<0o`000?ooo`3oool0103oool20000
o`030?ooo`000?l0oooo00L0oooo00<0o`000?ooo`3oool00P3o00000`3o
ool0003o0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool00`3oool010000?l0oooo0?l0003o00020?ooo`030?l0003o
ool0oooo00H0oooo00@0003o0?ooo`000?l0003o1P3oool00`3o0000oooo
0?ooo`050?ooo`80o`00103oool00`000?l0oooo0?ooo`0>0?ooo`<0003o
00<0o`000?ooo`3oool07P3oool00`000?l0oooo0?ooo`060?ooo`<0o`00
>P3oool005`0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3o
ool20?l000/0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00L0oooo0`3o000<0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00/0oooo00<000000?ooo`3oool0@03o
ool30?l000d0oooo00<0003o0?ooo`3oool07@3oool00`3o0000003o0?oo
o`0B0?ooo`040000o`3oool0o`000?l000X0oooo00@0o`000?ooo`3oool0
oooo0P000?l40?ooo`030000o`3oool0oooo00D0oooo0`3o00030?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo0`3o00070?oo
o`030000o`3oool0oooo0080oooo0P000?l40?ooo`030?l0003oool0oooo
00L0oooo0P3o00000`3oool0003o0?ooo`0C0?ooo`030?l000000?l0oooo
01d0oooo00<0003o0?ooo`3oool02P3oool30?l003L0oooo001K0?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool010000?l0
oooo0?ooo`000?l<0?ooo`<0o`002`3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool20?l0
00`0oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?ooo`0m
0?ooo`<0o`00403oool00`000?l0oooo0?ooo`0K0?ooo`80003o00<0o`00
0?ooo`3oool04P3oool00`000?l0o`000?ooo`0;0?ooo`040?l0003oool0
003o0000o`H0oooo00<0003o0?ooo`3oool0103oool30?l000D0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`070000o`030?l00000
0?l0003o00<0003o0`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo0`3o00060?ooo`030000o`3oool0oooo00@0oooo0P00
0?l00`3oool0o`000?ooo`0;0?ooo`030?l000000?l0oooo0180oooo00<0
o`000?ooo`3oool00P000?lL0?ooo`030000o`3oool0oooo00d0oooo0`3o
000d0?ooo`00F`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo0P000?l<0?ooo`040?l0003oool0oooo0?l000/0oooo00<0
003o0?ooo`3oool00`3oool50000o`030?l000000?l0003o00@0003o103o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo0080o`002`3o
ool00`000?l0oooo0000o`080?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool02P3oool00`000000oooo0?ooo`0j0?ooo`<0o`004`3o
ool00`000?l0oooo0?ooo`0I0?ooo`80003o0`3oool00`3o0000oooo0?oo
o`0@0?ooo`80o`0000<0003o0?ooo`3oool02P3oool00`000?l0o`000?oo
o`080?ooo`040000o`3oool0oooo0?ooo`80o`000P3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?l000000?l0
0P3oool00`000?l0oooo0?ooo`020?ooo`060?l0003oool0oooo0?ooo`00
0?l0oooo0`000?l00`3o0000003o0?ooo`020?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00P3o00030?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?l0003oool02`3oool010000?l0oooo0?l0003o000A
0?ooo`030?l0003oool0oooo0080oooo0P000?lI0?ooo`030000o`3oool0
oooo0140oooo0P3o000b0?ooo`00FP3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00P0oooo0P000?l;0?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0000o`030000
o`D0oooo00<0o`000?ooo`3oool0103oool50000o`/0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`090?oo
o`030000003oool0oooo03L0oooo0`3o000G0?ooo`030000o`3oool0oooo
01H0oooo0P000?l60?ooo`030?l0003oool0oooo00h0oooo00@0o`000?oo
o`3oool0003o2`3oool00`000?l0oooo0?l0000:0?ooo`030000o`3o0000
o`0000@0oooo00<0o`000?ooo`3oool0103oool01P000?l0oooo0000o`00
0?l0oooo0?l000<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo
0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00`000?l50?ooo`03
0?l0003oool0oooo00<0oooo0P3o00000`3oool0003o0?ooo`080?ooo`03
0?l000000?l0003o00/0oooo00@0003o0?ooo`3oool0oooo0P3o000>0?oo
o`030?l0003oool0oooo00D0oooo0P000?lG0?ooo`030000o`3oool0oooo
01<0oooo0`3o000_0?ooo`00F@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00P0oooo00@0003o0?ooo`3oool0003o2@3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo10000?l90?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`000?l00P000?l70?oo
o`030?l0003oool0oooo00@0oooo0P3o00080?ooo`030000o`3oool0003o
00X0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?oo
o`030000003oool0oooo03D0oooo0P3o000J0?ooo`030000o`3oool0oooo
01@0oooo0P000?l80?ooo`030?l0003oool0oooo00`0oooo0P3o00040?oo
o`030000o`3oool0oooo00H0oooo0P000?l30?ooo`030?l0003oool0oooo
00H0oooo00<0o`000000o`3oool01P3oool00`3o0000oooo0?ooo`030?oo
o`80003o0`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`00
0?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo0P00
0?l40?ooo`030?l0003oool0oooo00D0oooo00<0003o0?l0003oool01`3o
ool0103o0000oooo0?ooo`3oool20000o`P0oooo00<0003o0?ooo`3oool0
103oool20?l000`0oooo00<0o`000?ooo`3oool01`3oool20000oa@0oooo
00<0003o0?ooo`3oool05`3oool30?l002`0oooo001I0?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00@0oooo0P3o00070?ooo`030?l0003o
ool0oooo00<0oooo0P000?l30?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`80003o1@3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo0P00
0?l30?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`080?ooo`030000003oool0oooo03<0oooo0P3o
000M0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00@0o`000?ooo`3oool0003o1P3oool00`3o0000oooo
0?ooo`040000o`@0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool00P3oool01@3o0000
oooo0?ooo`3oool0003o0080oooo0P000?l00`3oool0o`000?ooo`060?oo
o`040000o`3oool0oooo0?l000H0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo0140oooo00<0003o0?ooo`3oool06P3oool30?l002T0oooo001H0?oo
o`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool01`3oool0103o0000oooo0?ooo`3oool20000o`H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00@0oooo0P000?l20?ooo`030?l0003oool0oooo00P0oooo00D0o`00
0?ooo`3oool0oooo0000o`060?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000003o
ool0oooo0340oooo0P3o000P0?ooo`030000o`3oool0oooo00l0oooo0P00
0?l<0?ooo`030?l0003oool0oooo00P0oooo0P3o00080?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103o
ool00`3o0000003o0?ooo`030?ooo`030000o`3oool0oooo0080oooo00D0
o`000?ooo`3oool0oooo0000o`030?ooo`040?l0003oool0oooo0000o`<0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3o0000oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool02`3oool20000oa00oooo00<0003o0?ooo`3o
ool07P3oool20?l002L0oooo001G0?ooo`030000o`3oool0o`0000H0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`040000
o`3oool0oooo0?l000/0oooo00<0o`000000o`000?l0203oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0o`000?ooo`0;0?ooo`030?l0003oool0003o00P0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`040?ooo`80
o`0000<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`1C0?ooo`03
0000o`3oool0oooo00d0oooo0P000?l?0?ooo`030?l0003oool0oooo00D0
oooo0P3o000;0?ooo`030000o`3oool0oooo0080003o2@3oool00`3o0000
oooo0?ooo`020?l000H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3o
ool0o`000000o`060?l000050000o`3o0000oooo0?ooo`3o00000`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0003o00@0oooo00<0003o
0?ooo`3oool0103oool20?l00080oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00T0oooo0P3o0006
0?ooo`030?l0003oool0oooo00h0oooo0P000?l>0?ooo`030000o`3oool0
oooo04L0oooo001G0?ooo`030000o`3oool0oooo0080o`00103oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0003o0?l0
003oool02P3oool20000o`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00L0oooo00<0o`000000o`000?l02`3oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool01@3o
0000oooo0?ooo`3oool0003o00P0oooo00<000000?ooo`3oool0E03oool0
0`000?l0oooo0?ooo`0:0?ooo`80003o4P3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00`0oooo0P000?l<0?ooo`80o`002@3oool0
10000?l0oooo0?ooo`000?l30?ooo`030?l0003oool0oooo0080oooo00@0
003o0?ooo`3oool0oooo103o00001@000?l0oooo0?ooo`3oool0o`000080
oooo00<0003o0?ooo`3o00000P3o00030?ooo`030000o`3oool0oooo0080
oooo00@0o`000?ooo`3oool0oooo0P000?l00`3oool0003o0?ooo`080?oo
o`80o`002`3oool010000?l0oooo0000o`000?l>0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool04@3oool20000o`/0oooo00<0003o
0?ooo`3oool0B03oool005H0oooo00<0003o0?ooo`3oool00`3oool20?l0
00030?ooo`3o0000oooo00P0oooo00<0003o0?ooo`3oool01`3oool20?l0
00030000o`3oool0oooo00L0oooo0P000?l20?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0000o`09
0?ooo`030000o`3oool0o`0000T0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`020?l000@0oooo00<0003o0?ooo`3oool01P3oool0
0`000000oooo0?ooo`1E0?ooo`030000o`3oool0oooo00L0oooo0P000?lD
0?ooo`040?l0003oool0oooo0?ooo`80o`003`3oool20000o``0oooo0P3o
000:0?ooo`80003o103oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0o`000P3oool01@000?l0oooo0?ooo`3oool0o`000080oooo
00D0003o0?ooo`3oool0o`000?ooo`020?l000030?ooo`000?l0oooo00<0
oooo00<0o`000?ooo`3oool00`3oool20000o`T0oooo0P3o000<0?ooo`03
0000o`3oool0oooo00l0oooo00D0o`000?ooo`3oool0oooo0?l0000E0?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0B03oool005H0
oooo00<0003o0?ooo`3oool01@3oool20?l000P0oooo00<0003o0?ooo`3o
ool01`3oool01@3o0000oooo0?ooo`3oool0003o00L0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo
0?ooo`X0o`000`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3o
ool0o`0000T0oooo00<0003o0?ooo`3oool01`3oool20?l000L0oooo00<0
003o0?ooo`3oool01@3oool00`000000oooo0?ooo`1E0?ooo`030000o`3o
ool0oooo00D0oooo0P000?lG0?ooo`030?l0003oool0o`000100oooo00@0
003o0?ooo`3oool0003o2P3oool0103o0000oooo0?ooo`3o00090?ooo`80
003o1@3oool00`3o0000oooo0?ooo`020?ooo`050000o`3o0000oooo0?oo
o`3o00000`3oool01P000?l0oooo0?ooo`3o0000oooo0000o`<0oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo00@0oooo
0P000?l80?ooo`040?l0003oool0oooo0?l000X0oooo00<0003o0?ooo`00
0?l04@3oool30?l001L0oooo0P000?l70?ooo`030000o`3oool0oooo04T0
oooo001E0?ooo`030000o`3oool0oooo00H0oooo0`3o00070?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool20000o`@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`070?ooo`040000
o`3o0000o`000?l000@0oooo00<0o`000?ooo`3oool00`3oool30?l00003
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool20000o`@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00D0oooo0P3o00080?ooo`030000o`3oool0oooo00D0
oooo00<000000?ooo`3oool0EP3oool00`000?l0oooo0?ooo`020?ooo`80
003o6P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo00@0oooo0P000?l00`3oool0003o0?ooo`040?ooo`03
0?l0003oool0oooo0080o`0000<0003o0?ooo`3oool00P3oool0103o0000
oooo0?ooo`000?l20?ooo`030?l0003oool0003o0080oooo00<0o`000?oo
o`3oool00P3oool00`000?l0o`000?l000020?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`000?l01P3oool00`3o0000oooo0?ooo`020?oo
o`030?l0003oool0oooo00L0oooo00@0003o0?ooo`3oool0003o4@3oool2
0?l001T0oooo0P000?l50?ooo`030000o`3oool0oooo04T0oooo001E0?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P3o00040?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool01000
0?l0oooo0?ooo`000?l80?ooo`030?l0003oool0oooo00@0oooo0P3o0000
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00@0003o
0?ooo`3o0000o`001@3oool00`3o0000oooo0?ooo`070?ooo`040000o`3o
ool0oooo0000o`L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`020?ooo`80o`000P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00@0oooo00<000000?ooo`3oool0E`3oool010000?l0oooo
0?ooo`000?lJ0?ooo`80o`0000<0oooo0?l0003oool03@3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool20?l000<0oooo00D0003o0?ooo`3o
ool0oooo0?l000020?ooo`060000o`3oool0oooo0?l0003oool0003o0P3o
ool01@3o0000oooo0?ooo`3oool0003o00<0oooo0P3o00060?ooo`050000
o`3oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool20000o`h0
oooo00@0o`000?ooo`3oool0o`006P3oool20000o`80oooo00<0003o0?oo
o`3oool0BP3oool005@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`030?ooo`80o`0000<0oooo0000o`3oool0203oool00`3o0000
oooo0?ooo`070?ooo`80003o2P3oool0103o0000oooo0?ooo`3oool20?l0
0080oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`040000o`3oool0oooo0?ooo`<0o`000P3oool00`3o0000oooo0?ooo`08
0?ooo`80003o2@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo0080o`00103oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00@0oooo00<000000?ooo`3oool0E`3oool30000oaX0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`05
0?ooo`80o`0000<0oooo0000o`3oool01@3oool00`000?l0oooo0?ooo`02
0?ooo`80o`00103oool010000?l0oooo0?ooo`3o00020?ooo`080000o`3o
ool0oooo0?l0003oool0003o0?ooo`3o00030?ooo`030000o`3oool0oooo
0080oooo0P3o00040?ooo`80003o1@3oool010000?l0oooo0?l0003o0008
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool06@3oool30000od`0oooo001D0?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`3o0000003o0?ooo`070?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool0103o
0000oooo0?l0003o00040?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`80o`00303oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo0P3o0007
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool0
0`000000oooo0?ooo`1G0?ooo`80003o6P3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool0
1@000?l0oooo0?ooo`3oool0o`0000X0oooo00<0o`000000o`3oool01P3o
ool010000?l0oooo0?ooo`3o00020?ooo`80o`000`3oool03@000?l0oooo
0?ooo`3o0000oooo0000o`3oool0003o0?l0003oool0003o0?ooo`3o0000
0P3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo0?l00080
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3o
ool06@3oool20000od`0oooo001C0?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0o`000?l000070?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`000?l02P3oool20?l000L0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00H0oooo0P3o000:0?ooo`030000o`3oool0003o00T0oooo
00<0o`000?ooo`3oool0103oool20?l000030?ooo`000?l0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000
003oool0oooo05H0oooo00<0003o0?ooo`000?l0603oool20?l000P0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0:0?ooo`030000
o`3oool0o`0000/0oooo00<0003o0?l0003o00001`3oool20000o`D0oooo
00@0o`000?ooo`3oool0003o0P3oool00`3o0000003o0000o`020000o`05
0?l000000?l0003o0000o`3o00000P3oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00<0o`000000o`3oool01P3oool20?l000030?ooo`000?l0
oooo00T0oooo00@0o`000?ooo`3oool0003o2`3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo0P3o000H0?ooo`040000o`3o
ool0oooo0000od/0oooo001C0?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?l000@0oooo00<0
o`000?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool0003o00L0oooo
0P3o00000`3oool0o`000?ooo`060?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`040?l0
003oool0oooo0?l000P0oooo00D0003o0?ooo`3oool0oooo0000o`090?oo
o`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`08
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool0
0`000000oooo0?ooo`1D0?ooo`80003o0`3oool00`000?l0oooo0?ooo`0D
0?ooo`030?l0003oool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0<0?ooo`80003o2P3oool01@000?l0oooo0?ooo`3o
ool0o`0000H0oooo00<0o`000?ooo`000?l01@3oool00`3o0000oooo0?oo
o`020000o`0:0?ooo`3o0000oooo0000o`3oool0o`000000o`3oool0o`00
0?ooo`80003o0P3oool20?l000D0oooo00<0003o0?l0003oool01@3oool0
1@3o0000oooo0?ooo`3oool0003o00/0oooo0P000?l=0?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0D0?ooo`030000o`3oool0oooo0080oooo0P000?m90?ooo`00D`3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool00`3oool20?l000030?ooo`3o0000oooo00P0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
103o0000oooo0?ooo`3oool20?l000D0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0080o`001@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool00P3oool00`000000oooo0?ooo`1C0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0303o
ool0103o0000oooo0?ooo`000?l90?ooo`030000o`3oool0oooo0080oooo
0P3o00030?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool03P3o0000
oooo0000o`000?l0oooo0?l0003oool0003o0?ooo`3o0000003o0?ooo`3o
0000oooo0P000?l00`3oool0o`000?ooo`040?ooo`80003o0P3oool0103o
0000oooo0?ooo`3oool20?l000D0oooo00<0003o0?ooo`3oool01P3oool2
0000o`030?ooo`3o0000oooo00`0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01<0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`160?ooo`00DP3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool20?l000P0oooo00<0003o0?ooo`3oool01@3oool01@00
0?l0oooo0?ooo`3oool0o`0000D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`030000o`030?l000000?l0003o0080003o0P3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00D0o`00
0?ooo`3oool0oooo0000o`060?ooo`030000o`3oool0oooo00L0oooo0P3o
00070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo0580oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo00`0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0<0?ooo`040?l0003oool0oooo0?ooo`80003o1P3oool00`000?l0oooo
0?ooo`050?ooo`040?l0003oool0oooo0?l000@0oooo00<0003o0?ooo`3o
ool00`3oool03@3o0000oooo0?ooo`000?l0o`000?ooo`000?l0oooo0?l0
00000?l0o`000?ooo`000?l00P3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0o`001`3oool00`00
0?l0oooo0?ooo`040?ooo`80003o0`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0303oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool0A@3oool00580oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
00001`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0o`0000L0
oooo00<0o`000?ooo`3oool0103oool30000o`<0oooo00@0o`000?ooo`3o
ool0oooo1@000?l50?ooo`030?l0003oool0oooo00D0oooo00<0o`000?oo
o`000?l0203oool00`000?l0oooo0?ooo`040?ooo`<0o`00203oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00D0003o0?oo
o`3oool0oooo0000001B0?ooo`80003o2@3oool00`000?l0oooo0?ooo`0?
0?ooo`030?l0003oool0oooo00h0oooo00@0o`000?ooo`3oool0003o3P3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool01`3oool20?l000H0oooo0P000?l20?ooo`030000o`3o
ool0o`000080oooo00<0003o0?l0003oool00P000?l00`3oool0o`000000
o`020?ooo`030?l0003oool0003o0080oooo0P000?l60?ooo`80o`002@3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0303oool010000?l0oooo0?ooo`3o000@0?ooo`030?l0
003oool0oooo00l0oooo00<0003o0?ooo`3oool0203oool20000odD0oooo
001B0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0080o`00103o
ool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00@0
o`000?ooo`3oool0oooo10000?l50?ooo`030?l0003oool0oooo00@0oooo
00@0003o0?ooo`000?l0003o0P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3o0000oooo00P0oooo00<0003o0?ooo`3oool00P3oool01@3o0000
oooo0?ooo`3oool0o`0000P0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000000D@3oool0
0`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool0403oool20?l000h0oooo00<0o`000?ooo`3oool01P3oool2
0000o`80oooo00<0003o0?ooo`3oool0203oool30?l000H0oooo0P000?l3
0?ooo`050?l0003oool0003o0?l0003oool00P000?l01@3o0000oooo0000
o`3oool0o`0000<0oooo0P000?l60?ooo`<0o`002P3oool00`000?l0oooo
0?ooo`020000o`L0oooo00<0o`000?ooo`3oool03@3oool20?l00180oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030000
o`3oool0oooo0480oooo001A0?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00<0oooo0P3o00000`3oool0003o0?ooo`090?ooo`030?l0003o
ool0003o00P0oooo00<0o`000000o`000?l0103oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0o`000?ooo`080?ooo`040000o`3oool0oooo0?l000P0oooo
00<0003o0?ooo`3oool00P3o00040?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`050000
o`3oool0oooo0?ooo`000000C`3oool20000o`h0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0o`0000`0
oooo00<0o`000?ooo`3oool02@3oool30000o`T0oooo00@0o`000?ooo`3o
ool0oooo103o00030?ooo`<0003o0P3oool0103o0000oooo0000o`3o0002
0000o`040?l000000?l0oooo0?l00080oooo0`000?l40?ooo`<0o`000P3o
ool00`3o0000oooo0?ooo`090?ooo`80003o2P3oool00`3o0000oooo0?oo
o`0;0?ooo`030?l0003oool0003o01<0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo0440oooo001A
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0000o`3oool0203oool01@3o0000oooo0?ooo`3oool0003o00H0oooo0P00
0?l00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l00000
0?l0003o00D0oooo0P000?l30?ooo`030?l0003oool0oooo00L0oooo0P3o
00070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0oooo000004h0oooo
00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo0140oooo00@0003o0?ooo`3oool0oooo0P3o000:0?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool00P000?l70?ooo`03
0?l0003oool0oooo00D0oooo0P3o0000103oool0003o0000000000020000
o`030000003o0000oooo00@0003o00<0oooo0?l0003oool00P000?l30?oo
o`040000o`3o0000o`000?l000H0oooo00<0o`000?ooo`3oool01@3oool4
0000o``0oooo00<0o`000?ooo`3oool0203oool20?l00080oooo00<0003o
0?ooo`3oool04P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00l0oooo0P000?m10?ooo`00D03oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3o0000o`0000L0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo
0?l000D0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
o`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000003o0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`040000o`3o
ool0oooo000004d0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
0`3oool20?l000L0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`020?ooo`80003o1@3oool00`3o0000oooo0?ooo`070?ooo`H0o`00
0P000?l50?l000030000o`3o0000o`0000H0o`002@3oool00`3o0000oooo
0?ooo`030?ooo`80003o103oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00H0oooo0P3o00050?ooo`030000o`3oool0oooo0180oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0B0?ooo`030000
o`3oool0oooo03h0oooo001@0?ooo`D0003o0`3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`020?l000@0oooo00<0o`000?ooo`3oool01@3o
ool010000?l0oooo0000o`000?l40?ooo`030?l0003oool0oooo00<0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0000o`070?ooo`03
0?l0003oool0oooo00<0oooo0P3o00020?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`04
0?l0003oool0oooo0?ooo`D0003o0P3oool00`000000oooo0?ooo`190?oo
o`80003o5@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool01P3oool20?l000D0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`040?ooo`@0003o00<0oooo0?l0
003oool0203oool01@000?l0oooo0?ooo`3oool000000080oooo00<0003o
0?l000000?l0103o00000`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo00P0oooo00<0o`000000o`000?l00P000?l60?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool00`3oool20?l000L0oooo00<0003o
0?ooo`3oool04P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo01@0oooo00<0003o0?ooo`3oool0?@3oool00500oooo00<0003o0?oo
o`3oool00P3oool30000o`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00<0oooo0P3o00000`3oool0o`000?ooo`080?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00P3o0004
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`040?l0003oool0003o0000o`@0oooo00@0
003o0?ooo`3oool00000BP3oool00`000?l0oooo0?ooo`0F0?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`090?ooo`80o`000P3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00P0oooo4P000?l30?l00080003o0`3o000B0000o`X0oooo
00<0003o0?ooo`3oool02P3oool0103o0000oooo0?ooo`3oool20?l000X0
oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo01H0oooo0P000?lm0?ooo`00D03oool00`000?l0oooo
0?ooo`050?ooo`<0003o1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`080?ooo`80003o1P3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0o`0000D0o`0000<0oooo0000o`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0003o00T0oooo0P3o00070?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`<0003o1`3oool00`000?l0oooo000000190?ooo`030000
o`3oool0oooo01P0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`0B0?ooo`030000o`3oool0oooo00/0oooo0`3o000=0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool01@000?l0oooo
0?ooo`3oool000000080o`0000<0oooo0000o`3oool00P3o00020000o`03
0?ooo`3o0000o`0000@0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00/0oooo0`3o000=0?ooo`03
0000o`3oool0oooo0180oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0I0?ooo`030000o`3oool0oooo03X0oooo001?0?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P000?l80?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool30?l000L0oooo
00@0003o0?ooo`3oool0003o1@3oool01`3o0000oooo0?ooo`3oool0o`00
0000o`3o00000P3oool01P3o0000oooo0?ooo`3o0000003o0?l000<0oooo
00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o00H0
oooo0`3o00080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool60000o`030?ooo`3o0000oooo00L0oooo00<0003o0?ooo`00
0000B03oool00`000?l0oooo0?ooo`0J0?ooo`040000o`3oool0oooo0?l0
01@0oooo00<0003o0?ooo`3oool03@3oool30?l000/0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`80003o0`3o00020?oo
o`080000o`3oool0o`000000o`3o0000003o0?l000000?l20?ooo`<0o`00
00<0oooo0000o`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00T0oooo0P3o000?0?ooo`030000o`3oool0oooo01<0oooo
00@0o`000?ooo`3oool0003o7@3oool00`000?l0oooo0?ooo`0i0?ooo`00
C`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
10000?l50?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool0103o0000oooo0?ooo`3oool20?l000@0oooo00<0003o0?ooo`3o
ool00P3oool20000o`@0oooo0`3o00000`3oool0003o0?ooo`020?ooo`06
0?l0003oool0oooo0?ooo`000?l0oooo0`3o00050?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3o
ool0o`0000L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`030?ooo`@0003o1`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0000004L0oooo00<0003o0?ooo`3oool0703oool00`000?l0o`000?oo
o`0D0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0103o
00070?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool01`3o
ool30?l000<0oooo0P000?l0203oool0o`000?ooo`000?l0o`000000o`3o
0000oooo0P000?l30?ooo`<0o`002@3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00D0oooo103o00020?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool04`3oool00`3o0000003o0?ooo`0N0?oo
o`030000o`3oool0oooo03P0oooo001?0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool010000?l0oooo0?ooo`3oool30000
o`030?ooo`3o0000oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`030?ooo`040?l0003oool0oooo0000o`L0oooo00<0003o
0?ooo`3oool00`3o00020?ooo`050000o`3oool0oooo0?ooo`3o00000`3o
ool010000?l0oooo0?ooo`3oool20?l000<0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`020?l000@0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0003o0080003o
0`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`000000AP3oool00`000?l0oooo0?ooo`0M0?ooo`030?l0
00000?l0oooo01<0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`040?ooo`<0o`00103oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00D0oooo0P3o00020?ooo`040000o`3oool0oooo0000o`80
oooo00P0o`000?ooo`000?l0oooo0?l000000?l0oooo0?l00080oooo00@0
003o0?ooo`3oool0003o0P3oool20?l000L0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`020?ooo`<0o`001P3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo0180oooo00<0003o0?l0003oool0
7`3oool00`000?l0oooo0?ooo`0g0?ooo`00C`3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool30000o`H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`80o`0000<0003o0?ooo`3oool01P3oool01@000?l0o`000?oo
o`3oool0o`0000<0oooo00@0003o0?ooo`3oool0o`000P3oool01@000?l0
oooo0?ooo`3oool0o`000080oooo0P3o00000`000?l0oooo0?ooo`060?oo
o`80o`001`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo0`000?l60?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l000000?ooo`140?ooo`030000o`3oool0oooo
01h0oooo00<0o`000?ooo`000?l04`3oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo00P0oooo1`3o00090?ooo`P0o`001@3oool20000
o`<0oooo00P0o`000?ooo`000?l0oooo0?l0003oool0003o0?l000<0oooo
00<0003o0?ooo`000?l0103oool80?l000T0oooo1`3o000:0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool04@3oool010000?l0oooo
0?ooo`3o000P0?ooo`030000o`3oool0oooo03H0oooo001?0?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0003o00D0003o203oool00`3o0000oooo
0?ooo`060?ooo`030000o`3o0000o`0000H0oooo00<0o`000000o`3oool0
0`3oool0103o0000oooo0?ooo`000?l20?ooo`040?l0003oool0oooo0000
o`<0oooo00H0o`000?ooo`3oool0oooo0?l000000?l70?ooo`030?l00000
0?l0oooo00L0oooo00<0o`000?ooo`3oool01P3oool70000o`030?ooo`3o
0000oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`000000oooo04<0oooo00<0003o0?ooo`3oool07P3o
ool0103o0000oooo0?ooo`3oool20000oa00oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0;0?ooo`040000o`3oool0oooo0?ooo`X0
o`00303oool01`000?l0oooo0?ooo`3oool0o`000?ooo`000?l00P3oool0
1@3o0000oooo0000o`3oool0o`0000<0oooo00<0003o0?ooo`3oool02P3o
ool:0?l000<0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00h0oooo0P000?l30?ooo`030?l0003o
ool0oooo01l0oooo00<0003o0?ooo`3oool0=@3oool004l0oooo00@0003o
0000000000000000103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool30000o`H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?l000@0oooo00<0
o`000?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l20?ooo`040?l0
0000000000000000o`80000000<0o`000?ooo`3oool00P3oool00`000?l0
o`000?ooo`040?ooo`80o`000P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00<0oooo0`000?l70?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`000000oooo0480oooo00<0003o0?ooo`3oool07P3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0203oool01@000?l0oooo0000o`3oool0o`00
0080oooo00H0003o0?ooo`3oool0o`000?ooo`000?l20?ooo`050?l0003o
ool0003o0?ooo`000?l02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
7`3oool00`000?l0oooo0?ooo`0d0?ooo`00C`3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0003o0P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo0P3o
00000`3oool0o`000?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000
0P3oool00`000?l0oooo0?l000020?ooo`030000o`3oool0o`0000@0oooo
00<0003o0?ooo`3oool00P3o00000`3oool0o`000?l000050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00`000?l20?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0000003oool0
@@3oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo00D0oooo
0P000?l<0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00H0oooo
0P000?l30?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool00`3o0000
oooo0000o`020?ooo`030000o`3o0000oooo0080oooo0P000?l80?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00X0oooo0P000?l70?ooo`03
0?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0<`3oool004l0oooo
00<0003o0000003oool0103oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`030?ooo`H0003o1@3oool00`000?l0oooo0?ooo`050?ooo`80o`00
103oool01P000?l0oooo0?ooo`3oool0o`000?ooo`80003o00H0o`000000
o`000?l0003o0?ooo`3o00030?ooo`030000o`3oool0oooo0080oooo0P3o
00070?ooo`030000o`3oool0oooo00<0oooo1@000?l60?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0000003oool0@03o
ool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo00P0oooo0P00
0?l:0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00@0oooo0P00
0?l40?ooo`030?l0003oool0003o0080003o0`3oool00`3o0000oooo0000
o`030000o`030?ooo`3o0000oooo00<0oooo0`000?l50?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00P0oooo0P000?l:0?ooo`030?l0003o
ool0oooo0200oooo00<0003o0?ooo`3oool0<P3oool004T0oooo10000000
1@3oool0003o0?ooo`3oool0000000@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool0103o0000oooo0?ooo`3oool30000o`030?oo
o`000?l0oooo00L0oooo0`3o00040?ooo`040000o`3oool000000?l000<0
003o00D0o`000?ooo`000?l0003o0?l000030?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3o00001`3oool00`000?l0oooo0?ooo`030000
o`80oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`000000oooo03h0oooo0P000?lQ0?oo
o`030?l0003oool0oooo00/0oooo0P000?l70?ooo`030000o`3oool0oooo
00l0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo0080oooo0P000?l50?ooo`030?l0003oool0oooo
0080oooo10000?l0103o0000003o0000o`000?l40?ooo`030?l0003oool0
oooo00@0oooo0P000?l30?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo00D0oooo0P000?l=0?ooo`030?l0003oool0oooo0200oooo00<0003o
0?ooo`3oool0<@3oool004h0oooo00D0003o0000003oool0oooo00000003
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool30000o`H0oooo00@0o`000?ooo`3oool0oooo0P3o
00030?ooo`<0003o00P0o`000?ooo`000?l0o`000?ooo`000?l000000?l0
00<0003o0`3oool20?l00080oooo00<0o`000?ooo`3oool01@3oool30000
o`H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`000000oooo03d0oooo00<0003o0?oo
o`3oool0803oool00`3o0000oooo0?ooo`0>0?ooo`<0003o103oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool0103o0000003o0000o`000?l60?ooo`030?l0003oool0
oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool01P3oool20000o`030?ooo`3o
0000oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0?0?ooo`030000o`3oool0oooo00<0oooo0P000?l?0?ooo`030?l0003o
ool0oooo0240oooo00<0003o0?ooo`3oool0<03oool004h0oooo00@0003o
0?ooo`0000000000103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`000?l00P00
0?l30?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P00
0?l0203oool0o`000?ooo`000?l0o`000?ooo`000?l0o`000P3oool00`00
0?l0oooo0?ooo`020?l000D0oooo00@0o`000?ooo`3oool0oooo0`000?l0
0`3oool0003o0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l000000?ooo`0l
0?ooo`030000o`3oool0oooo0240oooo00<0o`000?ooo`3oool04@3oool2
0000o`030?ooo`000?l0oooo0140oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0;0?ooo`80003o2@3oool00`3o0000oooo0?ooo`03
0?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00L0oooo0P000?l=0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`020000oa80oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?oo
o`0_0?ooo`00CP3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`020?ooo`H0003o103oool20?l0000?0000o`3oool0
003o0?ooo`3o0000oooo0?l000000?l0oooo0?l0003oool0003o0?ooo`00
0?l0o`0000D0oooo1P000?l40?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`000000oooo03/0oooo00<0003o0?ooo`3oool08@3o
ool00`3o0000oooo0?ooo`0D0?ooo`80003o4@3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00P0oooo0`000?l20?ooo`030?l0003o
ool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool00`3o0000oooo
0?ooo`050?ooo`030?l0003oool0oooo00<0003o2P3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo0100oooo0`000?lE0?ooo`030?l0
003oool0oooo0200oooo00<0003o0?ooo`3oool0;`3oool004h0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`020000o`<0oooo00X0003o0?l0003o0000oooo
0000o`3o0000oooo0?l000000?l0o`000P000?l0103oool0o`000?l00000
0?l20?ooo`<0003o0P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`000000oooo03X0oooo00<0
003o0?ooo`3oool08@3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3o
ool0003o0080003o3P3oool00`3o0000oooo0?ooo`0=0?ooo`80003o1P3o
ool30000o`D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo
0000o`060?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool30000o`L0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0=0?ooo`<0003o5`3oool00`3o0000oooo0?ooo`0Q0?ooo`030000
o`3oool0oooo02h0oooo001>0?ooo`80o`001P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`@0003o0P3o
ool20?l000030000o`3o0000o`000080003o00<0oooo0?l0003o00000P3o
ool30000o`D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool20000ocX0oooo00<0003o0?ooo`3oool08P3o
ool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo0`00
0?l;0?ooo`030?l0003oool0oooo00h0oooo00@0003o0?ooo`3oool0oooo
0`000?l90?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo00L0oooo0`000?l30?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool02@3oool40000o`<0oooo00<0003o0?ooo`3oool0
5@3oool00`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo02d0oooo
001=0?ooo`@0o`001@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`@0003o0P3oool20?l00080003o0P3o
00000`3oool0003o0000o`020000o`L0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool40000o`L0oooo0P00
00000`3oool000000000000/0?ooo`030000o`3oool0oooo0280oooo00<0
o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`050?ooo`@0003o1`3o
ool00`3o0000oooo0?ooo`0>0?ooo`040000o`3oool0003o0000o``0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`050?ooo`040?l0003oool0oooo0?l000d0oooo10000?l@0?ooo`03
0?l0003oool0oooo00D0oooo10000?l70?ooo`030000o`3oool0oooo01D0
oooo00<0o`000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0/0?ooo`00
BP3oool2000004H0o`000`000?m70?l000H0003o00<000000?ooo`3oool0
103oool00`000000oooo0000000/0?ooo`030000o`3oool0oooo0280oooo
00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0:0?ooo`T0003o
1P3oool;0000o`l0oooo00@0o`000?ooo`3oool0o`001`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?l0000@0?ooo`X0003o1P3oool90000o`/0
oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0R0?ooo`03
0000o`3oool0oooo02/0oooo001<0?ooo`H0o`00103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`040000
o`3oool0oooo0?ooo`<0003o103o00020000o`<0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo0P000?l70?ooo`030?l0003oool0oooo0080
oooo1P000?l80?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3o
ool08`3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`000?l01P000?l80?ooo`030000o`3oool0oooo00l0
oooo0P3o00070?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool01P3oool70000o`030?ooo`3o0000oooo0140
oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0R0?ooo`03
0000o`3oool0oooo02X0oooo001=0?ooo`@0o`001@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`@0003o
00@0oooo0?l0003o0000o`000`000?l20?l000@0003o1`3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool20?l000D0oooo10000?l70?ooo`80
000000<0oooo000000000000:@3oool00`000?l0oooo0?ooo`0S0?ooo`03
0?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0?0?ooo`030000o`3oool0oooo00d0oooo0`3o00070?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0o`0000l0oooo00<0003o0?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo01H0
oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0Y0?ooo`00
CP3oool20?l000H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P000?l01P3oool0o`000?l000000?l0oooo0?l0
0080003o00<0o`000000o`3oool00P3o00000`3oool0003o0000o`040000
o`80oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool20000ocD0oooo00<0003o0?ooo`3oool0903oool00`3o
0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo0180oooo00<0o`000?oo
o`3oool03`3oool00`000?l0oooo0?ooo`0<0?ooo`040?l0003oool0oooo
0?ooo`80o`00103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3o
ool0o`0000h0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool08`3o
ool00`000?l0oooo0?ooo`0X0?ooo`00CP3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`<0003o1@3oool2
0?l00080oooo00<0003o0?l0003oool00P000?l00`3o0000oooo0000o`02
0?ooo`030?l0003oool0oooo00@0oooo0`000?l70?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`000000oooo03<0oooo00<0003o
0?ooo`3oool0903oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0
oooo0180oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0000
o`070?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo01L0oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?oo
o`0W0?ooo`00CP3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`020?ooo`<0003o00<0o`000?ooo`3oool0103oool0
403o0000oooo0000o`3oool0003o0?ooo`3o0000003o0?l0003oool0003o
0?l0003oool0003o0?ooo`000?l20?l000H0oooo00@0o`000000o`000?l0
003o103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
00000?ooo`0b0?ooo`030000o`3oool0oooo02D0oooo00<0o`000?ooo`3o
ool05`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`80
o`0000<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo0080o`001`3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo0100oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0H0?ooo`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3o
ool09P3oool004h0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`000?l00P000?l30?ooo`030?l0003oool0oooo0080oooo
0P3o00020?ooo`80003o00P0oooo0?l0003oool0003o0?l0003oool0003o
0?l00080oooo00@0003o0?ooo`3oool0oooo0P3o00030?ooo`030?l0003o
ool0oooo0080oooo0`000?l00`3oool0003o0?ooo`060?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l000000?ooo`0b0?ooo`030?l0003oool0oooo02@0oooo00<0
o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool01`3oool20?l000/0oooo00<0
003o0?l0003oool01P3oool00`3o0000oooo0?ooo`040?ooo`030?l00000
0?l0o`0000X0oooo0P3o00090?ooo`030000o`3oool0oooo0100oooo00<0
o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003o
ool0oooo02D0oooo00<0o`000?ooo`3oool09@3oool004h0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`040?l0003oool0oooo0?ooo`H0003o1`3oool0103o0000oooo0?l0
003o00040?ooo`030000o`3oool0o`000080oooo00T0003o0?l0003oool0
003o0?ooo`3o0000003o0?ooo`000?l0103oool00`3o0000oooo0?l00008
0?ooo`H0003o0P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0000003oool0<`3oool2
0?l002@0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0B
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00@0o`000`3oool0
103o0000oooo0?ooo`3oool30?l000030?ooo`000?l0oooo00`0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo0180oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?oo
o`0R0?ooo`80o`00:03oool004h0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`040?l000000?l0
003o0000o`@0oooo00<0003o0?ooo`3oool01P3oool20?l000D0oooo00@0
003o0?ooo`3oool0o`000`000?l00`3o0000003o0000o`020000o`040?l0
003oool0oooo0000o`@0oooo0P3o00080?ooo`030000o`3oool0oooo00<0
oooo0P000?l00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0000003oool0=@3oool00`3o0000
oooo0?ooo`0P0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`040?ooo`L0
o`001@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0B0?ooo`03
0000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool08@3oool00`3o0000
oooo0?ooo`0X0?ooo`00CP3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00<0oooo0`000?l80?ooo`030000
o`3oool0oooo00@0oooo0`3o00040?ooo`040000o`3oool0oooo0?l00080
oooo00<0003o0?ooo`3o00000P3oool00`000?l0oooo0?l000030?ooo`06
0000o`3oool0oooo0?ooo`3o0000oooo0P3o00060?ooo`030000o`3oool0
oooo00D0oooo0`000?l50?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0000003oool0=P3oool00`3o0000oooo0?ooo`0O
0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool04`3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo01l0oooo00<0o`00
0?ooo`3oool0:@3oool004l0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool60000o`<0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`020?ooo`80o`000P3oool01@3o0000oooo0?ooo`3oool0
003o00<0oooo00H0o`000?ooo`3oool0003o0?ooo`3o00020?ooo`040000
o`3oool0oooo0?l000<0oooo00@0003o0?ooo`3oool0o`000`3oool20?l0
00<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060000
o`P0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0000003oool0=`3oool20?l0
01l0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0C0?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool00P3o000>0?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0<0?ooo`80o`000P3oool00`000?l0oooo0?ooo`0B0?oo
o`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0603oool00`3o
0000oooo0?ooo`0M0?ooo`80o`00;03oool004l0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool00`3oool30000o`P0oooo00<0o`000?ooo`3o
ool01P3oool010000?l0oooo0?l0003o00050?ooo`030?l0003oool0003o
00<0oooo00@0o`000?ooo`3oool0003o0P3oool0103o0000oooo0?ooo`00
0?l20?ooo`030?l0003oool0oooo0080oooo00<0003o0?l0003oool01@3o
ool0103o0000oooo0?ooo`000?l80?ooo`030?l0003oool0oooo00D0oooo
10000?l40?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`060?ooo`030000o`000000oooo03T0oooo
00<0o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0I0?ooo`030000
o`3oool0oooo01<0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo
0?l0000?0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0003o01@0oooo
00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0
003oool0oooo01/0oooo00<0o`000?ooo`3oool0;03oool004l0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`000?l00P000?l20?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool20?l000P0oooo00D0
003o0?ooo`3oool0oooo0?l000030?ooo`040000o`3oool0oooo0?l00080
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo
00D0oooo0P3o00080?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool00P3oool30000o`030?ooo`3o0000oooo00L0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`060?ooo`030000o`000000oooo
03X0oooo0P3o000K0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?oo
o`3oool0503oool00`3o0000oooo0?ooo`0B0?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool04`3oool00`3o
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?oo
o`3oool06@3oool20?l002l0oooo001?0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`H0
003o1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`000?l01`3oool00`000?l0oooo0?l000020?ooo`05
0?l0003oool0oooo0?ooo`000?l00P3oool0103o0000oooo0?ooo`000?l4
0?ooo`060?l0003oool0o`000?l0003oool0003o1`3oool00`000?l0o`00
0?l000060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool60000o`<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0000003d0oooo0P3o000I0?ooo`030?l0
003oool0oooo01T0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo
0?ooo`0@0?ooo`80o`0000<0oooo0000o`3oool03@3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
3P3oool00`000?l0o`000?l0000B0?ooo`030?l0003oool0oooo01@0oooo
00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0G0?ooo`030?l0
003oool0oooo02l0oooo001?0?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01P3oool40000o`@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo0P3o
00020?ooo`030000o`3oool0oooo00<0oooo0P000?l30?ooo`80o`000`3o
ool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00@0003o0?ooo`3oool0
oooo0P3o00040?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`@0003o1P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0000003l0oooo00<0o`000?oo
o`3oool05@3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo
01D0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00`0oooo00@0003o0?oo
o`3oool0oooo0P3o000@0?ooo`030?l0003oool0oooo01@0oooo00<0003o
0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0E0?ooo`80o`00<P3oool0
04l0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`<0003o203oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00@0o`000?ooo`3o0000o`001@3oool01@000?l0oooo0?ooo`3o
ool0003o00H0oooo103o00001@000?l0oooo0?ooo`3oool0o`0000<0oooo
00H0003o0?ooo`3o0000o`000?ooo`3o00050?ooo`050000o`3oool0oooo
0?ooo`000?l01@3oool20?l00080oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo0`000?l4
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`000000@03oool2
0?l001D0oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0E
0?ooo`030?l0003oool0oooo00d0oooo0P3o00050?ooo`030000o`3oool0
oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0103oool2
0?l000h0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0I
0?ooo`030?l0003oool0oooo01<0oooo0P3o000d0?ooo`00C`3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00<0003o0P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool20?l000P0oooo00<0003o0?ooo`000?l01P3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3o0000o`0000D0o`0000<0003o0?l0
003oool00P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0003o
00P0oooo0P3o00080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool010000?l0oooo0?ooo`3oool30000o`030?ooo`3o0000
oooo00H0oooo00@0003o0?ooo`3oool00000@P3oool20?l00180oooo00<0
o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003o
ool0oooo00`0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3o
ool0oooo01X0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0d0?ooo`00C`3oool00`000?l0oooo0?ooo`030?ooo`H0003o1P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool30?l000T0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0203oool30?l000D0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo1@00
0?l40?ooo`040000o`3oool0oooo000004@0oooo0P3o000@0?ooo`030?l0
003oool0oooo01X0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo
0?ooo`090?ooo`80o`002P3oool00`000?l0oooo0?ooo`080?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo00T0oooo0P3o000:0?ooo`030?l0
003oool0oooo01H0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo
0?ooo`0?0?ooo`80o`00=`3oool00500oooo00<0003o0?ooo`000?l00P00
0?l30?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo0P3o
00030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`000?l01@3o
ool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`000?l0203oool0103o0000oooo0?ooo`3oool20?l000<0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00@0o`000?ooo`3oool0oooo0`000?l01@3o
ool0003o0?ooo`3oool0000004H0oooo00<0o`000?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo01H0oooo00<0o`00
0?ooo`3oool01`3oool20?l000d0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0<0?ooo`80o`00203oool0
0`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01/0oooo00<0o`00
0?ooo`3oool0303oool20?l003T0oooo001@0?ooo`80003o1P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool010000?l0oooo0?l0003o00050?ooo`030?l0003oool0
oooo00@0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030?l0003o
ool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000
o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool0103o0000
oooo0?ooo`000?l80?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`80003o0P3oool00`00
0000oooo0?ooo`150?ooo`80o`00303oool00`3o0000oooo0?ooo`0K0?oo
o`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool01@3oool20?l0
0100oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0?0?ooo`80o`001P3oool00`3o0000oooo0?ooo`0F0?oo
o`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool02P3oool20?l0
03/0oooo001@0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?l0003oool01`3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`001@3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00P3oool0103o0000oooo0000o`000?l50?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool01@3oool20?l000P0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00@0003o0?ooo`3oool00000B@3oool20?l000X0oooo00<0
o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0G0?ooo`040?l0003o
ool0oooo0?ooo`<0o`004`3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo0180oooo0P3o00040?ooo`030?l0
003oool0oooo01H0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo
0?ooo`080?ooo`80o`00?@3oool00540oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool0103oool20?l000030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
0000oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01P3o
ool01@000?l0oooo0?ooo`3oool0o`0000T0oooo00<0003o0?l0003o0000
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0000004/0
oooo0`3o00070?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3o
ool05`3oool0103o0000oooo0?l0003o000G0?ooo`80003o0`3oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00D0003o0?oo
o`3oool0oooo0000o`0G0?ooo`80o`0000<0oooo0?l0003oool0603oool0
0`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo00@0oooo0`3o000o
0?ooo`00D@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?oo
o`80o`000P3oool00`000?l0oooo0?ooo`070?ooo`040?l0003oool0oooo
0000o`P0oooo00<0o`000000o`000?l0103oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?l000080?ooo`030000o`3oool0o`0000T0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`050000o`3o
ool0oooo0?ooo`000000CP3oool40?l00080oooo00<0o`000?ooo`3oool0
703oool00`000?l0oooo0?ooo`0F0?ooo`<0o`006`3oool30000oa00oooo
00<0o`000?ooo`3oool03@3oool010000?l0oooo0000o`000?lJ0?ooo`<0
o`00603oool00`000?l0oooo0?ooo`0L0?ooo`040?l0003oool0oooo0?oo
o`<0o`00@P3oool00580oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00@0o`000?ooo`3o
ool0o`001@3oool00`000?l0oooo0?ooo`070?ooo`030?l000000?l0oooo
00L0oooo00@0o`000?ooo`3oool0oooo10000?l50?ooo`030?l0003oool0
oooo00@0oooo10000?l20?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`80o`000P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool01@000?l0oooo0?ooo`3oool000000580oooo0`3o
000N0?ooo`030000o`3oool0oooo0180oooo103o00020?ooo`030?l0003o
ool0oooo01/0oooo0P000?l?0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`040?l001@0oooo00<0
003o0?ooo`3oool07@3oool30?l004D0oooo001B0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`<0o`001`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o0000
o`0000L0oooo00<0o`000?ooo`3oool0103oool60000o`030?l000000?l0
003o00D0003o1P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
003o00P0oooo00<0003o0?ooo`3oool01@3oool20?l000P0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`050000o`3oool0
oooo0?ooo`000000D`3oool00`3o0000oooo0?l000020?l001/0oooo00<0
003o0?ooo`3oool03P3oool40?l000H0oooo00<0o`000?ooo`3oool06P3o
ool00`000?l0oooo0?ooo`020000o`d0oooo00<0o`000?ooo`3oool0303o
ool20000o`030?ooo`000?l0oooo01X0oooo00<0o`000?ooo`3oool0103o
ool40?l00100oooo00<0003o0?ooo`3oool06@3oool50?l004L0oooo001B
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`040?ooo`<0o`00203oool00`000?l0oooo0?ooo`05
0?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00D0
o`000?ooo`3oool0oooo0000o`060?ooo`030000o`3oool0oooo00L0oooo
0`3o00060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo0540oooo
00<0o`000?ooo`3oool00P3oool30?l001P0oooo00<0003o0?ooo`3oool0
2@3oool50?l000X0oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo
0?ooo`020?ooo`80003o0P3oool4000000D0oooo00<0o`000?ooo`3oool0
2P3oool20000o`<0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo
0?ooo`090?ooo`D0o`002`3oool00`000?l0oooo0?ooo`0F0?ooo`<0o`00
1@3oool00`3o0000oooo0?ooo`140?ooo`00D`3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00@0003o0?ooo`3oool0oooo
0P3o00020?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`80o`000P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0?l000040?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`020?ooo`030000003oool0oooo0500oooo00<0o`000?ooo`3o
ool01P3oool70?l00140oooo00<0003o0?ooo`3oool01@3oool40?l00100
oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`050?ooo`80
003o00<000000?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`D0
003o1P3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo00h0
oooo103o00070?ooo`030000o`3oool0oooo0100oooo1P3o00080?ooo`03
0?l0003oool0oooo04@0oooo001C0?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool010000?l0oooo0?l0003o00050?ooo`03
0?l0003oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`080?oo
o`030?l0003oool0o`0000L0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00@0o`000?oo
o`3o0000o`001`3oool010000?l0oooo0?ooo`000?l90?ooo`030?l0003o
ool0oooo00<0oooo0P3o00020?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000003o
ool0oooo0500oooo00<0o`000?ooo`3oool03@3ooolI0?l001@0oooo00<0
o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`080?ooo`T0003o00<0
o`000000o`000?l01@000?l;0?ooo`030000o`3oool0oooo01L0oooo00<0
o`000?ooo`3oool04P3ooolJ0?l000h0oooo00<0o`000?ooo`3oool0A03o
ool005<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0000o`0:0?ooo`80o`001P3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool2
0?l000X0oooo0P000?l:0?ooo`030?l0003oool0oooo00D0oooo0P3o0008
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool0
0`000000oooo0?ooo`1@0?ooo`030?l0003oool0oooo01h0oooo00<0003o
0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0
oooo00/0oooo00<000000?ooo`3oool0103oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool06P3oool0
0`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo04@0oooo001C0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool20?l0
00030?ooo`000?l0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`090?ooo`040?l0003oool0o`000?l000@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00<0oooo0P3o00000`3oool0o`000?ooo`090?ooo`80003o2@3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3o0000o`0000H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0
oooo0500oooo00<0o`000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0J
0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool02@3oool0
10000000oooo0?ooo`0000050?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3o
ool0oooo01h0oooo00<0o`000?ooo`3oool0A03oool005@0oooo00<0003o
0?ooo`3oool01`3oool0103o0000oooo0?ooo`3oool20?l000<0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0003o00T0oooo00<0o`000?ooo`3oool00P3oool20?l00080oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`040000o`3o
ool0oooo0?ooo`80o`000`3oool00`3o0000oooo0?ooo`070?ooo`040000
o`3oool0oooo0000o`L0oooo00<0o`000?ooo`3oool01`3oool010000?l0
oooo0?ooo`3oool20?l000<0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`040?ooo`030000003oool0oooo0500oooo00<0o`000?oo
o`3oool07`3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo
01<0oooo00<0003o0?ooo`3oool02`3oool2000000H0oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo
01/0oooo00<0003o0?ooo`3oool07P3oool00`3o0000oooo0?ooo`140?oo
o`00E03oool00`000?l0oooo0?ooo`070?ooo`040?l0003oool0o`000?l0
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?oo
o`80003o0`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00@0oooo0P3o00000`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?l0003o00001P3oool00`3o0000oooo0?ooo`040?oo
o`80003o103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`3o0008
0?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool0C`3oool0
0`3o0000oooo0?ooo`0P0?ooo`030000o`3oool0oooo01/0oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0
oooo01<0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0L
0?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0A03oool0
05D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo0000o`06
0?ooo`80003o1@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o0000
o`0000h0o`0000<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0?l0
000:0?ooo`030000o`3oool0oooo00D0oooo0P3o00080?ooo`030000o`3o
ool0oooo00D0oooo00<000000?ooo`3oool0C`3oool00`3o0000oooo0?oo
o`0P0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo01<0oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3o
ool0oooo01l0oooo00<0o`000?ooo`3oool0A03oool005H0oooo00<0003o
0?ooo`3oool0103oool30?l000T0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0000o`090?ooo`80003o0P3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`000?l02@3o
ool010000?l0oooo0?ooo`3o00090?ooo`030000o`3oool0oooo00L0oooo
0`3o00060?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`3oool0
C`3oool00`3o0000oooo0?ooo`0P0?ooo`030000o`3oool0oooo01`0oooo
00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0
003oool0oooo01@0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo
0?ooo`0L0?ooo`030000o`3oool0oooo0200oooo00<0o`000?ooo`3oool0
@`3oool005H0oooo00<0003o0?ooo`3oool00P3oool20?l000<0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3o
ool0oooo00X0oooo00<0003o0?ooo`3o00002@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000003o0000o`0;0?ooo`030000o`3o0000oooo00T0oooo00<0
003o0?ooo`3oool01P3oool01@3o0000oooo0?ooo`3oool0o`0000@0oooo
00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`1?0?ooo`030?l0
003oool0oooo0200oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool0
5@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo01d0oooo
00<0003o0?ooo`3oool0803oool00`3o0000oooo0?ooo`130?ooo`00E`3o
ool010000?l0oooo0?ooo`3o00050?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?l0000<0?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
2`3oool00`3o0000003o0?ooo`080?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool00P3oool20?l00080oooo00<0003o0?ooo`3oool0
1P3oool00`000000oooo0?ooo`1?0?ooo`030?l0003oool0oooo0200oooo
00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo01H0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo01h0oooo00<0003o0?ooo`3oool0
803oool00`3o0000oooo0?ooo`130?ooo`00E`3oool00`000?l0o`000?l0
00070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0103o
ool01@000?l0oooo0?ooo`3oool0o`0000/0oooo00<0o`000000o`000?l0
203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01@3oool20000o`030?ooo`3o0000oooo00X0oooo
00@0o`000?ooo`3oool0003o1`3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00D0oooo0P3o00090?ooo`030000003oool0oooo04l0
oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`0N0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool05P3oool00`3o0000
oooo0?ooo`0F0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool07P3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo0480
oooo001H0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool01`3oool0103o0000oooo0?ooo`3oool20000o`D0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0?l000090?oo
o`80o`00103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?oo
o`030000003oool0oooo04h0oooo00<0o`000?ooo`3oool08@3oool00`00
0?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool05`3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0R0?oo
o`030?l0003oool0oooo0480oooo001I0?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`80003o0`3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00@0003o0?ooo`3oool0oooo0`000?l50?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool01@00
0?l0oooo0?ooo`3oool0003o00T0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030000003oool0oooo04h0oooo00<0o`00
0?ooo`3oool08P3oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0G
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool07`3oool0
0`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo0480oooo001I0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool01000
0?l0oooo0?ooo`000?l80?ooo`80o`001@3oool00`3o0000oooo0?ooo`06
0?ooo`H0003o1`3oool00`3o0000oooo0?ooo`070?ooo`@0003o2@3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`000?l02P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00T0oooo00<000000?ooo`3oool0CP3oool00`3o0000oooo0?ooo`0R
0?ooo`030000o`3oool0oooo0200oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo01P0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0P0?ooo`030000o`3oool0
oooo0280oooo00<0o`000?ooo`3oool0@P3oool005X0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`80003o2`3oool01@3o
0000oooo0?ooo`3oool0o`0000/0oooo00@0003o0?ooo`3oool0oooo1`00
0?l00`3o0000003o0000o`070000o`030?ooo`000?l0oooo00X0oooo00@0
o`000?ooo`3oool0oooo0P3o000;0?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0:0?ooo`030000
003oool0oooo04h0oooo00<0o`000?ooo`3oool08P3oool00`000?l0oooo
0?ooo`0Q0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
6@3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0
003oool0oooo0480oooo001K0?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01P3oool30000o`/0oooo00@0o`000?ooo`3oool0o`00
2`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool02P3oool30?l000`0oooo00<0003o0?ooo`000?l0
203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00X0oooo
00<000000?ooo`3oool0CP3oool00`3o0000oooo0?ooo`0R0?ooo`030000
o`3oool0oooo0280oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0J0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0280oooo
00<0o`000?ooo`3oool0@P3oool005/0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`000?l0
2`3oool20?l000`0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
2`3oool01@000?l0oooo0?ooo`3oool0003o00H0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo04h0
oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0R0?ooo`05
0?l0003oool0oooo0?ooo`000?l07@3oool00`3o0000oooo0?ooo`0J0?oo
o`050000o`3oool0oooo0?ooo`3o0000903oool00`000?l0oooo0?ooo`0S
0?ooo`030?l0003oool0oooo0480oooo001L0?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo00T0oooo0`3o000:0?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?oo
o`80o`0000<0oooo0?l0003oool02@3oool20000o`D0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00`0oooo00<000000?ooo`3oool0CP3oool00`3o0000oooo0?ooo`0S0?oo
o`030000o`3oool0oooo02<0oooo00<0o`000?ooo`000?l07P3oool00`3o
0000oooo0?ooo`0K0?ooo`030000o`3o0000o`0002D0oooo00<0003o0?oo
o`3oool0903oool00`3o0000oooo0?ooo`110?ooo`00G@3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo0080003o1`3oool20000o`P0
oooo00@0o`000?ooo`3oool0oooo0`3o00070?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`050?oo
o`80o`000`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00H0oooo00@0003o0?ooo`3oool0o`002@3oool00`000?l0oooo0?ooo`0=
0?ooo`030000003oool0oooo04d0oooo00<0o`000?ooo`3oool0903oool0
0`000?l0oooo0?ooo`0T0?ooo`030?l000000?l0oooo01d0oooo00<0o`00
0?ooo`3oool06`3oool00`3o0000003o0?ooo`0U0?ooo`030000o`3oool0
oooo02@0oooo00<0o`000?ooo`3oool0@@3oool005h0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000003o0?ooo`0:0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool30?l000@0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
0080oooo0`3o00060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0203oool00`000?l0o`000?ooo`080?ooo`030000o`3oool0oooo
00h0oooo00<000000?ooo`3oool0C@3oool00`3o0000oooo0?ooo`0U0?oo
o`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3o00007@3oool00`3o
0000oooo0?ooo`0J0?ooo`030?l0003oool0003o02H0oooo00<0003o0?oo
o`3oool0903oool00`3o0000oooo0?ooo`110?ooo`00GP3oool00`000?l0
oooo0?ooo`070?ooo`030000o`3o0000o`0000/0oooo0P000?l40?ooo`03
0?l0003oool0oooo00P0oooo0`3o00000`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00X0oooo00@0003o0?l0003o0000o`002@3oool00`3o
0000oooo0?ooo`030?ooo`80003o2`3oool00`3o0000003o0?ooo`070?oo
o`030000o`3oool0oooo00l0oooo00<000000?ooo`3oool0C@3oool00`3o
0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0280oooo00D0003o0?oo
o`3oool0oooo0?l0000L0?ooo`030?l0003oool0oooo01P0oooo0P3o0003
0?ooo`030000o`3oool0oooo0280oooo00<0003o0?ooo`3oool09@3oool0
0`3o0000oooo0?ooo`110?ooo`00G`3oool00`000?l0oooo0?ooo`050?oo
o`050000o`3oool0oooo0?ooo`3o0000303oool010000?l0oooo0?ooo`3o
000>0?ooo`030000o`3o0000o`0000T0oooo00<0o`000?ooo`3oool01`3o
ool30?l000030000o`3oool0oooo00/0oooo00D0o`000?ooo`3oool0oooo
0000o`0<0?ooo`040?l0003oool0oooo0000o`L0oooo00<0003o0?ooo`3o
ool03`3oool00`000000oooo0?ooo`1=0?ooo`030?l0003oool0oooo02D0
oooo00<0003o0?ooo`3oool08@3oool00`000?l0oooo0?ooo`030?ooo`80
o`006P3oool00`3o0000oooo0?ooo`0F0?ooo`80o`001P3oool00`000?l0
oooo0?ooo`0Q0?ooo`030000o`3oool0oooo02D0oooo00<0o`000?ooo`3o
ool0@@3oool00600oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00X0oooo0P000?l00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo01<0o`000`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l000000?l0003o00`0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0100oooo
00<000000?ooo`3oool0C@3oool00`3o0000oooo0?ooo`0V0?ooo`030000
o`3oool0oooo01l0oooo00<0003o0?ooo`3oool01P3oool20?l001P0oooo
00<0o`000?ooo`3oool0503oool20?l000T0oooo00<0003o0?ooo`3oool0
803oool00`000?l0oooo0?ooo`0U0?ooo`030?l0003oool0oooo0440oooo
001Q0?ooo`050000o`3oool0oooo0?ooo`000?l01`3oool00`3o0000oooo
0?ooo`0:0?ooo`030?l000000?l0oooo00`0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`040?ooo`050000
o`3oool0oooo0?ooo`000?l04`3oool00`000000oooo0?ooo`1=0?ooo`03
0?l0003oool0oooo02H0oooo00<0003o0?ooo`3oool07P3oool00`000?l0
oooo0?ooo`090?ooo`80o`005P3oool00`3o0000oooo0?ooo`0C0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool07P3oool00`000?l0
oooo0?ooo`0V0?ooo`030?l0003oool0oooo0440oooo001R0?ooo`030000
o`3oool0003o00T0oooo00<0o`000?ooo`3oool02@3oool0103o0000oooo
0000o`000?l;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`090?ooo`80003o00<0oooo0?l0003o
ool02P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0003o01@0
oooo00<000000?ooo`3oool0C@3oool00`3o0000oooo0?ooo`0W0?ooo`03
0000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool02`3oool20?l001@0
oooo00<0o`000?ooo`3oool04@3oool20?l000d0oooo00<0003o0?ooo`3o
ool07P3oool00`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo0440
oooo001S0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00L0oooo0P000?l30?ooo`030?l0003oool0oooo00P0oooo
00<0o`000?ooo`3oool0203oool20000oa@0oooo00<000000?ooo`3oool0
C@3oool00`3o0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo01`0oooo
00<0003o0?ooo`3oool03P3oool20?l00180oooo00<0o`000?ooo`3oool0
3`3oool20?l00100oooo00<0003o0?ooo`3oool0703oool00`000?l0oooo
0?ooo`0W0?ooo`030?l0003oool0oooo0440oooo001T0?ooo`80003o2P3o
ool20?l000L0oooo00<0o`000?ooo`3oool00`3oool20000o`L0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00D0oooo0P000?l60?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0C0?ooo`030000003o
ool0oooo04d0oooo00<0o`000?ooo`3oool09`3oool00`000?l0oooo0?oo
o`0K0?ooo`030000o`3oool0oooo0140oooo0`3o000?0?ooo`030?l0003o
ool0oooo00d0oooo0P3o000C0?ooo`030000o`3oool0oooo01/0oooo00<0
003o0?ooo`3oool09`3oool00`3o0000oooo0?ooo`110?ooo`00IP3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool01P3oool30000o`@0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo0`000?l8
0?ooo`030?l0003oool0oooo00@0oooo0P3o000;0?ooo`030000o`3oool0
oooo01@0oooo00<000000?ooo`3oool0C@3oool00`3o0000oooo0?ooo`0X
0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool05@3oool3
0?l000`0oooo00<0o`000?ooo`3oool02@3oool40?l001H0oooo00<0003o
0?ooo`3oool06@3oool00`000?l0oooo0?ooo`0X0?ooo`030?l0003oool0
oooo0440oooo001W0?ooo`030000o`3oool0oooo00T0oooo00D0o`000?oo
o`3oool0oooo0?l0000<0?ooo`D0003o3@3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0003o0080003o303oool0103o0000oooo0?ooo`3o
ool20?l000`0oooo00<0003o0?ooo`3oool05@3oool00`000000oooo0?oo
o`1=0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool0603o
ool00`000?l0oooo0?ooo`0I0?ooo`L0o`001@3oool00`3o0000oooo0?oo
o`030?ooo`H0o`006`3oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3o
ool0oooo02P0oooo00<0o`000?ooo`3oool0@@3oool006P0oooo00<0003o
0?ooo`3oool02@3oool20?l000030?ooo`3o0000oooo00h0oooo10000?l;
0?ooo`030?l0003oool0oooo00P0oooo1@000?l@0?ooo`<0o`00303oool2
0000oaP0oooo00<000000?ooo`3oool0C@3oool00`3o0000oooo0?ooo`0Y
0?ooo`030000o`3oool0oooo01L0oooo00<0003o0?ooo`3oool0803oool;
0?l00240oooo00<0003o0?ooo`3oool05`3oool00`000?l0oooo0?ooo`0Y
0?ooo`030?l0003oool0oooo0440oooo001Y0?ooo`030000o`3oool0oooo
00X0oooo0P3o000?0?ooo`040000o`3oool0oooo0?ooo`/0003o00<0o`00
0000o`000?l020000?l40?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0
oooo04d0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0F
0?ooo`030000o`3oool0oooo02H0oooo00<0o`000?ooo`3oool09@3oool0
0`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo02X0oooo00<0o`00
0?ooo`3oool0@@3oool006X0oooo00<0003o0?ooo`3oool02@3oool0103o
0000oooo0?l0003o000=0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`80o`0000<0oooo
0?l0003oool02P3oool00`000?l0oooo0?ooo`0I0?ooo`030000003oool0
oooo04d0oooo00<0o`000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0D
0?ooo`030000o`3oool0oooo02L0oooo00<0o`000?ooo`3oool09P3oool0
0`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo02X0oooo00<0o`00
0?ooo`3oool0@@3oool006/0oooo0P000?l80?ooo`030?l0003oool0oooo
0080oooo0P3o000;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`080?ooo`<0o`000`3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo01X0oooo00<000000?oo
o`3oool0C@3oool00`3o0000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo
01<0oooo00<0003o0?ooo`3oool0:03oool00`3o0000oooo0?ooo`0W0?oo
o`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0:`3oool00`3o
0000oooo0?ooo`110?ooo`00K@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo0P3o00090?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`80
o`001`3oool00`3o0000oooo0?ooo`050?ooo`80003o7@3oool00`000000
oooo0?ooo`1=0?ooo`030?l0003oool0oooo02/0oooo00<0003o0?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0Y0?ooo`030?l0003oool0oooo02P0
oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0[0?ooo`03
0?l0003oool0oooo0440oooo001^0?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool01`3oool20?l000H0oooo00<0003o0?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00@0oooo
0P3o000:0?ooo`030?l0003oool0oooo0080oooo0P000?lO0?ooo`030000
003oool0oooo04d0oooo00<0o`000?ooo`3oool0:`3oool00`000?l0oooo
0?ooo`0@0?ooo`030000o`3oool0oooo02X0oooo00<0o`000?ooo`3oool0
:@3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo02`0oooo
00<0o`000?ooo`3oool0@@3oool006l0oooo00D0003o0?ooo`3oool0oooo
0?l0000<0?ooo`80o`00103oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00h0oooo00@0003o0?ooo`3oool0oooo0P3o000<0?ooo`03
0?l0003oool0oooo0080003o8@3oool00`000000oooo0?ooo`1=0?ooo`03
0?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0[0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0/0?ooo`030?l0003oool0oooo0440
oooo001`0?ooo`80003o00<0oooo0?l0003oool03@3oool40?l000030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool010000?l0o`00
0?l0003o000?0?ooo`030?l000000?l0oooo0280oooo00<000000?ooo`3o
ool0C@3oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo00d0
oooo00<0003o0?ooo`3oool0;03oool00`3o0000oooo0?ooo`0[0?ooo`80
003o3@3oool00`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0oooo0440
oooo001b0?ooo`030?l0003oool0oooo0100oooo00<0003o0?l0003o0000
0P3o000<0?ooo`030?l0003oool0oooo00X0oooo103o00000`000?l0oooo
0?ooo`0?0?ooo`030000o`3o0000oooo02<0oooo00<000000?ooo`3oool0
C@3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo00/0oooo
00<0003o0?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0]0?ooo`030000
o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0;P3oool00`3o0000oooo
0?ooo`110?ooo`00L`3oool20000oa00oooo00<0003o0?ooo`3oool00P3o
oolI0?l000@0oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0?oo
o`0T0?ooo`030000003oool0oooo04d0oooo00<0o`000?ooo`3oool0;P3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo02h0oooo00<0
o`000?ooo`3oool0;P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3o
ool0oooo02h0oooo00<0o`000?ooo`3oool0@@3oool007D0oooo0P000?l>
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0<0?ooo`80003o9`3oool00`000000oooo0?ooo`1=
0?ooo`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0_0?ooo`030?l0003oool0oooo02l0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0_0?ooo`030?l0003oool0
oooo0440oooo001g0?ooo`80003o2`3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool02@3oool20000
obT0oooo00<000000?ooo`3oool0CP3oool00`3o0000oooo0?ooo`0^0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0<03oool00`3o
0000oooo0?ooo`0`0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool0;`3oool00`3o0000oooo0?ooo`120?ooo`00N@3oool20000o`T0
oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo00L0oooo0P000?l[0?ooo`030000003oool0oooo04h0
oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo0340oooo00<0o`000?ooo`3oool0<@3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo0300oooo00<0o`000?ooo`3o
ool0@P3oool007/0oooo10000?l50?ooo`030000o`3oool0oooo00l0oooo
00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`040?ooo`<0003o
;@3oool00`000000oooo0?ooo`1>0?ooo`030?l0003oool0oooo0300oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0b0?ooo`030?l0
003oool0oooo0380oooo00D0003o0?ooo`3oool0oooo0000o`0b0?ooo`03
0?l0003oool0oooo0480oooo001o0?ooo`@0003o00<0oooo0000o`3oool0
403oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0003o00<0003o
<03oool00`000000oooo0?ooo`1>0?ooo`030?l0003oool0oooo0340oooo
00@0003o0?ooo`000?l0003o=@3oool00`3o0000oooo0?ooo`0c0?ooo`03
0000o`3oool0003o03<0oooo00<0o`000?ooo`3oool0@P3oool008<0oooo
0P000?lA0?ooo`030?l0003oool0oooo0100oooo0P000?ld0?ooo`030000
003oool0oooo04h0oooo00<0o`000?ooo`3oool0<P3oool00`000?l0oooo
0?ooo`0e0?ooo`030?l0003oool0oooo03@0oooo0P000?lc0?ooo`030?l0
003oool0oooo0480oooo00250?ooo`@0003o3@3oool00`3o0000oooo0?oo
o`0;0?ooo`D0003o;`3oool500000080oooo00<000000?ooo`3oool0CP3o
ool00`3o0000oooo0?ooo`0a0?ooo`80003o;`3oool2000000H0oooo00<0
o`000?ooo`3oool0<`3oool010000?l0oooo0?ooo`000?lb0?ooo`030?l0
003oool0oooo0480oooo00290?ooo``0003o00<0oooo0?l0003oool03000
0?lf0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0CP3o
ool00`3o0000oooo0?ooo`0_0?ooo`80003o0P3oool00`000?l0oooo0?oo
o`0[0?ooo`040000003oool0oooo000000D0oooo00<0o`000?ooo`3oool0
<`3oool01@000?l0oooo0?ooo`3oool0003o0340oooo00<0o`000?ooo`3o
ool0@P3oool009D0oooo00@0003o0?l000000?l0003o@@3oool00`000000
oooo0?ooo`020?ooo`800000C`3oool00`3o0000oooo0?ooo`0^0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0;03oool00`000000
oooo0?ooo`040?ooo`030?l000000000oooo0380oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo0480
oooo003J0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
]@3oool00`000000oooo0?ooo`2d0?ooo`00fP3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0;80oooo00@000000?ooo`3oool00000
]P3oool00=T0oooo0P0000040?ooo`030000003oool0oooo0;<0oooo0P00
002g0?ooo`00o`3ooooo0?oooe00oooo003o0?ooool0ooooD03oool00?l0
ooooo`3ooom@0?ooo`00o`3ooooo0?oooe00oooo003o0?ooool0ooooD03o
ool00?l0ooooo`3ooom@0?ooo`00g@3oool200000?l0ooooL03oool00=h0
oooo00<000000?ooo`3oool0o`3ooom^0?ooo`00g`3oool00`000000oooo
0?ooo`2j0?ooo`800000/03oool00=h0oooo00<000000?ooo`000000^`3o
ool200000;00oooo003M0?ooo`040000003oool0oooo00000;X0oooo00@0
00000?ooo`3oool00000[`3oool00=`0oooo0`0000000`3oool000000000
002h0?ooo`8000000P3oool200000:h0oooo003o0?ooool0ooooD03oool0
0?l0ooooo`3ooom@0?ooo`00o`3ooooo0?oooe00oooo003o0?ooool0oooo
D03oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{590, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  For convenience, we choose the ordered triple  ",
  Cell[BoxData[
      RowBox[{\(z\_1 = \(-2\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        "  ", \(z\_2 = \(-1\) - \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], "  ", \(z\_3 = 0\)}]]],
  ", which gives the circle  ",
  Cell[BoxData[
      \(C : \ \(\(|\)\(z + 1\)\(|\)\) = \ 1\)]],
  "  a positive orientation and the disk ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " a left orientation.  From Example 10.5, the corresponding image points \
are   \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(w\_1\ \  = \ \ \(S \((z\_1)\)\ \  = \ \ \(S \((\(-2\))\)\ \  \
= \ \ \(-1\)\)\)\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["  ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(w\_2\ \  = \ \ \(S \((z\_2)\)\ \  = \ \ \(S \
\((\(-1\) - \[ImaginaryI])\)\ \  = \ \ 0\)\)\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[
          RowBox[{
            StyleBox["  ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  "}]], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{\(w\_3\), "  ", "=", "  ", 
          RowBox[{\(S \((z\_3)\)\), "  ", "=", "  ", 
            RowBox[{\(S \((0)\)\), "  ", "=", "  ", 
              RowBox[{"1", 
                StyleBox[" ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox[".",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["  ",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}]}]}]}]]],
  "  \n\n\nBecause the ordered triple of points  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(w\_2 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(w\_3 = 1\)}]]],
  ",  lie on the ",
  StyleBox["u",
    FontFamily->"Courier"],
  " axis, it follows that the image of circle ",
  StyleBox["C",
    FontFamily->"Courier"],
  " is the ",
  StyleBox["u",
    FontFamily->"Courier"],
  " axis.  The points  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(w\_2 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(w\_3 = 1\)}]]],
  " give the upper half-plane  ",
  Cell[BoxData[
      \(G : Im \((w)\) > 0\)]],
  "  a left orientation.  Therefore ",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(\((1 - \[ImaginaryI])\) z\ \  + \ \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\ \  + \ \ 2\)\)\)],
    AspectRatioFixed->True],
  " maps the disk ",
  StyleBox["D",
    FontFamily->"Courier"],
  " onto the upper half-plane ",
  StyleBox["G",
    FontFamily->"Courier"],
  ".  To check our work, we choose a point ",
  Cell[BoxData[
      \(z\_0\)]],
  " that lies in ",
  StyleBox["D",
    FontFamily->"Courier"],
  " and find the half-plane in which its image, ",
  Cell[BoxData[
      \(w\_0\)]],
  " lies.  The choice  ",
  Cell[BoxData[
      \(z\_0 = \(-1\)\)]],
  "  yields  ",
  Cell[BoxData[
      \(w\_0\  = \ \(S \((z\_0)\) = \[ImaginaryI]\)\)]],
  ".  Hence the upper half-plane is the correct image.  This situation is \
illustrated in Figure 10.6. "
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 10.6",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/mobiustranformation/\
MobiusTranformationFigures/mat1006.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The bilinear mapping  ",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(\((1 - \[ImaginaryI])\) z\ \  + \ \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\ \  + \ \ 2\)\)\)],
    AspectRatioFixed->True],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(S \((z)\) = \(\((1 - \[ImaginaryI])\) z\ \  + \ \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\ \  + \ \ 2\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(S = \(w = \(W = \(z = \(Z = 0\)\)\)\); \ 
    Remove[S, w, W, z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[d, g, solset, w1, w2, w3, z1, z2, z3];\)\ \), "\n", 
    \(\(S[
          z_]\  = \ \(\((1 - \[ImaginaryI])\) z\  + \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\  + \ 2\);\)\ \), "\n", 
    \(\(Print["\<S(z) = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["To show  S(z)  is one-to-one, find the inverse function.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset\  = \ Solve[w \[Equal] S[z], z];\)\ \), "\n", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<z = \!\(S\^\(-1\)\)[w] = \>\"", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
To show  S(z)  is onto, use the method of oriented points on the boundary \
curve.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(z\_1\  = \ \(-2\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(z\_2\  = \ \(-1\) - \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(z\_3\  = \ 0;\)\ \ \), "\n", 
    \(\(w\_1\  = \ \(-1\);\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\_2\  = \ 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\_3\  = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,      \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,      \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,      \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,          \!\(w\_3\) = \>\"", w\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<S[\!\(z\_1\)] = \>\"", 
        S[z\_1], \*"\"\<,   S[\!\(z\_2\)] = \>\"", 
        S[z\_2], \*"\"\<,       S[\!\(z\_3\)] = \>\"", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Therefore, the image of the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z + 1\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  is the upper half plane  ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  ".  In order to graph the image of the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z + 1\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  under  w = S(z)  we use the change of variable and find the image of  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  under  ",
  Cell[BoxData[
      \(w = \(g \((z)\) = S \((z - 1)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(g[z_]\  = \ S[z - 1];\)\ \), "\n", 
    \(\(Print["\<         S(z) = \>", S[z]];\)\ \), "\n", 
    \(\(Print["\<g(z) = S(z-1) = \>", g[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
To plot the graph we use the shifted disk and the functions d[z] = z-1  and  \
g[z] = S[z-1].\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[S, z];\)\ \), "\[IndentingNewLine]", 
    \(\(d[z_]\  = \ z - 1;\)\ \), "\n", 
    \(\(S[
          z_]\  = \ \(\((1 - \[ImaginaryI])\) z\  + \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\  + \ 2\);\)\ \), "\[IndentingNewLine]", 
    \(\(g[z_]\  = \ S[z - 1];\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{\(-2\), 0}, {\(-1\), \(-1\)}, {0, 
            0}};\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(zdots = 
        Graphics[{{Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Green, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{\(-1\), 0}, {0, 0}, {1, 
            0}};\)\ \), "\[IndentingNewLine]", 
    \(\(wdots = 
        Graphics[{{Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Green, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(zplane = 
        PolarMap[
          d\ \ \ , {0.00005, 0.99995, 0.1111}, {0, 
            2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] \
{{\(-2.05\), 0.05}, {\(-1.05\), 
                1.05}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-2\), 1, 
                1], Range[1, 1, 
                1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Red, Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(wplane = 
        PolarMap[
          g\ \ \ , {0.00005, 0.99995, 0.1111}, {0, 
            2  \[Pi], \[Pi]\/12}, \[IndentingNewLine]Ticks \[Rule] \
{Range[\(-3\), 3, 1], Range[0, 3, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 
            1\/2, PlotRange \[Rule] {{\(-3\), 3}, {0, 
                3}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Red, Blue}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[zplane, zdots, 
        PlotRange \[Rule] {{\(-2.05\), 0.05}, {\(-1.05\), 
              1.05}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-2\), 1, 1], 
            Range[1, 1, 1]}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The disk |z+1| < 1.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[wplane, wdots, PlotRange \[Rule] {{\(-3\), 3}, {0, 3}}, 
        AspectRatio \[Rule] 
          1\/2, \[IndentingNewLine]Ticks \[Rule] {Range[\(-3\), 3, 1], 
            Range[0, 3, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image half-plane Im[w] > 0,\>"];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", z\_1, "\<] = \>", 
        S[z\_1], \[IndentingNewLine]"\<,   S[\>", z\_2, "\<] = \>", 
        S[z\_2], \[IndentingNewLine]"\<,   S[\>", z\_3, "\<] = \>", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that the transformation  ",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(\((1 - \[ImaginaryI])\) z\ \  + \ \ 2\)\/\(\((1 + \
\[ImaginaryI])\) z\ \  + \ \ 2\)\)\)],
    AspectRatioFixed->True],
  "  maps the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z + 1\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  one-to-one and onto the upper half plane  ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Corollary 10.1 (The Implicit Formula with a point at Infinity).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  In equation ",
  StyleBox["(10-18)",
    FontColor->RGBColor[0, 0, 1]],
  " the point at infinity can be introduced as one of the prescribed points \
in either the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane or the  ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Corollary 10.1 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Case 1.",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(z\_3 = \[Infinity]\)]],
  ",  then we can write  ",
  Cell[BoxData[
      \(\((z\_2\  - \ z\_3)\)\/\((z\  - \ z\_3)\)\  = \ \(\((z\_2\  - \ \
\[Infinity])\)\/\((z\  - \ \[Infinity])\)\  = \ 1\)\)]],
  "  and substitute this expression into Equation ",
  StyleBox["(10-18)",
    FontColor->RGBColor[0, 0, 1]],
  " to obtain  ",
  Cell[BoxData[
      \(\(\((z\  - \ z\_1)\)\ \((z\_2\  - \ \[Infinity])\)\)\/\(\((z\  - \ \
\[Infinity])\) \((z\_2\  - \ z\_1)\)\)\  = \ \(\((w\  - \ w\_1)\)\ \((w\_2\  \
- \ w\_3)\)\)\/\(\((w\  - \ w\_3)\) \((w\_2\  - \ w\_1)\)\(\ \)\)\)]],
  "  which can be rewritten as ",
  Cell[BoxData[
      \(\(\((z\  - \ z\_1)\)\ \((z\_2\  - \ \[Infinity])\)\)\/\(\((z\_2\  - \ \
z\_1)\) \((z\  - \ \[Infinity])\)\)\  = \ \(\((w\  - \ w\_1)\)\ \((w\_2\  - \ \
w\_3)\)\)\/\(\((w\  - \ w\_3)\) \((w\_2\  - \ w\_1)\)\(\ \)\)\)]],
  "  and simplifies to obtain  \n\t\n\t\t\t",
  Cell[BoxData[
      \(\(\(z\)\(\ \)\(-\)\(\ \)\(z\_1\)\(\ \)\)\/\(z\_2\  - \ z\_1\)\  = \ \
\(\((w\  - \ w\_1)\)\ \((w\_2\  - \ w\_3)\)\)\/\(\((w\  - \ w\_3)\) \((w\_2\  \
- \ w\_1)\)\(\ \)\)\)]],
  ".  \n\n",
  StyleBox["Case 2.",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(w\_3 = \[Infinity]\)]],
  ",  then we can write  ",
  Cell[BoxData[
      \(\(\(\ \)\((w\_2\  - \ w\_3)\)\)\/\((w\  - \ w\_3)\)\  = \(\(\(\ \
\)\((w\_2\  - \ \[Infinity])\)\)\/\((w\  - \ \[Infinity])\)\  = \ 1\)\)]],
  " and substitute this expression into Equation ",
  StyleBox["(10-18)",
    FontColor->RGBColor[0, 0, 1]],
  " to obtain  ",
  Cell[BoxData[
      \(\(\((z\  - \ z\_1)\)\ \((z\_2\  - \ z\_3)\)\)\/\(\((z\  - \ z\_3)\) \
\((z\_2\  - \ z\_1)\)\)\  = \ \(\((w\  - \ w\_1)\)\ \((w\_2\  - \ \
\[Infinity])\)\)\/\(\((w\  - \ \[Infinity])\) \((w\_2\  - \ w\_1)\)\(\ \
\)\)\)]],
  " which can be rewritten as   ",
  Cell[BoxData[
      \(\(\((z\  - \ z\_1)\)\ \((z\_2\  - \ z\_3)\)\)\/\(\((z\  - \ z\_3)\) \
\((z\_2\  - \ z\_1)\)\)\  = \ \(\((w\  - \ w\_1)\)\ \((w\_2\  - \ \
\[Infinity])\)\)\/\(\((w\_2\  - \ w\_1)\)\ \((w\  - \ \[Infinity])\)\)\)]],
  " and simplifies to obtain\n\n",
  StyleBox["(10-21)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(\(\((z\  - \ z\_1)\)\ \((z\_2\  - \ z\_3)\)\)\/\(\((z\  - \ z\_3)\) \
\((z\_2\  - \ z\_1)\)\)\  = \ \(w\  - \ w\_1\)\/\(w\_2\  - \ w\_1\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "      Equation ",
  StyleBox["(10-21)",
    FontColor->RGBColor[0, 0, 1]],
  " is sometimes used to map the crescent-shaped region that lies between the \
tangent circles onto an infinite strip."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 10.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the bilinear transformation ",
  Cell[BoxData[
      \(w = S \((z)\)\)]],
  " that maps the crescent-shaped region that lies inside the disk ",
  Cell[BoxData[
      \(D : \(\(|\)\(z - 2\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  "  and outside the circle ",
  Cell[BoxData[
      \(\(\(|\)\(z - 1\)\(|\)\) = \ 1\)]],
  "  onto a horizontal strip."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:g0000[b000`400?l0
0000o`00003oo`3ooooo0?oookT0oooo003o0?ooool0oooo^@3oool00?l0
ooooo`3oooni0?ooo`00o`3ooooo0?oookT0oooo003o0?ooool0oooo^@3o
ool00?l0ooooo`3oooni0?ooo`00hP3oool300000400oooo0`0000100?oo
o`800000O`3oool200000400oooo0`00000o0?ooo`<00000A`3oool00>@0
oooo00<000000?ooo`3oool0?P3oool010000000oooo0?ooo`00000n0?oo
o`040000003oool0oooo000007d0oooo00@000000?ooo`3oool00000?`3o
ool010000000oooo0?ooo`0000100?ooo`030000003oool0oooo04D0oooo
003S0?ooo`<00000?`3oool010000000oooo0?ooo`0000100?ooo`030000
003oool0oooo07h0oooo00<000000?ooo`3oool0?P3oool010000000oooo
0?ooo`00000o0?ooo`<00000AP3oool00=`0oooo100000020?ooo`040000
003oool0oooo000003T0oooo100000020?ooo`<00000>@3oool4000000D0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0m0?ooo`<0
0000?`3oool010000000oooo0?ooo`0000160?ooo`00hP3oool010000000
oooo0?ooo`0000100?ooo`030000003oool0oooo03h0oooo00@000000?oo
o`3oool00000O@3oool010000000oooo0?ooo`0000100?ooo`030000003o
ool0oooo03h0oooo00@000000?ooo`3oool00000AP3oool000L0oooo1000
003H0?ooo`<00000@03oool3000003l0oooo0P00001o0?ooo`800000@@3o
ool3000003l0oooo0`0000160?ooo`001`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0?l0ooooo`3ooonY0?ooo`00203oool00`00
0000oooo0?ooo`020?ooo`800000o`3ooooo0?ooojX0oooo00000`3oool0
000000000002000000@0oooo00D000000?ooo`3oool0oooo0000000l0?oo
oa<0003oo`3ooooo0?oooe`0oooo00070?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0=@3oool50000oa40oooo00<0o`000?oo
o`000?l01P000?oo0?ooool0ooooE@3oool000P0oooo0P0000030?ooo`03
0000003oool0oooo0340oooo10000?l20?ooo`030000o`3oool0oooo0100
oooo00<0o`000?ooo`3oool01`3oool30000ool0ooooo`3ooomB0?ooo`00
3@3oool00`000000oooo0?ooo`0]0?ooo`@0003o1P3oool00`000?l0oooo
0?ooo`0@0?ooo`030?l0003oool0oooo00X0oooo0P000?oo0?ooocl0oooo
0`3o0?lC0?ooo`<00?oom`3oool000d0oooo00<000000?ooo`3oool0:P3o
ool30000o`X0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0<0?ooo`<0003oo`3ooolk0?ooo`D0o`3o4@3oool5003ook`0oooo1000
000f0?ooo`003@3oool00`000000oooo0?ooo`0X0?ooo`80003o3@3oool0
10000?l0oooo0?ooo`3oool50?l000X0oooo00<0o`000?ooo`3oool03`3o
ool20000og<0ooooa00000070?l0o`l000001`00oon^000000`0oooo00@0
00000?ooo`3oool00000=`3oool000d0oooo00<000000?ooo`3oool09P3o
ool20000o`030?l0003oool0oooo00P0oooo203o00050?ooo`P0o`000P3o
ool00`3o0000oooo0?ooo`0A0?ooo`<0003oL03oooo40000o`L0o`3o3`00
0?l7003oojh0003o303oool010000000oooo0?ooo`00000g0?ooo`003@3o
ool00`000000oooo0?ooo`0T0?ooo`80003o0`3oool00`3o0000oooo0?oo
o`020?ooo`D0o`00103oool00`000?l0oooo0?ooo`0>0?ooo`H0o`004`3o
ool20000ofh0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0103o
ool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0:0?ooo`030000003o
ool0oooo00@0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo00h0oooo1`3o0?l?0?ooo`L00?oo3P3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00<0oooo00<0
00000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool02`3oool00`000000oooo0?oo
o`030?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00T0oooo0P00
00000`3oool000000000000g0?ooo`003@3oool00`000000oooo0?ooo`0R
0?ooo`80003o1P3oool40?l000T0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`020?ooo`<0o`004P3oool20000of`0oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<0o`00
0?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo00l0oooo1@3o0?lA0?ooo`D00?oo3`3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo04D0oooo000=0?ooo`030000003oool0oooo
0200oooo0P000?l60?ooo`<0o`003@3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00D0oooo0`3o000?0?ooo`040000o`3oool0003o
0000ofX0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0403oool30?l0oa80oooo00@0o`00
003oo`00ool00?oo403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool0A@3oool000d0oooo00<000000?ooo`3oool07P3oool2
0000o`H0oooo0P3o00020?ooo`030?l0003oool0oooo00L0oooo2P000?l;
0?ooo`030?l0003oool0oooo00P0oooo0`3o000<0?ooo`040000o`3oool0
oooo0?ooo`80003oJ03oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool000d0oooo00<00000
0?ooo`3oool07@3oool00`000?l0oooo0000o`040?ooo`80o`001@3oool0
0`3o0000oooo0000o`060000o`@0oooo00<0003o0?ooo`3oool00`3oool6
0000o`@0oooo00<0o`000?ooo`3oool0303oool20?l000T0oooo00<0003o
0?ooo`3oool0103oool20000ofH0oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo000=0?oo
o`030000003oool0oooo01`0oooo00H0003o0?ooo`3oool0oooo0000o`3o
ool20?l000H0oooo0`000?l;0?ooo`030000o`3oool0oooo00T0oooo1@00
0?l@0?ooo`80o`001`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo06<0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo04D0oooo000=0?ooo`030000003oool0
oooo01X0oooo0P000?l40?ooo`80o`00103oool40000o`030?ooo`3o0000
oooo00/0oooo00<0003o0?ooo`3oool03@3oool0103o0000003o0000o`00
0?l?0?ooo`80o`00103oool00`000?l0oooo0?ooo`080?ooo`030000o`3o
ool0oooo0680oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo04D0oooo000=0?ooo`030000003oool0
oooo01T0oooo00<0003o0?ooo`3oool00P3oool20?l000030000o`3oool0
oooo00<0003o1@3oool00`3o0000oooo0?ooo`040?ooo`D0o`000P000?l?
0?ooo`040?l0003oool0oooo0?ooo`<0003o3P3oool20?l00080oooo00<0
003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`1Q0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`150?ooo`003@3oool00`000000oooo0?ooo`0G0?ooo`030?l000000?l0
oooo0080oooo0P3o00030?ooo`80003o1`3oool90?l000@0oooo1`3o0009
0?ooo`030?l0003oool0oooo00D0oooo0P000?l>0?ooo`030?l000000?l0
oooo00`0oooo00<0003o0?ooo`3oool0H03oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool0
00d0oooo00<000000?ooo`3oool05P3oool20000o`040?l0003oool0oooo
0?l000<0oooo0`000?l50?ooo`<0o`0000<0oooo0?l0003oool02P3oool0
0`000?l0oooo0?ooo`040?ooo`@0o`001@3oool00`3o0000oooo0?ooo`07
0?ooo`80003o303oool00`000?l0o`000?ooo`0=0?ooo`80003oH03oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool0A@3oool000d0oooo00<000000?ooo`3oool05@3oool01000
0?l0oooo0?ooo`3oool20?l00080oooo0P000?l30?ooo`030000o`3o0000
o`000080o`001@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00P0oooo103o00000`3oool0o`000?ooo`0:0?ooo`80003o2P3oool0
10000?l0oooo0?l0003o000>0?ooo`030000o`3oool0oooo05d0oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo04D0oooo000=0?ooo`030000003oool0oooo01@0oooo00<0003o
0?ooo`3oool0103o00000`3oool0003o0?ooo`020?ooo`<0o`001`3oool>
0000o`h0oooo0`3o000<0?ooo`80003o1`3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0G03ooooo
0?l00900o`00A`3oool000d0oooo00<000000?ooo`3oool04`3oool01000
0?l0oooo0?ooo`3o00030?ooo`80003o0P3oool20?l00080oooo00<0003o
0?ooo`3oool01@000?l20?ooo`030?l0003oool0oooo00P0oooo1P000?l9
0?ooo`030?l0003oool0oooo0080o`00303oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`1K0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`150?ooo`003@3oool00`00
0000oooo0?ooo`0B0?ooo`80003o00@0oooo0?l0003oool0oooo0P000?l0
103oool0o`000?l0003o00050?ooo`80003o1`3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00<0oooo10000?l40?ooo`030?l0003o
ool0oooo00<0oooo0P3o000;0?ooo`80003o0`3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0FP3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool0A@3oool000d0oooo00<000000?ooo`3oool04@3oool0
10000?l0oooo0000o`3o00020?ooo`030000o`3oool0oooo0080o`000`3o
ool50000o`D0oooo2P3o00040?ooo`030000o`3oool0oooo00L0oooo0P00
0?l20?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0000o`090?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0F@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool000d0oooo00<00000
0?ooo`3oool0403oool020000?l0oooo0?l0003o0000003o0?ooo`000?l0
oooo0P3o00000`3oool0o`000000o`020000o`@0oooo1P3o00030?ooo`03
0?l0003oool0oooo00@0oooo1@3o000;0?ooo`<0003o203oool20?l000/0
oooo00<0003o0?ooo`3oool02@3oool20?l000d0oooo00<0003o0?ooo`3o
ool0F03oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool0A@3oool000d0oooo00<000000?ooo`3oool0
403oool010000?l0o`000?ooo`3oool20000o`040?ooo`3o0000oooo0?oo
o`80003o00@0o`000?ooo`3oool0oooo0`3o00000`3oool0003o0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o00000P3o0009
0?ooo`040?l0003oool0003o0000o`P0oooo0P3o00080?ooo`040000o`3o
ool0003o0000o`/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`1H0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`150?ooo`003@3oool00`000000oooo0?oo
o`0>0?ooo`030?l000000?l0o`000080oooo00@0003o0?ooo`3o0000o`00
0P3oool00`000?l0oooo0?ooo`040?l000@0oooo3@000?l50?ooo`030000
o`3oool0oooo0080oooo0`3o00060?ooo`040?l0003oool0oooo0?ooo`80
003o203oool20?l000D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool0E`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool0A@3oool000d0oooo00<000000?ooo`3oool0
3P3oool020000?l0o`000?l0003oool0003o0?ooo`3o0000oooo0`000?l0
1@3oool0o`000?l0003oool0o`0000<0oooo10000?l70?ooo`030?l0003o
ool0oooo0080oooo1P000?l70?ooo`80o`00103oool00`3o0000oooo0?oo
o`030?ooo`80003o203oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo05H0oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo000=
0?ooo`030000003oool0oooo00d0oooo00P0003o0?l0003oool0o`000000
o`3oool0o`000?ooo`<0003o0P3o00030?ooo`@0003o0`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo10000?l70?ooo`@0
o`00203oool00`000?l0oooo0?ooo`060?ooo`80o`0000<0oooo0000o`3o
ool01P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool0E@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool000d0oooo
00<000000?ooo`3oool02`3oool20000o`040?ooo`3o0000oooo0000o`80
o`0000<0oooo0000o`3oool00P3o00000`3oool0003o0000o`020000o`03
0?l0003oool0oooo0140o`00103oool010000?l0oooo0?ooo`3oool30000
o`L0oooo0`3o00070?ooo`80003o203oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`1E0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`150?ooo`003@3oool00`000000
oooo0?ooo`0;0?ooo`80003o00D0o`000?ooo`3o0000o`000?ooo`020000
o`80o`0000<0oooo0000o`000?l0103oool30?l000@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`@0o`0000<0003o0?oo
o`3oool0103oool20000o`@0oooo00D0o`000?ooo`3oool0oooo0?l00008
0?ooo`80003o1@3oool00`000?l0oooo0?l000090?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`1D
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`150?ooo`003@3oool00`000000oooo0?ooo`0;0?oo
o`050000o`3o0000003o0?l0003oool00P000?l0203oool0o`000?ooo`3o
ool0003o0?ooo`000?l0oooo0`3o00000`3oool0o`000000o`0>0000o`L0
oooo103o00050?ooo`80003o00<0oooo0?l0003oool0103oool20?l000P0
oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo05<0oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo000=0?ooo`03
0000003oool0oooo00X0oooo00@0003o0?l0003oool0o`000P000?l00`3o
ool0o`000?l000020?l000030000o`3oool0o`000080o`001@000?l50?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@000?l20?oo
o`040000o`3oool0oooo0?ooo`80o`001@3oool20000o`L0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0000o`050?ooo`80o`00203oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool0DP3ooooo0000oi00003oA`3oool000d0oooo00<000000?oo
o`3oool02@3oool01@000?l0o`000?ooo`3o0000oooo0080003o00<0o`00
0?ooo`3oool00P000?l20?l000030?ooo`000?l0003o00<0oooo3`3o0007
0?ooo`<0003o1@3oool20?l000<0oooo00@0o`000?ooo`000?l0003o1P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool0D@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3o
ool000L0oooo1@0000000`3oool000000?ooo`090?ooo`080000o`3oool0
o`000000o`3o0000003o0?ooo`3o00030000o`<0o`000P000?l50?l00003
0?ooo`3o0000oooo0080003o0P3oool00`000?l0oooo0?ooo`040?ooo`@0
o`001@3oool010000?l0oooo0000o`000?l50?ooo`030?l0003oool0o`00
00@0oooo0P000?l50?ooo`030?l0003oool0oooo00D0oooo0P000?l80?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`080?ooo`030?l0003oool0003o0580oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
04D0oooo00090?ooo`050000003oool0oooo0?ooo`0000002@3oool20000
o`080?l000000?l0o`000000o`3oool0o`000?ooo`000?l20?l000030?oo
o`000?l0003o0080o`000P3ooolA0000o`040?l0003oool0oooo0?ooo`<0
o`0000<0oooo0000o`3oool00`3oool20000o`@0oooo0P3o00060?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool010000?l0
oooo0?ooo`000?l80?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`050?ooo`80o`000`3oool00`00
0?l0oooo0?ooo`1?0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`150?ooo`002@3oool010000000
oooo0?ooo`3oool2000000P0oooo00P0003o0?l000000?l0o`000000o`3o
ool0o`000000o`80o`000`000?l30?l000@0003o0P3oool00`3o0000003o
0000o`040000o`030?l0003oool0oooo00@0oooo0P000?l50?ooo`<0o`00
1@3oool20000o`80oooo00<0o`000?ooo`3o00001P3oool00`000?l0oooo
0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0C`3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool000030?oo
o`000000000000800000103oool01@000000oooo0?ooo`3oool0000000P0
oooo00<0003o0?l000000?l00P000?l01@3oool0o`000000o`3o0000oooo
0080003o0P3o00000`3oool0003o0000o`060?l000030?ooo`000?l0003o
00@0003o00<0oooo0?l0003o00000P3o0000103oool0o`000?ooo`3oool2
0000o`<0oooo00<0003o0?ooo`3oool00P3o00050?ooo`030000o`3o0000
oooo0080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0003o00H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00@0o`00
0?ooo`3oool0oooo0P3o00070?ooo`030000o`3oool0oooo04h0oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo04D0oooo00090?ooo`050000003oool0oooo0?ooo`000000203o
ool0203o0000003o0?ooo`000?l0oooo0?l000000?l0o`000P000?l20?l0
00<0003o0P3o00080?ooo`@0003o1P3oool50?l000030?ooo`000?l0003o
0080003o103oool20?l000@0oooo00<0003o0?ooo`3oool00P3oool20?l0
00D0oooo00<0003o0?ooo`3oool00`3oool20?l000L0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00P0oooo0`3o00090?ooo`030000o`3oool0oooo04h0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
04D0oooo00080?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`04
0000o`3o0000003o0000o`80o`0000H0003o0?l000000?l0oooo0?l0003o
ool20000o`80o`002`3oool20000o``0oooo0P3o0000103oool0003o0000
o`000?l50?ooo`80o`000P3oool00`3o0000003o0000o`040?ooo`030?l0
003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`1=0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`150?ooo`00
3@3oool00`000000oooo0?ooo`050?ooo`080?l000000?l0o`000000o`3o
0000003o0?l000000?l20?l00080003o0P3o000M0?ooo`80o`000P3oool2
0000o`D0oooo0P3o00030?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0000o`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo0P3o00000`3oool0o`000?ooo`0:
0?ooo`030000o`3oool0oooo04d0oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo000=0?oo
o`030000003oool0oooo00@0oooo00T0003o0?l000000?l0003o0?l00000
0?l0o`000000o`3o00000P000?l20?l00240oooo0P3o00020?ooo`80003o
0`3oool20?l000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0o`0000/0
oooo00<0003o0?ooo`3oool0C@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool000d0oooo
00<000000?ooo`3oool0103oool02@3o0000003o0?l0003o0000003o0?l0
00000?l0o`000000o`020?l002D0oooo00@0o`000?ooo`3oool0oooo0P00
0?l0103o0000oooo0?ooo`3o00040?ooo`030000o`3oool0oooo0080oooo
00L0o`000?ooo`3oool0oooo0000o`3oool0003o00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00H0oooo00@0003o0?ooo`3oool0oooo0P3o00050?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool0C03oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool0
00d0oooo00<000000?ooo`3oool00`3oool20000o`@0o`000`000?l00`3o
0000oooo0?ooo`0V0?ooo`060?l0003oool0oooo0?ooo`3o0000003o0`3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
o`000000o`000?l00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3o0000o`0000L0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`1<0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`150?ooo`003@3oool0
0`000000oooo0?ooo`030?ooo`<0o`0000<0oooo0?l000000?l00P000?l0
0`3o0000oooo0?ooo`0X0?ooo`030?l0003oool0o`000080oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`060000o`3oool0oooo0?ooo`000?l0
o`00103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`80
o`0000<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo04/0ooooo`3o002@0?l004L0oooo000=0?ooo`030000
003oool0oooo0080oooo0P000?l30?l00080003o0P3o000/0?ooo`80o`00
0`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00H0003o0?ooo`3o
ool0003o0?ooo`3o00040?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`040?l0003oool0
oooo0?ooo`80o`000`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool0B`3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3o
ool000d0oooo00<000000?ooo`3oool00P3oool010000?l0o`000?l0003o
00020000o`030?l0003oool0oooo02d0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`040?l0003oool0oooo0?ooo`<0003o0P3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`040?l0003oool0oooo0?l0
00D0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo04/0oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo000=0?ooo`03
0000003oool0oooo0080oooo00@0o`000000o`3o0000003o0P3o000a0?oo
o`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`02
0000o`@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool2
0?l000L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo04X0oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo000=0?oo
o`050000003oool0oooo0?ooo`000?l00P3o000010000?l0o`000?l0003o
000b0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo
0000o`020?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00P3oool20?l000030?ooo`3o0000oooo00H0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo04X0
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo04D0oooo000=0?ooo`050000003oool0oooo0?ooo`3o
00000`000?l00`3o0000003o0?ooo`0c0?ooo`050?l0003oool0oooo0?oo
o`000?l00P3oool00`000?l0o`000?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o00000P3o00030?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo04T0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
04D0oooo000=0?ooo`030000003oool0oooo0080003o00<0o`000000o`3o
0000=`3oool0103o0000oooo0?ooo`3oool20000o`80oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030?l000000?l0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0B@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool0A@3oool000d0oooo00<000000?ooo`3oool00`000?l20?l0
03P0oooo00D0o`000?ooo`000?l0oooo0000o`030?ooo`040?l0003oool0
oooo0000o`@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0o`000080o`0000<0oooo0000o`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`190?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`150?ooo`003@3oool00`000000oooo0?ooo`020?l000030000o`3o0000
oooo03T0oooo00@0o`000?ooo`3oool0003o0`3oool01@3o0000oooo0?oo
o`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`030?ooo`80o`001@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo04P0oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo
000=0?ooo`050000003oool0oooo0?l000000?l00P3o000j0?ooo`050?l0
003oool0oooo0?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l50?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3o00000`3o
ool0o`000?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0B03oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool000d0
oooo00<000000?ooo`3o00000P000?l00`3o0000oooo0?ooo`0j0?ooo`04
0?l0003oool0oooo0000o`<0oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0003oool00P3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool0B03oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool0
00d0oooo00D000000?ooo`3o0000003o0?l0000m0?ooo`050?l0003oool0
oooo0?ooo`000?l00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo
00@0o`000?ooo`3oool0oooo0P3o00000`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`170?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`150?ooo`00
3@3oool01@000000oooo0?l000000?l0o`0003h0oooo00@0o`000?ooo`3o
ool0003o0`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo0`3o0002
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo04L0ooooo`000?n@0000odL0oooo000=0?ooo`030000003oool0oooo
0400oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`060?l0003oool0
oooo0?ooo`000?l0oooo103o00050?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo04L0oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo
000=0?ooo`030000003oool0oooo0440oooo00@0o`000?ooo`3oool0003o
0`3oool01@3o0000oooo0?ooo`3o0000003o00<0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`170?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`150?ooo`003@3oool00`000000oooo
0?ooo`110?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool30?l00003
0?ooo`000?l0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`170?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`150?ooo`003@3oool00`000000oooo0?ooo`110?ooo`050?l0
003oool0oooo0?ooo`000?l00P3o00001@3oool0o`000?ooo`3oool0003o
00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`170?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`150?oo
o`003@3oool00`000000oooo0?ooo`120?ooo`<0o`0000D0003o0?ooo`3o
ool0oooo0?l000030?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`160?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`150?ooo`003@3oool00`000000
oooo0?ooo`0N0?ooo`D000007P3oool01P000000o`00000000000000oooo
0000o`80oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`040000o`3oool00000000000<0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00T0oooo
00@0003o0000000000000000A@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool000d0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0N0?ooo`030000
003o0000oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00D0003o0000003o
ool0oooo000000020?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool00000
04H0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo04D0oooo000=0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool07`3oool01@000000o`000?ooo`3oool0003o
00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`03
0?ooo`040000o`3oool0oooo000000<0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0
00000000o`0000000P0000150?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`150?ooo`003@3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0200oooo00@0o`00
0?ooo`3oool0003o0`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo000000030?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`04000000000?l0oooo000004H0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
04D0oooo000=0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool07P3oool01P000000oooo0?l000000000oooo0000o`<0oooo00D0o`00
0?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`040000o`3o
ool0oooo000000<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`000000
AP3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool0A@3oool000d0oooo00<000000?ooo`3oool07`3o
ool200000240oooo00D000000?l0003oool0oooo0000o`030?ooo`050?l0
003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0103oool00`000?l0
0000000000040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`000000000004H0
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo04D0oooo000=0?ooo`030000003oool0oooo04<0oooo
00D0o`000?ooo`3oool0oooo0000o`020?ooo`050?l0003oool0oooo0?oo
o`000?l0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo04H0ooooo`3o002@0?l0
04L0oooo000=0?ooo`030000003oool0oooo04<0oooo0P00o`020?ooo`04
0000o`3oool0oooo0?l000<0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?oo
o`80o`3oA`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool0A@3oool000d0oooo00<000000?ooo`3o
ool0@P3oool4003o00050?ooo`000?l0oooo0?ooo`3o00000`3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo103o0?l60?ooo`80000000<0oooo0000
00000000>`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool0A@3oool000`0ooooA@000006003o00<0
003o00<0o`000000o`000?l01P000?l00`3o0000003o0000o`070000o`03
0?l000000?l0003o00/0003o00<0o`000000o`000?l03`000?l00`3o0000
003o0000o`060000o`H0o`3o1P3oool00`000000oooo0000000l0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`150?ooo`003@3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo01h0oooo1P00o`0010000?l0oooo0?ooo`3o00030?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`00
0000103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool60?l0o`L0oooo00<000000?ooo`3o
ool0>`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool0A@3oool000d0oooo00<000000?ooo`3oool0
@P3oool4003o00050?ooo`000?l0oooo0?ooo`3o00000`3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo103o0?l60?ooo`80000000<0oooo00000000
0000>`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool0A@3oool000d0oooo00<000000?ooo`3oool0
@`3oool2003o0080oooo00@0003o0?ooo`3oool0o`000`3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00P0oooo0P3o0?m70?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`150?ooo`00
3@3oool00`000000oooo0?ooo`130?ooo`050?l0003oool0oooo0?ooo`00
0?l00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`160?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`150?ooo`003@3oool00`000000
oooo0?ooo`130?ooo`040?l0003oool0oooo0000o`<0oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0AP3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool0A@3oool000d0oooo00<000000?ooo`3oool0@`3oool0103o
0000oooo0?ooo`000?l30?ooo`050?l0003oool0oooo0?ooo`000?l00`3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo04H0oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo000=
0?ooo`030000003oool0oooo04<0oooo00@0o`000?ooo`3oool0003o0`3o
ool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`160?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`150?ooo`003@3oool00`000000oooo0?oo
o`130?ooo`040?l0003oool0oooo0000o`80oooo00<0o`000?ooo`3oool0
0P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0AP3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool0A@3oool000d0oooo00<000000?ooo`3oool0@`3oool00`3o0000oooo
0000o`030?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo04H0ooooo`000?n@0000odL0oooo000=0?ooo`030000
003oool0oooo0480oooo00@0o`000?ooo`3oool0003o0`3oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`160?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`15
0?ooo`003@3oool00`000000oooo0?ooo`120?ooo`<0o`0000@0003o0?oo
o`3oool0o`00103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0AP3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool0A@3oool000d0oooo00<000000?ooo`3oool0@P3oool0
103o0000oooo0000o`3oool30?l000<0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo04L0oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo000=
0?ooo`030000003oool0oooo0440oooo00@0o`000?ooo`3oool0003o0`3o
ool20?l00080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo04L0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo04D0oooo000=0?ooo`030000003oool0
oooo0440oooo00@0o`000?ooo`3oool0003o0`3oool01P3o0000oooo0?l0
003o0000003o0?l00080oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`170?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`150?ooo`003@3oool01@000000oooo0?ooo`000?l0o`0003h0
oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`050?l0003oool0oooo
0?ooo`000?l00P3oool30?l000@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool0
00d0oooo00D000000?ooo`3o0000003o0?l0000n0?ooo`040?l0003oool0
oooo0000o`<0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`@0o`00
00<0oooo0000o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
B03oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool0A@3oool000d0oooo00H000000?ooo`000?l0003o
0?l000000?ll0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool0103o
0000oooo0?ooo`000?l40?ooo`030?l0003oool0oooo0080oooo00<0003o
0?l0003oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0B03oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool0A@3oool000d0oooo00H000000?ooo`000?l0o`000000o`3o
000k0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool010000?l0
oooo0?l0003o00020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`180?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`150?ooo`003@3oool01@000000oooo0?ooo`3o0000003o
0080o`00>P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0o`00
0?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo00<0oooo00@0
003o0?ooo`3oool0oooo0`3o00050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0B@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
A@3oool000d0oooo00<000000?ooo`3oool00P000?l30?l003P0oooo00D0
o`000000o`000?l0oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
oooo00@0o`000?ooo`3o0000o`000`3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo04T0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
04D0oooo000=0?ooo`030000003oool0oooo00<0003o0P3o000g0?ooo`04
0?l0003oool0oooo0?ooo`80003o0P3oool00`3o0000oooo0?ooo`020?oo
o`050000o`3oool0oooo0?ooo`3o00001@3oool00`000?l0oooo0?ooo`03
0?ooo`040?l0003oool0oooo0?ooo`80o`0000<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`190?ooool0o`00T03o
00170?ooo`003@3oool01@000000oooo0?ooo`000?l0o`000080003o0P3o
000f0?ooo`040?l0003oool0oooo0?ooo`80003o0P3oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0003o
00001@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`190?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`150?ooo`003@3oool010000000oooo0?ooo`3oool20?l00004
0000o`3o0000003o0?l003@0oooo00D0o`000?ooo`3oool0oooo0000o`02
0?ooo`030000o`3o0000oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l0
00050?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?l000<0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0BP3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool000d0oooo00L00000
0?ooo`3oool0oooo0000o`3o0000003o0080o`0000<0003o0?l0003oool0
<@3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000000o`00
0?l00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo0`3o00080?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`1:0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`150?ooo`003@3oool00`000000oooo0?ooo`020?ooo`80o`00
00D0003o0?l0003o0000o`000000o`0`0?ooo`050?l0003oool0oooo0?oo
o`000?l00`3oool0103o0000oooo0?ooo`3oool20000o`@0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool01@3oool20?l000H0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo04X0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo04D0oooo000=0?ooo`030000003oool0oooo
0080oooo00@0003o0?l000000?l0003o103o000^0?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool0103o0000oooo0?ooo`3oool20000o`@0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`020?l000@0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo04/0oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo
000=0?ooo`030000003oool0oooo0080oooo00<0003o0?l0003o00000P3o
0000103oool0o`000?l000000?l/0?ooo`80o`000P3oool00`000?l0oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool20000o`03
0?ooo`3o0000oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool00P3oool20?l000030?ooo`000?l0oooo00T0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`1;0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`150?ooo`00
3@3oool00`000000oooo0?ooo`030?ooo`80o`0000@0003o0?l0003o0000
oooo0`3o000Z0?ooo`030?l0003oool0oooo0080003o103oool01@3o0000
oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030?l000000?l0oooo
00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`1<0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`150?ooo`003@3oool00`000000oooo0?ooo`030?ooo`04
0000o`3o0000o`000000o`80o`0000@0003o0?l000000?l0o`00:03oool0
1P3o0000oooo0?ooo`000?l0oooo0?l000<0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0003o0080oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?l000080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
C03oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool0A@3oool000d0oooo00<000000?ooo`3oool0103o
ool30?l000060000o`3o0000o`000000o`3o0000003o0P3o000T0?ooo`80
o`000P3oool01@000?l0oooo0?ooo`3o0000oooo0080o`00103oool00`00
0?l0oooo0?ooo`020?ooo`070?l0003oool0oooo0?ooo`000?l0oooo0000
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0080o`001@3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo04d0oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo04D0oooo000=0?ooo`030000003oool0oooo00D0oooo0P3o0000
0`000?l0o`000?ooo`020000o`030?ooo`3o0000003o0080o`00803oool2
0?l000<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`80003o103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool2
0?l000<0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`1=
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`150?ooo`003@3oool00`000000oooo0?ooo`050?oo
o`060?l0003oool0o`000000o`3o0000oooo0`000?l00`3oool0o`000000
o`020?l001`0oooo0P3o00000`000?l0oooo0?ooo`020000o`@0oooo00<0
o`000?ooo`3o00000P3oool00`000?l0oooo0?ooo`020?ooo`80o`001@3o
ool010000?l0oooo0000o`000?l30?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo0`3o000;0?ooo`030000o`3oool0oooo04h0oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo04D0oooo00070?ooo`D0000000<0oooo0000003oool01`3o
ool01@3o0000003o0?l000000?l0o`000080003o00<0o`000000o`3o0000
0P3o00000`000?l0o`000?l0000;0?ooo`80o`002`3oool20?l000<0oooo
0P000?l40?ooo`80o`000`3oool20000o`@0oooo00<0o`000?ooo`3oool0
103oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool0203oool20?l000X0oooo00<0003o0?ooo`3o
ool0CP3ooooo0000oi00003oA`3oool000T0oooo00D000000?ooo`3oool0
oooo000000080?ooo`80o`0000P0003o0?l000000?l0o`000?ooo`000?l0
o`000000o`80oooo00<0o`000000o`000?l01@3o00050?ooo`@0o`001P3o
ool40?l000<0oooo0`000?l30?ooo`80o`00103oool00`000?l0o`000?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0o`000?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`040?l0003o
ool0oooo0?l000P0oooo00<0003o0?ooo`3oool0C`3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
A@3oool000T0oooo00@000000?ooo`3oool0oooo0P0000080?ooo`050?l0
003oool0003o0?l000000?l00P3o00050000o`80o`000P000?l30?ooo`l0
o`0000<0oooo0?l0003oool00P3oool20000o`<0oooo00<0003o0?ooo`3o
0000103oool20000o`80oooo00@0o`000?ooo`3oool0o`001P3oool00`00
0?l0oooo0?ooo`030?ooo`80o`0000<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`020?ooo`80o`001P3oool00`00
0?l0oooo0?ooo`1?0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`150?ooo`002@3oool01@000000
oooo0?ooo`3oool0000000T0oooo00H0003o0?l0003oool0o`000?ooo`00
0?l20?l000040?ooo`000?l0o`000000o`80oooo0P3o00050000o`80oooo
1P3o00000`000?l0oooo0?ooo`020?ooo`D0003o103oool30?l000<0oooo
0P000?l40?ooo`<0o`001@3oool20000o`D0oooo00D0o`000?ooo`3oool0
oooo0000o`030?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1@0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`150?ooo`002@3oool01@000000oooo0?ooo`3oool0000000X0
oooo00<0003o0?l000000?l00P3o00000`000?l0oooo0?l000020000o`04
0?l000000?l0003o0?l00080oooo0`3o0000103oool0003o0000o`000?l4
0?l000H0003o0P3oool00`3o0000oooo0?ooo`040?l000040?ooo`000?l0
oooo0?ooo`80003o1P3oool20?l000D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0003o00P0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo0P3o00020?ooo`030000o`3oool0oooo0500oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo04D0oooo00080?ooo`8000000`3oool00`000000oooo0?ooo`09
0?ooo`80o`0000<0003o0?l0003oool00P000?l00`3o0000oooo0000o`02
0?l00080003o0P3oool00`000?l0oooo0?l000030?l000030?ooo`3o0000
o`000080oooo00<0003o0?ooo`3oool00P3oool50?l000D0oooo0`000?l6
0?ooo`80o`000P3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo0P3o
00070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0
o`000000o`3oool0DP3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool000d0oooo00<00000
0?ooo`3oool02@3oool02P000?l0o`000?ooo`000?l0o`000?ooo`000?l0
oooo0?l0003oool20000o`030?l0003oool0003o00@0003o0P3oool;0?l0
0080oooo00<0o`000?ooo`3oool00`3oool20000o`030?ooo`000?l0oooo
00@0oooo0P3o00040?ooo`040?l0003oool0003o0000o`D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0000o`060?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo0540oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo000=0?oo
o`030000003oool0oooo00X0oooo00P0003o0?l0003oool0003o0?l0003o
ool0003o0?ooo`80o`0000<0oooo0000o`3o00000P3o00000`000?l0oooo
0?ooo`040000o`@0oooo00<0003o0?ooo`3oool0103oool00`3o0000003o
0000o`030000o`@0oooo00<0003o0?ooo`3oool00P3o00060?ooo`80003o
1P3oool00`3o0000oooo0?ooo`050?ooo`80003o0`3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0580oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo04D0oooo000=0?ooo`030000003oool0oooo00X0oooo00<0
003o0?ooo`3o00000P000?l20?l00080003o0P3o0000103oool0003o0000
o`000?l30?l00080oooo00<0o`000?ooo`000?l02`000?l00`3o0000oooo
0?ooo`040?ooo`D0o`001@3oool30000o`80oooo00@0o`000?ooo`3oool0
oooo0P3o00070?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3o
ool0o`002@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool0D`3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool000d0
oooo00<000000?ooo`3oool02`3oool20000o`040?l0003oool0003o0?oo
o`80o`0000@0003o0?ooo`3o0000o`000`000?l20?ooo`D0o`000`3oool0
0`000?l0oooo0?ooo`050?ooo`040?l0003oool0oooo0?ooo`<0o`000P3o
ool00`000?l0oooo0?ooo`030?ooo`80003o1@3oool0103o0000oooo0?oo
o`3o00080?ooo`030000o`3oool0oooo00H0oooo00<0003o0?l0003oool0
203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0D`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool000d0oooo00<0
00000?ooo`3oool0303oool01@000?l0oooo0?l0003oool0003o0080o`00
00@0oooo0000o`000?l0oooo0P3o00001@3oool0003o0000o`000?l0o`00
00<0oooo3`3o00050?ooo`040000o`3oool0oooo0?ooo`80003o203oool2
0?l000P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`1D0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`150?ooo`003@3oool00`00
0000oooo0?ooo`0=0?ooo`060000o`3o0000oooo0?l000000?l0oooo0P3o
0000103oool0003o0?ooo`3oool20?l00080oooo1@000?l20?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool40000o`P0oooo
0`3o00070?ooo`80003o203oool20?l000030?ooo`000?l0oooo00H0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo05D0ooooo`3o002@0?l004L0oooo000=0?ooo`030000003o
ool0oooo00h0oooo00D0003o0?l0003oool0oooo0000o`020?ooo`040?l0
00000?l0003o0000o`80oooo0`3o00040?ooo`H0003o103oool00`3o0000
oooo0000o`060000o`030?ooo`000?l0oooo00L0oooo0P3o00030?ooo`03
0?l0003oool0oooo0080oooo0P000?l90?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0EP3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool0A@3oool000d0oooo00<000000?ooo`3oool03P3oool00`3o0000003o
0?l000020?ooo`040000o`3oool0003o0?l00080oooo00<0003o0?ooo`3o
ool0103o00040?ooo`040000o`3oool0oooo0?ooo`H0003o203oool00`00
0?l0oooo0?ooo`040?ooo`80o`001@3oool00`3o0000oooo0?ooo`020000
o`X0oooo00<0o`000?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0
003o00X0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`1F
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`150?ooo`003@3oool00`000000oooo0?ooo`0?0?oo
o`030000o`3oool0o`000080oooo0P000?l0103oool0o`000?l0003oool2
0000o`040?l0003oool0oooo0?ooo`D0o`001`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00@0o`001`3oool00`3o0000003o0000
o`0:0?ooo`80o`00203oool00`000?l0oooo0000o`0:0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0E`3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3o
ool000d0oooo00<000000?ooo`3oool0403oool010000?l0oooo0?l0003o
00020000o`<0oooo00<0o`000?ooo`3o00000`000?l40?ooo`030000o`3o
ool0o`0001<0o`002@3oool30000o`X0oooo0P3o000:0?ooo`80003o2P3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo05P0oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo04D0oooo000=0?ooo`030000003oool0oooo0140oooo00D0003o
0?ooo`000?l0o`000?ooo`020000o`80oooo0P3o00030?ooo`D0003o203o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00@0oooo1000
0?l30?ooo`030?l0003oool0oooo00@0oooo0`3o000;0?ooo`<0003o203o
ool20?l000h0oooo00<0003o0?ooo`3oool0F@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3o
ool000d0oooo00<000000?ooo`3oool04P3oool010000?l0oooo0?ooo`3o
00020?ooo`80003o00@0o`000?ooo`3o0000o`00103oool60000o`@0oooo
00<0o`000?ooo`3oool0203oool010000?l0oooo0?ooo`3oool30000o`L0
oooo00<0o`000?ooo`3oool00P3oool20?l000`0oooo0P000?l30?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0303oool20000oe`0
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo04D0oooo000=0?ooo`030000003oool0oooo01<0oooo
00<0003o0?ooo`3oool00P3o00020?ooo`80003o0P3oool20?l00080oooo
00<0003o0?ooo`3oool00`3oool70000o`@0oooo20000?l;0?ooo`@0o`00
303oool20000o`D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo05`0oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo
000=0?ooo`030000003oool0oooo01@0oooo00@0003o0?ooo`3oool0oooo
0P3o00020?ooo`80003o0P3oool30?l000T0oooo00<0o`000?ooo`3oool0
10000?l40?ooo`030000o`3oool0oooo00/0oooo0P3o000>0?ooo`030000
o`3oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo0?l0000>0?ooo`03
0000o`3oool0oooo05d0oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo000=0?ooo`030000
003oool0oooo01D0oooo00@0003o0?ooo`3oool0oooo0P3o00030?ooo`80
003o0P3oool00`000?l0o`000?l000020?l000@0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`090?ooo`80o`000P3oool00`3o0000
oooo0?ooo`090?ooo`80003o2P3oool00`000?l0o`000?l0000>0?ooo`03
0000o`3oool0oooo05h0oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo000=0?ooo`030000
003oool0oooo01H0oooo00<0003o0?l0003o00000P3oool00`3o0000oooo
0?ooo`020?ooo`80003o1@3oool50?l000/0oooo00<0003o0?ooo`3oool0
103oool50?l000@0oooo00<0o`000?ooo`3oool01`3oool20000o``0oooo
00<0o`000?ooo`3oool0303oool20000of40oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo04D0oooo
000=0?ooo`030000003oool0oooo01L0oooo0P000?l30?ooo`80o`000`3o
ool20000o`P0oooo4`3o000:0?ooo`030?l0003oool0oooo00<0oooo0`00
0?l<0?ooo`80o`0000<0oooo0000o`3oool02`3oool00`000?l0oooo0?oo
o`1Q0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`150?ooo`003@3oool00`000000oooo0?ooo`0I
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`000?l00P3oool2
0000o`H0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo00<0003o3P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0HP3ooooo
0000oi00003oA`3oool000d0oooo00<000000?ooo`3oool06P3oool00`00
0?l0oooo0?ooo`020?ooo`80o`00103oool40000o`80oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`<0003o3`3oool20?l0
00D0oooo00<0003o0?ooo`3oool01P3oool20000ofD0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
04D0oooo000=0?ooo`030000003oool0oooo01/0oooo00H0003o0?ooo`3o
ool0oooo0000o`3oool20?l000H0oooo1P000?l90?ooo`030000o`3oool0
oooo00P0oooo1@000?l00`3o0000oooo0?ooo`0=0?ooo`80o`00203oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo06D0oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo04D0oooo000=0?ooo`030000003oool0oooo01`0oooo0`000?l40?oo
o`80o`001@3oool00`3o0000oooo0?ooo`020?oooa@0003o1@3oool00`3o
0000oooo0?ooo`0:0?ooo`<0o`002P3oool00`000?l0oooo0?ooo`020?oo
o`80003oJ03oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool0A@3oool000d0oooo00<000000?ooo`3o
ool07P3oool20000o`D0oooo103o00000`3oool0o`000?ooo`0<0?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool01`3oool20?l000h0
oooo00@0003o0?ooo`3oool0003oJP3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool000d0
oooo00<000000?ooo`3oool0803oool20000o`L0oooo0`3o000<0?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool01@3oool20?l00100
oooo0`000?m[0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`150?ooo`003@3oool00`000000oooo
0?ooo`0R0?ooo`80003o1@3oool00`3o0000oooo0?ooo`040?l000L0oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?l000050?l00140oooo
0`000?m/0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`150?ooo`003@3oool00`000000oooo0?oo
o`0T0?ooo`80003o0`3oool00`3o0000oooo0?ooo`040?ooo`D0o`000P3o
ool00`000?l0oooo0?ooo`0=0?ooo`@0o`005@3oool20000ofl0oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo04D0oooo000=0?ooo`030000003oool0oooo02H0oooo0P000?l0
0`3o0000oooo0?ooo`0:0?oooa80o`000`3oool00`3o0000oooo0?ooo`0@
0?ooo`<0003oL@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool0A@3oool000d0oooo00<000000?oo
o`3oool0:03oool20000o`d0oooo00<0003o0?ooo`3oool0403oool00`3o
0000oooo0?ooo`0>0?ooo`80003oM03oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool000d0
oooo00<000000?ooo`3oool0:P3oool30000o`X0oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0<0?ooo`80003oMP3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo00/0oooo0`000?l20?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0403oool3003o0180oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`030?l000h0oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`150?ooo`003@3oool00`000000oooo0?ooo`0]0?ooo`D0003o
1@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00T0oooo
0`000?mh0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool02P3oool50000o`030?oo
o`000?l0oooo0180oooo00<0o`000?ooo`3oool01`3oool5000000<0oooo
1@00o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o0000
103o000=0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool0A@3oool000L0oooo1000
00020?ooo`030000003oool0oooo0380oooo10000?l00`3oool0003o0?oo
o`0:0?ooo`800?oo1P3oool00`3o0000oooo0?ooo`040?ooo`@0003oN`3o
oonH0?l000L0003o9@3o0007003o0<@0o`00A`3oool000L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0f0?ooo`D0003o1`3oool4
003oo`D0oooo00<0o`000000o`000?l010000?oo0?oooaP0oooo1`000?lP
0?ooo`030000003oool0oooo0080oooo1`00o`0U0?ooo`L0o`00g`3oool0
00P0oooo00<000000?ooo`3oool00P3oool2000003`0oooo1P000?l6003o
o`D0003oo`3ooolN0?ooo`L0003o803oool00`000000oooo0?ooo`020?oo
o`L00?l09@3oool70?l00=l0oooo00090?ooo`050000003oool0oooo0?oo
o`000000@`3oool6003oool0oooo903oool50000ob40oooo00<000000?oo
o`3oool00`3oool5003o02L0oooo1@3o003P0?ooo`001`3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo0480oooo1000oooo0?oo
obH0oooo0`000?lQ0?ooo`8000001P3oool3003o02T0oooo0`3o003Q0?oo
o`00203oool2000004T0oooo0P00oooo0?ooool0ooooI03oool00?l0oooo
o`3oooni0?ooo`00o`3ooooo0?oookT0oooo003o0?ooool0oooo^@3oool0
0?l0ooooo`3oooni0?ooo`002`3oool200000?l0ooooo`3ooon/0?ooo`00
303oool00`000000oooo0?ooo`3o0?ooool0ooooZP3oool000d0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooojT0oooo000<0?ooo`030000003oool0
00000?l0ooooo`3ooonZ0?ooo`002`3oool010000000oooo0?ooo`00003o
0?ooool0ooooZP3oool000X0oooo0`0000000`3oool000000000003o0?oo
ool0ooooZ@3oool00?l0ooooZ03oool200000?l0oooo3`3oool00?l0oooo
Z03oool200000?l0oooo3`3oool00?l0ooooY`3oool010000000oooo0?oo
o`00003o0?ooo`h0oooo003o0?ooojH0oooo0P0000020?ooo`800000o`3o
ool=0?ooo`00o`3ooooo0?oookT0oooo003o0?ooool0oooo^@3oool00?l0
ooooo`3oooni0?ooo`00o`3ooooo0?oookT0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{695, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  For convenience we choose  ",
  Cell[BoxData[
      RowBox[{\(z\_1 = 4\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        " ", \(z\_2 = 2 + 2  \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(z\_3 = 0\)}]]],
  "  and the image values  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(w\_2 = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(w\_3 = \[Infinity]\)}]]],
  ",  respectively.  The ordered triple  ",
  Cell[BoxData[
      RowBox[{\(z\_1 = \(-4\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        " ", \(z\_2 = 2 + 2  \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(z\_3 = 0\)}]]],
  "  gives the circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z - 2\)\(|\)\) = \ 2\)]],
  "  a positive orientation and the disk  ",
  Cell[BoxData[
      \(D : \(\(|\)\(z - 2\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  "  has a left orientation.  The image points  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(w\_2 = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(w\_3 = \[Infinity]\)}]]],
  "  all lie on the extended ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " axis, and they determine a left orientation for the upper half-plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  ".  Therefore we can use the second implicit formula (Equation ",
  StyleBox["(10-21)",
    FontColor->RGBColor[0, 0, 1]],
  ") to write  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\((z\  - \ 4)\)\ \((2\  + \ 2  \[ImaginaryI]\  - \ 0)\)\)\/\(\((z\  \
- \ 0)\) \((2\  + \ 2  \[ImaginaryI]\  - \ 4)\)\)\  = \ \(w\  - \ 0\)\/\(1\  \
- \ 0\)\)]],
  ",  \n\nwhich determines a mapping of the disk  ",
  Cell[BoxData[
      \(D : \(\(|\)\(z - 2\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  "  onto the upper half-plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  ".  Use the fact that ",
  Cell[BoxData[
      \(\(\(\ \)\(2\  + \ 2  \[ImaginaryI]\)\)\/\(\(-2\)\  + \ 2  \
\[ImaginaryI]\)\  = \(-\[ImaginaryI]\)\)]],
  "  to simplify the preceding equation and get \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(z\  - \ 
                4\)\/\(\(z\)\(\ \)\)\) \(\(\ \)\(2\  + \ 2  \[ImaginaryI]\)\)\
\/\(\(-2\)\  + \ 2  \[ImaginaryI]\)\  = \(\(\(z\  - \ 
                  4\)\/\(\(z\)\(\ \)\)\) \((\(-\[ImaginaryI]\))\)\  = \ \ \
w\/1\)\)]],
  " \n\nwhich can be written in the form  \n\n\t\t\t",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(\(-\[ImaginaryI]z\)\  + \ \[ImaginaryI]4\)\/\(\(z\
\)\(\ \)\)\)\)],
    AspectRatioFixed->True],
  ". "
}], "Text"],

Cell[TextData[{
  "A straightforward calculation shows that the points  ",
  Cell[BoxData[
      RowBox[{\(z\_4 = 1 - \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(z\_5 = 2\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        " ", \(z\_6 = 1 + \[ImaginaryI]\)}]]],
  "  are mapped onto the points  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(w\_4\ \  = \ \ \(S \((z\_4)\)\ \  = \ \ \(S \((1 - \
\[ImaginaryI])\)\ \  = \ \ \(-2\) + \[ImaginaryI]\)\)\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["  ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(w\_5\ \  = \ \ \(S \((z\_5)\)\ \  = \ \ \(S \
\((2)\)\ \  = \ \ \[ImaginaryI]\)\)\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[
          RowBox[{
            StyleBox["  ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  "}]], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(w\_6\ \  = \ \ \(S \((z\_6)\)\ \  = \ \ \(S \
\((1 + \[ImaginaryI])\)\ \  = \ \ 2 + \[ImaginaryI]\)\)\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["  ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  "  \n\nrespectively.  The points  ",
  Cell[BoxData[
      RowBox[{\(w\_4 = \(-2\) + \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(w\_5 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        " ", \(w\_6 = 2 + \[ImaginaryI]\)}]]],
  "  lie on the horizontal line  ",
  Cell[BoxData[
      \(Im \((w)\) > 1\)]],
  "  in the upper half-plane.  Therefore the crescent-shaped region is mapped \
onto the horizontal strip  ",
  Cell[BoxData[
      \(0 < Im \((w)\) < 1\)]],
  ",  as shown in Figure 10.7. "
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 10.7",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/mobiustranformation/\
MobiusTranformationFigures/mat1007.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The mapping  ",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(\(-\[ImaginaryI]z\)\  + \ \[ImaginaryI]4\)\/\(\(z\
\)\(\ \)\)\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter three points and their images and solve for  w = S(z).  For \
convenience we choose  ",
  Cell[BoxData[
      \(z\_1 = 4, \ z\_2 = 2 + 2  \[ImaginaryI], \ z\_3 = 0\)],
    AspectRatioFixed->True],
  "  which are mapped onto the points  ",
  Cell[BoxData[
      \(w\_1 = 0, \ w\_2 = 1, \ w\_3 = \[Infinity]\)],
    AspectRatioFixed->True],
  ",  respectively.  In this case we remove the terms involving  ",
  Cell[BoxData[
      \(w\_3\  = \ \[Infinity]\)],
    AspectRatioFixed->True],
  ",  in the implicit formula, because this implies that  ",
  Cell[BoxData[
      \(\(w\_2\  - \ w\_3\)\/\(w\  - \ w\_3\) = \(\(w\_2\  - \ \
\[Infinity]\)\/\(w\  - \ \[Infinity]\) = 1\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(S = \(T = \(w = \(W = \(z = \(Z = 0\)\)\)\)\); \ 
    Remove[S, T, w, W, z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[formula, Iden, solset];\)\ \), "\n", 
    \(\(formula\  = \ \(\((z - z\_1)\) \((z\_2 - z\_3)\)\)\/\(\((z - z\_3)\) \
\((z\_2 - z\_1)\)\)\  \[Equal] \ \(w - w\_1\)\/\(w\_2 - w\_1\);\)\ \), "\n", 
    \(\(Print[formula];\)\ \), "\n", 
    \(\(z\_1\  = \ 4;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(z\_2\  = \ 2 + 2  \[ImaginaryI];\)\ \ \), "\[IndentingNewLine]", 
    \(\(z\_3\  = \ 0;\)\ \ \), "\n", 
    \(\(w\_1\  = \ 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\_2\  = \ 1;\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\_3\  = \ \[Infinity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute the values\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,    \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,   \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,    \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,       \!\(w\_3\) = \>\"", 
        w\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[formula];\)\ \), "\n", 
    \(\(solset\  = \ Solve[formula, w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S(z) = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Check our work and look at the images of  ",
  Cell[BoxData[
      \(z\_1, \ z\_2, \ z\_3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,      \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,    \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,      \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,        \!\(w\_3\) = \>\"", w\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<S[\!\(z\_1\)] = \>\"", 
        S[z\_1], \*"\"\<,   S[\!\(z\_2\)] = \>\"", 
        S[z\_2], \*"\"\<,     S[\!\(z\_3\)] = \>\"", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "And we need to look at the images of three more points;   ",
  Cell[BoxData[
      \(z\_4 = 1 - \[ImaginaryI], \ z\_5 = 2, \ z\_6 = 1 + \[ImaginaryI]\)],
    AspectRatioFixed->True],
  "  and  ",
  Cell[BoxData[
      \(w\_4 = \(-2\) + \[ImaginaryI], \ w\_5 = \[ImaginaryI], \ 
      w\_6 = 2 + \[ImaginaryI]\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(z\_4\  = \ \ 1 - \[ImaginaryI]; \ \ \ \ \ z\_5\  = \ 
      2; \ \ \ \ z\_6\  = \ 1 + \[ImaginaryI];\ \), "\n", 
    \(w\_4\  = \ \(-2\) + \[ImaginaryI]; \ \ \ w\_5\  = \ \[ImaginaryI]; \ \ \
\ w\_6\  = \ 2 + \[ImaginaryI];\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(z\_4\) = \>\"", 
        z\_4, \*"\"\<,       \!\(z\_5\) = \>\"", 
        z\_5, \*"\"\<,       \!\(z\_6\) = \>\"", z\_6];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_4\) = \>\"", 
        w\_4, \*"\"\<,      \!\(w\_5\) = \>\"", 
        w\_5, \*"\"\<,       \!\(w\_6\) = \>\"", w\_6];\)\ \), "\n", 
    \(\(Print[\*"\"\<S[\!\(z\_4\)] = \>\"", 
        S[z\_4], \*"\"\<,   S[\!\(z\_5\)] = \>\"", 
        S[z\_5], \*"\"\<,    S[\!\(z\_6\)] = \>\"", 
        S[z\_6]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
To illustrate the mapping, consider the inverse image of the horizontal \
strip.  We will need to use the inverse function.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Iden[w_]\  = \ w;\)\ \), "\n", 
    \(\(solset\  = \ Solve[formula, z];\)\ \), "\n", 
    \(\(T[w_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<w = S[z] = \>", S[z]];\)\ \), "\n", 
    \(\(Print["\<z = T[w] = \>", T[w]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<T[S[z]] = \>", T[S[z]], "\< = \>", 
        Simplify[T[S[z]]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<S[T[w]] = \>", S[T[w]], "\< = \>", 
        Simplify[S[T[w]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Now plot the graphs using T[w] then the identity map.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(set\  = \ \ {{4, 0}, {2, 2}, {1, \(-1\)}, {2, 0}, {1, 
            1}};\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(zdots = 
        Graphics[{{Magenta, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Cyan, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}, {Green, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(4\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(5\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{0, 0}, {1, 0}, {\(-2\), 1}, {0, 1}, {2, 
            1}};\)\ \), "\[IndentingNewLine]", 
    \(\(wdots = 
        Graphics[{{Magenta, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Cyan, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}, {Green, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(4\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(5\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(zplane = 
        CartesianMap[
          T\ \ \ , {\(-9\), 9, 0.3}, {0.005, 0.995, 
            0.09}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.05\), 
                4.05}, {\(-2.05\), 
                2.05}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 4, 1], 
              Range[2, 2, 
                1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(wplane = 
        CartesianMap[
          Iden, {\(-9\), 9, 0.9}, {0.005, 0.995, 
            0.09}, \[IndentingNewLine]PlotRange \[Rule] {{\(-9\), 9}, {0, 
                1}}, AspectRatio \[Rule] 
            1\/3, \[IndentingNewLine]Ticks \[Rule] {Range[\(-9\), 9, 3], 
              Range[0, 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[zplane, zdots, 
        PlotRange \[Rule] {{\(-0.05\), 4.05}, {\(-2.05\), 2.05}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 4, 1], 
            Range[2, 2, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The the crescent-shaped region that lies inside\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<the disk |z-2| < 2 and outside the circle |z-1| = 1.\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Show[wplane, wdots, PlotRange \[Rule] {{\(-9\), 9}, {0, 1}}, 
        AspectRatio \[Rule] 
          1\/3, \[IndentingNewLine]Ticks \[Rule] {Range[\(-9\), 9, 3], 
            Range[0, 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image is the horizontal strip 0 < v < 1,\>"];\)\ \), "\n\
", 
    \(\(Print["\<under the mapping  w = \>", 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", z\_1, "\<] = \>", 
        S[z\_1], \[IndentingNewLine]"\<,      S[\>", z\_2, "\<] = \>", 
        S[z\_2], \[IndentingNewLine]"\<,   S[\>", z\_3, "\<] = \>", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", z\_4, "\<] = \>", 
        S[z\_4], \[IndentingNewLine]"\<,   S[\>", z\_5, "\<] = \>", 
        S[z\_5], \[IndentingNewLine]"\<,   S[\>", z\_6, "\<] = \>", 
        S[z\_6]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We have constructed the transformation ",
  Cell[BoxData[
      \(w = \(S[
            z] = \(-\(\(\[ImaginaryI]\ \((\(-4\)\  + \ z)\)\)\/z\)\)\)\)]],
  "  and see that the image of the crescent-shaped region that lies inside \
the disk ",
  Cell[BoxData[
      \(\(\(|\)\(z - 2\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  "  and outside the circle ",
  Cell[BoxData[
      \(\(\(|\)\(z - 1\)\(|\)\) = \ 1\)]],
  "  is the horizontal strip  ",
  Cell[BoxData[
      \(0 < v < 1\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Lines of Flux",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tIn electronics, images of certain lines represent lines of electric \
flux, which comprise the trajectory of an electron placed in an electrical \
field. Consider the bilinear transformation  \n\n\t\t\t",
  Cell[BoxData[
      \(w\  = \ \(S \((z)\)\  = \ z\/\(z\  - \ a\)\)\)]],
  "    and    ",
  Cell[BoxData[
      \(z\  = \ \(\(-1\) \((w)\)\  = \ \(a\ w\)\/\(w\  - \ 1\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe half rays  ",
  Cell[BoxData[
      \({Arg \((w)\) = c}\)]],
  ",  where c is a constant, that meet at the origin ",
  Cell[BoxData[
      \(w = 0\)]],
  " represent the lines of electric flux produced by a source located at ",
  Cell[BoxData[
      \(w = 0\)]],
  "  (and a sink at ",
  Cell[BoxData[
      \(w = \[Infinity]\)]],
  " ).  The preimage of this family of lines is a family of circles that pass \
through the points ",
  Cell[BoxData[
      RowBox[{"z", "=", 
        RowBox[{
          RowBox[{"0", " ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", "z"}], "=", "a"}]}]]],
  ".  We visualize these circles as the lines of electric flux from one point \
charge to another.  The limiting case as a is called a dipole and is \
discussed in Exercise 6, Section 10.11.  The graphs for ",
  Cell[BoxData[
      \(a = 1\)]],
  ", ",
  Cell[BoxData[
      \(a = 0.5\)]],
  ", and ",
  Cell[BoxData[
      \(a = 0.1\)]],
  " are shown in Figure 10.8."
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 10.8",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/mobiustranformation/\
MobiusTranformationFigures/mat1008.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Images of ",
  Cell[BoxData[
      \(Arg \((w)\) = c\)]],
  " under the mapping ",
  Cell[BoxData[
      \(z\  = \ \(\(-1\) \((w)\)\  = \ \(a\ w\)\/\(w\  - \ 1\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Conformal Mapping",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ConformalMappingBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Mobius - Bilinear Transformation",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/MobiusTranformationBib.\
html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Smith Chart",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/SmithChartBib.html"], None},
  
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{976, 643},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[132613, 2531, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[464797, 8411, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 605730, 11000}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 147, 3, 33, "Text"],
Cell[2252, 67, 2802, 77, 272, "Text"],
Cell[5057, 146, 1479, 41, 260, "Text"],
Cell[6539, 189, 1816, 46, 322, "Text"],
Cell[8358, 237, 1194, 32, 94, "Text"],
Cell[9555, 271, 507, 18, 37, "Text",
  Evaluatable->False],
Cell[10065, 291, 105265, 1729, 189, 105151, 1725, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[115333, 2022, 1113, 35, 137, "Text"],
Cell[116449, 2059, 622, 20, 94, "Text"],
Cell[117074, 2081, 1463, 38, 373, "Text"],
Cell[118540, 2121, 1361, 42, 109, "Text"],
Cell[119904, 2165, 1302, 41, 52, "Text"],
Cell[121209, 2208, 779, 24, 56, "Text"],

Cell[CellGroupData[{
Cell[122013, 2236, 112, 2, 33, "Text"],
Cell[122128, 2240, 180, 6, 37, "Text"],
Cell[122311, 2248, 357, 7, 145, "Input"],
Cell[122671, 2257, 120, 2, 33, "Text",
  Evaluatable->False],
Cell[122794, 2261, 549, 12, 171, "Input"],
Cell[123346, 2275, 95, 2, 33, "Text",
  Evaluatable->False],
Cell[123444, 2279, 506, 9, 153, "Input"],
Cell[123953, 2290, 661, 16, 56, "Text",
  Evaluatable->False],
Cell[124617, 2308, 265, 6, 90, "Input"],
Cell[124885, 2316, 325, 7, 52, "Text",
  Evaluatable->False],
Cell[125213, 2325, 102, 2, 50, "Input"],
Cell[125318, 2329, 394, 11, 71, "Text",
  Evaluatable->False],
Cell[125715, 2342, 1411, 28, 345, "Input"],
Cell[127129, 2372, 379, 13, 37, "Text"],
Cell[127511, 2387, 1637, 32, 250, "Input"]
}, Closed]],
Cell[129163, 2422, 1622, 50, 160, "Text"],
Cell[130788, 2474, 1474, 41, 96, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[132287, 2519, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[132435, 2525, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[132613, 2531, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[132973, 2543, 502, 16, 30, "Text",
  Evaluatable->False],
Cell[133478, 2561, 80429, 1321, 189, 80315, 1317, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[213910, 3884, 951, 21, 162, "Text"],
Cell[214864, 3907, 1630, 35, 388, "Text"],
Cell[216497, 3944, 218, 6, 75, "Text"],

Cell[CellGroupData[{
Cell[216740, 3954, 112, 2, 33, "Text"],
Cell[216855, 3958, 90, 2, 33, "Text"],
Cell[216948, 3962, 1706, 32, 466, "Input"],
Cell[218657, 3996, 187, 7, 33, "Text",
  Evaluatable->False],
Cell[218847, 4005, 585, 12, 90, "Input"],
Cell[219435, 4019, 134, 4, 33, "Text",
  Evaluatable->False],
Cell[219572, 4025, 3943, 78, 657, "Input"],
Cell[223518, 4105, 2641, 50, 506, "Input"]
}, Closed]],
Cell[226174, 4158, 498, 16, 30, "Text",
  Evaluatable->False],
Cell[226675, 4176, 100559, 1651, 189, 100445, 1647, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[327237, 5829, 952, 21, 160, "Text"],
Cell[328192, 5852, 429, 11, 77, "Text"],
Cell[328624, 5865, 1283, 28, 302, "Text"],

Cell[CellGroupData[{
Cell[329932, 5897, 112, 2, 33, "Text"],
Cell[330047, 5901, 90, 2, 33, "Text"],
Cell[330140, 5905, 1701, 32, 466, "Input"],
Cell[331844, 5939, 289, 8, 38, "Text",
  Evaluatable->False],
Cell[332136, 5949, 595, 13, 161, "Input"],
Cell[332734, 5964, 181, 7, 33, "Text",
  Evaluatable->False],
Cell[332918, 5973, 575, 12, 90, "Input"],
Cell[333496, 5987, 134, 4, 33, "Text",
  Evaluatable->False],
Cell[333633, 5993, 4148, 82, 687, "Input"]
}, Closed]],
Cell[337796, 6078, 2119, 71, 68, "Text"],
Cell[339918, 6151, 1843, 60, 71, "Text"],
Cell[341764, 6213, 562, 18, 38, "Text",
  Evaluatable->False],
Cell[342329, 6233, 107900, 1772, 189, 107786, 1768, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[450232, 8007, 5472, 155, 264, "Text"],
Cell[455707, 8164, 588, 18, 38, "Text"],

Cell[CellGroupData[{
Cell[456320, 8186, 112, 2, 33, "Text"],
Cell[456435, 8190, 217, 7, 38, "Text"],
Cell[456655, 8199, 424, 9, 127, "Input"],
Cell[457082, 8210, 120, 2, 33, "Text",
  Evaluatable->False],
Cell[457205, 8214, 384, 8, 111, "Input"],
Cell[457592, 8224, 154, 5, 33, "Text",
  Evaluatable->False],
Cell[457749, 8231, 933, 18, 210, "Input"],
Cell[458685, 8251, 616, 19, 52, "Text",
  Evaluatable->False],
Cell[459304, 8272, 240, 5, 90, "Input"],
Cell[459547, 8279, 165, 5, 33, "Text",
  Evaluatable->False],
Cell[459715, 8286, 3728, 72, 722, "Input"],
Cell[463446, 8360, 470, 15, 38, "Text",
  Evaluatable->False]
}, Closed]],
Cell[463931, 8378, 513, 17, 49, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[464469, 8399, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[464617, 8405, 177, 4, 33, "Text",
  Evaluatable->False],
Cell[464797, 8411, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[465157, 8423, 2457, 60, 218, "Text"],
Cell[467617, 8485, 226, 6, 33, "Text"],
Cell[467846, 8493, 514, 16, 52, "Text",
  Evaluatable->False],
Cell[468363, 8511, 115008, 1888, 189, 114894, 1884, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[583374, 10401, 2781, 74, 277, "Text"],
Cell[586158, 10477, 3907, 107, 202, "Text"],
Cell[590068, 10586, 558, 18, 36, "Text"],

Cell[CellGroupData[{
Cell[590651, 10608, 112, 2, 33, "Text"],
Cell[590766, 10612, 771, 21, 58, "Text",
  Evaluatable->False],
Cell[591540, 10635, 1682, 32, 466, "Input"],
Cell[593225, 10669, 181, 7, 33, "Text",
  Evaluatable->False],
Cell[593409, 10678, 587, 12, 90, "Input"],
Cell[593999, 10692, 428, 13, 33, "Text",
  Evaluatable->False],
Cell[594430, 10707, 848, 16, 130, "Input"],
Cell[595281, 10725, 195, 5, 33, "Text",
  Evaluatable->False],
Cell[595479, 10732, 665, 15, 210, "Input"],
Cell[596147, 10749, 117, 2, 33, "Text",
  Evaluatable->False],
Cell[596267, 10753, 4270, 82, 681, "Input"],
Cell[600540, 10837, 513, 16, 55, "Text"]
}, Closed]],
Cell[601068, 10856, 513, 13, 109, "Text"],
Cell[601584, 10871, 1254, 39, 71, "Text"],
Cell[602841, 10912, 569, 19, 36, "Text"],
Cell[603413, 10933, 290, 7, 33, "Text"],
Cell[603706, 10942, 291, 7, 33, "Text"],
Cell[604000, 10951, 306, 7, 33, "Text"],
Cell[604309, 10960, 277, 7, 33, "Text"],
Cell[604589, 10969, 257, 5, 33, "Text"],
Cell[604849, 10976, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

