(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    356380,       6613]*)
(*NotebookOutlinePosition[    357194,       6643]*)
(*  CellTagsIndexPosition[    357117,       6637]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["10.3  Mapping Involving Elementary Functions",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tIn Section 5.1 we saw that the function  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \[ExponentialE]\^z\)\)]],
  "  is a one-to-one mapping of the fundamental period strip  ",
  Cell[BoxData[
      \(\(-\[Pi]\) < y \[LessEqual] \[Pi]\)]],
  "  in the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-plane onto the w-plane with the point  ",
  Cell[BoxData[
      \(w = 0\)]],
  "  deleted.  Because  ",
  Cell[BoxData[
      \(f' \((z)\) \[NotEqual] 0\)]],
  ",  the mapping  ",
  Cell[BoxData[
      \(w = \[ExponentialE]\^z\)]],
  "  is a conformal mapping at each point ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " in the complex plane.  The family of horizontal lines  ",
  Cell[BoxData[
      \(y = c\ \ and\ \  - \[Pi] < c \[LessEqual] \[Pi]\)]],
  ",  and segments  ",
  Cell[BoxData[
      \(x = a\ \ and\ \  - \[Pi] < y \[LessEqual] \[Pi]\)]],
  "  form an orthogonal grid in the fundamental period strip.  Their images \
under the mapping  ",
  Cell[BoxData[
      \(w = \[ExponentialE]\^z\)]],
  "  are the rays  ",
  Cell[BoxData[
      \(\[Rho]\  > 0\ \ and\ \ \[Phi] = c\)]],
  "  and the circles  ",
  Cell[BoxData[
      \(\(\(|\)\(w\)\(|\)\) = \[ExponentialE]\^a\)]],
  ",  respectively.  These images form an orthogonal curvilinear grid in the \
",
  StyleBox["w",
    FontFamily->"Courier New"],
  "-plane, as shown in Figure 10.9. If  ",
  Cell[BoxData[
      \(\(-\[Pi]\) < c < d \[LessEqual] \[Pi]\)]],
  ",  then the rectangle  ",
  Cell[BoxData[
      \(R = {x + \(iy : \ a < x < b\), c < y < d}\)]],
  "  is mapped one-to-one and onto the region  ",
  Cell[BoxData[
      \(G = {\[Rho]\ \(\(\[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\)\) : \
\[ExponentialE]\^a < \[Rho] < \[ExponentialE]\^b\), c < \[Phi] < d}\)]],
  ".   The inverse mapping is the principal branch of the logarithm  ",
  Cell[BoxData[
      \(z = Log\ w\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 10.9",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/mapelementaryfun/\
MapElementaryFunFigures/mat1009.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The conformal mapping  ",
  Cell[BoxData[
      \(w\  = \ \[ExponentialE]\^z\)]],
  ". "
}], "Text"],

Cell["\<\
\tIn this section we show how compositions of conformal transformations are \
used to construct mappings with specified characteristics.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 10.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  "Show that the transformation",
  "  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ \(\[ExponentialE]\^z\  - \ \
\[ImaginaryI]\)\/\(\[ExponentialE]\^z\  + \ \[ImaginaryI]\)\)\)],
    AspectRatioFixed->True],
  "  is a one-to-one conformal mapping of the horizontal strip  ",
  Cell[BoxData[
      \(0 < y < \[Pi]\)]],
  "  onto the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(w\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ".  Furthermore, the x-axis is mapped onto the lower semicircle bounding \
the disk, and the line  ",
  Cell[BoxData[
      \(y = \[Pi]\)]],
  "  is mapped onto the upper semicircle."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007L0000Q2000`400?l0
0000o`00003oo`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooooM0?ooo`00
o`3ooooM0?ooo`00o`3ooooM0?ooo`00o`3ooon@0?ooo`030000003oool0
oooo04X0oooo001T0?ooo`<000007P3oool3000001T0oooo1000000f0?oo
o`@00000703oool3000001X0oooo0`00001d0?ooo`030000003oool0oooo
04X0oooo001T0?ooo`040000003oool0oooo000001h0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`00001c
0?ooo`030000003oool0oooo04X0oooo001T0?ooo`040000003oool0oooo
000001/0oooo1@00000J0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool06P3oool5000001X0oooo00@000000?ooo`3oool00000L`3o
ool00`000000oooo0?ooo`1:0?ooo`00GP3oool400000080oooo0`00000F
0?ooo`@000000P3oool010000000oooo0?ooo`00000D0?ooo`@00000103o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01T0oooo00@0
00000?ooo`3oool000006`3oool3000006d0oooo1@0000020?ooo`030000
003oool0oooo04X0oooo001U0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`0000006P3oool010000000oooo0?ooo`00000f0?ooo`040000
003oool0oooo000001/0oooo00<000000?ooo`000000703oool00`000000
oooo0?ooo`1^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0BP3oool006D0oooo0`00000M0?ooo`8000006`3oool2000003P0oooo
0P00000M0?ooo`800000703oool3000006T0oooo50000?m30?ooo`00o`3o
oon30?ooo`04000000000?l0003o000000@0oooo00<000000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`070?ooo`D0003o?P3oool00?l0ooooOP3o
ool60000o`L0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0<0?ooo`<0003o>`3oool00?l0ooooO03oool20000o``0oooo0P000004
0?ooo`030000o`3oool0oooo00l0oooo0P000?li0?ooo`00o`3ooolX0?oo
o`80000000<0oooo000000000000C@3oool20000oa@0oooo00<0003o0?oo
o`3oool04@3oool20000ocL0oooo003o0?ooobT0oooo00<000000?ooo`00
0000C03oool20000oaH0oooo00<0003o0?ooo`3oool04`3oool20000ocD0
oooo001M0?ooo`H00000^0000?l6000000P0oooo00<000000?ooo`3oool0
B@3oool20000o`030?ooo`3o0000oooo01D0oooo00<0003o0?ooo`3oool0
4`3oool00`3o0000oooo0000o`0d0?ooo`00H`3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?ooo`80000000<0
oooo000000000000B03oool01@000?l0oooo0?ooo`3oool0o`0001H0oooo
00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`020000oc80oooo
001S0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo05D0oooo0P000?l50?ooo`030?l0003oool0oooo01<0oooo00<0
003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`030?ooo`80003o<03o
ool006<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0D`3oool20000o`L0oooo00<0o`000?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0;@3oool006<0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0DP3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo02`0oooo001S0?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0540
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0=0?ooo`X0
o`003`3oool00`3o0000oooo0?ooo`080?ooo`80003o;03oool006<0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
D03oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00L0oooo
1@3o00050?ooo`030000o`3oool0oooo0080oooo1@3o00090?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0:@3oool006<0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0C`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo1@3o
000:0?ooo`030000o`3oool0oooo00L0oooo1P3o00030?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0:03oool006<0oooo^03o001@
0?ooo`030000o`3oool0oooo00h0oooo00@0o`000?ooo`3o0000o`003`3o
ool00`000?l0oooo0?ooo`0=0?ooo`<0o`00403oool00`000?l0oooo0?oo
o`0W0?ooo`00H`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`1=0?ooo`030000o`3oool0oooo00l0oooo0P3o000A
0?ooo`030000o`3oool0oooo00l0oooo0`3o000>0?ooo`030000o`3oool0
oooo02L0oooo001S0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo04`0oooo00<0003o0?ooo`3oool03P3oool30?l0
0180oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`020?l0
00d0oooo00<0003o0?ooo`3oool09P3oool006<0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0B`3oool00`000?l0
oooo0?ooo`0<0?ooo`<0o`000P3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool00`3oool20?l000`0
oooo0P000?lV0?ooo`00H`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`1;0?ooo`80003o2P3oool30?l000H0oooo
00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00D0oooo0P3o000:0?ooo`80003o9P3oool006<0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0BP3o
ool010000?l0oooo0?ooo`000?l70?ooo`80o`002@3oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0oooo0000obD0
oooo001S0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo04T0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00P0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo0280oooo001S0?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo04T0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?l000`0oooo00<0o`000?ooo`3oool01`3o
oolB0000o`H0oooo00<0o`000?ooo`3oool02P3oool20?l000<0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0R0?ooo`00H`3ooonh
0000odX0oooo00<0003o0?ooo`3oool01@3oool00`000?l0o`000?ooo`0>
0?ooo`030?l0003oool0oooo00H0003o203oool00`000?l0oooo0?ooo`07
0?ooo`@0003o0P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0
003o00L0oooo00<0003o0?ooo`3oool08@3oool006<0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0A`3oool00`00
0?l0oooo0?ooo`060?ooo`030?l000000?l0oooo00h0oooo0`000?l>0?oo
o`030000o`3oool0oooo00/0oooo0`000?l?0?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool0803oool006<0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0A`3oool00`000?l0
oooo0?ooo`050?ooo`040?l0003oool0oooo0000o`X0oooo10000?l00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00d0oooo00@0o`000000
o`000?l0003o2`3oool00`000?l0oooo0?l000090?ooo`030000o`3oool0
oooo01l0oooo001S0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo04H0oooo00<0003o0?ooo`3oool01@3oool01@3o
0000oooo0?ooo`3oool0003o00P0oooo0P000?l50?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`02
0?ooo`80003o2@3oool00`000?l0oooo0?ooo`020?l000P0oooo00<0003o
0?ooo`3oool07P3oool006<0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0A@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool20000
o`L0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00@0oooo0P000?l60?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0N0?oo
o`00H`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`150?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`020000o`X0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00H0
oooo0P000?l30?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0M0?ooo`00H`3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`140?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool20000o``0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00P0oooo0P000?l00`3oool0003o0?ooo`070?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool07@3oool006<0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0A03o
ool00`000?l0o`000?ooo`030?ooo`030?l0003oool0oooo00L0oooo0P00
0?l=0?ooo`030?l0003oool0oooo00<0oooo4P3o00050?ooo`030?l0003o
ool0oooo00/0oooo0P000?l90?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`000?l07P3oool006<0oooo^03o00150?ooo`030000o`3oool0
oooo0080o`000P3oool00`3o0000oooo0?ooo`050?ooo`80003o0P3oool0
0`000?l0oooo0?ooo`0:0?ooo`H0o`002@3oool00`000?l0oooo0?ooo`06
0?ooo`L0o`00303oool010000?l0oooo0000o`000?l80?ooo`040?l0003o
ool0oooo0?l00080oooo00<0003o0?ooo`3oool0703oool006<0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0@`3o
ool00`000?l0oooo0?ooo`020?ooo`80o`001`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00L0oooo103o000>0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3o00000P3o00080?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool01P3oool20?l000<0oooo00<0
003o0?ooo`3oool0703oool006<0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0@`3oool00`000?l0oooo0?ooo`02
0?ooo`80o`001P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo0`3o00030?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`030?ooo`<0o`001@3oool0
0`000?l0oooo0?ooo`030?ooo`80003o1@3oool00`3o0000oooo0?l00004
0?ooo`030000o`3oool0oooo01/0oooo001S0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo0480oooo00<0003o0?oo
o`3oool00P3oool0103o0000oooo0?ooo`3o00030?ooo`80003o1`3oool0
0`000?l0oooo0?ooo`030?l000L0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo0`3o0000
0`3oool0003o0?ooo`070?ooo`050000o`3oool0oooo0?ooo`3o00000P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo01/0oooo001S
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo0480oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030?l00000
0?l0003o00T0oooo0`3o000:0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`<0o`00203o
ool20000o`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0oooo
0000o`0M0?ooo`00H`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`110?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool00`000?l0o`000?ooo`070?ooo`80o`0000<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool010000?l0oooo0?l0
003o00070?ooo`030?l000000?l0oooo00<0oooo00D0o`000?ooo`3oool0
oooo0000o`0M0?ooo`00H`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`110?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool010000?l0oooo0?ooo`3o00050?ooo`80o`000`3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo2`000?l70?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool00P3oool20?l0
00@0oooo00@0o`000?ooo`3oool0003o103oool01@3o0000oooo0?ooo`3o
ool0003o01`0oooo001S0?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo0440oooo0`000?l00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o0005
0?ooo`030000o`3oool0oooo00T0oooo2@000?l50?ooo`030000o`3oool0
oooo00<0oooo20000?l;0?ooo`030000o`3oool0oooo00@0oooo0P3o0000
0`3oool0o`000?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o00000P3o
ool20000oa`0oooo001S0?oookP0003o@`3oool010000?l0oooo0?ooo`3o
00030?ooo`030000o`3oool0oooo00@0oooo0P3o00070?ooo`030000o`3o
ool0oooo0080oooo1`000?l00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000000o`000?l01P000?l30?ooo`030000o`3o
ool0oooo00H0oooo0P3o00050?ooo`080000o`3oool0oooo0?ooo`3o0000
003o0?ooo`000?lL0?ooo`00H`3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`110?ooo`040000o`3oool0o`000?oo
o`<0003o1@3oool30?l000T0oooo10000?l80?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?oo
o`@0003o203oool0103o0000oooo0?l0003o00040?ooo`040000o`3oool0
003o0?l000<0oooo00<0003o0?ooo`3oool06@3oool006<0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0@03oool0
1P000?l000000000003o000000000?ooo`80003o103oool01@3o0000oooo
0?ooo`3oool0o`0000D0oooo10000?l;0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0003o0080003o1@3oool01@3o0000oooo0?ooo`3oool0o`00
00<0oooo0P000?l20?ooo`040?l0003oool000000000o`<00000603oool0
06<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0@03oool00`000?l0oooo0?l000020?ooo`050000o`3oool0oooo
0000o`3oool00P3o00040?ooo`030?l0003oool0oooo00<0003o0`3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo0080oooo0`000?l00`3oool0o`000?ooo`040?ooo`80o`0000H0003o
0?ooo`3oool0003o0?ooo`3o00020?ooo`030000o`000000oooo01T0oooo
001S0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo0400oooo00<0003o0?l0003o00000P3oool01@000?l0oooo0?oo
o`3oool0o`0000D0oooo10000?l70?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool01@3oool20000o`H0oooo
00D0003o0?l0003oool0oooo0000o`020?ooo`80o`0000<0003o0000003o
ool06@3oool006<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0>P3oool400000080oooo00D0003o0?ooo`3o0000
o`000000o`030?ooo`040?l0003oool0003o0?ooo`<0003o00<0oooo0?l0
003oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0o`00
01D0o`0000<0oooo0?l0003oool02@3oool00`000?l0oooo0?ooo`060?oo
o`040?l0003oool0003o0000o`@0oooo00<0003o0?ooo`3o00000P3oool0
1P000?l0o`000?l0003oool0003o000001X0oooo001S0?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0400oooo00H0
003o0?l000000000003o0?l0003oool20?l00080oooo0P000?l50?ooo`03
0?l0003oool0oooo00H0oooo00@0003o0?ooo`3oool0oooo2@3o000;0?oo
o`030000o`3oool0oooo00P0oooo2`3o00000`3oool0003o0?ooo`070?oo
o`040?l0003oool0oooo0?ooo`80003o00<0oooo0000o`3oool00P3oool0
203o0000oooo0?l000000?l0oooo0?l0003oool0003o6P3oool006<0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
@03oool01@000?l0o`00000000000?l0oooo0080o`0000@0oooo0000o`00
0?l0003o1P3oool00`3o0000oooo0?ooo`0:0?l000L0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00L0oooo1P3o00040?ooo`030?l0003oool0oooo00<0oooo0`000?l30?oo
o`050?l0003oool0003o0?ooo`3o00000P000?lJ0?ooo`00H`3ooonh0?l0
0440oooo00L0003o0?l0003oool0003o0?ooo`3o0000oooo0080003o0`3o
ool010000?l0oooo0?ooo`3oool50?l000H0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`P0o`00
0P3oool20000o`0;0?ooo`000?l0003o0000o`3oool0o`000?ooo`000?l0
o`000?ooo`000?l06P3oool006<0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0?`3oool020000?l0o`000000o`3o
ool0o`000?ooo`000?l0o`000`3oool50?l00080oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00H0oooo00@0o`000?ooo`3oool0oooo1@3o00020?oo
o`080?l000000?l0003o0?l0003oool0003o0?l000000?lJ0?ooo`00H`3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0o0?ooo`80003o00D0o`000000o`000?l0003o0?ooo`040?l000030?oo
o`000?l0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?l000050?oo
o`000?l0003o0000o`3o00000P000?l;0?ooo`@000002`3oool006<0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
?`3oool00`3o0000003o0?l000040?l000030?ooo`3o0000oooo0080oooo
0P000?l50?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00<0oooo00@0003o0?ooo`3oool0oooo1`3o00020000o`X0
oooo00@000000?ooo`3oool00000303oool006<0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0>P3oool500000080
003o00<0o`000000o`000?l0GP000?l20?l000030000o`000000000000<0
00001@3oool010000000oooo0?ooo`00000<0?ooo`00H`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0o0?ooo`04
0000o`3o0000o`000000o`<0o`0000<0oooo0?l0003oool00P3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l00002
0?ooo`80o`0010000?l90?ooo`80000000<0oooo000000000000303oool0
06<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0?`3oool010000?l0o`000000o`3o00020000o`040?ooo`3o0000
o`000?l00080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`040000o`3o
ool0oooo0?ooo`<0o`000P000?l0103oool0003o0?l000000?lJ0?ooo`00
H`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0o0?ooo`030000o`3o0000003o0080o`0000<0oooo0000o`000?l0
0P3oool50?l000<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo
00@0o`000?ooo`3oool0oooo1P3o00002@3oool0003o0000o`3oool0o`00
0000o`3oool0o`000000o`0J0?ooo`00H`3ooonh0000od40oooo00P0003o
0?l000000?l0003o0?ooo`3o0000oooo0?l00080003o0P3oool00`000?l0
oooo0?ooo`0:0?l00080oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`030?ooo`L0o`000`3oool030000?l0
oooo0000o`000?l0o`000?ooo`3o0000oooo0000o`3o0000oooo0000oaX0
oooo001S0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo0400oooo00H0003o0?l0003oool0003o0?ooo`3o00030?oo
o`80003o1P3oool00`3o0000oooo0?ooo`040?ooo`D0o`00203oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool01`3oool70?l000<0oooo00<0o`000?ooo`3oool0103oool20000
o`<0oooo00D0o`000?ooo`000?l0oooo0?l000020000oaX0oooo001S0?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
0400oooo00@0003o0?l0003oool0003o0`3o00030?ooo`<0003o103oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo02/0o`0000<0oooo
0000o`3oool01`3oool00`3o0000oooo0?ooo`020?ooo`80003o00T0oooo
0000o`3oool0oooo0?l0003oool0003o0?ooo`3o00000P3oool00`000?l0
oooo0?ooo`0H0?ooo`00H`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`100?ooo`050000o`3oool0o`000?l00000
0?l00P3oool20?l000040000o`3oool0oooo0?ooo`80003o00<0oooo0?l0
003oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00P000?l30?oo
o`060000o`3oool0o`000?ooo`000?l0oooo0P3o00000`3oool0003o0?oo
o`0J0?ooo`00H`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`100?ooo`030000o`3o0000o`000080oooo00D0003o
0?ooo`3oool0oooo0?l000050?ooo`<0003o203oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00@0oooo1000
0?l50?ooo`050000o`3o0000oooo0?ooo`000?l00P3oool20?l000030000
o`3oool0oooo01T0oooo001S0?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo0400oooo00<0003o0?ooo`3o00000`3o
ool010000?l0oooo0000o`3oool20?l000@0oooo00<0o`000?ooo`000?l0
10000?l20?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool010000?l30?ooo`030?l0003oool0oooo0080oooo
0P3o00000`000?l0oooo0000o`020?ooo`040?l0003oool0oooo0000oa/0
oooo001S0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo0440oooo00<0003o0?ooo`3o00000`3oool00`000?l0oooo
0?ooo`020?ooo`040?l0003oool0oooo0?l000L0oooo1@000?l90?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`070?ooo`D0003o1`3oool00`3o0000oooo0?ooo`020?l000<0
oooo0P000?l20?ooo`040?l0003oool0oooo0000oa/0oooo001S0?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0440
oooo00<0003o0?ooo`3o00000P3oool00`000?l0oooo0000o`040?ooo`<0
o`002@3oool00`000?l0oooo0?ooo`020000o`H0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080
oooo10000?l20?ooo`030000o`3oool0oooo00P0oooo0P3o00050?ooo`<0
003o00D0o`000?ooo`3oool0oooo0000o`0K0?ooo`00H`3ooonh0?l004<0
oooo00D0003o0?ooo`3oool0o`000000o`030?ooo`030000o`3oool0oooo
0080oooo0P3o00080?ooo`030000o`3oool0oooo00<0oooo1P000?l00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00P0oooo1`000?l70?oo
o`030000o`3oool0oooo00D0oooo0`3o00050?ooo`050000o`3oool0oooo
0?ooo`3o00000P3oool00`000?l0oooo0?ooo`0J0?ooo`00H`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`110?oo
o`<0003o00<0oooo0?l0003oool00`3oool01P000?l0oooo0?ooo`3oool0
o`000?ooo`80o`001P3oool00`000?l0oooo0?ooo`090?oooaT0003o0P3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo0P3o
00030?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo
0000o`020000oa`0oooo001S0?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo0440oooo00D0003o0?ooo`3oool0oooo
0?l000050?ooo`030000o`3oool0o`0000@0oooo0`3o00020?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00@0003o0?ooo`3oool0
oooo0P3o00050?ooo`040?l0003oool0oooo0000o`@0oooo00D0o`000?oo
o`3oool0oooo0000o`0L0?ooo`00H`3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`110?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?oo
o`80o`0000<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0o`000?l000080?ooo`030?l000000?l0oooo00<0oooo00D0o`000?oo
o`3oool0oooo0000o`0M0?ooo`00H`3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`120?ooo`030000o`3oool0oooo
0080oooo00L0o`000?ooo`3oool0oooo0?l0003oool0003o00T0oooo0`3o
000:0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`090?ooo`80o`002@3oool20000o`050?l0003o
ool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`0K0?ooo`00H`3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`120?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0o`00
0P3oool20000o`H0oooo00@0003o0?ooo`3oool0oooo0`3o00070?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`060?ooo`<0o`000P3oool00`000?l0oooo0?ooo`050?ooo`05
0000o`3oool0oooo0?ooo`3o00000P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo01/0oooo001S0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo04<0oooo00<0003o0?ooo`3o
ool00P3oool30?l000D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`040?ooo`80o`00103oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool30?l000D0
oooo00<0003o0?ooo`3oool00`3oool20000o`D0oooo0P3o00040?ooo`03
0000o`3oool0oooo01`0oooo001S0?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo04<0oooo00<0003o0?ooo`3oool0
0P3oool20?l000L0oooo0P000?l30?ooo`030000o`3oool0oooo00H0oooo
1P3o000=0?ooo`030000o`3oool0oooo00X0oooo1P3o00080?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool30?l000<0oooo
00<0003o0?ooo`3oool0703oool006<0oooo^0000?m50?ooo`030000o`3o
ool0oooo0080o`000P3oool00`3o0000oooo0?ooo`060?ooo`<0003o3@3o
ool00`3o0000oooo0?l000080?l000@0oooo00<0003o0?ooo`3oool00P3o
ool80?l000030?ooo`3o0000oooo00`0oooo00@0003o0?ooo`000?l0003o
1`3oool01@3o0000oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`3o
ool0703oool006<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0A03oool00`000?l0o`000?ooo`030?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`080?ooo`X0o`002@3oool00`3o0000oooo0?ooo`0;0?ooo`80003o
203oool00`3o0000oooo0?ooo`030?ooo`030?l000000?l0oooo01h0oooo
001S0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo04@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`060?ooo`040000o`3oool0003o0000o`X0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00T0oooo
0`000?l70?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
7@3oool006<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0A@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00@0003o0?ooo`3oool0oooo0P000?l80?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`070?ooo`80003o0P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool07P3oool006<0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0A@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool20000o`H0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00D0oooo0P00
0?l50?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`0N0?ooo`00H`3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`160?ooo`030000o`3oool0
oooo00D0oooo0P3o00020?ooo`030000o`3oool0oooo00L0oooo0P000?l3
0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`030?ooo`80003o203oool010000?l0oooo0?ooo`3o
00080?ooo`030000o`3oool0oooo01l0oooo001S0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo04L0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0000o`0;0?ooo`80003o00<0oooo
0?l0003oool03`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
003o0080003o2P3oool00`000?l0oooo0?l000090?ooo`030000o`3oool0
oooo01l0oooo001S0?oookP0o`00B@3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00`0oooo1@000?l=0?ooo`030000o`3oool0oooo
00/0oooo10000?l>0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool0803oool006<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0B03oool00`000?l0oooo0?ooo`040?ooo`80
003o00<0oooo0?l0003o00003@3oool0103o0000oooo0?ooo`3oool60000
o`L0oooo00<0003o0?ooo`3oool01@3oool60000o`80oooo00<0o`000?oo
o`3oool02`3oool20?l000030?ooo`000?l0003o00H0oooo00<0003o0?oo
o`3oool08@3oool006<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0B@3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool02@3oool00`3o0000
oooo0?ooo`080?ooo`l0003o203oool00`3o0000oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0R0?ooo`00H`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`1:0?ooo`040000o`3oool0oooo0000o`L0
oooo0P3o00090?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`070?ooo`80o`001`3oool01@000?l0
oooo0?ooo`3oool0003o02@0oooo001S0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo04X0oooo00@0003o0?ooo`3o
ool0003o2@3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00l0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`000?l09@3oool006<0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0B`3oool20000o`/0oooo0P3o00060?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`040?ooo`80
o`00303oool00`000?l0oooo0?ooo`0T0?ooo`00H`3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1<0?ooo`030000
o`3oool0oooo00/0oooo0P3o00030?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool03`3oool0103o0000oooo0?ooo`3oool20?l000d0
oooo00<0003o0?ooo`3oool09@3oool006<0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0C@3oool00`000?l0oooo
0?ooo`0<0?ooo`80o`0000<0oooo0?l0003oool04@3oool00`000?l0oooo
0?ooo`0?0?ooo`040?l0003oool0o`000?l000h0oooo00<0003o0?ooo`3o
ool09P3oool006<0oooo^0000?m@0?ooo`030000o`3oool0oooo00d0oooo
0P3o000B0?ooo`030000o`3oool0oooo00h0oooo0`3o000?0?ooo`030000
o`3oool0oooo02L0oooo001S0?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo04l0oooo00<0003o0?ooo`3oool03@3o
ool60?l000d0oooo00<0003o0?ooo`3oool02P3oool40?l00080oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0W0?ooo`00H`3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1@
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0103oool2
0?l000/0oooo00<0003o0?ooo`3oool0203oool20?l000H0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0X0?ooo`00H`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1A0?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool01P3ooolF0?l0
00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0Y0?oo
o`00H`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`1B0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool04P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool0:P3oool006<0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0D`3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`070?ooo`80003o;@3oool006<0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0E03o
ool20000o`H0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`0B0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0;@3o
ool006<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0EP3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo01@0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`03
0?ooo`80003o<03oool006<0oooo^03o001I0?ooo`80003o0P3oool00`3o
0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?oo
o`3oool00P000?lb0?ooo`00H`3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`1I0?ooo`80003o5`3oool00`000?l0
oooo0?ooo`0D0?ooo`80003o=03oool006<0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0F`3oool20000oaD0oooo
00<0003o0?ooo`3oool04P3oool20000ocH0oooo001S0?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo05d0oooo0`00
0?lB0?ooo`030000o`3oool0oooo00l0oooo0`000?lh0?ooo`00H`3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1P
0?ooo`<0003o3`3oool00`000?l0oooo0?ooo`0<0?ooo`<0003o>`3oool0
06<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0H`3oool20000o`H0oooo1@0000020?ooo`030000o`3oool0oooo
00X0oooo0P000?ln0?ooo`00H`3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`1U0?ooo`@0003o103oool00`000000
oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo0`000?m00?ooo`00
H`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo
00H000000?ooo`3oool0o`000?ooo`0000050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo06T0oooo4`000?m30?ooo`00H`3ooonh0000ofl0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1:0?ooo`00
]P3oool00`000000oooo000000060?ooo`030000003oool0oooo0<P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1:0?ooo`00]P3o
ool00`000000oooo000000060?ooo`030000003oool0oooo0<L0oooo0P00
00040?ooo`030000003oool0oooo04X0oooo002e0?ooo`D00000e@3oool0
0`000000oooo0?ooo`1:0?ooo`00o`3ooon@0?ooo`030000003oool0oooo
04X0oooo003o0?ooomd0oooo003o0?ooomd0oooo003o0?ooomd0oooo003o
0?ooomd0oooo003o0?ooomd0oooo002m0?ooo`800000o`3ooolN0?ooo`00
_P3oool00`000000oooo0?ooo`3o0?oooa`0oooo002o0?ooo`030000003o
ool0oooo0<`0oooo0P00001<0?ooo`00_P3oool00`000000oooo0000003=
0?ooo`800000C03oool00;d0oooo00@000000?ooo`3oool00000c03oool0
10000000oooo0?ooo`00001;0?ooo`00_03oool3000000030?ooo`000000
00000<X0oooo0P0000020?ooo`800000BP3oool00?l0oooog@3oool00?l0
oooog@3oool00?l0oooog@3oool00?l0oooog@3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{476, 132},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The function  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ \(\[ExponentialE]\^z\  - \ \
\[ImaginaryI]\)\/\(\[ExponentialE]\^z\  + \ \[ImaginaryI]\)\)\)],
    AspectRatioFixed->True],
  " is the composition of  ",
  Cell[BoxData[
      \(Z\  = \ \[ExponentialE]\^z\)]],
  "  followed by  ",
  Cell[BoxData[
      \(w\  = \ \(Z\  - \ \[ImaginaryI]\)\/\(Z\  + \ \[ImaginaryI]\)\)],
    AspectRatioFixed->True],
  ".  The transformation ",
  Cell[BoxData[
      \(Z = \[ExponentialE]\^z\)]],
  " maps the horizontal strip  ",
  Cell[BoxData[
      \(0 < y < \[Pi]\)]],
  "  onto the upper half plane  ",
  Cell[BoxData[
      \(Im \((Z)\) > 0\)]],
  ";  the ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " axis is mapped on to the positive ",
  StyleBox["X",
    FontFamily->"Courier New"],
  " axis;  and the line  ",
  Cell[BoxData[
      \(y = \[Pi]\)]],
  "  is mapped onto the negative ",
  StyleBox["X",
    FontFamily->"Courier New"],
  " axis.  Then the bilinear transformation  ",
  Cell[BoxData[
      \(w\  = \ \(Z\  - \ \[ImaginaryI]\)\/\(Z\  + \ \[ImaginaryI]\)\)],
    AspectRatioFixed->True],
  "  maps the upper half plane    ",
  Cell[BoxData[
      \(Im \((Z)\) > 0\)]],
  "  onto the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(w\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ";  the positive ",
  StyleBox["X",
    FontFamily->"Courier New"],
  " axis is mapped onto the lower semicircle;  and the negative ",
  StyleBox["X",
    FontFamily->"Courier New"],
  " axis onto the upper semicircle.  Figure 10.10 illustrates the composite \
mapping. "
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 10.10",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/mapelementaryfun/\
MapElementaryFunFigures/mat1010.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The composite transformation  ",
  Cell[BoxData[
      \(w\  = \ \(\[ExponentialE]\^z\  - \ \[ImaginaryI]\)\/\(\[ExponentialE]\
\^z\  + \ \[ImaginaryI]\)\)],
    AspectRatioFixed->True],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f \((z)\) = \(\[ExponentialE]\^z\  - \ \[ImaginaryI]\)\/\(\
\[ExponentialE]\^z\  + \ \[ImaginaryI]\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(w = \(z = 0\); \ Remove[w, z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, solset];\)\ \), "\n", 
    \(\(f[
          z_]\  = \ \ \(\[ExponentialE]\^z - \[ImaginaryI]\)\/\(\
\[ExponentialE]\^z + \[ImaginaryI]\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To show  ",
  Cell[BoxData[
      \(f \((z)\) = \(\[ExponentialE]\^z\  - \ \[ImaginaryI]\)\/\(\
\[ExponentialE]\^z\  + \ \[ImaginaryI]\)\)],
    AspectRatioFixed->True],
  "  is one-to-one conformal we need to find the inverse function"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset\  = \ Solve[w\  \[Equal] \ f[z], z];\)\ \), "\n", 
    \(\(g[w_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(Print["\<g[w] = \>", g[w]];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<f[g[w]] = \>", f[g[w]], "\< = \>", 
        Simplify[f[g[w]]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", g[f[z]]];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", 
        Simplify[g[f[z]]], "\< = \>", \[IndentingNewLine]PowerExpand[
          Simplify[g[f[z]]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["The image is traced using a graph.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, z];\)\ \), "\n", 
    \(\(f[
          z_]\  = \ \ \(\[ExponentialE]\^z - \[ImaginaryI]\)\/\(\
\[ExponentialE]\^z + \[ImaginaryI]\);\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Identity, {\(-6\), 6, 
          0.5}, {0, \[Pi], \[Pi]\/12}, \[IndentingNewLine]PlotRange \[Rule] \
{{\(-6.4\), 6.4}, {0, 3.2}}, 
        AspectRatio \[Rule] 
          1\/2, \[IndentingNewLine]Ticks \[Rule] {Range[\(-6\), 6, 2], 
            Range[0, \[Pi], \[Pi]]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Blue, Red}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The horizontal strip 0 < y < \[Pi].\>"];\)\ \), "\n", 
    \(\(CartesianMap[f, {\(-6\), 6, 0.5}, {0, \[Pi], \[Pi]\/12}, 
        PlotRange \[Rule] {{\(-1.1\), 1.1}, {\(-1.1\), 
              1.1}}, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Red}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image is the disk |w|< 1,\>"];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \(\[ExponentialE]\^z\  - \ \[ImaginaryI]\)\/\(\
\[ExponentialE]\^z\  + \ \[ImaginaryI]\)\)\)],
    AspectRatioFixed->True],
  "  maps the horizontal strip  ",
  Cell[BoxData[
      \(0 < y < \[Pi]\)]],
  "  onto the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(w\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example10.9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the transformation  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ Log \((\(1\  + \ z\)\/\(1\  - \ z\))\)\)\)],
    
    AspectRatioFixed->True],
  "  is a one-to-one conformal mapping of the unit disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  onto the horizontal strip  ",
  Cell[BoxData[
      \(\(\(|\)\(v\)\(|\)\(\(<\)\(\ \)\(\[Pi]\/2\)\)\)\)]],
  ".  Furthermore, the upper semicircle of the disk is mapped onto the line  \
",
  Cell[BoxData[
      \(v = \[Pi]\/2\)]],
  "  and the lower semicircle onto  ",
  Cell[BoxData[
      \(v = \(-\ \[Pi]\)\/2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007=0000Q2000`400?l0
0000o`00003oo`3oooo>0?ooo`00o`3oooo>0?ooo`00o`3oooo>0?ooo`00
o`3oooo>0?ooo`00o`3oooo>0?ooo`00P@3oool00`000000oooo0?ooo`3o
0?ooodX0oooo00210?ooo`030000003oool0oooo0?l0ooooBP3oool00840
oooo00<000000?ooo`3oool0o`3ooom:0?ooo`00P@3oool00`000000oooo
0?ooo`3o0?ooodX0oooo001j0?ooo`D000000P3oool00`000000oooo0?oo
o`3o0?ooodX0oooo001l0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`2A0?ooo`00N03oool90000
o`030?l000000?l0003o00H0003oZ03oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000@0oooo100000050?ooo`030000003oool0
oooo0880oooo001b0?ooo`H0003o103oool00`000000oooo0?ooo`020?oo
o`030?l0003oool0oooo00H0oooo1@000?nN0?ooo`@000000P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`220?ooo`00L03oool20000
o`80oooo00<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`000?l00P000?nR0?oo
o`030000003oool0000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`050?ooo`<00000PP3oool006h0oooo0P000?l40?ooo`03
0000o`3oool0oooo00@0oooo0P0000040?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool00P3oool20000oj00oooo00<000000?ooo`00
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0PP3oool006`0oooo0P000?l60?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`040?ooo`80003oW@3oool5000000<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0PP3oool006X0oooo0P000?l90?ooo`030000o`3oool0oooo00@0oooo
2P3o00070?ooo`030000o`3oool0oooo00H0oooo0P000?nT0?ooo`040000
003oool0oooo0?ooo`8000001P3oool00`000000oooo0?ooo`220?ooo`00
I`3oool00`3o0000003o0000o`0;0?ooo`030000o`3o0000o`0000@0o`00
1@3oool00`3o0000oooo0?ooo`020?ooo`D0o`0000<0oooo0000o`3oool0
2P3oool20000o`030?l0003oool0oooo0:/0oooo00<000000?ooo`3oool0
PP3oool006L0oooo00<0o`000?ooo`3oool02P3oool00`3o0000003o0?oo
o`0:0?ooo`030?l0003oool0oooo00L0oooo00<0o`000000o`3o00000P3o
00090?ooo`030?l000000?l0003o0440oooo?0000?l00`3o0000003o0000
o`0I0000o`030?l000000?l0003o0100003o00<0o`000000o`000?l04@00
0?l00`3o0000003o0000o`0I0000o`030?l000000?l0003o03X0003o603o
ool006D0oooo0P000?l00`3oool0o`000?ooo`070?ooo`<0o`0000<0oooo
0000o`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo0080oooo0P3o00070?ooo`030?l0003oool0oooo0080003oH@3oool2
0000oaP0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool2
0?l000P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool05P3oool0
0`000?l0oooo0?ooo`0i0?ooo`00I03oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo0`3o00050?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?oo
o`80o`00103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
05l0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`060?ooo`80o`00203oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo03T0oooo001S0?ooo`03
0000o`3oool0oooo00@0oooo00@0o`000?ooo`3o0000o`00203oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01P3oool01@3o0000oooo0?ooo`3oool0o`0000H0oooo0P000?mO
0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0>@3oool0
0640oooo0P000?l70?ooo`80o`002P3oool010000?l0oooo0?ooo`3oool7
0000o`030?l000000?l0003o00H0003o00<0oooo0000o`3oool0203oool3
0?l000T0oooo00<0003o0?ooo`3oool0G03oool00`000?l0oooo0?ooo`0F
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool02@3oool:
0?l000030000o`3o0000o`000100o`0000<0003o0?l0003o0000203o000;
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool05P3oool0
0`000?l0oooo0?ooo`0i0?ooo`00H03oool00`000?l0oooo0?ooo`050?oo
o`80o`0000<0oooo0?l0003oool02@3oool40000o`L0oooo00<0o`000?oo
o`3oool01P3oool20000o`/0oooo0P3o00090?ooo`030000o`3oool0oooo
05/0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0<0?oo
o`030?l000000?l0o`0000/0o`002@3oool00`000?l0oooo0?ooo`060?oo
o`80o`00203oool00`000?l0oooo0?ooo`070?ooo``0o`0000<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo
03T0oooo001O0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`040?ooo`<0003o00<0oooo0000o`3o
ool0203oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0003o0080
003o1`3oool0103o0000oooo0?ooo`3o00090?ooo`030000o`3oool0oooo
05X0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`040?oo
o`L0o`0000<0oooo0000o`3oool02P3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00H0oooo0P3o00080?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0o`000?l000040?l0
00P0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0i0?oo
o`00G@3oool20000o`L0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`020?ooo`80003o103oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool20000o`@0
oooo00<0o`000?ooo`3oool00P3oool20?l000P0oooo00<0003o0?ooo`3o
ool0F@3oool00`000?l0oooo0?ooo`0G0?ooo`L0o`00203oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`040?ooo`H0
o`000P3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo03T0
oooo001M0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool0103o0000oooo0000o`000?l60?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`80
003o0P3oool00`3o0000oooo0?ooo`040?ooo`80o`001@3oool00`000?l0
oooo0000o`1K0?ooo`030000o`3oool0oooo01<0oooo103o000?0?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool90000o`80
o`002@000?l90?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool02`3oool40?l001L0oooo00<0003o0?ooo`3oool0>P3oool005`0oooo
00<0003o0?ooo`000?l01@3oool00`3o0000oooo0?ooo`060?ooo`030?l0
00000?l0oooo00L0oooo00<0003o0?ooo`3oool00`3oool80?l000@0oooo
00<0003o0?ooo`3oool01`3oool00`000?l0o`000?ooo`080?ooo`030?l0
003oool0oooo0080oooo00@0003o0?ooo`3oool0003oFP3oool00`000?l0
oooo0?ooo`0?0?ooo`@0o`000`3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000000o`000?l020000?l80?ooo`80
o`00203oool:0000o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`050?l00180oooo00<0003o0?ooo`3o
ool0>P3oool005/0oooo00@0003o0?ooo`3oool0oooo0P000?l20?ooo`03
0?l0003oool0oooo00D0oooo0P000?l00`3oool0o`000?ooo`080?ooo`03
0000o`3o0000o`000080o`00103oool0103o0000oooo0?ooo`3oool40?l0
00030000o`3oool0oooo00L0oooo00@0o`000?ooo`000?l0003o203oool0
103o0000oooo0000o`000?l40?ooo`030000o`3oool0oooo05L0oooo00<0
003o0?ooo`3oool02`3oool40?l000L0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`030?ooo`D0003o00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`060?ooo`80o`00203oool00`000?l0oooo0?oo
o`060?ooo`030?l000000?l0003o00<0003o1P3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00D0oooo1P3o000<0?ooo`030000o`3o
ool0oooo03X0oooo001J0?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3o00001`3oool01@000?l0oooo0?ooo`3oool0o`0000H0oooo0`3o
00000`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?l0003o00001P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`1F0?ooo`030000o`3oool0oooo00L0oooo103o000<0?ooo`030?l0003o
ool0oooo00`0oooo1P000?l60?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool20?l000L0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`030?ooo`L0003o3P3oool00`3o0000oooo0?oo
o`0;0?ooo`@0o`00203oool00`000?l0oooo0?ooo`0j0?ooo`00F@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l000000?l0oooo00H0oooo00<0003o
0?ooo`3oool00`3oool0103o0000oooo0?ooo`3oool20?l000<0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo0080o`00103oool00`3o0000oooo0?ooo`030?ooo`80003o1P3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo05D0oooo00<0
003o0?ooo`3oool0103oool30?l00100oooo00<0o`000?ooo`3oool01`3o
ool60000o`/0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`80o`001`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00P0oooo1P000?l:0?ooo`030?l0003oool0oooo00l0oooo0P3o
00050?ooo`030000o`3oool0oooo03/0oooo001H0?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00P000?l30?ooo`80003o1P3oool0
103o0000oooo0?l0003o00050?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`80o`0000<0
oooo0?l0003oool01`3oool010000?l0oooo0?ooo`3oool20000o`030?oo
o`3o0000oooo00H0oooo00<0003o0?ooo`3oool0EP3oool00`000?l0oooo
0?l000030?l001@0oooo00<0o`000?ooo`3oool00P3oool40000o`H0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`030?l0
00000?l0o`0000l0o`0000<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00<0oooo10000?l50?ooo`030?l0
003oool0oooo0180oooo0P3o00030?ooo`030000o`3oool0oooo03/0oooo
001H0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3o
ool010000?l0oooo0?ooo`000?l80?ooo`80o`00203oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool20?l000T0oooo00<0003o0?ooo`000?l0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo05D0oooo00<0003o0?l0003oool0
5`3oool00`3o0000oooo0000o`020000o`X0oooo00<0003o0?ooo`3oool0
203oool90?l000030?ooo`000?l0oooo00H0oooo0P3o00070?ooo`030000
o`3o0000o`0000L0o`002P3oool00`000?l0oooo0?ooo`080?ooo`<0003o
0P3oool00`3o0000oooo0?ooo`0D0?ooo`80o`0000<0003o0?ooo`3oool0
?03oool005L0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`80003o1`3oool20?l000030?ooo`3o0000oooo00L0oooo00<0
003o0?ooo`000?l01@000?l00`3o0000003o0000o`030000o`030?ooo`00
0?l0oooo00H0oooo00@0o`000?ooo`3o0000o`00203oool20000o`D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1B0?ooo`80o`00
00<0oooo0000o`3oool05`3oool00`000?l0o`000?ooo`0<0?ooo`030000
o`3oool0oooo00@0oooo1@3o00090?ooo`030000o`3oool0oooo00D0oooo
0P3o00070?ooo`030000o`3oool0oooo00H0oooo1P3o00050?ooo`030000
o`3oool0oooo00/0oooo00<0003o0?l0003oool05`3oool010000?l0oooo
0?l0003o000l0?ooo`00EP3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo0`000?l50?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool00`3oool40000o`H0oooo00<0o`000?ooo`3oool0
0`3oool30000o`H0oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`<0
003o1P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0500
oooo0P3o00040?ooo`030000o`3oool0oooo01<0oooo0P000?l00`3oool0
o`000?ooo`0<0?ooo`030000o`3oool0oooo0080oooo0P3o00040?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool20?l000L0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`@0
o`0000<0oooo0000o`3oool03@3oool00`3o0000003o0000o`0F0?ooo`04
0000o`3oool0oooo0?ooo`<0o`00>@3oool005D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0003o00@0
oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`020000o`<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`04
0000o`3oool0003o0000o`<0oooo00<0o`000?ooo`3oool00`3oool20?l0
00<0oooo00D0003o0?ooo`3oool0oooo0000o`060?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0C@3oool20?l000H0oooo00<0003o
0?ooo`3oool04@3oool20000o`@0oooo00<0o`000?ooo`3oool02`3oool0
10000?l0o`000?l0003o00070?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`3o0000003o0?l0
000<0?ooo`040?l0003oool0oooo0?ooo`<0003o4P3oool00`000?l0oooo
0?ooo`050?ooo`80o`00=`3oool005D0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`000?l0
0P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o00D0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo0P000?l00`3o0000oooo0?ooo`060?ooo`040?l0
003oool0oooo0000o`@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo04`0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0>0?ooo`80003o1P3oool00`3o0000
oooo0?ooo`0:0?ooo`030?l000000?l0oooo00T0oooo00<0o`000?ooo`3o
ool01P3oool80000o`030?l000000?l0003o00H0003o203oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo0080o`002P3oool00`3o0000
oooo0?ooo`040?ooo`80003o403oool00`000?l0oooo0?ooo`070?ooo`80
o`00=@3oool005@0oooo00@0003o0?ooo`3o0000o`000`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo0P000?l80?ooo`03
0000o`3o0000oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000000o`3o
ool01`3oool20000o`D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`020?l000030?ooo`000?l0oooo04X0oooo0P3o000:0?ooo`03
0000o`3oool0oooo00`0oooo0P000?l90?ooo`030?l0003oool0oooo00H0
oooo0`3o00020?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool00P3oool50000o`H0oooo00<0o`000?ooo`3oool01@3oool40000o`D0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`80
o`001`3oool00`3o0000oooo0?ooo`070?ooo`80003o3@3oool00`000?l0
oooo0?ooo`0:0?ooo`80o`00<`3oool005@0oooo00@0003o0?ooo`3oool0
oooo0`3o00060?ooo`030000o`3oool0oooo00@0oooo00<0o`000000o`3o
ool01P3oool00`000?l0oooo0?l000070?ooo`030000o`3oool0oooo0080
oooo0P3o00050?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3o
ool0003o1P3oool00`000?l0oooo0?l000060?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3o00000`3oool00`000?l0oooo0?ooo`170?oo
o`80o`003@3oool00`000?l0oooo0?ooo`090?ooo`80003o2`3oool00`3o
0000oooo0?ooo`030?ooo`<0o`001@3oool00`000?l0oooo0?ooo`080?oo
o`030?l000000?l0003o0080003o103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0oooo10000?l0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00D0oooo0P3o0005
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`0=0?ooo`80o`00<@3oool005<0oooo00<0003o0?oo
o`3oool00`3oool20?l000H0oooo00<0003o0?ooo`3oool00`3oool0103o
0000oooo0?ooo`000?l40?ooo`80003o0`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3o0000o`000080o`0000<0oooo0?l0003o00000`3o0000
0`000?l0oooo0?ooo`040?ooo`040?l0003oool0oooo0?ooo`80003o103o
ool010000?l0oooo0?ooo`3o00060?ooo`030000o`3oool0oooo00<0oooo
0P3o00050?ooo`030000o`3oool0oooo04D0oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`060?ooo`80003o3P3oool00`3o0000oooo
0?ooo`020?l000T0oooo00<0003o0?ooo`3oool0103oool30000o`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000000o`000?l0
0P000?l50?ooo`030000o`3oool0oooo00P0oooo00D0o`000?ooo`3oool0
oooo0?l0000=0?ooo`80003o203oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo02h0oooo001C0?ooo`030000o`3oool0oooo00<0oooo
00@0o`000?ooo`3o0000o`000`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo0080oooo0P000?l00`3oool0003o0?ooo`040?ooo`04
0?l0003oool0oooo0?ooo`<0o`0000<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3o0000o`0000<0oooo00<0o`000?oo
o`3oool0103oool010000?l0oooo0000o`000?l40?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00P3o00000`3oool0o`000?ooo`04
0?ooo`030000o`3oool0oooo04<0oooo0P3o000B0?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool03`3oool20?l000`0oooo00@0003o
0?ooo`3oool0oooo0P000?l30?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool30000o`80oooo00<0
003o0?ooo`3oool02@3oool30?l00100oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0B0?ooo`80o`00;P3oool00580oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80o`0000<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`80003o1`3oool3
0?l000<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00@0o`001`3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0003o0000103oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0400oooo0P3o000E
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool03`3oool3
0?l000`0oooo10000?l60?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool20?l000H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`80003o3@3oool30?l00100oooo0P000?l4
0?ooo`030000o`3oool0oooo01@0oooo0P3o000/0?ooo`00DP3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0
003o0000103oool00`3o0000oooo0?ooo`040?ooo`80003o1`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo0000o`050?ooo`<0o`001P3oool20000o`L0oooo00@0o`00
0?ooo`3oool0oooo0P3o00000`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool0?`3oool00`3o0000oooo0?oo
o`0F0?ooo`040000o`3oool0003o0000oa40oooo00@0o`000?ooo`3oool0
o`002`3oool30000o`P0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
o`000?l0000<0?l000030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01`3oool30000o`/0oooo00<0o`000?ooo`3oool00P3o000@0?ooo`80
003o00<0oooo0000o`3oool0603oool00`3o0000oooo0?ooo`0Y0?ooo`00
DP3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00P3o00000`3oool0o`000?ooo`050?ooo`030000
o`3oool0oooo0080003o103oool00`3o0000oooo0?l000050?ooo`030000
o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`04
0?l0003oool0oooo0?l000<0oooo0P000?l20?ooo`030000o`3oool0oooo
00@0oooo00@0o`000?ooo`3o0000o`000`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0?P3oool0
0`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo0100oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`80003o0P3oool0
0`000?l0oooo0?ooo`070?ooo`040?l0003oool0oooo0?ooo`<0o`0000<0
oooo0000o`3oool0103oool20?l000D0oooo00<0003o0?l0003o00000`3o
00020?ooo`030?l0003oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo
0000o`090?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo02P0oooo
001A0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`80o`001@3oool00`000?l0oooo0?oo
o`030?ooo`040000o`3oool0o`000?l000<0oooo00<0o`000?ooo`3oool0
0P3oool50000o`030?l000000?l0003o0080003o103oool00`3o0000oooo
0?ooo`020?ooo`030?l0003oool0003o00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0k0?ooo`80o`00
6P3oool00`000?l0oooo0000o`0@0?ooo`030?l0003oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00H0oooo103o00040?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`80o`00
203oool00`000?l0oooo0?ooo`030?ooo`80003o1P3oool00`3o0000oooo
0?ooo`050?ooo`030?l0003oool0oooo00`0oooo0P000?l00`3oool0003o
0?ooo`0J0?ooo`030?l0003oool0oooo02L0oooo001A0?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0o`0000@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000003o0?ooo`040?ooo`040?l0003oool0oooo0?ooo`<0003o
0`3oool0103o0000oooo0?ooo`3oool20000o`80oooo00<0o`000?ooo`3o
ool0103oool00`000?l0o`000?ooo`050?ooo`040000o`3oool0oooo0?oo
o`<0o`001P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool0>P3oool00`3o0000oooo0?ooo`0I0?oo
o`050000o`3oool0oooo0?ooo`000?l03P3oool00`3o0000oooo0?ooo`06
0?ooo`040?l0003oool0oooo0?ooo`80003o1`3oool00`000?l0oooo0?oo
o`030?ooo`@0o`001P3oool00`000?l0oooo0?ooo`030?ooo`80o`001@3o
ool00`000?l0oooo0?ooo`040?ooo`@0o`00103oool00`000?l0oooo0?oo
o`060?ooo`80003o0`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0I0?ooo`030?l0003oool0oooo02H0oooo001A0?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`040?l0003oool0oooo0?ooo`80o`0000<0oooo0000o`3oool0103o
ool0103o0000oooo0?ooo`000?l50?ooo`050?l000000?l0003o0?ooo`00
0?l0103oool0103o0000oooo0?ooo`000?l20?ooo`80003o00<0o`000?oo
o`3oool00`3oool010000?l0oooo0?ooo`3o00060?ooo`030000o`3o0000
o`0000<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0>@3oool0
0`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool02@3oool20?l000X0oooo00<0o`000?ooo`000?l02P3oool0
0`000?l0oooo0?ooo`020?l000<0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`80o`001@3oool00`000?l0oooo0?ooo`04
0?ooo`040?l0003oool0oooo0?ooo`<0o`0000<0oooo0000o`3oool02@3o
ool00`000?l0oooo0?l0000;0?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003o
ool0oooo02D0oooo001@0?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo0P3o00050?ooo`050?l0003oool0oooo0?ooo`000?l00`3o
ool00`000?l0o`000?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o0000
0P3oool01@000?l0oooo0?ooo`3oool0o`000080003o0`3oool01@000?l0
oooo0?ooo`3oool0o`0000D0oooo0P3o00050?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo03L0oooo00<0o`000?ooo`3oool06@3oool00`00
0?l0oooo0?ooo`050?ooo`80003o203oool00`3o0000oooo0?ooo`0:0?oo
o`030?l000000?l0oooo00X0oooo00<0003o0?ooo`3o00001P3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?l0003oool02P3oool00`3o0000oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo02@0oooo001@0?ooo`<0
003o0`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?l0003o00020?oo
o`030?l0003oool0oooo00<0oooo0`000?l20?ooo`050?l0003oool0oooo
0?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l30?ooo`030?l0003o
ool0oooo00<0003o1@3oool00`3o0000oooo0?ooo`020?l00080oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00@0o`000?ooo`3oool0oooo0`000?li0?ooo`030?l0
003oool0oooo01P0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00X0oooo0P000?l00`3o0000oooo
0?ooo`090?ooo`030?l000000?l0oooo00H0oooo00<0o`000?ooo`3oool0
103oool50000o`030?l000000?l0003o00@0003o1P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0o`0000T0oooo00<0o`000?ooo`000?l0
3@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00P0oooo
00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0T0?ooo`00D03o
ool00`000?l0oooo0?ooo`040000o`@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo0`3o
00050?ooo`80003o0`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo
00@0o`000?ooo`3oool0003o0P3oool00`3o0000oooo0?ooo`020?ooo`80
003o1@3oool00`3o0000oooo0?l000040?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`@0
003o0P3oool00`000?l0oooo0?ooo`0f0?ooo`030?l0003oool0oooo01P0
oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo00X0oooo00@0003o0?ooo`3oool0oooo0P3o00070?oo
o`80o`0000<0oooo0000o`3oool01P3oool0103o0000oooo0?ooo`3oool4
0000o`@0oooo00<0o`000?ooo`3oool00`3oool30000o`<0oooo00<0o`00
0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0o`0000L0oooo00D0
o`000?ooo`3oool0oooo0000o`0=0?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0
003oool0oooo02<0oooo001?0?ooo`030000o`3oool0oooo00<0oooo00@0
o`000?ooo`000?l0003o0P3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool20?l000D0oooo
00<0003o0?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l50?l00005
0000o`3o0000oooo0?ooo`3o00000`3oool30000o`D0oooo0P3o00050?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`020000o`030?ooo`3o0000oooo00@0oooo00<0003o0?oo
o`3oool0=03oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo
00`0oooo0P000?l00`3oool0o`000?ooo`0;0?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00P3oool20?l000@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000003o0000o`030?ooo`030000o`3oool0oooo
0080oooo0P3o00030?ooo`040000o`3oool0oooo0?ooo`<0003o00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`80o`00103oool0
0`3o0000oooo0?ooo`030?ooo`80003o303oool0103o0000oooo0000o`00
0?l>0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool08`3o
ool004l0oooo00<0003o0000000000000P0000000`3oool0o`000?ooo`02
0?ooo`@0003o0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3o00020?ooo`050000o`3oool0
oooo0?ooo`000?l00P3oool01@3o0000oooo0?l0003oool0003o0080oooo
00@0o`000?ooo`000?l0oooo0P3o00030?ooo`050000o`3oool0oooo0?oo
o`000?l00P3oool20?l00080oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo10000?l30?oo
o`030?l0003oool0oooo0080oooo00<000000000o`0000000P00000c0?oo
o`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00H0oooo00@0o`000?oo
o`3oool0o`001`3oool00`000?l0oooo0?ooo`020?ooo`80003o00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80o`000`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l000000?l0003o00D0oooo00<0003o
0?ooo`3oool01@3oool0103o0000oooo0?ooo`3o00080?ooo`030000o`3o
ool0oooo00X0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0G0?ooo`030?l0003oool0oooo0280oooo001?0?ooo`030000o`3oool0
000000<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0000o`03
0000o`D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`80o`0000<0003o0?ooo`3oool00P3oool010000?l0oooo0?l0003o
00020?ooo`060000o`3oool0oooo0?l0003oool0003o0P3oool30?l00003
0000o`3oool0oooo00<0oooo0P3o00040?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool40000o`030?ooo`000?l0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`000?l000000?ooo`0c0?ooo`03
0?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool03P3oool0103o0000
oooo0000o`000?l90?ooo`030000o`3oool0oooo00P0oooo0P3o00090?oo
o`040000o`3oool0003o0000o`<0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool0103o0000oooo0?ooo`3oool20000o`80oooo00<0
003o0?ooo`3oool01`3oool20?l000T0oooo00<0003o0?ooo`3oool0203o
ool20000o`030?ooo`3o0000oooo00l0oooo00<0003o0?ooo`3oool0603o
ool00`3o0000oooo0?ooo`0Q0?ooo`00C`3oool00`000?l0oooo00000003
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000003o0000o`020000o`030?ooo`000?l0oooo00<0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0o`000?l000040?ooo`030000o`3oool0
o`000080oooo00P0003o0?ooo`3oool0o`000?ooo`000?l0oooo0?l00080
oooo00<0003o0?ooo`3oool00P3oool20?l000030?ooo`000?l0oooo00<0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0000o`030000o`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`030?ooo`030000o`000000oooo0380oooo00<0o`000?ooo`3o
ool0603oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0080
oooo0P000?l60?ooo`030000o`3oool0oooo00T0oooo00@0o`000?ooo`3o
0000o`00203oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool20000o`P0oooo0`3o000;
0?ooo`030000o`3oool0oooo00D0oooo0P000?l30?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0Q
0?ooo`00B@3oool400000080oooo00<0003o0?ooo`0000000P3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool40000o`80oooo00<0o`000?ooo`3oool0103oool01000
0?l0oooo0?ooo`3o00020?ooo`070?l0003oool0003o0?ooo`3o0000oooo
0000o`020?ooo`090?l000000?l0oooo0?ooo`3o0000oooo0000o`3oool0
o`000080oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`030?l0003o
ool0oooo00@0003o103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l000000?oo
o`0b0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`040?ooo`80003o103oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0000o`050?ooo`030?l0003oool0oooo0080oooo00@0
003o0?ooo`3oool0oooo0P3o00030?ooo`050000o`3oool0oooo0?ooo`3o
00001P3oool00`000?l0oooo0000o`060?ooo`050?l0003oool0oooo0?oo
o`3o00002`3oool00`000?l0oooo0?ooo`020?ooo`80003o1P3oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?oo
o`3oool0803oool004l0oooo00<0003o0?ooo`0000000P3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00P3oool010000?l0oooo0?ooo`3oool40000o`@0oooo00<0003o0?oo
o`3oool00P3oool20?l000<0oooo00@0003o0?ooo`3o0000oooo0P000?l0
103o0000003o0?ooo`3o00020?ooo`030000o`3oool0oooo0080o`00103o
ool00`000?l0oooo0?ooo`020?ooo`@0003o0`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0300oooo00<0
o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00L0oooo0P000?l00`3oool0003o0?ooo`090?ooo`030?l0003o
ool0oooo00@0oooo00@0o`000?ooo`3oool0oooo0P000?l30?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3o00000`000?l0o`00
0?l000040?l000030000o`3o0000oooo0080oooo00<0o`000?ooo`3oool0
0`3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0003o0080
003o2@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01P0
oooo00<0o`000?ooo`3oool07`3oool004h0oooo00@0003o0?ooo`000000
00000P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0003o00@0003o1@3oool20?l000<0oooo00P0003o0?l00000
0?l0003o0?ooo`3o0000003o0?l000<0003o0`3oool20?l000D0oooo1000
0?l20?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00P3oool00`000000003o0?ooo`0a0?ooo`030?l0003o
ool0oooo01P0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`090?ooo`<0003o2@3oool00`3o0000oooo0?ooo`050?ooo`80o`0000<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`<0o`000P3o
ool010000?l0oooo0?ooo`3o00030?ooo`030000o`3oool0o`000080o`00
1@3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0o`000?l000L0
oooo00<0o`000?ooo`3oool01`3oool20000o``0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo01h0
oooo001>0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`<0003o
0`3oool0103o0000oooo0?ooo`3o00020?ooo`80003o00H0o`000000o`3o
ool0o`000000o`3o00020000o`80oooo0P3o00000`3oool0o`000?ooo`02
0?ooo`<0003o1@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0;`3oool0
0`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`020000o`H0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0o`000?ooo`060?ooo`040000o`3oool0
oooo0?ooo`80o`000`3oool010000?l0oooo0?ooo`3o00020?ooo`030000
o`3oool0oooo0080oooo0P3o00030?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`80003o
00<0oooo0000o`3oool0303oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo01P0oooo00<0o`000?ooo`3oool07P3oool004h0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01@00
0?l20?ooo`80o`0000P0003o0?ooo`000?l0003o0?ooo`000?l0o`000?oo
o`80003o0P3o00030?ooo`@0003o0P3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0Y0?ooo`800000103oool00`3o
0000oooo0?ooo`0H0?ooo`030000o`000000000000800000303oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo0`000?l30000
00030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o00001`3oool00`00
0?l0o`000?l000020?ooo`040?l0003oool0oooo0000o`80oooo00@0o`00
0?ooo`3oool0003o0`3oool00`3o0000oooo0?ooo`020?l000030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`000?l02@3oool0103o0000oooo0000
000000030000o`@0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0;0?ooo`<0000000<0003o0?ooo`3oool06@3oool00`3o0000oooo
0?ooo`030?ooo`800000603oool004h0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0000
o`030000o`80o`0000<0oooo0000o`000?l00`000?l20?l000D0003o00<0
oooo0?l0003oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo0080oooo0P000?l40?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00L0oooo0P0000000`3oool000000000000L0?ooo`040000003o
ool0oooo00000080oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo
0000000>0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
1P3oool30000o`T0oooo00@0003o0?ooo`3oool0oooo0P3o00040?ooo`80
o`0000<0003o0?ooo`3oool00P3oool00`3o0000oooo0000o`020?ooo`04
0?l0003oool0oooo0000o`80oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0o`000?ooo`040?ooo`80o`000P3oool00`000?l0oooo0?ooo`080?oo
o`<0003o00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000o`0J
0?ooo`030?l0003oool0oooo0080oooo00@000000?ooo`3oool000005`3o
ool004h0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`<0003o0P3o0002
0000o`030?l000000?l0003o0080003o1@3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00P0oooo00<000000?ooo`0000007`3oool01@000000oooo0?ooo`3o
ool0o`0001X0oooo00@0003o0?ooo`3oool000003@3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00L0oooo00<000000?l000000?l0
0P000?l60?ooo`030000o`3oool0oooo00<0oooo0P3o00000`3oool0o`00
0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool00`000?l0
oooo0?l000020?ooo`030000o`3oool0o`0000@0oooo00<0003o0?ooo`3o
ool00P3o00000`3oool0o`000?l000050?ooo`030000o`3oool0oooo00@0
oooo0`000?l0103o0000oooo0?ooo`0000060?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool02`3oool010000000oooo0?ooo`000?lJ
0?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool0
04T0oooo1@00001V0?l000D000001P3oool00`000000oooo0?ooo`0F0?oo
o`@000001@3oool00`000000oooo0?l0000G0?ooo`<0000000<0003o0?oo
o`3oool00P3oool00`000000oooo0?ooo`090?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`0000000`0000040?ooo`030?l0003oool0oooo
0080oooo0`000?l20?ooo`030000o`3oool0oooo00H0oooo0P3o00040?oo
o`060000o`3oool0oooo0?ooo`3o0000oooo0P000?l01P3o0000003o0?oo
o`000?l0oooo0?l000<0oooo00<0003o0?ooo`3oool00P3oool20?l000P0
oooo00<0003o0?ooo`000?l00`000?l40?ooo`030?l0003oool0000000L0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000003oool0003o01X0oooo00<0o`000?ooo`3oool01@3oool00`000000
oooo0?ooo`0E0?ooo`00CP3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo0080oooo0P000?l40?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo0P3o00030?ooo`@0003o00H0oooo0?l0003o0000
o`000000o`3oool40000o`@0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?oo
o`80000000<0oooo000000000000703oool01P000000oooo0?ooo`000000
oooo0?l001X0oooo00@0003o0?ooo`3oool000000P3oool00`000000oooo
0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`050?ooo`<0003o203oool30?l000@0oooo
00@0003o0?ooo`3oool0o`000`000?l01@3o0000oooo0000o`000?l0o`00
00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?l000070?oo
o`<0003o203oool00`3o0000oooo000000080?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02P3oool01P000000oooo0?ooo`000000
oooo0000oaX0oooo00D0o`000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo01D0oooo001>0?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`000?l0003o
0?ooo`020000o`80o`0000T0oooo0?l0003o0000o`000000o`3o0000oooo
0000o`3oool00P000?l20?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0:@3oool2
00000080oooo00<0o`000?ooo`3oool0603oool010000?l0oooo0?ooo`3o
ool2000000/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`070?ooo`030000003o0000oooo00P0oooo1@000?l30?ooo`040?l0003o
ool0oooo0?ooo`<0o`000P3oool30000o`080?l0003oool0003o0?l0003o
ool0003o0?ooo`3o00030000o`80oooo0`3o00020?ooo`030?l0003oool0
oooo0080oooo0`000?l00`3oool0003o0?ooo`080?ooo`030?l000000000
000000P0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:
0?ooo`8000000P3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0
oooo0080oooo0P00000H0?ooo`00CP3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00`3oool010000?l0oooo0?ooo`3oool40000o`<0oooo0P3o0000
103oool0003o0?l0003oool20?l000040?ooo`000?l0o`000?l000<0oooo
10000?l30?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo02d0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo
0`000?l00`3o0000oooo0?ooo`040?ooo`80o`000P000?l0203oool0o`00
0?ooo`000?l0o`000?ooo`000?l0o`000P3oool010000?l0oooo0?l0003o
00060?ooo`040?l000000?l0003o0000o`D0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0
003oool0oooo01`0oooo001>0?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`@0003o0P3oool00`3o0000oooo0?ooo`020?l000090?ooo`00
0?l0003o0?l000000?l0oooo0?l000000?l0o`000080003o00<0oooo0?l0
003o00000P3oool00`3o0000oooo0?ooo`040000o`D0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo02d0oooo00<0o`000?ooo`3oool0603oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00H0oooo0`000?l50?ooo`0:0000o`3o0000oooo0000o`3oool0o`000?oo
o`3o0000003o0?l00080oooo00@0003o0?ooo`3o0000003o1@3oool30000
o`P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo01`0oooo001?0?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000003o0000o`020000o`030?ooo`000?l0oooo00@0
oooo0P3o00020?ooo`030000o`3oool0o`0000<0003o00H0o`000000o`00
0?l0o`000?ooo`000?l20?ooo`80o`001@3oool00`000?l0oooo0000o`03
0000o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0
oooo01P0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`050?ooo`040?l0003oool0oooo0?ooo`H0003o00D0
oooo0?l0003o0000003o0?ooo`020?l000040000o`3o0000003o0000o`80
o`0000<0oooo0000o`000?l010000?l20?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0H0?ooo`030?l0003oool0oooo01`0oooo001?0?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
10000?l50?ooo`030000o`3oool0oooo0080oooo0P3o00030?ooo`0:0000
o`3o0000oooo0?ooo`000?l0oooo0?l000000?l0oooo0?l00080oooo00<0
003o0?ooo`3oool00P3o00040?ooo`030000o`3oool0oooo00<0oooo1000
0?l20?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`D0003o00@0o`000000o`3o0000003o
103o00040000o`P0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01P0oooo
00<0o`000?ooo`3oool03@3oool4000000/0oooo001?0?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`040?l0003oool0oooo0?ooo`@0003o0`3oool00`3o0000oooo
0?ooo`040?ooo`040000o`3oool0o`000?l00080oooo00L0o`000000o`00
0?l0oooo0?l0003oool0003o0080oooo00D0o`000000o`3oool0oooo0?l0
00020?ooo`040000o`3o0000oooo0?ooo`80o`0000<0oooo0000o`3oool0
1@3oool0103o0000oooo0?ooo`3oool40000o`<0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool0:03ooomX0?l000<0003oK@3o00080?ooo`04
0000003oool0oooo000000`0oooo001?0?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`04
0?l0003oool0003o0000o`80oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`030?ooo`80o`00103oool010000?l0o`000?ooo`3o0002
0?ooo`080000o`3oool0oooo0?l0003oool0003o0?ooo`3o00020?ooo`03
0000o`3oool0oooo00<0oooo0P3o00050?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00P000?l00`3oool0o`000?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0X0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0603oool00`000?l0oooo0000000>0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool01P3oool00`000000oooo0?l000080?ooo`80
003o1`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0080
oooo0`000?l30?l00080003o0`3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
00000?ooo`070?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool02`3oool010000000oooo0?ooo`000?lJ0?ooo`030?l0003oool0oooo
00<0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`00000<
0?ooo`00C`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo00@0003o0?ooo`3oool0oooo10000?l40?ooo`030000o`3oool0
oooo00<0oooo00@0o`000?ooo`3oool0oooo0P3o00000`3oool0003o0?oo
o`030?ooo`040000o`3oool0o`000?l00080oooo00H0003o0?ooo`3oool0
o`000?ooo`000?l20?ooo`80o`0000<0oooo0000o`3oool00`3oool01000
0?l0oooo0?l0003o00030?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool40000o`80oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo02P0oooo00<00000
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0
000000h0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`06
0?ooo`030000003oool0o`0000T0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`@0003o0`3o00030000o`80o`0010000?l8
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool0
0`3o000000000?ooo`070?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool02`3oool010000000oooo0?ooo`000?lJ0?ooo`030?l0003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool2000000030?ooo`00
0000000000`0oooo001?0?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00P3oool40000o`<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`<0o`000`3oool00`000?l0oooo0?ooo`02
0000o`80oooo00D0o`000?ooo`3o0000o`000000o`020?ooo`040?l0003o
ool0003o0?ooo`80o`000`3oool20000o`80oooo00@0003o0?ooo`3oool0
oooo0`3o00050?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3o
ool0oooo10000?l40?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0;P3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool02@3oool20000o`T0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`80o`000P3oool60000
o`070?ooo`3o0000o`000000o`3oool0o`000000o`020?l00080003o0P3o
00000`3oool0003o0000o`040000o`80oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo01P0oooo00<0o`000?ooo`3oool0703oool004l0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000003o0000o`020000o`030?ooo`000?l0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo0P000?l40?ooo`040?l0003oool0
oooo0000o`D0o`0000D0003o0?l0003oool0oooo0?l000040?ooo`80003o
1P3oool20?l000@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0003o00<0003o00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0_0?ooo`030?l0003oool0oooo01P0oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`060?ooo`<0003o1@3oool01`000?l0o`000?ooo`000?l0oooo0?l0
003oool00P000?l01P3o0000oooo0?ooo`000?l0oooo0?l000H0oooo0`00
0?l80?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0L0?ooo`00D03oool0
0`000?l0oooo0000o`030000o`D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0?ooo`80o`0000<0
oooo0?l0003oool01@3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo
00D0003o0?ooo`3oool0oooo0?l000020?ooo`040000o`3oool0oooo0?l0
00@0oooo0P000?l50?ooo`040?l0003oool0oooo0?l00080oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo10000?l00`3oool0003o0?ooo`0`0?ooo`030?l0003oool0
oooo01P0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`030?ooo`<0003o00<0o`000?ooo`3oool0103oool2
0?l00080003o00P0oooo0?l0003oool0003o0?l0003oool0003o0?l00080
oooo0P000?l20?l000H0oooo00@0o`000000o`000?l0003o1@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo
01P0oooo00<0o`000?ooo`3oool0703oool00500oooo0P000?l40?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3o0000o`0000@0oooo00@0o`000?ooo`3o
ool0oooo0P000?l01@3oool0003o0?ooo`3oool0o`0000<0oooo00D0003o
0?ooo`3oool0oooo0?l000020?ooo`050000o`3oool0oooo0?ooo`3o0000
0P3oool010000?l0oooo0?ooo`000?l40?ooo`040?l0003oool0oooo0?oo
o`80o`0000<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool20000
oc40oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00<0003o103oool00`3o
0000oooo0?ooo`030?l00080oooo0P000?l02@3o0000oooo0?ooo`000?l0
o`000?ooo`000?l0oooo0?l000030000o`80oooo0P3o00030?ooo`030?l0
003oool0oooo0080oooo0`000?l00`3oool0003o0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0
703oool00500oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3o
ool20?l000H0oooo00@0o`000?ooo`3oool0003o103oool00`000?l0o`00
0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool00`000?l0
oooo0?ooo`020?ooo`030?l000000?l0oooo0080oooo00D0003o0?ooo`3o
ool0oooo0?l000060?ooo`80o`00103oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0_0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?oo
o`3oool03P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01@3oool40000o`L0oooo0`3o00040?oo
o`040000o`3oool0oooo0?l000<0003o00<0o`000000o`000?l00P000?l0
103o0000oooo0?ooo`000?l30?ooo`<0o`00203oool30000o`P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?oo
o`0L0?ooo`00D@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3o
ool0o`000080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0000
o`040?ooo`030?l0003oool0003o00<0003o103oool0103o0000oooo0?oo
o`000?l20?ooo`80003o00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?l000060?ooo`040000o`3oool0oooo0?l00080oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool0<03oool00`3o0000oooo0?ooo`0H0?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo0080oooo0`000?l20?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool01P000?l0
oooo0?ooo`3oool0o`000?ooo`80003o00H0o`000000o`3oool0003o0?oo
o`3o00030?ooo`030000o`3oool0oooo0080oooo0P3o00080?ooo`030000
o`3oool0003o0080003o103oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo
0?ooo`0H0?ooo`030?l0003oool0oooo01d0oooo001A0?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0o`0000@0oooo00<0003o0?ooo`3oool00`3o
ool20000o`D0oooo00<0o`000?ooo`3oool00P3oool30000o`80oooo00<0
o`000?ooo`000?l00`000?l30?ooo`030?l0003oool0oooo00<0oooo0P00
0?l60?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l000050?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`0`0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00P0
oooo00@0o`000000o`000?l0003o1P3oool00`000?l0oooo0?ooo`030?oo
o`80o`0000<0oooo0?l0003oool00P3oool01@000?l0oooo0?ooo`3oool0
o`000080oooo00<0003o0?ooo`3o00000P3oool010000?l0oooo0?ooo`3o
00030?ooo`040000o`3oool0oooo0?l00080oooo0P3o00050?ooo`030000
o`3oool0oooo00<0oooo10000?l00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo
0?ooo`0H0?ooo`030?l0003oool0oooo01d0oooo001A0?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo
0000o`020?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool00`000?l0
oooo0?ooo`020000o`050?l000000?l0oooo0?ooo`000?l0103oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0003o00D0oooo00<0003o0?oo
o`3oool00`3oool20?l000D0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo0340oooo00<0o`000?oo
o`3oool0603oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool01P3oool30000o`T0oooo00@0003o0?oo
o`3oool0oooo0P3o00040?ooo`80o`0000<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0000o`020?ooo`040?l0003oool0oooo0000o`80oooo00<0
o`000?ooo`3oool00P3oool00`000?l0o`000?ooo`040?ooo`80o`000P3o
ool00`000?l0oooo0?ooo`070?ooo`040?l000000?l0003o0000o`P0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo01P0oooo00<0o`000?ooo`3oool07@3oool00580oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`040000o`3o
ool0oooo0?ooo`80o`0000<0oooo0?l0003oool01@3oool010000?l0oooo
0?ooo`000?l30?ooo`040?l0003oool0oooo0?l000D0oooo00<0003o0?oo
o`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00@0o`00
0?ooo`3o0000o`000`3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo
00@0o`000?ooo`3oool0o`000`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0<P3oool00`3o0000
oooo0?ooo`0I0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`030?ooo`80003o0`3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0o`0000L0oooo00<0003o0?l0003o
ool00P3oool0103o0000oooo0?ooo`000?l20?ooo`040?l0003oool0oooo
0000o`<0oooo00H0o`000?ooo`3oool0oooo0?l000000?l70?ooo`030?l0
003oool0003o00T0oooo00@0o`000?ooo`3oool0oooo0P000?l50?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0H0?ooo`030?l0003oool0oooo01h0oooo001B0?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool010000?l0oooo
0?l0003o00040?ooo`030?l0003oool0oooo00@0oooo0P000?l50?ooo`80
o`001@3oool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?oo
o`000?l01@3oool20?l000H0oooo0`000?l60?ooo`040?l0003oool0oooo
0?ooo`80o`0000<0oooo0000o`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo03<0oooo00<0o`000?ooo`3oool0603oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00X0oooo00@0003o
0?ooo`3oool0oooo0P000?l50?ooo`030?l0003oool0oooo00P0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?l000<0oooo00@0
003o0?ooo`3oool0o`000P3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0o`000080oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0oooo00@0oooo0P000?l30?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo
0?ooo`0H0?ooo`030?l0003oool0oooo01h0oooo001B0?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool20?l000H0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0000o`060?ooo`<0o`000`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00L0
003o0?ooo`3oool0oooo0?l0003oool0o`0000L0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`040?ooo`80o`00103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo03@0oooo00<0o`000?ooo`3o
ool0603oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00X0
oooo0`000?l80?ooo`030?l0003oool0oooo00D0oooo0P3o00000`3oool0
003o0?ooo`040?ooo`030000o`3oool0oooo0080oooo0`3o00020?ooo`04
0000o`3oool0oooo0?l000<0oooo00<0003o0?ooo`3oool00`3o00040?oo
o`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3o0000o`001`3oool0
0`3o0000oooo0?ooo`060?ooo`<0003o303oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool07`3oool0
05<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?l0
00030?ooo`000?l0oooo00H0oooo00<0o`000?ooo`3oool00P3oool01000
0?l0oooo0?ooo`000?l40?ooo`040?l0003oool0oooo0?ooo`<0o`0000<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`040000o`3o
0000o`000?l00080oooo00<0o`000?ooo`3oool00`3oool20000o`030?oo
o`000?l0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`020?l00080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0e0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`070?ooo`@0003o2P3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0
oooo0000o`050?ooo`030?l0003oool0oooo0080o`0000<0003o0?l0003o
0000103o00000`000?l0o`000?l000020?ooo`030?l0003oool0oooo00<0
oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool0203oool010000?l0oooo0000o`000?l:
0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0603oool0
0`3o0000oooo0?ooo`0O0?ooo`00D`3oool00`000?l0oooo0?ooo`030?oo
o`<0o`00103oool00`000?l0oooo0?ooo`050?ooo`040?l0003oool0003o
0000o`@0oooo00D0003o0?ooo`3oool0oooo0?l000060?ooo`030000o`3o
0000o`0000T0o`0000<0003o0?ooo`3oool00`3oool01@3o0000oooo0?oo
o`3oool0003o00@0oooo0P000?l00`3oool0o`000?ooo`060?ooo`030000
o`3oool0oooo0080oooo0P3o00050?ooo`030000o`3oool0oooo03H0oooo
00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
003oool0oooo00@0oooo0P000?l40?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0003o00D0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo
0?ooo`3oool20?l000<0oooo00D0003o0?ooo`3oool0oooo0?l000060?oo
o`030000o`3oool0003o00H0oooo00D0o`000?ooo`3oool0oooo0?l0000;
0?ooo`040000o`3oool0oooo0?ooo`80003o1`3oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0803o
ool005@0oooo00<0003o0?ooo`3oool00P3oool20?l000H0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
o`0000H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000000o`000?l01P3oool0
0`000?l0oooo0?l000060?ooo`030000o`3oool0oooo00@0oooo0`3o0003
0?ooo`030000o`3oool0oooo03L0oooo00<0o`000?ooo`3oool0603oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`090?ooo`040?l0003oool0
o`000?l000P0oooo0P000?l50?ooo`030?l0003oool0oooo0080oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`060?ooo`80o`00
00<0oooo0?l0003oool02@3oool00`000?l0oooo0?ooo`040?ooo`80003o
103oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01P0oooo
00<0o`000?ooo`3oool08@3oool005@0oooo00<0003o0?ooo`3oool00P3o
00000`3oool0o`000?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?l0003oool01P3oool00`3o0000003o0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`030?ooo`070?l0003oool0oooo0?ooo`3o0000
oooo0000o`0j0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`020000o`P0oooo00<0003o0?ooo`3o
ool0203oool20?l000T0oooo00@0003o0?ooo`3oool0003o0`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo0P3o00030?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool20000
o`030?ooo`000?l0oooo00P0oooo0P3o00090?ooo`030000o`3oool0oooo
00L0oooo0P000?l20?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool0603oool00`3o0000oooo0?ooo`0Q0?ooo`00E@3oool20?l000@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`80
003o0P3oool00`3o0000oooo0?ooo`040?ooo`040?l0003oool0003o0000
o`@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o00001`3oool0103o
0000oooo0000o`000?l40?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool20?l003/0oooo00<0o`000?ooo`3oool06@3oool0
0`000?l0oooo0?ooo`0>0?ooo`80003o2`3oool00`000?l0oooo0?ooo`06
0?ooo`040?l0003oool0oooo0?l000L0oooo00<0003o0?ooo`3oool00P3o
ool20000o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool20?l000<0oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0000
o`000?l40?ooo`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3oool0
o`00203oool00`000?l0oooo0?ooo`090?ooo`80003o403oool00`000?l0
oooo0?ooo`0H0?ooo`030?l0003oool0oooo0280oooo001F0?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool010000?l0oooo
0?ooo`000?l50?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool20000o`80oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo0080003o0P3oool00`3o0000
oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0>`3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo
00d0oooo00<0003o0?ooo`3o0000303oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l000000?l0oooo00<0oooo00<0003o0?oo
o`3oool00P3oool20?l000<0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0o`000?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`000?l03P3oool00`000?l0oooo0?ooo`0I0?oo
o`030?l0003oool0oooo0280oooo001F0?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0000o`060?ooo`05
0?l0003oool0oooo0?ooo`3o00001P3oool50000o`@0oooo00@0o`000?oo
o`3oool0oooo1P000?l50?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0000o`060?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0?03oool00`3o0000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo00X0oooo0P000?l30?ooo`030?l0003oool0
oooo00X0oooo00@0003o0?ooo`3oool0oooo0P3o00060?ooo`80o`000P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0003o103o
ool00`3o0000oooo0?ooo`030?ooo`D0003o00<0oooo0?l0003oool01P3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00@0
o`000?ooo`3oool0oooo0P000?l<0?ooo`040?l0003oool0oooo0?ooo`80
003o303oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo02<0
oooo001G0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool20000o`P0oooo00<0o`000?ooo`3o0000203oool010000?l0oooo
0?ooo`3oool40000o`040?l000000?l0003o0000o`<0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`020?l000L0oooo0P000?l50?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0?P3oool00`3o
0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0o`00
00X0oooo00<0o`000?ooo`000?l01`3oool00`3o0000oooo0?ooo`040?oo
o`D0003o00<0o`000000o`000?l010000?l60?ooo`030?l0003oool0oooo
00D0oooo00@0003o0?ooo`3o0000o`00203oool00`3o0000oooo0000o`0=
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo02<0oooo001H0?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool01000
0?l0oooo0?ooo`000?l80?ooo`80o`001`3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool2
0?l000P0oooo00<0003o0?ooo`000?l0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo0400oooo00<0o`000?ooo`3oool0603oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool02P3oool00`3o0000003o0?ooo`0:0?ooo`030000o`3o0000
oooo00H0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`80o`00103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?l0003oool02P3oool00`3o0000oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo02@0oooo001I0?oo
o`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`03
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o00000P3o0004
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`030?ooo`<0o`001`3oool20000o`<0oooo00D0003o
0?ooo`3oool0oooo0?l000060?ooo`030000o`3oool0oooo0440oooo00<0
o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`030?ooo`80003o2P3o
ool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0003o00X0oooo00<0
003o0?ooo`3o00000P3o00030?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool20?l000D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`020?ooo`80o`0000<0oooo0000o`3oool02@3o
ool00`000?l0oooo0?l0000;0?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool00`3oool20000oa/0oooo00<0o`000?ooo`3oool09@3o
ool005T0oooo00<0003o0?ooo`3oool0103oool00`3o0000003o0000o`05
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool2
0?l00080oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`040000o`3oool0oooo0?ooo`80o`000`3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00@0oooo0P000?l00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo04<0oooo00<0o`000?ooo`3oool0603o
ool01@000?l0oooo0?ooo`3oool0003o00d0oooo00<0o`000?ooo`3oool0
1`3oool01@3o0000oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3o
ool00`3oool20?l000030?ooo`3o0000oooo00D0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00P3o00030?ooo`030000o`3oool0oooo00H0
oooo0P000?l30?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3o
ool02P3oool01@000?l0oooo0?ooo`3oool0003o01/0oooo0P3o000X0?oo
o`00FP3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o0000o`0000H0
oooo0P000?l30?ooo`030?l0003oool0oooo00D0oooo0P3o00000`000?l0
o`000?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0o`000000o`3o
00000P3o00050?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000003o0?ooo`040?ooo`030000o`3oool0oooo04D0
oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0000o`0?0?ooo`80
o`001P3oool00`3o0000oooo0?ooo`030?ooo`80003o1@3oool00`000?l0
oooo0?ooo`060?ooo`80o`001P3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool30?l000H0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo0P3o000>0?ooo`030000o`3oool0003o01/0
oooo00<0o`000?ooo`3oool0:03oool005/0oooo00D0003o0?ooo`3oool0
oooo0000o`030?ooo`030?l0003oool0oooo00D0oooo0P000?l00`3oool0
o`000?ooo`070?ooo`030000o`3oool0oooo00h0o`0000<0oooo0000o`3o
ool0203oool0103o0000oooo0000o`000?l80?ooo`040?l0003oool0oooo
0000o`<0oooo00<0003o0?ooo`3oool0A`3oool00`3o0000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`060?ooo`80003o0P3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0o`0000<0o`000P3oool00`000?l0oooo0?ooo`03
0?ooo`80o`001@3oool00`000?l0oooo0?ooo`040?l000030?ooo`3o0000
oooo00L0oooo00@0003o0?ooo`3oool0oooo0P000?l80?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool03`3oool20000oaX0oooo00<0
o`000?ooo`3oool0:@3oool005`0oooo00<0003o0?ooo`000?l01@3oool0
0`3o0000oooo0?ooo`060?ooo`030?l000000?l0oooo00L0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?l0003o0000203oool00`3o0000oooo0?ooo`02
0?ooo`040000o`3oool0oooo0000odX0oooo00<0o`000?ooo`3oool05P3o
ool00`000?l0oooo0000o`0B0?ooo`80o`0000<0oooo0?l0003oool02P3o
ool00`000?l0oooo0000o`080?ooo`030?l0003oool0oooo00@0oooo00<0
o`000000o`3o00003@3o00000`000?l0o`000?ooo`040?ooo`030?l0003o
ool0oooo00L0oooo0`000?l;0?ooo`040?l0003oool0oooo0?l00100oooo
0P000?l20?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool0
:P3oool005d0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0003o1@3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103o
ool20000o`80oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`80003oC03oool00`3o0000oooo0?ooo`0D0?ooo`040000o`3o
ool0oooo0?ooo`80003o4P3oool20?l000`0oooo0P000?l80?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool20?l000H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00/0oooo0`3o000@0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool04`3oool20?l002d0oooo001N0?ooo`030000o`3o
ool0oooo00D0oooo0P3o00040?ooo`030?l0003oool0oooo00<0oooo0P00
0?l30?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool010000?l0oooo0?ooo`3oool30000o`D0oooo00<0o`000?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo04`0oooo
0P3o000C0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
3`3oool30?l000/0oooo00<0003o0?ooo`000?l00`000?l30?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool20000o`030?ooo`000?l0oooo00/0oooo0P3o000@0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo
0?ooo`0]0?ooo`00G`3oool00`000?l0oooo0?ooo`060?ooo`040?l0003o
ool0oooo0?l000P0oooo0`000?l:0?ooo`030?l0003oool0oooo00H0oooo
00@0003o0?ooo`000?l0003o203oool0103o0000oooo0?ooo`3oool20?l0
00L0oooo00<0003o0?ooo`3oool0C`3oool00`3o0000oooo0?ooo`0?0?oo
o`030000o`3oool0oooo00H0oooo0P000?l>0?ooo`050?l0003oool0oooo
0?ooo`3o00002@3oool00`000?l0oooo0?ooo`040?ooo`<0003o00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0000o`<0oooo00<0003o0?ooo`3oool0203oool20?l00080oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool0;P3oool00600oooo00<0003o0?oo
o`3oool01P3oool30?l000X0oooo1@000?l60?ooo`030?l0003oool0oooo
00<0oooo1@000?l;0?ooo`<0o`001`3oool20000oe<0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`090?ooo`80003o2`3oool00`3o
0000oooo0?ooo`030?ooo`80o`001P3oool00`000?l0oooo0?ooo`080?oo
o`040?l000000?l0003o0000o`D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo0P000?l0
0`3o0000003o0000o`080?ooo`030000o`3oool0oooo00D0oooo0P3o0005
0?ooo`030?l0003oool0oooo00T0oooo0P000?l:0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool0;`3oool00640oooo00<0003o0?oo
o`3oool01P3oool30?l000T0oooo00<0003o0?ooo`3oool00P3oool60000
o`030?l000000?l0003o00<0003o103oool00`000?l0oooo0?ooo`080?oo
o`80o`00203oool00`000?l0oooo0?ooo`1D0?ooo`80o`00303oool00`00
0?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool01@3oool20?l000@0oooo00<0003o0?ooo`3oool0203oool0103o
0000oooo0?ooo`3oool40000o`030?ooo`000?l0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0000o`030000o`<0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`80o`001`3oool0
0`3o0000oooo0?ooo`070?ooo`80003o3@3oool00`000?l0oooo0?ooo`0;
0?ooo`80o`00<P3oool00680oooo0P000?l60?ooo`030?l0003oool0oooo
0080o`001`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01P3oool20?l00080oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`1G0?ooo`80o`002P3oool00`00
0?l0oooo0?ooo`0=0?ooo`80003o1`3oool00`3o0000oooo0?ooo`080?oo
o`<0o`0000<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?oo
o`P0003o00<0o`000000o`000?l01`000?l70?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3o00000P3o000:0?ooo`030?l0003oool0oooo
00@0oooo0P000?l@0?ooo`030000o`3oool0oooo00P0oooo0P3o000d0?oo
o`00I03oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0
oooo0P3o00040?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`040?ooo`80o`00103oool00`3o0000
oooo0?ooo`020?ooo`80003oG03oool20?l000L0oooo00<0003o0?ooo`3o
ool0403oool30000o`@0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
o`000?l000080?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool30?l000030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool00P3oool20000oa80oooo00<0003o0?ooo`3o
ool01P3oool20?l003H0oooo001U0?ooo`040000o`3oool0oooo0?l000P0
oooo00D0o`000?ooo`3oool0oooo0000o`0;0?ooo`030?l0003oool0oooo
00P0oooo00@0003o0?ooo`3oool0oooo0P3o00070?ooo`040?l0003oool0
oooo0000of00oooo0P3o00050?ooo`030000o`3oool0oooo01<0oooo0P00
0?l00`3oool0o`000?ooo`0<0?ooo`040000o`3oool0oooo0?ooo`@0o`00
0`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo
0P3o00070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3o00030?ooo`030000o`3oool0oooo00`0oooo00@0o`000?ooo`000?l0
003o5@3oool00`000?l0oooo0?ooo`030?ooo`80o`00>03oool006H0oooo
00<0003o0?l0003oool02@3oool30?l000030000o`3o0000o`0000T0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000003o0?l000020?l000X0oooo
00<0o`000000o`3oool0HP3oool30?l000030?ooo`000?l0oooo01L0oooo
00<0003o0?l000000?l0303oool00`000?l0oooo0?ooo`050?ooo`@0o`00
2@3oool00`000?l0oooo0?ooo`050?ooo`80o`001`3oool00`000?l0oooo
0?ooo`050?ooo`@0o`00203oool00`000?l0oooo0?ooo`0;0?ooo`030000
o`3o0000003o01L0oooo00@0003o0?ooo`3oool0oooo0P3o000j0?ooo`00
J03oool20000o`/0oooo00<0003o0?ooo`3oool01`3o00020?ooo`030?l0
003oool0o`0000L0o`000P3oool00`000?l0oooo0?ooo`080?ooo`80003o
J03oool00`000?l0o`000?l0000G0?ooo`030?l0003oool0oooo00<0003o
2@3oool00`000?l0oooo0?ooo`080?ooo`L0o`000`3oool00`000?l0oooo
0?ooo`050?ooo`80o`001`3oool010000?l0oooo0?ooo`3oool40?l00003
0?ooo`3o0000oooo00T0oooo00<0003o0?ooo`3oool01`3oool40000o`80
oooo00<0o`000?ooo`3oool05P3oool00`000?l0o`000?l0000l0?ooo`00
JP3oool20000o`T0oooo00<0003o0?ooo`3oool01`3oool40?l000X0oooo
00<0003o0?ooo`3oool01P3oool20000ofX0oooo00<0003o0?ooo`3oool0
0`3o000D0?ooo`030?l0003oool0oooo00<0oooo10000?l50?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool30?l000030000
o`3o0000o`0000h0o`0000@0003o0?l0003o0000o`001P3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00<0oooo0`000?l60?ooo`03
0?l0003oool0oooo0180oooo103o00000`3oool0003o0?ooo`0l0?ooo`00
K03oool20000o`H0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00@0oooo0P000?m[0?ooo`030000
o`3oool0oooo00@0oooo0`3o000@0?ooo`030?l0003oool0oooo00P0oooo
1@000?l;0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool20?l000L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0003o00<0003o2P3oool00`3o0000oooo
0?ooo`0=0?ooo`@0o`001@3oool00`000?l0oooo0?ooo`0k0?ooo`00KP3o
ool30000o`<0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo0080oooo0P000?m]0?ooo`030000o`3o
ool0oooo00L0oooo103o000<0?ooo`030?l0003oool0oooo00`0oooo1`00
0?l50?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool20?l000L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`@0003o3P3oool00`3o0000oooo0?ooo`0:0?ooo`<0o`002P3o
ool00`000?l0oooo0?ooo`0j0?ooo`00L@3oool40000o`D0oooo1@000002
0?ooo`030?l0003oool0oooo00X0oooo10000?m_0?ooo`030000o`3oool0
oooo00/0oooo103o00070?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool0103oool40000o`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01P3oool20?l000P0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060000o`<0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`060?ooo`@0o`003@3oool00`000?l0oooo0?ooo`0j
0?ooo`00M03oool50000o`<0oooo00<000000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`050?ooo`H0003oLP3oool00`000?l0oooo0?ooo`0?0?oo
o`D0o`000P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00P0oooo00<0o`000000o`000?l020000?l80?ooo`80o`00203oool:0000
o`030?l000000?l0oooo00P0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`060?l00140oooo00<0003o0?ooo`3oool0>P3oool007T0
oooo20000?l00`3o0000003o0000o`050000ogP0oooo00<0003o0?ooo`3o
ool0503oool40?l000h0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`070?ooo`T0003o0P3o00090000o`T0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0;0?ooo`@0o`005`3oool00`000?l0
oooo0?ooo`0j0?ooo`00O03oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo07`0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo
0?l000050?l000L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool01P3oool40?l00080oooo00<0o`000?ooo`3oool0
5`3oool00`000?l0oooo0?ooo`0i0?ooo`00O03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo07`0oooo00<0003o0?ooo`3oool05`3o
ool00`3o0000oooo0?ooo`050?ooo`L0o`0000<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo0P3o
00080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool30?l000030000o`3o0000o`0000H0o`001P3oool00`3o0000oooo0?oo
o`0G0?ooo`030000o`3oool0oooo03T0oooo001k0?ooo`800000103oool0
0`000000oooo0?ooo`1l0?ooo`030000o`3oool0oooo01H0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0o`000?l0000:0?l000T0oooo00<0003o
0?ooo`3oool01P3oool20?l000P0oooo00<0003o0?ooo`3oool01P3oool:
0?l000<0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0G
0?ooo`030000o`3oool0oooo03T0oooo00210?ooo`030000003oool0oooo
07`0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00T0oooo2P3o00000`000?l0o`000?l0000@0?l0
00030000o`3o0000o`0000H0o`0000<0oooo0?l0003oool02P3oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?oo
o`3oool0>@3oool00840oooo00<000000?ooo`3oool0O03oool00`000?l0
oooo0?ooo`0F0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0
oooo0P3o00080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo01H0
oooo00<0003o0?ooo`3oool0>@3oool00?l0oooo0@3oool00`000?l0oooo
0?ooo`0F0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo
0P3o00080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo01H0oooo
00<0003o0?ooo`3oool0>@3oool00?l0oooo0P000?lH0?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0F0?ooo`80003o>P3o
ool00=d0oooo?0000?l00`3o0000003o0000o`0I0000o`030?l000000?l0
003o0100003o00<0o`000000o`000?l04@000?l00`3o0000003o0000o`0I
0000o`030?l000000?l0003o03X0003o603oool00?l0ooooB@3oool00`00
0000oooo0?ooo`220?ooo`00o`3ooom90?ooo`030000003oool0oooo0880
oooo001o0?ooo`800000^03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0880oooo00200?ooo`030000003oool0oooo0:l0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`@00000
1@3oool00`000000oooo0?ooo`220?ooo`00P@3oool00`000000oooo0?oo
o`2_0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`<00000PP3oool00800oooo00<0
00000?ooo`000000/@3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`220?ooo`00O`3oool010000000oooo0?ooo`00002a0?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0880oooo001n0?ooo`<0000000<0oooo
000000000000[`3oool5000000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo08P0oooo003o0?ooocd0oooo00@00000
0?ooo`3oool0oooo0P00002;0?ooo`00o`3oooo>0?ooo`00o`3oooo>0?oo
o`00o`3oooo>0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{461, 132},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The function  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ Log \((\(1\  + \ z\)\/\(1\  - \ z\))\)\)\)],
    
    AspectRatioFixed->True],
  "  is the composition of the bilinear transformation  ",
  Cell[BoxData[
      \(Z\  = \ \(1\  + \ z\)\/\(1\  - \ z\)\)],
    AspectRatioFixed->True],
  "  followed by the logarithmic mapping  ",
  Cell[BoxData[
      \(w\  = \ Log \((Z)\)\)],
    AspectRatioFixed->True],
  ".  The image of the disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  "  under the bilinear mapping  ",
  Cell[BoxData[
      \(Z\  = \ \(1\  + \ z\)\/\(1\  - \ z\)\)],
    AspectRatioFixed->True],
  "  is the right half-plane  ",
  Cell[BoxData[
      \(Re \((Z)\) > 0\)]],
  ";  the upper semicircle is mapped onto the positive ",
  StyleBox["Y",
    FontFamily->"Courier New"],
  " axis;  and the lower semicircle is mapped onto the negative ",
  StyleBox["Y",
    FontFamily->"Courier New"],
  " axis.  The logarithmic function  ",
  Cell[BoxData[
      \(w\  = \ Log \((Z)\)\)],
    AspectRatioFixed->True],
  "  then maps the right half-plane onto the horizontal strip;  the image of \
the positive ",
  StyleBox["Y",
    FontFamily->"Courier New"],
  " axis is the line  ",
  Cell[BoxData[
      \(v = \[Pi]\/2\)]],
  ";  and the image of the negative ",
  StyleBox["Y",
    FontFamily->"Courier New"],
  " axis is the line  ",
  Cell[BoxData[
      \(v = \(-\ \[Pi]\)\/2\)]],
  ".  Figure 10.11 shows the composite mapping."
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 10.11",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/mapelementaryfun/\
MapElementaryFunFigures/mat1011.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The composite transformation  ",
  Cell[BoxData[
      \(w\  = \ Log \((\(1\  + \ z\)\/\(1\  - \ z\))\)\)],
    AspectRatioFixed->True],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f \((z)\) = Log \((\(1\  + \ z\)\/\(1\  - \ z\))\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(w = \(z = 0\); \ Remove[w, z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, solset, w, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ \ Log[\(1 + z\)\/\(1 - z\)];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To show  ",
  Cell[BoxData[
      \(f \((z)\) = Log \((\(1\  + \ z\)\/\(1\  - \ z\))\)\)],
    AspectRatioFixed->True],
  "  is one-to-one conformal we need to find the inverse function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset\  = \ Solve[w\  \[Equal] \ f[z], z];\)\ \), "\n", 
    \(\(g[w_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(Print["\<g[w] = \>", g[w]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", g[f[z]], "\< = \>", 
        Simplify[g[f[z]]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<f[g[w]] = \>", f[g[w]]];\)\ \), "\n", 
    \(\(Print["\<f[g[w]] = \>", 
        Simplify[f[g[w]]], "\< = \>", \[IndentingNewLine]PowerExpand[
          Simplify[f[g[w]]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["The image is traced using a graph.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ \ \ Log[\(1 + z\)\/\(1 - z\)];\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Identity, {0.000005, 0.999995, 0.11111}, \[IndentingNewLine]{0, 
          2  \[Pi], \[Pi]\/12}, 
        PlotRange \[Rule] {{\(-1.1\), 1.1}, {\(-1.1\), 1.1}}, 
        PlotRegion \[Rule] {{0.15, 0.85}, {0.15, 0.85}}, 
        AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[\(-1\), 1, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The unit disk |z| < 1.\>"];\)\ \), "\n", 
    \(\(PolarMap[
        f, {0.000005, 0.999995, 0.11111}, \[IndentingNewLine]{0, 
          2  \[Pi], \[Pi]\/12}, 
        PlotRange \[Rule] {{\(-3\), 3}, {\(-1.6\), 1.6}}, 
        AspectRatio \[Rule] 1.6\/3, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], 
            Range[\(-\[Pi]\)\/2, \[Pi]\/2, \[Pi]\/2]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The image is the horizontal strip |v| < \
\!\(\[Pi]\/2\),\>\""];\)\ \), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = Log \((\(1\  + \ z\)\/\(1\  - \ z\))\)\)\)],
    AspectRatioFixed->True],
  "  maps the unit disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  onto the horizontal strip  ",
  Cell[BoxData[
      \(\(\(|\)\(v\)\(|\)\(\(<\)\(\ \)\(\[Pi]\/2\)\)\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the transformation  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ \(\((1\  + \ z)\)\^2\/\((1\  - \ z)\)\^2\  \
= \ \((\(1\  + \ z\)\/\(1\  - \ z\))\)\^2\)\)\)],
    AspectRatioFixed->True],
  "  is a one-to-one conformal mapping of the portion of the unit disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  that lies in the upper half-plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  onto the upper half-plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  ".  Furthermore, the upper semicircular portion of the boundary is mapped \
onto the line negative u-axis, and the segment  ",
  Cell[BoxData[
      \(\(-1\) < x < 1, y = 0\)]],
  "  is mapped onto the positive u-axis."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000980000Q2000`400?l0
0000o`00003oo`3ooooo0?ooodX0oooo003o0?ooool0ooooBP3oool00?l0
ooooo`3ooom:0?ooo`00o`3ooooo0?ooodX0oooo003o0?ooool0ooooBP3o
ool00?l0ooooo`3ooom:0?ooo`00HP3oool5000002D0oooo0P0000040?oo
o`800000103oool2000004d0oooo0P0000040?ooo`800000103oool20000
02L0oooo1@00001D0?ooo`@00000K03oool4000003L0oooo0`00000U0?oo
o`00I03oool00`000000oooo0?ooo`0T0?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool00000B`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000002P0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0903oool006@0oooo00<000000?ooo`3oool0903o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo04T0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool0K@3oool00`000000
oooo0?ooo`0e0?ooo`D000009@3oool005`0oooo100000040?ooo`030000
003oool0oooo01h0oooo100000020?ooo`040000003oool0oooo000000T0
oooo0P00001<0?ooo`040000003oool0oooo000000T0oooo0P00000Y0?oo
o`030000003oool0oooo04h0oooo100000040?ooo`030000003oool0oooo
06d0oooo00<000000?ooo`3oool0=03oool010000000oooo0?ooo`00000V
0?ooo`00I03oool00`000000oooo0?ooo`0T0?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool0B`3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0E03o
ool010000000oooo0?ooo`00001/0?ooo`040000003oool0oooo000003H0
oooo00<000000?ooo`0000009P3oool006<0oooo0P00000W0?ooo`800000
2P3oool3000004`0oooo0P00000:0?ooo`<000009`3oool2000005L0oooo
0P00001^0?ooo`800000>03oool2000002H0oooo003o0?ooool0ooooBP3o
ool00?l0ooooo`3ooom:0?ooo`00o`3ooooo0?ooodX0oooo002o0?ooo`03
0000003oool0oooo06L0oooo0P0000000`3oool000000000003o0?oooa/0
oooo002o0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`000000
o`3oool90?ooo`@000003`3oool005`0oooo1@00001O0?l000030000o`3o
0000o`0005`0o`001@0000070?ooo`030000003oool0oooo01d0oooo3@00
0?l00`3o0000003o0000o`0f0000o`030?l000000?l0003o0100003o00<0
o`000000o`000?l010000?lP0?l000030000o`3o0000o`0005@0o`002P00
00080?ooo`040000003oool0oooo00000100oooo001Q0?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00@0
o`000?ooo`3oool000000P3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool50000o`040?l000000?l0o`000?l000@0003o1P3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00@0003o0?ooo`3oool000000`3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00P0oooo0P0000000`3oool000000000000Z0?ooo`030?l0003oool0oooo
01T0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?l000020?l000040000o`3o0000o`000?l00080003o0P3o0000
1`000?l0oooo0?l0003oool0003o0?ooo`3o00000P3oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`000?l00`000?l20?l000<0
003o1@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0B0?ooo`03
0?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool04@3oool010000000
oooo0?ooo`00000@0?ooo`00H@3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00@0003o0P3oool00`3o0000
003o0?l000020?l000040000o`3o0000oooo0?ooo`@0003o0`3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
03L0oooo00<0o`000?ooo`3oool06@3oool00`000000oooo0?ooo`060?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool01`3oool20?l0
00030000o`3o0000o`0000H0o`000`3oool30000o`030?l000000?l0003o
00<0003o00H0oooo0?l0003oool0003o0?ooo`3o00020?ooo`040000o`3o
ool0oooo0?ooo`L0003o00@0oooo0?l0003o0000003o0P3o00000`000?l0
o`000?l000040000o`030?ooo`000?l0oooo00T0oooo00<0o`000?ooo`3o
ool01P3oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo0180
oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0@0?ooo`80
000000<0oooo000000000000403oool00640oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo
0P000?l50?ooo`<0003o103oool20?l000070000o`3o0000003o0?l00000
0?l0o`000000o`020?l000040000o`3oool0oooo0?ooo`@0003o1@3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0g0?ooo`030?l0003oool0
oooo0280oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`02
0?ooo`D0o`000P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o0000
003o00@0003o00L0o`000000o`3o0000o`000000o`3o0000oooo00d0003o
0P3o00040?ooo`80o`0000D0oooo0000o`3o0000003o0?l000020000o`03
0?ooo`3o0000oooo0080oooo1@000?l70?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0J0?ooo`03
0000o`3oool0oooo02D0oooo001Q0?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0003o00<0003o00<0o`000?ooo`3oool00P3oool20?l00080003o
00L0o`000?ooo`000?l0o`000000o`3o0000oooo0080003o0P3o00040?oo
o`030?l0003oool0003o0080003o0P3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0g0?ooo`030?l0003oool0oooo0280oooo00<0003o0?oo
o`3oool03P3oool80?l000L0oooo00<0003o0?ooo`3oool00`000?l20?oo
o`090?l0003oool0o`000?l0003oool0003o0?ooo`3o000000000080o`00
00D0oooo0000o`3o0000oooo0000o`020?ooo`040?l0003oool0oooo0000
o`@0oooo1@3o00030000o`080?ooo`3o0000003o0?l000000?l0o`000000
o`3oool20?l000030?ooo`000?l0oooo00<0oooo0P000?l50?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo
0?ooo`0J0?ooo`030000o`3oool0oooo02D0oooo001Q0?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`@0003o103oool00`3o0000oooo0?ooo`020?l00080oooo0P00
0?l01`3o0000oooo0000o`3o0000003o0?ooo`3o00000P000?l20?ooo`80
o`000P3oool00`3o0000oooo0?ooo`020?ooo`@0003o103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0=`3oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00@0
oooo2P3o00030?ooo`030?l0003oool0oooo00P0oooo10000?l40?ooo`<0
o`0000L0oooo0000o`000?l0oooo0000o`3oool0003o00H0o`0000@0003o
0?ooo`3o0000o`000P3oool60?l000<0oooo10000?l02P3o0000003o0?l0
003oool0003o0?l0003oool0003o0?ooo`000?l20?l000H0oooo0P000?l3
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool04P3oool0
0`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo02D0oooo001Q0?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool40000
o`80oooo00<0003o0?ooo`3oool0103oool20?l000<0oooo00@0003o0?oo
o`3o0000oooo0P000?l0103o0000003o0000o`3o00020?ooo`040000o`3o
ool0oooo0?ooo`80o`001P3oool00`000?l0oooo0?ooo`040000o`H0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0g0?ooo`030?l0
003oool0oooo0240oooo00<0o`000000o`3o00001@3o000=0?ooo`030?l0
003oool0oooo0080oooo1P000?l20?ooo`030000o`3oool0oooo00<0o`00
00D0oooo0?l000000?l0003o0?ooo`020?l00080003o00L0o`000?ooo`3o
ool0003o0?ooo`3o0000oooo00L0o`0000H0003o0?ooo`3oool0oooo0?l0
003oool20000o`<0oooo00X0o`000000o`3oool0o`000?ooo`000?l0oooo
0?l0003oool0003o0`3oool00`3o0000oooo0?ooo`050?ooo`<0003o3`3o
ool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo01/0oooo00<0
003o0?ooo`3oool09@3oool00640oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool2
0000o`030?ooo`000?l0003o0080003o00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`020?ooo`<0o`000P3oool030000?l0oooo0?ooo`3o
0000oooo0000o`3oool0o`000?ooo`000?l0oooo0?l00080oooo0P000?l0
0`3oool0o`000?ooo`020?l000@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000003o0000o`020000o`80oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0h0?ooo`030?l0003oool0oooo01`0oooo1@3o0002
0?ooo`030000o`3oool0oooo0100oooo00<0003o0?l000000?l00P000?l7
0?ooo`040?l000000?l0o`000?l000<0oooo0P000?l00`3o0000oooo0?l0
00020?ooo`030000o`3oool0003o0080003o0P3oool00`3o0000oooo0000
o`020?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool20000o`@0oooo
00D0o`000?ooo`000?l0003o0?l000030000o`040?l000000?l0oooo0000
o`<0oooo00<0o`000?ooo`3oool01@3oool0103o0000oooo0000o`000?l=
0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool06P3oool0
0`000?l0oooo0?ooo`0V0?ooo`00H@3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`<0003o103oool00`3o0000oooo0?ooo`040?ooo`050000o`3oool0oooo
0?ooo`3o00000P3oool00`3o0000oooo0000o`020?ooo`080?l0003oool0
oooo0000o`3oool0o`000?ooo`000?l20?ooo`060?l0003oool0oooo0?oo
o`000?l0o`000`3oool0103o0000oooo0?ooo`000?l60?ooo`030?l0003o
ool0oooo0080oooo10000?l40?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo03P0oooo00<0
o`000?ooo`3oool05`3oool50?l000L0oooo00<0003o0?ooo`3oool0303o
ool40000o`030?ooo`3o0000oooo00L0oooo0P3o00000`3oool0003o0?oo
o`020?ooo`80003o0P3oool20?l00080oooo00D0003o0?ooo`3o00000000
0?ooo`030000o`80oooo00@0003o0?ooo`3oool0o`000`3oool40000o`04
0?ooo`3o0000oooo0?ooo`80o`0000@0oooo0000o`3oool0o`000P3oool0
10000?l0oooo0?ooo`3o00020?ooo`040000o`3oool0oooo0?ooo`80o`00
1@3oool0103o0000oooo0?ooo`3oool20000o`/0oooo00<0003o0?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo02H0
oooo001Q0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0003o00<0003o00<0oooo0000o`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o0000o`0000@0oooo
00D0003o0?ooo`3oool0oooo0?l000020?ooo`050000o`3oool0o`000?oo
o`000?l00P3oool01P3o0000oooo0?ooo`3oool0o`000000o`@0oooo0P3o
00000`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`000?l00`3oool0o`000?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0h0?ooo`030?l0003o
ool0oooo0140oooo1P3o000<0?ooo`030000o`3oool0oooo00T0oooo0`00
0?l60?ooo`030?l0003oool0oooo0080oooo0`3o00040?ooo`<0003o0P3o
ool20?l00080oooo0P3o00001@3oool0o`000?ooo`000000003o0080oooo
00<0o`000000o`000?l020000?l50?ooo`80o`000P3oool010000?l0oooo
0?ooo`3o00020?ooo`040000o`3oool0oooo0?l00080oooo00<0003o0?oo
o`3oool00`3oool01@3o0000oooo0?ooo`3oool0o`0000H0oooo0`000?l7
0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool06P3oool0
0`000?l0oooo0?ooo`0V0?ooo`00H@3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00<0oooo00@0003o0?ooo`3oool0oooo10000?l50?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool20?l000D0oooo00D0003o
0?ooo`3o0000oooo0?l000020?ooo`060000o`3oool0oooo0?l0003oool0
003o0`3oool01@3o0000oooo0?l0003oool0003o00D0oooo00<0003o0?l0
003oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo10000?l30?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0h0?ooo`030?l0003oool0oooo00/0oooo1P3o000B0?oo
o`030000o`3oool0oooo00D0oooo10000?l90?ooo`030?l0003oool0oooo
0080o`001P3oool30000o`80oooo00<0o`000?ooo`3oool00P3oool01`00
0?l0oooo0?l0003o0000oooo000000000?l00P3oool0103o0000oooo0?oo
o`000?l20?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3o00001@3oool0o`000?ooo`3oool0003o0080oooo00@0o`000?ooo`3o
ool0003o0P3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00<0o`00
0?ooo`3o00002P3oool20000o`@0oooo00<0003o0?ooo`3oool04`3oool0
0`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo02H0oooo001Q0?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool40000o`<0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
0080o`000P3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo0P3o0002
0?ooo`040000o`3oool0oooo0?l00080oooo00<0003o0?ooo`3oool00P3o
00030?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool20?l000<0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`040?l0
003oool0oooo0?ooo`@0003o1P3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo03T0
oooo00<0o`000?ooo`3oool00`3oool70?l001T0oooo00<0003o0?ooo`3o
ool010000?l>0?ooo`80o`001P3oool20000o`<0oooo00<0003o0?l0003o
ool00`3oool00`000?l0oooo0?ooo`030?l000040000o`3oool0oooo0?l0
00<0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`<0o`00103oool0
0`3o0000003o0?ooo`020?ooo`040?l0003oool0oooo0000o`80oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00/0oooo0`000?l00`3oool0003o0?ooo`0D0?ooo`030?l0003o
ool0oooo01X0oooo00<0003o0?ooo`3oool09`3oool00640oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0000o`030000o`030?ooo`000?l0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
o`0000D0oooo00<0003o0?ooo`000?l0103oool01`3o0000oooo0?l0003o
0000003o0?l0003oool00`3o00001@000?l0o`000?l0003oool0o`0000@0
oooo00@0003o0?ooo`3oool0003o103oool30?l000H0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`D0003o00<0oooo0?l0
003oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0i0?ooo`H0o`00803oool30000oa00oooo0`3o00050?oo
o`80003o1@3oool0103o0000003o0?ooo`3oool20000o`80oooo00@0o`00
0?ooo`3oool0oooo103o00030?ooo`040000o`3oool0oooo0?ooo`@0o`00
00<0003o0?ooo`3oool00`3oool20000o`80o`0000<0oooo0?l0003oool0
0P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?l0000?0?ooo`80003o5@3oool00`3o0000
oooo0?ooo`0J0?ooo`030000o`3oool0oooo02L0oooo001R0?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo
0`000?l50?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`80o`001`3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o0000
0`3o00001@000?l0oooo0?ooo`3oool0o`0000D0oooo0P000?l70?ooo`80
o`00103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool40000o`<0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0=03oool60?l00280
oooo0`000?l00`3oool0003o0?ooo`0>0?ooo`80o`000`3oool00`3o0000
oooo0?ooo`020000o`H0oooo00<0o`000?ooo`3oool00P000?l30?ooo`06
0?l0003oool0oooo0?ooo`000?l000000P3oool90?l000@0oooo00D0003o
0?ooo`3oool0oooo0000o`040?ooo`80o`000`3oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00@0003o0?l0003o0000o`000`3oool00`3o0000
oooo0?ooo`0<0?ooo`040000o`3oool0003o0000oa80oooo00<0o`000?oo
o`3oool06`3oool00`000?l0oooo0?ooo`0W0?ooo`00HP3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool50000o`80oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00@0003o0?ooo`3oool0oooo0P3o00000`3oool0o`000?ooo`050?oo
o`80003o103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0o`00
0?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo0P00
0?l60?ooo`040?l0003oool0oooo0?l000<0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool010000?l60?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`0^0?ooo`H0o`001P3oool00`3o0000oooo0?ooo`0M0?ooo`80003o
103oool00`000?l0oooo0?ooo`0;0?ooo`80o`001@3oool00`3o0000oooo
0000o`070?ooo`040?l0003oool0oooo0?ooo`80003o0`3oool01P3o0000
oooo0?ooo`3oool0003o00000080oooo00D0o`000?ooo`3oool0oooo0000
o`030?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`000?l0003o
1@3oool40?l000030000o`3oool0oooo0080oooo00H0o`000?ooo`3oool0
oooo0?l000000?l70?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool00P3oool20000oa00oooo00<0o`000?ooo`3oool06`3oool00`00
0?l0oooo0?ooo`0W0?ooo`00HP3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool010000?l60?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0o`000?l0
00@0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l2
0?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`000?l0003o
0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
0P3o00000`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`@0003o
0P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0:`3oool30?l000`0oooo
00<0o`000?ooo`3oool06P3oool30000o`H0oooo00<0003o0?ooo`3oool0
203oool30?l000L0oooo00<0003o0?l0003oool01P3oool01@3o0000oooo
0?ooo`3oool0003o0080oooo0`000?l40?ooo`050000o`000000oooo0?oo
o`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0003o
0?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0003o00T0o`000P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool0103oool20000o`d0oooo00<0o`000?ooo`3oool0703o
ool00`000?l0oooo0?ooo`0W0?ooo`00HP3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo10000?l4
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool0103o0000oooo0?ooo`000?l40?ooo`80003o00<0
o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000003o0?ooo`040?ooo`040000
o`3oool0oooo0?l000L0oooo0P3o00050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`04
0000o`3oool0oooo0?ooo`@0003o103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo03X0oooo00<0o`000?oo
o`3oool05`3oool30000o`X0oooo00<0003o0?ooo`3oool01@3oool20?l0
00T0oooo00@0003o0?ooo`3oool0o`00103oool20?l000@0oooo00H0003o
0?ooo`3oool0oooo0?l0003oool20000o`060?ooo`000?l0oooo0000003o
ool0o`00103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
0080003o00<0oooo0000o`000?l00`3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo0P000?l90?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool06`3oool00`00
0?l0oooo0?ooo`0X0?ooo`00HP3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`D0003o00<0oooo0?l0003oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`020?ooo`80o`0000<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0000o`060?ooo`060?l0003oool0003o0000
o`3oool0003o103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0
003o0?ooo`3o00001P3oool00`000?l0oooo0?l000060?ooo`030000o`3o
ool0oooo0080o`000`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0003o00@0003o1P3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0k0?ooo`030?l0003oool0oooo01@0oooo0`00
0?l=0?ooo`030000o`3oool0oooo00<0oooo0P3o00090?ooo`80003o103o
ool0103o0000oooo0?l0003o00050?ooo`030000o`3oool0oooo0080oooo
00@0o`000?ooo`3oool0oooo0P000?l0103oool000000?ooo`3o00040?oo
o`030000o`3oool0oooo00D0003o103oool010000?l0oooo0?ooo`3o0005
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool02P3oool20000o`T0oooo00<0o`000?ooo`3oool0703oool0
0`000?l0oooo0?ooo`0X0?ooo`00HP3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0103o
0000oooo0?ooo`3oool30000o`H0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool0103o0000oooo0?l0003o00030?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`020?ooo`<0003o0`3oool00`3o0000oooo0?ooo`020?ooo`<0003o0`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?l000060?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo10000?l20?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo03`0oooo00<0o`000?ooo`3oool0403o
ool30000oa40oooo00<0003o0?ooo`3oool00P3o000:0?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00<0oooo30000?l30?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?l0003oool0103oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00d0oooo0P00
0?l70?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool0:@3o
ool006<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo10000?l30?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool2
0?l000H0oooo00<0003o0?ooo`3oool0103oool00`000?l0o`000?ooo`04
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`000?l00P000?l0
0`3o0000003o0000o`030000o`D0oooo00<0o`000?ooo`3oool00P3oool2
0?l000030?ooo`000?l0oooo00@0oooo00<0003o0?ooo`3oool0103oool2
0?l000H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
10000?l0oooo0?ooo`3oool30000o`H0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo03`0oooo00<0
o`000?ooo`3oool03P3oool20000oaD0oooo00<0003o0?l0003oool02P3o
ool00`000?l0oooo0?ooo`050?ooo`040?l0003oool0o`000?l000<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`060000
o`3oool0oooo0000003oool0o`00103oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0o`000000o`000?l0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01`3oool01@3o0000oooo0?ooo`3oool0003o0180oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0
oooo02T0oooo001S0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040000o`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0o`0000L0oooo00<0003o0?oo
o`3oool00P3oool010000?l0oooo0?ooo`3o00030?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00@0oooo00@0o`000?ooo`3oool0o`00103o
ool01@000?l0oooo0?ooo`3oool0003o00L0oooo00<0o`000?ooo`3o0000
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00@0oooo00<0o`000000o`000?l00P000?l20?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0m0?ooo`030?l0003oool0oooo00/0oooo0`000?lE0?ooo`80o`00
00<0003o0?ooo`3oool0203oool20000o`L0oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0000o`050?ooo`030?l0003oool0oooo00<0oooo
00H0003o0?ooo`3oool000000?ooo`3o00040?ooo`030000o`3oool0oooo
00@0oooo00@0o`000?ooo`3oool0oooo0P3o00030?ooo`040000o`3oool0
oooo0000o`L0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0003o01@0oooo0P000?l20?ooo`030?l0003o
ool0oooo01d0oooo00<0003o0?ooo`3oool0:@3oool006<0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`@0003o1@3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00P3o00030?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00P000?l40?ooo`<0o`001P3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?l000060?ooo`<0003o1`3oool0
103o0000oooo0?ooo`3oool20?l00080oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo0080oooo10000?l40?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0?P3oool00`3o0000oooo0?ooo`070?ooo`<0003o5P3o
ool20?l000<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`060000o`3oool0oooo0000003oool0
o`00103oool00`000?l0oooo0?ooo`040?ooo`040?l0003oool0oooo0?l0
00H0oooo0`000?l70?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0o`000?ooo`0F0?ooo`80003o00<0o`000?oo
o`3oool0703oool00`000?l0oooo0?ooo`0Z0?ooo`00H`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0003o0080003o0P3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool20?l000H0oooo00<0o`000?ooo`3o
ool0103oool20000o`P0oooo0P3o00050?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`030?ooo`80o`001`3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`000?l00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo03h0
oooo00<0o`000?ooo`3oool01@3oool20000oaL0oooo0P3o00050?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3o0000o`0000<0oooo00<0o`000?ooo`3o
ool00`3oool01`000?l0oooo0?ooo`3oool000000?ooo`3o0000103oool0
0`000?l0oooo0?ooo`050?ooo`80o`00203oool30000o`D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`<0003o0P3oool0
0`3o0000oooo0?ooo`0E0?ooo`030?l000000?l0003o01d0oooo00<0003o
0?ooo`3oool0:P3oool006<0oooo00<0003o0?ooo`3oool00`3oool20000
o`D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo0P3o00000`3o
ool0003o0?ooo`060?ooo`030?l0003oool0oooo00<0oooo0P000?l70?oo
o`030?l0003oool0oooo0080o`000`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3o00080?oo
o`030000o`3oool0003o00D0oooo00<0o`000?ooo`3oool0103oool01000
0?l0oooo0?l0003o00040?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`80003o1@3oool00`000?l0oooo0?ooo`0o0?ooo`040?l0003oool0
oooo0?ooo`<0003o5`3oool20?l000P0oooo00<0003o0?ooo`3oool00P3o
ool20000o`P0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?oo
o`3oool20?l000030?ooo`3o0000oooo00@0oooo00L0003o0?ooo`3oool0
oooo0000003oool0o`0000D0oooo00@0003o0?ooo`3oool0oooo0`3o0000
0`3oool0o`000?ooo`070?ooo`030000o`3oool0oooo0080003o0`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo0P000?l6
0?ooo`030?l0003oool0oooo01<0oooo00@0o`000?ooo`3oool0oooo0P00
0?lJ0?ooo`030000o`3oool0oooo02/0oooo001T0?ooo`D0003o00<0oooo
0?l0003oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3oool0o`000`3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo00@0
003o0?ooo`3oool0003o1P3oool00`3o0000oooo0?ooo`020?ooo`<0o`00
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3o0000o`0000D0oooo00<0o`000?ooo`3oool00`3oool20000o`80oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`050000
o`3oool0oooo0?ooo`3o00000`3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0000o`050000od40oooo00@0o`000000o`00
0?l0003o603oool20?l000/0oooo00@0003o0?ooo`3oool0003o2@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo0P3o0004
0?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`3o00001@3oool0
10000?l0oooo0?l0003o00040?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool00`3oool30000o`030?l000000?l0oooo00H0oooo1@00
0?l80?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool0103o
ool20000oaP0oooo00<0003o0?ooo`3oool0:`3oool006@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool3
0?l000D0oooo00<0003o0?ooo`3oool01@3oool0103o0000oooo0?ooo`00
0?l40?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0o`000?l0000:0?l000030000o`3oool0oooo00H0oooo00D0
o`000?ooo`3oool0oooo0000o`050?ooo`040000o`3oool0oooo0?l000L0
oooo00<0003o0?ooo`3oool00`3oool30?l000H0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0?`3oool20000o`03
0?l0003oool0oooo01H0oooo0P3o000>0?ooo`80003o2@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
00001P3o00020?ooo`040000003oool0o`000?ooo`H0o`001`3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`000?l01P000?l00`3oool0003o0?ooo`0;0?ooo`030?l0003oool0oooo
0140oooo00<0o`000?ooo`3oool01P3oool20000oaD0oooo00<0003o0?oo
o`3oool0;03oool006@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool20?l000L0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000003o0?ooo`050?ooo`80003o0P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`040?l0003oool0003o0000
o`L0oooo00<0003o0?ooo`3o00001`3oool00`000?l0oooo0?ooo`050?oo
o`80o`001@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0l0?ooo`<0003o0P3oool00`3o0000oooo0?ooo`0E0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`000?l0203oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`060?l000@0oooo00<0003o0?oo
o`3oool01`3oool01@3o0000oooo0?ooo`3oool0003o00X0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo0100oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0A
0?ooo`030000o`3oool0oooo02d0oooo001T0?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`040000o`3oool0oooo0?ooo`80o`0000<0oooo
0?l0003oool01`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o0000
oooo00L0oooo00<0003o0?l0003oool01`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?l00080oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0>P3oool2
0000o`H0oooo00<0o`000?ooo`3oool04P3oool20?l000l0oooo00D0003o
0?ooo`3oool0oooo0000o`070?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<000000?ooo`3o00001P3oool00`000?l0oooo0?oo
o`070?ooo`040?l0003oool0oooo0000o`X0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00d0oooo
0P3o000=0?ooo`80003o4@3oool00`000?l0oooo0?ooo`0]0?ooo`00I@3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0o`000?l0
00040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3o
ool010000?l0oooo0?ooo`3o00070?ooo`040?l0003oool0003o0000o`H0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo0P000?l00`3o0000oooo0?ooo`070?ooo`03
0?l0003oool0003o00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0003o00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo03P0oooo0`000?l80?ooo`030?l0003oool0oooo0100
oooo0P3o000?0?ooo`80003o1@3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`3o
00001P3oool00`000?l0oooo0?ooo`080?ooo`030?l000000?l0oooo00T0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00X0oooo0P3o000A0?ooo`030000o`3oool0oooo00d0
oooo00<0003o0?ooo`3oool0;P3oool006D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo0P3o00060?ooo`030?l0003oool0oooo00H0oooo
00D0003o0?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo00@0
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?oo
o`80003o0`3oool00`3o0000oooo0?ooo`040?ooo`80o`000`3oool01@00
0?l0oooo0?ooo`3oool0003o00P0oooo00<0o`000?ooo`3oool0103oool2
0?l000D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo03H0oooo0P000?l<
0?ooo`030?l0003oool0oooo00d0oooo0P3o000@0?ooo`030000o`3oool0
oooo00H0oooo0P000?l20?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo0080oooo00<000000?ooo`3o00001`3oool00`000?l0oooo0?ooo`06
0?ooo`80003o00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00/0oooo00<0003o
0?ooo`3oool0;`3oool006D0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`050?l0003oool0oooo
0?ooo`3o00000P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00@0003o0?ooo`3oool0003o1P3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo00<0oooo1@000?l70?ooo`030?l0003o
ool0oooo00D0oooo00@0003o0?ooo`000?l0003o1@3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool0
003o1`3oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo0?l0
00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo03<0oooo0`000?l>0?oo
o`030?l0003oool0oooo00/0oooo0P3o000A0?ooo`030000o`3oool0oooo
00T0oooo00<0003o0?l0003oool0203oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`00
0000oooo0?l000080?ooo`030000o`3oool0oooo00@0oooo00@0003o0?oo
o`3oool0oooo0P3o00070?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0
oooo01@0oooo0P000?l;0?ooo`030000o`3oool0oooo02l0oooo001V0?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool30?l000<0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`80003o203oool20?l00080oooo00<0o`000?oo
o`3oool01`3oool80000o`030?l0003oool0003o00L0003o203oool01@3o
0000oooo0?ooo`3oool0o`0000P0oooo0P000?l70?ooo`030?l0003oool0
oooo00D0oooo00@0003o0?ooo`3oool0oooo0P3o00000`3oool0o`000?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0<@3oool20000oa80oooo00<0o`000?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0?0?ooo`80003o303oool00`3o0000003o0000
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`020?ooo`030000003oool0o`0000P0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00@0oooo0P3o000I0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool0<03oool006H0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`02
0?ooo`<0o`001P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo0P000?l:0?ooo`80o`002P3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3o0000003o00H0oooo00<0003o0?ooo`3oool0203oool3
0?l000T0oooo0`000?l50?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool30?l000@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0`0?ooo`80003o5@3oool0
0`3o0000oooo0?ooo`060?ooo`80o`004@3oool00`000?l0oooo0?ooo`0;
0?ooo`040?l0003oool0oooo0?ooo`80003o1@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool00P3o
ool010000000oooo0?ooo`3o00080?ooo`030000o`3oool0003o0080003o
203oool20?l000<0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo0080oooo0P3o000L0?ooo`80003o
1`3oool00`000?l0oooo0?ooo`0`0?ooo`00IP3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080o`000`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020000o`T0oooo0P3o
00080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00D0
003o0?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?l00080oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`170?ooo`030?l0003oool0oooo00@0oooo0P3o000B0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool00`3oool20000o`80oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`80003o
103oool010000000oooo0?ooo`3o00080?ooo`80003o3@3oool20?l00003
0?ooo`3o0000oooo00/0oooo00<0003o0?ooo`3oool03`3oool0103o0000
oooo0?l0003o000P0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0<@3oool006L0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool20?l000D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`060?ooo`040?l0003oool0oooo0000o`D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`020?l000H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00@0oooo0`3o00000`3oool0o`000?ooo`060?ooo`80003o1@3oool00`00
0?l0oooo0?l000080?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool00P3oool20?l000H0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0B@3oool0103o0000oooo0?ooo`3oool20?l001<0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`060?ooo`<0003o1`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00@00000
0?ooo`3oool0o`001P3oool20000o`80oooo00<0003o0?ooo`3oool0303o
ool20?l000`0oooo00<0003o0?ooo`3oool03P3oool30?l002<0oooo00D0
003o0?ooo`3oool0oooo0000o`0d0?ooo`00I`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030?l000000?l0oooo00H0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030?l00000
0?l0oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo0P3o
00040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0o`000?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0o`000?l000040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo04X0oooo0`3o000D0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0203oool40000o`D0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`040000003o
ool0oooo0?l000@0oooo0P000?l50?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3o00000P3o00090?ooo`030000o`3oool0oooo00`0oooo
0P3o00020?ooo`030?l0003oool0oooo0280oooo0`000?le0?ooo`00I`3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?l00080oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?l0003oool01`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00@0oooo103o00000`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o00000P3o
00070?ooo`040?l0003oool0oooo0?ooo`80003o203oool00`3o0000003o
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool010000?l0oooo0?ooo`3oool20?l000030?ooo`3o0000oooo00H0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo04/0oooo0P3o000D0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool02@3oool010000?l0oooo0?ooo`3oool30000
o`80oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?oo
o`060000003oool0oooo0?ooo`3o0000oooo0P000?l70?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool00`3oool40?l000D0oooo00<0
003o0?ooo`3oool02@3oool30?l000@0oooo00<0o`000?ooo`3oool08`3o
ool20000ocD0oooo001X0?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`80o`00103oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?l000L0oooo0P000?l0
0`3oool0o`000?ooo`0:0?ooo`030000o`3o0000o`0000<0o`00103oool0
0`3o0000oooo0?ooo`030?ooo`@0o`0000<0003o0?ooo`3oool0203oool0
103o0000oooo0000o`000?l90?ooo`040?l0003oool0oooo0000o`D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00<0oooo0P3o00060?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`1:0?ooo`030?l0
003oool0o`0001<0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00D0oooo1@000?l60?ooo`030000
o`3oool0oooo00<0oooo1P000?l:0?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool01`3oool50?l000030000o`3o0000o`0000T0o`00
203oool00`3o0000oooo0?ooo`0Q0?ooo`040000o`3oool0oooo0000oc@0
oooo001X0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`020?ooo`<0o`001P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00D0003o0?ooo`3oool0
oooo0000o`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?l0003o
ool02P3oool00`000?l0oooo0?ooo`030?ooo`X0o`00103oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00L0oooo0P3o00040?ooo`05
0000o`3oool0oooo0?ooo`000?l0203oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo0`3o00050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`180?oo
o`80o`000`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00`0003o00D000000?ooo`3oool0oooo0?l0000<
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0200oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0a0?ooo`00J@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00D0003o0?oo
o`3oool0oooo0?l000030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
003o00L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000003o0000o`09
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`070?ooo`80003o00<0oooo0?l0003oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`040000o`3oool0oooo0000o`L0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`040?l0003o
ool0oooo0?ooo`80o`000P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0B03oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
4P3oool00`3o0000oooo0?ooo`0M0?ooo`80003o1P3oool20000oc40oooo
001Y0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0o`000?l000040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool0103oool0103o0000oooo0?oo
o`3oool20000o`H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00D0oooo0P000?l30?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool20000o`L0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo0P3o00000`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0A`3oool00`3o0000oooo
0?ooo`060?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
4P3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00P0oooo
00<0003o0?ooo`3oool0;P3oool006X0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`80o`001`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0000o`090?ooo`80o`00103oool00`3o0000oooo0?oo
o`030?ooo`80003o103oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool20000o`H0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`080?ooo`80003o1P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0o`000?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0AP3oool20?l000X0oooo0P3o
000:0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool06P3o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo02d0oooo001Z
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00P3o0002
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo00@0003o
0?ooo`3oool0oooo0P000?l90?ooo`040?l0003oool0oooo0?l000P0oooo
1@000?l:0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`000?l0
0P000?l90?ooo`040?l0003oool0o`000?l000T0oooo0P000?l20?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo00@0003o0?ooo`3o
0000o`000`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
04D0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo
00/0oooo00@0003o0?ooo`3oool0o`004`3oool00`000?l0oooo0?ooo`0C
0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0/0?ooo`00J`3oool00`000?l0oooo0?ooo`050?oo
o`80o`001@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool0103o0000oooo0?ooo`000?l6
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o0000303oool4
0000o`L0oooo00<0o`000?ooo`3oool01@3oool50000o``0oooo0P3o000:
0?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`00203o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?l000060?ooo`030000o`3o
ool0oooo04D0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?l0003oool04P3oool00`000?l0oooo0?oo
o`0E0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`0[0?ooo`00J`3oool00`000?l0oooo0?ooo`04
0?ooo`80o`001P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000003o0?ooo`07
0?ooo`030000o`3oool0oooo00L0oooo0P3o000;0?ooo`030000o`3oool0
oooo0080oooo1`000?l00`3o0000003o0000o`050000o`<0oooo00<0003o
0?ooo`3oool02P3oool30?l000P0oooo0P000?l70?ooo`030000o`3o0000
oooo00L0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo0P3o00060?ooo`030000o`3oool0
oooo04@0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0
oooo00/0oooo00<0o`000000o`3oool04P3oool00`000?l0oooo0?ooo`0E
0?ooo`030?l0003oool0oooo01D0oooo0P000?lB0?ooo`030000o`3oool0
oooo02X0oooo001/0?ooo`040000o`3oool0oooo0?ooo`80o`000P3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o0000
oooo00P0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`02
0?l000<0oooo0P0000040?ooo`030000o`000000oooo00<0oooo0P000004
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01`3oool2
0?l00080oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`07
0?ooo`030?l000000?l0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00@0o`00
0?ooo`3o0000o`000`3oool00`000?l0oooo0?ooo`130?ooo`80o`00503o
ool0103o0000oooo0?ooo`000?lA0?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`090?ooo`030?l0003oool0oooo0080003o4@3oool00`000?l0oooo
0?ooo`0E0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0
4`3oool00`000?l0oooo0?ooo`0Y0?ooo`00K@3oool00`000?l0o`000?l0
00040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00@0
003o0?ooo`3oool0o`002@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo0080oooo0`3o00020?ooo`050000003oool0oooo0?ooo`00
0?l0103oool010000000oooo0?ooo`0000030?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool01@3oool20?l000D0oooo00<0o`000?oo
o`3oool00P3oool20000o`T0oooo00@0o`000?ooo`3oool0003o1@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`80o`0000<0oooo
0000o`3oool0@`3oool00`3o0000oooo0?ooo`0E0?ooo`030?l000000?l0
oooo0100oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool00P3oool0
0`000000oooo0?ooo`050?ooo`030?l0003oool0oooo00P0oooo00<0o`00
0?ooo`3oool00`3oool20000o`l0oooo00<0003o0?ooo`3oool05P3oool0
0`3o0000oooo0?ooo`0A0?ooo`80003o5`3oool20000obT0oooo001]0?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00D0003o0?oo
o`3oool0oooo0000o`040?ooo`80o`00203oool20000o`<0oooo00<0o`00
0?ooo`3oool01@3oool010000000o`000?l0003o00030?ooo`030000o`3o
ool0oooo00D0oooo00H000000?ooo`3oool0oooo0?l00000000:0?ooo`03
0000o`3oool0oooo00<0oooo0P3o00070?ooo`050?l0003oool0oooo0?oo
o`000?l02P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`120?ooo`030?l0003oool0oooo01H0oooo00<0003o0?l0
003o00003`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool02P3oool01@000?l0oooo0?ooo`3oool0
000000P0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`80003o3@3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0
oooo00l0oooo0P000?lK0?ooo`030000o`3oool0oooo02H0oooo001^0?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`000?l01`3oool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo
0?l000L0oooo00@000000?ooo`3oool000000P3o00000`000?l0oooo0?oo
o`040?ooo`800000103oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00<0o`002P3oool00`3o0000003o0000o`0:0?ooo`030?l0003o
ool0oooo00@0oooo00@0003o0?ooo`3oool0003o1P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`100?ooo`80o`00603oool01@000?l0oooo
0?ooo`3oool0o`0000h0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00D0003o0?ooo`3o
ool0oooo000000090?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool02@3oool20000o`/0oooo00<0003o0?ooo`3oool05P3oool00`3o
0000oooo0?ooo`0=0?ooo`80003o7P3oool00`000?l0oooo0?ooo`0U0?oo
o`00K`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
o`000?ooo`070?ooo`040000003oool0oooo00000080oooo00@0003o0?l0
003o0000o`000`3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0
oooo00T0oooo00<0o`000000o`3o00003@3oool00`000?l0o`000?ooo`09
0?ooo`030?l0003oool0oooo00H0oooo0P000?l60?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo0400oooo00<0o`000?ooo`3oool0603oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00L0oooo0`0000001@000?l0oooo0?ooo`3oool0000000X0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`80003o203o
ool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo00T0oooo0`00
0?lQ0?ooo`030000o`3oool0oooo02@0oooo001_0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`000?l02@3oool2
0?l000P0oooo00<0o`000000o`3oool01`3oool2000000<0oooo00@0003o
0?ooo`3oool0oooo5@3o00000`3oool0003o0?ooo`0;0?ooo`80003o00<0
oooo0?l0003oool0203oool00`3o0000oooo0?ooo`070?ooo`80003o1@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0o0?ooo`030?l0003o
ool0oooo01P0oooo00<0003o0?ooo`3oool0103oool20?l000X0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00L0oooo00@000000?ooo`3oool0003o0`3oool00`000000oooo
0?ooo`080?ooo`030?l0003oool0oooo0080o`004@3oool30000o`D0oooo
00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`070?ooo`80003o
9@3oool00`000?l0oooo0?ooo`0S0?ooo`00L03oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0?ooo`80003o
2@3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080003o
2`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool010000?l0oooo
0?ooo`000?l40?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo03h0
oooo0P3o000J0?ooo`030000o`3oool0oooo00L0oooo0P3o00070?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`080?ooo`040000003oool0oooo0000o`80oooo0`0000090?oo
o`80o`005P3oool30000o`80oooo00<0003o0?ooo`3oool0603oool00`3o
0000oooo0?ooo`040?ooo`<0003o:03oool00`000?l0oooo0?ooo`0R0?oo
o`00L03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool0103o0000oooo0?ooo`000?l60?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`<0003o1`3oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool01P3oool20000
o`D0oooo00<0o`000?ooo`3oool00`3oool20?l000T0oooo00<0003o0?oo
o`3oool00P3oool010000?l0oooo0?ooo`3o00070?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0n
0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool02P3oool2
0?l000@0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00T0oooo00<000000?ooo`000?l00P3oool0
0`000000oooo0?ooo`070?ooo`80o`0000<0oooo0?l0003oool0603oool4
0000oaT0oooo00<0o`000?ooo`3oool010000?l/0?ooo`030000o`3oool0
oooo0240oooo001a0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l000000?l0oooo
00L0oooo00<0003o0?ooo`3oool01`3oool20?l00080oooo00<0o`000?oo
o`3oool01P3oool30000o`@0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00<0oooo0`000?l80?oo
o`030?l0003oool0oooo0080o`002@3oool20000o`H0oooo00<0003o0?l0
003oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0?P3oool00`3o0000oooo0?ooo`0I0?oo
o`030000o`3oool0oooo00d0oooo0P3o00020?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`070?oo
o`050000003oool0oooo000000000?l00P3oool00`000000oooo0?ooo`05
0?ooo`80o`000`3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0
oooo00@0003o503oool20000o`030?l000000?l0oooo0300oooo00<0003o
0?ooo`3oool0803oool00780oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?l0
003oool0203oool00`000?l0oooo0?ooo`080?ooo`80o`00303oool20000
o`80oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0003o00<0003o2`3oool30?l000X0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000003o0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0l0?oo
o`80o`006`3oool00`000?l0oooo0?ooo`0@0?ooo`80o`003`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00P0oooo0P0000001@3o
ool0003o0?ooo`3oool0000000D0oooo0P3o00060?ooo`030?l0003oool0
oooo01L0oooo00<0003o0?ooo`3oool0103ooolD0000o`80oooo00<0o`00
0?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0O0?ooo`00LP3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool010000?l0oooo0?ooo`3o00090?ooo`030000o`3oool0
oooo00P0oooo0P3o000=0?ooo`D0003o2`3oool00`3o0000oooo0?ooo`0:
0?ooo`<0003o3`3oool20?l000X0oooo00<0003o0?ooo`3oool01P3oool0
103o0000oooo0?ooo`000?l50?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0l0?ooo`030?l0003o
ool0oooo01X0oooo00<0003o0?ooo`3oool04P3oool30?l000d0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0000000<0oooo0P3o00090?ooo`030?l0003oool0oooo01D0oooo00<0
003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0b0?ooo`030000o`3o
ool0oooo01h0oooo001c0?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0003o00@0oooo0P3o
00080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P3o
000<0?ooo`040000o`3oool0oooo0?ooo`H0003o1@3oool00`3o0000oooo
0?ooo`040?ooo`H0003o0P3oool00`000?l0oooo0?ooo`0;0?ooo`80o`00
0P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00L0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1I0?ooo`03
0000o`3oool0oooo0180oooo00@0o`000?ooo`3oool0oooo103o00090?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool01000
0?l0oooo0000003oool20?l000`0oooo00<0o`000?ooo`3oool0503oool0
0`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo03<0oooo00<0003o
0?ooo`3oool07@3oool007@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0003o00L0oooo00<0o`000?oo
o`3oool01P3oool20000o`H0oooo00<0o`000?ooo`3oool00P3oool20?l0
00X0oooo00<0003o0?ooo`3oool01`3oool50000o`030?l000000?l0003o
00@0003o203oool00`000?l0oooo0?ooo`090?ooo`80o`00103oool00`3o
0000oooo0?ooo`040?ooo`80003o203oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0003o00L0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`1H0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?oo
o`3oool01@3oool50?l000@0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`@0o`003`3oool00`3o0000oooo0?ooo`0B0?oo
o`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool0=03oool00`00
0?l0oooo0?ooo`0L0?ooo`00M@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool01@3oool20?l000P0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00L0oooo0P3o00070?ooo`04
0?l0003oool0oooo0?ooo`80003o203oool20?l000P0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
05T0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0;0?oo
o`<0o`0000<0oooo0000o`3oool03@3oool00`3o0000oooo0?ooo`090?oo
o`<0o`0000<0oooo0000o`000000403oool00`3o0000oooo0?ooo`0B0?oo
o`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool0=03oool00`00
0?l0oooo0?ooo`0K0?ooo`00M@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`000?l02@3oool00`3o0000
oooo0?ooo`070?ooo`040000o`3oool0oooo0?l000X0oooo0`3o00040?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`040?ooo`<0o`002P3oool00`3o0000003o0000o`090?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`000?l01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo05T0oooo00<0003o0?oo
o`3oool04`3oool00`3o0000oooo0?ooo`0>0?ooo`D0o`002`3oool0103o
0000oooo0?ooo`3oool80?l000@0oooo00<0003o0000003oool0403oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo01h0oooo00<0o`00
0?ooo`3oool0=@3oool00`000?l0oooo0?ooo`0J0?ooo`00MP3oool00`00
0?l0oooo0?ooo`060?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3o00003@3oool20?l00080oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0o`0000<0o`00303oool0
0`000?l0o`000?ooo`090?ooo`030?l0003oool0oooo00L0oooo00@0003o
0?ooo`3oool0oooo0P000?l30?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0F@3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3oool00P3oool?0?l000d0oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo01h0oooo00<0o`000?ooo`3oool0=@3oool00`3o0000oooo0?oo
o`0J0?ooo`00M`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
003o00D0oooo0P000?l80?ooo`80o`00203oool00`3o0000003o0?ooo`0>
0?ooo`80o`0000<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<
0?ooo`030?l000000?l0o`0000h0oooo0P000?l20?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0o`0000L0oooo00<0003o0?ooo`3oool0F@3oool0
0`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0O
0?ooo`030?l0003oool0oooo03<0oooo0P3o000M0?ooo`00N03oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
0080003o3`3oool00`000?l0o`000?l000050?l000P0oooo00<0o`000?oo
o`3oool01P3oool60?l000030?ooo`000?l0oooo00`0oooo0P000?l40?oo
o`030?l0003oool0oooo00@0oooo0P3o00090?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1I0?oo
o`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00<000000000
o`3oool04P3oool20?l000`0oooo00<0003o0?ooo`3oool0803oool00`3o
0000oooo0?ooo`0a0?ooo`80o`007`3oool007T0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?l000080?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80
003o303oool00`000?l0oooo0?ooo`060?oooa40o`001`3oool00`000?l0
oooo0?ooo`090?ooo`80003o1`3oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0oooo00L0oooo0P000?l80?ooo`030?l000000?l0oooo00D0
oooo00<0003o0?ooo`3oool0F@3oool00`000?l0oooo0?ooo`0E0?ooo`03
0?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0>0?ooo`03000000000?l0oooo01@0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo0300
oooo00<0o`000?ooo`3oool07`3oool007T0oooo00<0003o0?ooo`3oool0
0`3oool01@000?l0oooo0?ooo`3oool0o`0000P0oooo00<0003o0?ooo`3o
ool01`3oool20?l00080oooo00<0o`000?ooo`3oool01@3oool40000o`P0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo00D0oooo0`000?l90?ooo`030?l0003oool0oooo0080
o`002@3oool00`000?l0oooo0?ooo`070?ooo`040?l0003oool0oooo0000
o`D0oooo00<0003o0?ooo`3oool0F@3oool00`000?l0oooo0?ooo`0D0?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0>0?ooo`030000003oool0003o01D0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo
02d0oooo0P3o000R0?ooo`00NP3oool01@000?l0oooo0?ooo`3oool0003o
00D0oooo00<0o`000?ooo`3oool01P3oool20000o`T0oooo0`3o000;0?oo
o`<0003o1@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool00`3oool20000o`d0oooo0P3o000:0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0003o05/0oooo00<0003o0?ooo`3oool05@3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool03P3oool00`000000oooo0000o`0F0?ooo`80o`001`3oool0
0`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo02`0oooo00<0o`00
0?ooo`3oool08P3oool007/0oooo00<0003o0?ooo`000?l01`3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo0`3o000=0?oo
o`80003o0`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool00`000?l>0?ooo`030?l0003oool0o`00
00T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0003o05/0oooo00<0003o0?ooo`3oool05@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool03@3oool010000000oooo0?ooo`000?lG0?ooo`80o`00103oool0
0`000?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo02X0oooo0P3o000U
0?ooo`00O03oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo0P000?l70?ooo`030?l0003oool0oooo0080o`003@3oool40000
oa00oooo00<0o`000?ooo`3oool03@3oool40000o`l0oooo0P3o00020?oo
o`030?l0003oool0oooo00D0oooo0P000?l80?ooo`80o`00203oool00`00
0?l0oooo0?ooo`1J0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
00d0oooo00@000000?ooo`3oool0003o6@3oool20?l000030?ooo`000?l0
oooo02D0oooo00<0o`000?ooo`3oool0:03oool20?l002L0oooo001m0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo0P3o000=0?oo
o`030000o`3oool0003o00@0003o2`3oool00`3o0000oooo0?ooo`090?oo
o`@0003o0P3oool00`000?l0oooo0?ooo`0;0?ooo`<0o`001@3oool00`3o
0000oooo0?ooo`020?ooo`80003o2@3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo05X0oooo00<0003o0?ooo`3oool05@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool03@3oool01@000000oooo0?ooo`3oool0003o01X0oooo00<0o`00
0000o`3oool09P3oool00`3o0000oooo0?ooo`0V0?ooo`030?l0003oool0
oooo02L0oooo001n0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool0203oool20000o`80oooo00<0o`000?ooo`3oool01P3oool30?l0
00X0oooo00<0003o0?ooo`3oool0103oool;0000o`030?l000000?l0003o
00T0003o1`3oool00`000?l0oooo0?ooo`080?ooo`80o`00203oool00`3o
0000oooo0?ooo`020000o`X0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`1J0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo
00d0oooo00D000000?ooo`3oool0oooo0000o`0J0?ooo`030000o`3o0000
o`0002H0oooo00<0o`000?ooo`3oool0903oool20?l002X0oooo001o0?oo
o`80003o203oool20?l000X0oooo00<0003o0?ooo`3o00002`3oool20?l0
00P0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0@0?oo
o`030000o`3oool0oooo00D0oooo0`3o000;0?ooo`030?l000000?l0oooo
00X0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`1K0?oo
o`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool04P3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00`0oooo00<000000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo
0080o`00903oool00`3o0000oooo0?ooo`0R0?ooo`80o`00;03oool00840
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`03
0?l000000?l0oooo00`0oooo0P3o00050?ooo`030000o`3oool0oooo0100
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`020?ooo`80
o`003@3oool00`000?l0o`000?ooo`0:0?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool0F`3oool00`000?l0oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo0180oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3o
ool05P3oool00`000?l0oooo0?ooo`030?ooo`80o`008P3oool00`3o0000
oooo0?ooo`0P0?ooo`80o`00;P3oool00880oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`040?l0003oool0003o0000o`d0
oooo0P3o00030?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?l000020?l000h0oooo00@0003o0?ooo`3o
ool0o`00203oool20?l000P0oooo0P000?mM0?ooo`030000o`3oool0oooo
01H0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo00H0oooo0P3o000P0?oo
o`030?l0003oool0oooo01h0oooo0P3o000`0?ooo`00P`3oool00`000?l0
oooo0?ooo`070?ooo`80o`001P3oool00`3o0000oooo0?ooo`020?ooo`80
003o3@3oool30?l000030000o`3oool0oooo0100oooo00<0o`000?ooo`3o
ool03P3oool30?l000030000o`3o0000oooo00h0oooo0P000?l40?ooo`03
0?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`1M0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00`0
oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`0B0?ooo`03
0000o`3oool0oooo00T0oooo0`3o000M0?ooo`030?l0003oool0oooo01X0
oooo103o000b0?ooo`00Q03oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool20000o`d0oooo
00<0003o0?ooo`3o00000`3o000>0?ooo`030?l0003oool0oooo00X0oooo
103o00030?ooo`030000o`3oool0oooo00`0oooo0P000?l60?ooo`030?l0
003oool0oooo0080oooo0P3o00090?ooo`030000o`3oool0oooo05d0oooo
00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0D0?ooo`030000
o`3oool0oooo0180oooo00<0o`000?ooo`3oool02`3oool00`000000oooo
0?ooo`050?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0
3@3oool30?l001X0oooo00<0o`000?ooo`3oool05P3oool40?l003H0oooo
00250?ooo`80003o2@3oool20?l00080oooo00<0o`000?ooo`3oool01`3o
ool20000o`/0oooo00<0003o0?ooo`3oool00`3oool:0?l000@0oooo00<0
o`000?ooo`3oool00`3oool70?l000P0oooo00<0003o0?ooo`3oool0203o
ool30000o`T0oooo00@0o`000?ooo`3oool0o`002P3oool00`000?l0oooo
0?ooo`1M0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0
503oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00/0oooo
00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0?0?ooo`030000
o`3oool0oooo0100oooo103o000F0?ooo`030?l0003oool0oooo0180oooo
103o000j0?ooo`00Q`3oool00`000?l0oooo0?ooo`080?ooo`80o`00303o
ool20000o`T0oooo00<0003o0?ooo`3oool03@3oool:0?l000l0oooo00<0
003o0?ooo`3oool01@3oool30000o``0oooo0`3o000:0?ooo`030000o`3o
ool0oooo05h0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?oo
o`0D0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool02`3o
ool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00h0oooo00<0
003o0?ooo`3oool05@3oool60?l00100oooo00<0o`000?ooo`3oool03`3o
ool30?l003h0oooo00280?ooo`80003o2@3oool20?l000d0oooo0`000?l6
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`030?ooo`80003o3`3oool20?l000T0oooo0P000?mP
0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool05@3oool0
0`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00/0oooo00<00000
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo01`0oooo103o000<0?ooo`030?l0003oool0oooo00/0oooo103o0011
0?ooo`00RP3oool20000o`H0oooo00<0o`000?ooo`3oool00P3o000>0?oo
o`<0003o0P3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo
0180oooo00<0003o0?ooo`000?l00`000?l?0?ooo`80o`0000<0oooo0?l0
003oool01P3oool20000of40oooo00<0003o0?ooo`3oool0603oool00`3o
0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?oo
o`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000o`3oool0oooo
00X0oooo00<0003o0?ooo`3oool08@3ooolJ0?l004D0oooo002<0?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool20?l000l0
oooo10000?lC0?ooo`030?l0003oool0oooo0100oooo10000?lA0?ooo`80
o`00103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0640
oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0E0?ooo`03
0000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3o
ool0;P3oool00`3o0000oooo0?ooo`1@0?ooo`00S@3oool20000o`80oooo
00<0o`000?ooo`3oool01@3oool20?l000l0oooo00<0003o0?ooo`000?l0
0`000?l?0?ooo`030?l0003oool0oooo00h0oooo0P000?l30?ooo`030000
o`3oool0oooo00d0oooo0P3o00060?ooo`040?l0003oool0oooo0?ooo`80
003oH`3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo01H0
oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0_0?ooo`030?l0003oool0oooo0500oooo002?0?ooo`030000
o`3oool0o`0000T0oooo0`3o000<0?ooo`030000o`3oool0oooo00<0oooo
1@000?l:0?ooo`030?l0003oool0oooo00H0oooo20000?l50?ooo`030000
o`3oool0oooo00X0oooo0`3o00090?ooo`030?l000000?l0003o06@0oooo
00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0F0?ooo`030000
o`3oool0oooo01@0oooo00<0o`000?ooo`3oool02@3oool00`000000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
<03oool00`3o0000oooo0?ooo`1@0?ooo`00T03oool00`3o0000003o0?oo
o`0;0?ooo`80o`002@3oool00`000?l0oooo0?ooo`090?ooo`X0003o00<0
o`000000o`000?l01P000?l=0?ooo`030000o`3oool0oooo00L0oooo0`3o
000<0?ooo`030?l0003oool0oooo06@0oooo00<0003o0?ooo`3oool06@3o
ool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01@0oooo00<0
o`000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool0<@3oool00`3o0000oooo0?oo
o`1@0?ooo`00TP3oool20000o``0oooo0`3o00060?ooo`030000o`3oool0
oooo01<0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`03
0?ooo`<0o`003@3oool20000ofH0oooo00<0003o0?ooo`3oool06P3oool0
0`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01D0oooo00<0o`00
0?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo0080003o=03oool00`3o0000oooo0?ooo`1@0?ooo`00U03oool00`00
0?l0oooo0?ooo`0<0?ooo`<0o`000`3oool00`000?l0oooo0?ooo`0C0?oo
o`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool00`3o000>0?oo
o`80003oI`3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo
01H0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`080?oo
o`030000003oool0oooo00d0oooo0P000?lf0?ooo`030?l0003oool0oooo
0500oooo002E0?ooo`80003o3`3oool30?l000030000o`3oool0oooo01<0
oooo00<0o`000?ooo`3oool0503oool00`000?l0o`000?l0000?0?ooo`80
003oJ@3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo01L0
oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`080?ooo`03
0000003oool0oooo00`0oooo0`000?lf0?ooo`030?l0003oool0oooo0500
oooo002G0?ooo`80003o3`3oool00`000?l0oooo0?l000040?l00100oooo
00<0o`000?ooo`3oool04@3oool30?l000030000o`3oool0oooo00d0oooo
0P000?mZ0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool0
5`3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00P0oooo
00<000000?ooo`3oool02`3oool01@000?l0oooo0?ooo`3oool0003o03D0
oooo00<0o`000?ooo`3oool0D03oool009T0oooo0P000?l=0?ooo`030000
o`3oool0oooo00@0oooo1P3o000:0?ooo`030?l0003oool0oooo00T0oooo
203o00040?ooo`030000o`3oool0oooo00X0oooo0P000?m[0?ooo`030000
o`3oool0oooo01/0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo
0?ooo`0F0?ooo`030?l0003oool0oooo00L0oooo00<000000?ooo`3oool0
2@3oool20000o`D0oooo00<0003o0?ooo`3oool0<P3oool00`3o0000oooo
0?ooo`1@0?ooo`00V`3oool30000o`X0oooo00<0003o0?ooo`3oool02P3o
oolF0?l000`0oooo00<0003o0?ooo`3oool01`3oool30000ofd0oooo00<0
003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3o
ool0oooo01H0oooo00<0o`000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?ooo`030000o`3oool0oooo00H0oooo0P000?lb0?ooo`030?l0003o
ool0oooo0500oooo002N0?ooo`<0003o1`3oool00`000?l0oooo0?ooo`0D
0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0103oool3
0000ofl0oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`80003o2`3oool00`000?l0oooo0?ooo`0_
0?ooo`030?l0003oool0oooo0500oooo002Q0?ooo`<0003o0`3oool00`00
0?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?oo
o`3oool00`000?ma0?ooo`030000o`3oool0oooo01`0oooo00<0o`000?oo
o`3oool06@3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0<0?oo
o`030000o`3oool0oooo02h0oooo00<0o`000?ooo`3oool0D03oool00:@0
oooo10000?lG0?ooo`030?l0003oool0oooo01H0oooo0`000?md0?ooo`03
0000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool06@3oool00`000?l0
oooo0?ooo`0H0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3o
ool00`3oool20000oa00oooo0P000?l]0?ooo`030?l0003oool0oooo0540
oooo002X0?ooo`D0003o4P3oool00`3o0000oooo0?ooo`0B0?ooo`@0003o
MP3oool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo01T0oooo
00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo
0?ooo`0Z0?ooo`030?l0003oool0oooo0540oooo002]0?ooo`@0003o1`3o
ool500000080oooo00<0o`000?ooo`3oool03@3oool50000ogX0oooo00<0
003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3o
ool0oooo01T0oooo00<0o`000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool0003o01H0oooo00<0003o0?ooo`3oool0:@3oool00`3o0000oooo
0?ooo`1A0?ooo`00/@3oool:0000o`@0oooo00<0o`000?ooo`3oool00P3o
ool;0000ogh0oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?oo
o`0J0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0103o
ool010000000oooo0000o`000?lH0?ooo`80003o:@3oool00`3o0000oooo
0?ooo`1A0?ooo`00^P3oool00`000000003o0000o`020000o`030?l00000
0?l0003o0080003oR@3oool00`000?l0oooo0?ooo`0M0?ooo`030?l0003o
ool0oooo01X0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?oo
o`030?ooo`80003o703oool00`000?l0oooo0?ooo`0V0?ooo`030?l0003o
ool0oooo0540oooo002j0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0RP3oool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0
oooo01X0oooo00<0003o0?ooo`3oool06P3oool0103o0000oooo0?ooo`3o
ool20000o`030000003oool0oooo01`0oooo0P000?lV0?ooo`030?l0003o
ool0oooo0540oooo002j0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0R@3oool20000ob00oooo00<0o`000?ooo`3oool06P3oool0
0`000?l0oooo0?ooo`0K0?ooo`<0003o0P3oool00`000000oooo0?ooo`0N
0?ooo`80003o903oool00`3o0000oooo0?ooo`1A0?ooo`00^@3oool20000
0900oooo00@0003o0?ooo`000?l0003o7P3oool00`3o0000oooo0?ooo`0J
0?ooo`030000o`3oool0oooo01P0oooo0`000?l00`3o0000oooo0?ooo`02
0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`1A0?ooo`00o`3ooom<0?ooo`040000o`3oool0oooo
0?ooo`<0003o6`3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0
oooo01H0oooo0P000?l40?ooo`050?l0003oool0oooo0?ooo`0000008`3o
ool20000ob40oooo00<0o`000?ooo`3oool0D@3oool00?l0ooooD`3oool2
0000oaT0oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0C
0?ooo`<0003o1@3oool2000000040?l0003oool0oooo000002D0oooo0P00
0?lN0?ooo`030?l0003oool0oooo0580oooo003o0?oooeD0oooo0`000?lE
0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool0403oool3
0000o`T0oooo00D000000?l0003oool0oooo0000000W0?ooo`80003o703o
ool00`3o0000oooo0?ooo`1B0?ooo`00o`3ooomH0?ooo`80003o4`3oool0
0`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00d0oooo0P000?l9
0?ooo`D0000000<0o`000?ooo`0000000P00000W0?ooo`80003o6P3oool0
0`3o0000oooo0?ooo`1B0?ooo`00o`3ooomJ0?ooo`@0003o3`3oool00`3o
0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00X0oooo0`000?l;0?oo
o`080000003oool0oooo0000003oool0o`000?ooo`00000[0?ooo`<0003o
5`3oool00`3o0000oooo0?ooo`1B0?ooo`00o`3ooomN0?ooo`H0003o2@3o
ool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00H0oooo1000
0?l?0?ooo`030000003oool000000080oooo00<0o`000000003oool0;@3o
ool20000oa@0oooo00<0o`000?ooo`3oool0D`3oool00;d0oooo0P00002T
0?ooo`D0003o103oool00`3o0000oooo0?ooo`0L0?ooo`040000o`3oool0
oooo0?ooo`D0003o503oool2000000<0oooo00<0o`000?ooo`3oool0;P3o
ool20000oa80oooo00<0o`000?ooo`3oool0D`3oool00;h0oooo00<00000
0?ooo`3oool0Y`3oool90000oa@0oooo2P000?lN0?ooo`030?l0003oool0
oooo0300oooo0`000?l?0?ooo`030?l0003oool0oooo05<0oooo002o0?oo
o`030000003oool0oooo0:X0oooo00<0o`000?ooo`3oool00P3ooolD0000
o`L0oooo00<0003o0?ooo`3oool07P3oool00`000000o`000?ooo`0c0?oo
o`80003o303oool00`3o0000oooo0?ooo`1D0?ooo`00_P3oool00`000000
oooo0000002Z0?ooo`030?l0003oool0oooo01h0oooo00<0003o0?ooo`3o
ool07P3oool00`000000oooo0?l0000e0?ooo`<0003o2@3oool00`3o0000
oooo0?ooo`1D0?ooo`00_@3oool010000000oooo0?ooo`00002Z0?ooo`03
0?l0003oool0oooo01h0oooo00<0003o0?ooo`3oool07P3oool00`000000
oooo0?l0000h0?ooo`@0003o1@3oool00`3o0000oooo0?ooo`0f0?ooo`80
003o703oool00;`0oooo0`0000000`3oool000000000002Y0?ooo`030?l0
003oool0oooo01l0oooo00<0003o0?ooo`3oool07@3oool010000000oooo
0?ooo`3o000k0?ooo`@0003o00<0oooo0?l0003oool0=@3oool20000oah0
oooo003o0?ooof`0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo
0?ooo`0M0?ooo`050000003oool0oooo0?ooo`3o0000?P3oool0103o0000
003o0000o`000?l`0?ooo`@0003o803oool00?l0ooooK03oool00`3o0000
oooo0?ooo`0O0?ooo`030000o`3oool0oooo01d0oooo00<000000?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0k0?ooo`040?l0003oool0oooo0?oo
o`X0003o703oool:0000ob@0oooo003o0?ooof/0oooo00<0o`000?ooo`3o
ool08@3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo0080
oooo00<0o`000?ooo`3oool0>`3oool00`3o0000oooo0?ooo`0;0?ooo`X0
003o1P3oool<0000obh0oooo003o0?ooof/0oooo00<0o`000?ooo`3oool0
8@3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo
00<0o`000?ooo`3oool0>P3oool00`3o0000oooo0?ooo`0E0?ooo`H0003o
>P3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{584, 132},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The function  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ \(\((1\  + \ z)\)\^2\/\((1\  - \ z)\)\^2\  \
= \ \((\(1\  + \ z\)\/\(1\  - \ z\))\)\^2\)\)\)],
    AspectRatioFixed->True],
  "  is the composition of the bilinear transformation  ",
  Cell[BoxData[
      \(Z\  = \ \(1\  + \ z\)\/\(1\  - \ z\)\)],
    AspectRatioFixed->True],
  "  followed by the mapping  ",
  Cell[BoxData[
      \(w\  = \ Z\^2\)],
    AspectRatioFixed->True],
  ".  The image of the half-disk under the bilinear mapping  ",
  Cell[BoxData[
      \(Z\  = \ \(1\  + \ z\)\/\(1\  - \ z\)\)],
    AspectRatioFixed->True],
  "  is the first quadrant  ",
  Cell[BoxData[
      \(X > 0, Y > 0\)]],
  ";  the image of the segment  ",
  Cell[BoxData[
      \(y = 0, \(-1\) < x < 1\)]],
  ",  is the positive ",
  StyleBox["X",
    FontFamily->"Courier New"],
  " axis;  and the image of the semicircle is the positive ",
  StyleBox["Y",
    FontFamily->"Courier New"],
  " axis.  The mapping  ",
  Cell[BoxData[
      \(w\  = \ Z\^2\)],
    AspectRatioFixed->True],
  "  then maps the first quadrant in the ",
  StyleBox["Z",
    FontFamily->"Courier New"],
  " plane onto the upper half-plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  ",  as shown in Figure 10.12. "
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 10.12",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/mapelementaryfun/\
MapElementaryFunFigures/mat1012.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The composite transformation  ",
  Cell[BoxData[
      \(w\  = \ \((\(1\  + \ z\)\/\(1\  - \ z\))\)\^2\)],
    AspectRatioFixed->True],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f \((z)\) = \((1\  + \ z)\)\^2\/\((1\  - \ z)\)\^2\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(w = \(z = 0\); \ Remove[w, z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, solset];\)\ \), "\n", 
    \(\(f[z_]\  = \ \ \((1 + z)\)\^2\/\((1 - z)\)\^2;\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To show  ",
  Cell[BoxData[
      \(f \((z)\) = \((1\  + \ z)\)\^2\/\((1\  - \ z)\)\^2\)],
    AspectRatioFixed->True],
  "  is one-to-one conformal we need to find the inverse function.  Since \
there is two branches, one of them is appropriate for this problem."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(solset\  = \ Solve[w\  \[Equal] \ f[z], z];\)\ \), "\n", 
    \(\(g[w_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(Print["\<g[w] = \>", g[w]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<f[g[w]] = \>", f[g[w]], "\< = \>", 
        Simplify[f[g[w]]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", g[f[z]]];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", 
        PowerExpand[g[f[z]]], "\< = \>", \[IndentingNewLine]Simplify[
          PowerExpand[g[f[z]]]]];\)\ \), "\n", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["The image is traced using a graph.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ \ \((1 + z)\)\^2\/\((1 - z)\)\^2;\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Identity, {0.000005, 0.999995, 0.066666}, \n{0, \[Pi], \[Pi]\/12}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The portion of the unit disk |z| < 1,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<that lies in the upper half-plane Im[z] > 0.\>"];\)\ \), "\n\
", 
    \(\(PolarMap[f, {0.000005, 0.999995, 0.066666}, {0, \[Pi], \[Pi]\/12}, 
        PlotRange \[Rule] {{\(-3.45\), 4.4}, {0, 4.5}}, 
        AspectRatio \[Rule] 4.5\/8.85, 
        Ticks \[Rule] {Range[\(-4\), 4, 2], Range[0, 4, 2]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image is the upper half-plane Im[w] > 0,\>"];\)\ \), "\n\
", 
    \(\(Print["\<under the mapping w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \((1\  + \ z)\)\^2\/\((1\  - \ z)\)\^2\)\)],
    AspectRatioFixed->True],
  "  maps the portion of the unit disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  that lies in the upper half-plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  onto the upper half-plane  ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 10.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the function  ",
  Cell[BoxData[
      \(w = \ \(f \((z)\)\  = \ \((z\^2 - 1)\)\^\(1\/2\)\)\)],
    AspectRatioFixed->True],
  ",  which is the composition of the functions  ",
  Cell[BoxData[
      \(Z\  = \ z\^2 - 1\)]],
  "  and  ",
  Cell[BoxData[
      \(w\  = \ Z\^\(1\/2\)\)]],
  "  where the branch of the square root is  ",
  Cell[BoxData[
      \(Z\^\(1\/2\) = \(R\^\(1\/2\)\) \((cos \((\[CurlyPhi]\/2)\)\  + \ \
\[ImaginaryI]\ sin \((\[CurlyPhi]\/2)\))\)\)]],
  ",  where  ",
  Cell[BoxData[
      \(R = \(\(|\)\(Z\)\(|\)\)\)]],
  " ,  ",
  Cell[BoxData[
      \(\[CurlyPhi] = arg \((Z)\)\)]],
  ",  and  ",
  Cell[BoxData[
      \(0 \[LessEqual] \[CurlyPhi] < 2  \[Pi]\)]],
  ".  Then the transformation  ",
  Cell[BoxData[
      \(w = f \((z)\)\)],
    AspectRatioFixed->True],
  "  maps the upper half-plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  one-to-one and onto the upper-half plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  "  slit along the segment  ",
  Cell[BoxData[
      \(u = 0, 0 < v \[LessEqual] 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009n0000Ob000`400?l0
0000o`00003oo`3ooooo0?oooh00oooo000S0?ooo`8000009@3oool40000
02@0oooo1@0000180?ooo`D000008P3oool4000002D0oooo0P00001A0?oo
o`8000009@3oool4000002@0oooo1@0000180?ooo`D000008P3oool40000
02D0oooo0P00000^0?ooo`008P3oool010000000oooo0?ooo`00000T0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo02D0oooo00@000000?oo
o`3oool00000C`3oool010000000oooo0?ooo`00000T0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo02D0oooo00@000000?ooo`3oool00000
;@3oool002@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo02`0oooo000L0?ooo`@000001@3oool0
0`000000oooo0?ooo`0L0?ooo`@00000103oool00`000000oooo0?ooo`0M
0?ooo`@00000103oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`17
0?ooo`@000001@3oool00`000000oooo0?ooo`0L0?ooo`@00000103oool0
0`000000oooo0?ooo`0M0?ooo`@00000103oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0[0?ooo`008P3oool010000000oooo0?ooo`00000T
0?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000002@0oooo
00@000000?ooo`3oool00000C`3oool010000000oooo0?ooo`00000T0?oo
o`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000002@0oooo00@0
00000?ooo`3oool00000;@3oool002<0oooo0P00000V0?ooo`8000009P3o
ool2000004/0oooo0P00000U0?ooo`8000009P3oool200000540oooo0P00
000V0?ooo`8000009P3oool2000004/0oooo0P00000U0?ooo`8000009P3o
ool2000002h0oooo003o0?ooool0ooooP03oool00?l0ooooo`3ooon00?oo
o`00o`3ooooo0?oooh00oooo003o0?ooool0ooooP03oool00?l0oooo6@3o
ool2000000030?ooo`00000000000?l0oooo?@3oool400000240oooo000Q
0?oooo00o`00203oool00`000000oooo000000140?ooo`L00000L@3o0008
0000ofT0o`001`0000080?ooo`040000003oool0oooo00000280oooo000Q
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00L0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`040?oooaH0o`005P000?lH
0?l002H0003o1P3o00000`000?l0o`000?l0001_0?l000H0oooo00<00000
0?ooo`3oool01P3oool010000000oooo0?ooo`00000R0?ooo`008@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`050?ooo`80000000<0oooo
000000000000@`3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0
oooo01<0oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`08
0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool00P3oool0
0`000000oooo0?ooo`0S0?ooo`80o`0000<000000?l0003o00009@3oool0
1@000000oooo0?ooo`3oool0003o01P0oooo00<0o`000?ooo`3oool01`3o
ool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo0180oooo00<0
o`000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`80000000<0
oooo0000000000008P3oool00240oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool0E03oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0
oooo01<0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0X
0?ooo`80o`0000<000000?l0003o0000:@3oool00`000?l0oooo0?ooo`0F
0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool04P3oool0
0`3o0000oooo0?ooo`0c0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`1D0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?oo
o`3oool04`3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo
02P0oooo0P3o00000`000000o`000?l0000Y0?ooo`030000o`3oool0oooo
01H0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0B0?oo
o`030?l0003oool0oooo03<0oooo000Q0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo05@0oooo00<0o`000?ooo`3oool04`3oool00`000?l0
oooo0?ooo`0C0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3o
ool09`3oool00`3o0000oooo0?ooo`020?l000030?ooo`3o0000oooo02L0
oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0C0?ooo`03
0000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0<`3oool00240oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool0E03ooolj0000o`X0oooo
00<0003o0?ooo`3oool09P3oool01@3o0000oooo0?ooo`3oool0o`0000<0
oooo00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`080?ooocX0
003o=@3oool00240ooool0000?mF0?ooo`030?l0003oool0oooo01<0oooo
00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0;0?ooo`h0003o
903oool00`3o0000oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o
00009@3oool=0000o`h0oooo00<0o`000?ooo`3oool04`3oool00`000?l0
oooo0?ooo`0B0?ooo`030?l0003oool0oooo03<0oooo000Q0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo05@0oooo00<0o`000?ooo`3oool0
4`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo01D0oooo
00@0003o0?ooo`3oool0oooo2@000?lK0?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0E0?ooo`d0
003o0P3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo01<0
oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0c0?ooo`00
8@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`1D0?ooo`030?l0
003oool0oooo01<0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo
0?ooo`0E0?ooo`030000o`3oool0oooo00X0oooo1`000?lC0?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`0A0?ooo`<0003o3`3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0
003oool0oooo01<0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo
0?ooo`0c0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`1D0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool04`3o
ool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo0140oooo0`00
0?l?0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000oooo0?ooo`0=0?ooo`<0003o4P3oool00`000?l0oooo0?oo
o`0F0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool04P3o
ool00`3o0000oooo0?ooo`0c0?ooo`008@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`1D0?ooobL0o`001@3oool00`3o0000oooo0?ooo`0E
0?ooo`030000o`3oool0oooo01@0oooo0P000?l<0?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0;
0?ooo`80003o5@3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0
oooo00H0oooo8`3o000e0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`1D0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?oo
o`3oool03P3ooolC0?l000X0oooo00<0003o0?ooo`3oool05P3oool20000
o`X0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo00L0oooo0`000?lH0?ooo`030000o`3oool0oooo
00T0oooo5@3o000=0?ooo`030000o`3oool0oooo0180oooo00<0o`000?oo
o`3oool0<`3oool00240ooool03o001F0?ooo`030?l0003oool0oooo01<0
oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0;0?ooo`d0
o`00603oool20000o`L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo0P000?lJ0?ooo`d0
o`00303oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0180
oooo00<0o`000?ooo`3oool0<`3oool00240oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool0E03oool00`3o0000oooo0?ooo`0C0?ooo`030000
o`3oool0oooo01<0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo
0?ooo`050?l001D0oooo0P000?l40?ooo`030?l0003oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo01D0oooo1@3o00000`3oool0003o0?ooo`0F0?ooo`030?l0
003oool0oooo01<0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo
0?ooo`0c0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`1D0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool04`3o
ool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00D0oooo103o
000C0?ooo`050000o`3oool0oooo0?ooo`3o00002@3oool00`3o0000oooo
0?ooo`070?ooo`050?l0003oool0oooo0?ooo`000?l04`3oool50?l000H0
oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0C0?ooo`03
0000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0<`3oool00240oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool0E03ooolA0000o`D0oooo
00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0E0?ooo`030000
o`3oool0oooo00T0oooo0`3o000A0?ooo`030000o`3oool0o`0000X0oooo
00<0o`000?ooo`3oool0203oool00`3o0000003o0000o`0B0?ooo`80o`00
2`3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo01<0oooo
00<0003o0?ooo`3oool00`3oool@0000ocD0oooo000Q0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo05@0oooo00<0o`000?ooo`3oool03P3o
oolN0000oaD0oooo00<0003o0?ooo`3oool0303oool20?l00100oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
0000oooo00l0oooo0`3o000=0?ooo`030000o`3oool0oooo01<0oooo7P00
0?l?0?ooo`030?l0003oool0oooo03<0oooo000Q0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo05@0oooo00<0o`000?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00/0003o2P3oool0
0`000?l0oooo0?ooo`0>0?ooo`<0o`003@3oool00`3o0000003o0?ooo`09
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?l0003oool0303oool3
0?l00100oooo00<0003o0?ooo`3oool01`3oool<0000o`80oooo00<0o`00
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0
oooo03<0oooo000Q0?oooo00003oEP3oool00`3o0000oooo0?ooo`0B0?oo
o`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool02`3oool60000
o`<0oooo00<0003o0?ooo`3oool04P3oool30?l000T0oooo00<0o`000?oo
o`000?l02P3oool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo
0?l000X0oooo0P3o000C0?ooo`030000o`3oool0oooo0080oooo1@000?l>
0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool04P3oool0
0`3o0000oooo0?ooo`0c0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`1D0?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool04`3oool00`3o0000oooo0?ooo`0B0?ooo`L0003o503oool20?l0
00H0oooo00D0o`000?ooo`3oool0oooo0000o`090?ooo`030?l0003oool0
oooo00L0oooo00D0003o0?ooo`3oool0oooo0?l000070?ooo`80o`00503o
ool60000oa<0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`0B0?ooo`030?l0003oool0oooo03<0oooo000Q0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo05@0oooo1@3o000@0?ooo`030000o`3oool0
oooo01<0oooo00<0o`000?ooo`3oool05@3oool010000?l0oooo0?ooo`3o
ool50000oa40oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo0P3o
000A0?ooo`D0003o00<0oooo0000o`3oool05P3oool00`3o0000oooo0?oo
o`0C0?ooo`030000o`3oool0oooo00d0oooo1P3o000e0?ooo`008@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`1D0?ooo`030?l0003oool0
oooo0080oooo8@3o00050?ooo`030?l0003oool0oooo01D0oooo00<0003o
0?ooo`3oool01P3oool30000o`l0oooo00D0o`000?ooo`3oool0oooo0?l0
00050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`3o0000
3`3oool40000o`H0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo
0?ooo`030?ooob00o`001@3oool00`3o0000oooo0?ooo`0c0?ooo`008@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`1D0?ooo`030?l0003o
ool0oooo0180oooo00<0003o0?ooo`3oool03P3oool>0?l000l0oooo00<0
003o0?ooo`3oool02@3oool30000o``0oooo00D0o`000?ooo`3oool0oooo
0?l000060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`040?l0003oool0oooo0?l000d0
oooo0`000?l;0?ooo`030000o`3oool0oooo0180oooo203o000@0?ooo`03
0000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0<`3oool00240oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool0E03oool00`3o0000oooo
0?ooo`0B0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0
1P3oool60?l000T0oooo00<0003o0?ooo`3oool0303oool20000o`/0oooo
00<0o`000?ooo`3o00001`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool20?l000/0oooo
0`000?l>0?ooo`030000o`3oool0oooo00H0oooo303o00020?ooo`030?l0
003oool0oooo01<0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo
0?ooo`0c0?ooo`008@3oooo`0?l005H0oooo00<0o`000?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00`0oooo1P3o
00030?ooo`030000o`3oool0oooo00h0oooo0P000?l:0?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203o
ool20000oa40oooo00@0003o0?ooo`3oool0oooo1@3o000>0?ooo`030?l0
003oool0oooo01<0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo
0?ooo`0c0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`1D0?ooo`D0003o403oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003o
ool0oooo0180oooo1P3o000@0?ooo`80003o203oool20?l000P0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3o00001`3oool20000oa40oooo1P3o
000C0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`0b0?ooo`008@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`1D0?ooo`030?l0003oool0oooo0080oooo6@000?l=
0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool01@3o000=
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3o0006
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`050?ooo`040?l0003oool0oooo0?l000H0oooo00<0
003o0?ooo`3oool0303oool50?l00080oooo00<0003o0?ooo`3oool0503o
ool00`3o0000oooo0?ooo`0?0?oooaX0003o00<0o`000?ooo`3oool0<P3o
ool00240oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0E03oool0
0`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00H0oooo20000?l5
0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool01@3oool2
0?l000`0oooo0P000?l40?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool2
0?l000L0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`02
0?ooo`d0003o103oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0
oooo0380oooo000Q0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
05@0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0>0?oo
o`h0003o3`3oool00`000?l0oooo0?ooo`070?ooo`80o`00303oool01000
0?l0oooo0?ooo`3o00050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0000o``0oooo0P3o00090?ooo`030000o`3oool0oooo00/0oooo3P000?lA
0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0<P3oool0
0240oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0E03oool00`3o
0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?oo
o`3oool01P3oool50000o`T0oooo00<0003o0?ooo`3oool02P3oool20?l0
00/0oooo0P000?l00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`3o
0000oooo0000o`0<0?ooo`80o`002`3oool00`000?l0oooo0?ooo`050?oo
o`H0003o2@3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo
01<0oooo00<0o`000?ooo`3oool0<P3oool00240ooool0000?mF0?ooo`03
0?l0003oool0oooo0180oooo00<0003o0?ooo`3oool04`3oool00`3o0000
oooo0?ooo`0;0?ooo`H0003o0`3oool00`000?l0oooo0?ooo`0<0?ooo`<0
o`002@3oool00`3o0000003o0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`090?ooo`80o`003P3oool00`000?l0oooo0000o`040000oa00
oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0C0?ooo`03
0?l0003oool0oooo0380oooo000Q0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo05@0oooo6`3o000@0?ooo`030?l0003oool0oooo0140oooo
1P000?l?0?ooo`80o`001`3oool00`3o0000oooo0000o`060?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool00`000?l0o`000?ooo`080?ooo`80o`003@3oool50000oaD0oooo
00<0o`000?ooo`3oool03P3ooolK0?l003@0oooo000Q0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo05@0oooo00<0o`000?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`030?ooo`/0o`001@3oool00`3o0000oooo0?oo
o`0D0?ooo`030000o`3oool0oooo00D0003o303oool20?l000D0oooo00@0
o`000?ooo`3oool0003o1@3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool0
o`001@3oool30?l000`0oooo0`000?l30?ooo`030000o`3oool0oooo01@0
oooo00<0o`000?ooo`3oool01@3oool90?l000@0oooo00<0003o0?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`0b0?ooo`008@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`1D0?ooo`030?l0003oool0oooo0180oooo
00<0003o0?ooo`3oool03P3oool80?l001@0oooo00<0003o0?ooo`3oool0
1@3oool30000o`/0oooo00D0o`000?ooo`3oool0oooo0?l000030?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?oo
o`3o00000`3oool20?l000`0oooo0`000?l60?ooo`030000o`3oool0oooo
00h0oooo3P3o000=0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?oo
o`3oool0<P3oool00240oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool0E03oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo01<0
oooo00<0o`000?ooo`3oool02`3o00090?ooo`030000o`3oool0oooo00P0
oooo0P000?l:0?ooo`80o`0000<0oooo0?l0003oool00`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3o
ool0oooo0?l000030?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0o`00
00/0oooo0`000?l90?ooo`030000o`3oool0oooo00H0oooo203o00060?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool04`3oool00`3o
0000oooo0?ooo`0b0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`1D0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`0;0?ooo`D0o`00103oool00`000?l0
oooo0?ooo`0:0?ooo`80003o2P3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool01@000?l0
oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo0P3o000:0?oo
o`80003o303oool00`000?l0oooo0?ooo`020?ooo`@0o`003P3oool00`3o
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0180oooo00<0o`000?oo
o`3oool0<P3oool00240ooool03o001F0?oooa00003o1@3oool00`000?l0
oooo0?ooo`0C0?ooo`030?l0003oool0oooo0100oooo0`3o00000`3oool0
003o0?ooo`0=0?ooo`80003o203oool20?l000H0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?oo
o`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0003o
0?ooo`3oool0103oool20?l000P0oooo0P000?l>0?ooo`030000o`3oool0
o`000080o`004P3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0
oooo00<0oooo40000?ld0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`1D0?ooo`030?l0003oool0oooo00d0oooo5P000?l50?oo
o`030?l0003oool0oooo01<0oooo103o000>0?ooo`80003o1@3oool0103o
0000oooo0?ooo`3o00060?ooo`030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`000?l0
0`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3o00001P3oool20000o`h0oooo103o000E0?ooo`030?l0
003oool0oooo00<0oooo5P000?l?0?ooo`030?l0003oool0oooo0380oooo
000Q0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo05@0oooo00<0
o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0>0?ooo`P0003o4`3o
ool010000?l0oooo0?ooo`3oool50?l000/0oooo0P000?l30?ooo`050?l0
003oool0oooo0?ooo`3o00001@3oool00`000?l0oooo0?ooo`020?ooo`05
0?l0003oool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0
003o0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`80o`000P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00T0oooo1@3o00020?ooo`030000o`3oool0oooo0180oooo20000?l@
0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0<P3oool0
0240oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0E03oool00`3o
0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?oo
o`3oool01@000?l>0?ooo`030000o`3oool0oooo00H0oooo0P3o000;0?oo
o`80003o00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool010000?l0oooo0?ooo`3o
00030?ooo`040000o`3oool0oooo0?l000@0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080003o
2@3oool30?l000L0oooo00<0003o0?ooo`3oool03@3oool50000o`80oooo
00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0
003oool0oooo0380oooo000Q0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo05@0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?oo
o`0B0?ooo`030?l0003oool0oooo00H0oooo1P000?l80?ooo`030000o`3o
ool0oooo00P0oooo0P3o000;0?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`000?l00P3oool0103o0000oooo0?ooo`000?l30?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`040?oo
o`030?l000000?l0003o00T0oooo0P3o000:0?ooo`030000o`3oool0oooo
00L0oooo1P000?l70?ooo`030?l0003oool0oooo01<0oooo00<0003o0?oo
o`3oool04P3oool00`3o0000oooo0?ooo`0b0?ooo`008@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`1D0?oooa00o`001@3oool00`000?l0
oooo0?ooo`0B0?ooo`030?l0003oool0oooo00`0oooo1@000?l30?ooo`03
0000o`3oool0oooo00X0oooo0P3o00090?ooo`030?l000000?l0oooo00D0
oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`00
00<0oooo00@0003o0?ooo`3oool0o`000P3oool01@000?l0oooo0?ooo`3o
ool0o`000080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3o0000oooo00L0oooo0P3o000=0?ooo`030000o`3o
ool0oooo00H0003o3@3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3o
ool0oooo00<0oooo403o000d0?ooo`008@3oooo`0000oeH0oooo00<0o`00
0?ooo`3oool03@3oool;0?l000l0oooo00<0o`000?ooo`3oool04@3oool5
0000o`d0oooo0P3o00070?ooo`030?l0003oool0003o00H0oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00@0
003o0?ooo`3oool0o`000P3oool010000?l0oooo0?ooo`3o00030?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?l000060?ooo`80o`003P3oool40000oa<0oooo00<0o`000?ooo`3o
ool03P3oool;0?l000l0oooo00<0o`000?ooo`3oool0<P3oool00240oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool0E03oool00`3o0000oooo
0?ooo`0B0?ooo`030000o`3oool0oooo00<0oooo2P3o00050?ooo`030?l0
003oool0oooo01@0oooo00<0003o0?ooo`000?l00P000?l<0?ooo`80o`00
103oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00D0o`000?ooo`3o
ool0oooo0000o`030?ooo`040?l0003oool0oooo0000o`80oooo00@0o`00
0?ooo`3oool0003o0P3oool0103o0000oooo0?ooo`000?l40?ooo`030?l0
003oool0oooo00<0oooo0P000?l30?ooo`040?l0003oool0oooo0?ooo`80
o`00303oool40000o`030?ooo`000?l0oooo01@0oooo00<0o`000?ooo`3o
ool00`3oool;0?l000D0oooo00<0003o0?ooo`3oool04P3oool00`3o0000
oooo0?ooo`0b0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`1D0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0
3@3oool80?l001<0oooo00<0003o0?ooo`3oool00`3oool20000o``0oooo
0P3o00020?ooo`030?l0003oool0oooo0080oooo0P000?l50?ooo`050?l0
003oool0oooo0?ooo`000?l00P3oool0103o0000oooo0?ooo`000?l20?oo
o`060?l0003oool0oooo0000o`3oool0o`000`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool0103o0000oooo0?l0003o000:0?ooo`@0003o1@3oool00`000?l0oooo
0?ooo`0A0?ooo`P0o`00403oool00`000?l0oooo0?ooo`0B0?ooo`030?l0
003oool0oooo0380oooo000Q0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo05@0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?oo
o`0B0?ooo`030?l0003oool0oooo00/0o`00203oool00`000?l0oooo0?oo
o`050?ooo`<0003o2`3oool30?l000H0oooo00<0003o0?ooo`3oool00`3o
ool0103o0000oooo0?ooo`000?l30?ooo`080?l0003oool0oooo0000o`3o
ool0o`000?ooo`000?l20?ooo`040?l0003oool0oooo0000o`@0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`80o`002@3o
ool30000o`T0oooo00<0003o0?ooo`3oool01P3oool;0?l00080oooo00<0
o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003o
ool0oooo0380oooo000Q0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo05@0oooo1@000?l@0?ooo`030000o`3oool0oooo0180oooo00<0o`00
0?ooo`3oool02`3oool60?l00080oooo00<0003o0?ooo`3oool0203oool3
0000o`T0oooo0`3o00060?ooo`030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`020?ooo`0:0?l0003oool0oooo0000o`3oool0
o`000?ooo`000?l0oooo0?l00080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3o00001`3oool20000o``0oooo00@0003o0?ooo`3oool0oooo1@3o
000=0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool03@3o
ool60000oc@0oooo000Q0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo05@0oooo00<0o`000?ooo`3oool00P3ooolF0000o`l0oooo00<0o`00
0?ooo`3oool04@3oool40?l000`0oooo0P000?l70?ooo`040?l0003oool0
oooo0?l000H0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?oo
o`3oool0003o0080oooo00D0o`000000o`000?l0003o0?l000020000o`05
0?ooo`3o0000oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00@0oooo00@0o`000?ooo`3oool0o`001@3oool2
0000o`l0oooo00<0003o0?l0003o00004`3oool00`3o0000oooo0?ooo`0=
0?oooaD0003o1@3oool00`3o0000oooo0?ooo`0b0?ooo`008@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`1D0?ooo`030?l0003oool0oooo
0180oooo00<0003o0?ooo`3oool00`3oool:0000o`D0oooo00<0o`000?oo
o`3oool04`3oool010000?l0oooo0?l0003o000<0?ooo`80003o1@3oool0
103o0000oooo0?ooo`3oool20?l000D0oooo00<0003o0?ooo`3oool00P3o
ool0103o0000oooo0?ooo`000?l20?ooo`060?l000000?l0003o0?ooo`3o
0000oooo0P000?l00`3o0000oooo0000o`030?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0
o`0000<0oooo0P000?l?0?ooo`<0o`005@3oool00`3o0000oooo0?ooo`03
0?ooo`X0003o1@3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0
oooo0380oooo000Q0?oooo00o`00EP3oool00`3o0000oooo0?ooo`0B0?oo
o`030000o`3oool0oooo00d0oooo20000?lC0?ooo`040000o`3oool0oooo
0?ooo`<0o`002`3oool20000o`80oooo00<0o`000?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P000?l02@3o0000oooo0000o`3oool0o`000000o`3oool0
o`000?ooo`020000o`<0oooo00D0o`000?ooo`3oool0oooo0000o`050?oo
o`80o`001@3oool00`3o0000003o0000o`0>0?ooo`<0o`000P3oool00`00
0?l0oooo0?ooo`0A0?ooo`P0003o3`3oool00`000?l0oooo0?ooo`0B0?oo
o`030?l0003oool0oooo0380oooo000Q0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo05@0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0B0?ooo`030?l0003oool0oooo00H0003o303oool00`000?l0
oooo0?ooo`050?ooo`<0o`002P3oool20000o`030?l0003oool0oooo00D0
oooo0P3o00040?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool20000
o`090?ooo`3o0000003o0?ooo`3o0000003o0?ooo`3o0000oooo0080003o
0P3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0:0?ooo`@0o`001@3oool00`000?l0
oooo0?ooo`0;0?ooo`H0003o0P3oool00`3o0000oooo0?ooo`0B0?ooo`03
0000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0<P3oool00240oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool0E03oool50?l00100oooo
00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`060?ooo`D0003o
1`3oool00`000?l0oooo0?ooo`080?ooo`<0o`00203oool00`3o0000003o
0000o`080?ooo`030?l0003oool0oooo0080oooo01D0003o0?ooo`3oool0
oooo0?l000000?l0oooo0000o`3oool0o`000?ooo`000?l0o`000000o`3o
ool0o`000?ooo`000?l0oooo0000o`3o00000`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo0P000?l00`3o0000oooo0?oo
o`070?ooo`<0o`002@3oool00`000?l0oooo0?ooo`060?ooo`D0003o203o
ool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00d0oooo1P3o
000d0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`1D
0?ooo`030?l0003oool0oooo0080oooo5@3o000@0?ooo`030?l0003oool0
oooo00/0oooo1@000?l20?ooo`030000o`3oool0oooo00/0oooo0P3o0006
0?ooo`030?l0003oool0oooo0080003o1`3oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0000o`3o00000P0000002@000?l0o`000?oo
o`000?l0o`000000o`3o0000oooo0000o`020?ooo`030?l0003oool0oooo
0080003o1@3oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo
0?l000L0oooo0P3o000<0?ooo`030000o`3oool0oooo00H0003o3@3oool0
0`3o0000oooo0?ooo`0=0?oooaD0o`001@3oool00`3o0000oooo0?ooo`0b
0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`1D0?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool00P3oool;0?l0
00D0oooo00<0o`000?ooo`3oool0403oool40000o`h0oooo0`3o00030?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`020?ooo`090000o`3oool0003o0?l000000000oooo0000
o`3oool0o`0000<0003o00H0o`000000o`3oool0oooo0?l0003oool20000
o`D0oooo0P3o00050?ooo`80003o0`3oool00`3o0000oooo0?ooo`020?oo
o`<0o`003@3oool40000oa<0oooo00<0o`000?ooo`3oool00`3oool:0?l0
00D0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0b0?oo
o`008@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`1D0?ooo`03
0?l0003oool0oooo0180oooo00<0003o0?ooo`3oool03@3oool80?l00180
oooo00<0003o0?ooo`000?l00`000?l=0?ooo`<0o`001P3oool20000o`H0
oooo00<0o`000?ooo`3oool00P3oool01`000?l0oooo0?ooo`3o0000oooo
0000o`3oool00P3o000010000?l0o`000?ooo`000?l20?ooo`040?l0003o
ool0003o0000o`@0oooo00<0o`000?ooo`3oool00`3oool20000o`H0oooo
00@0o`000?ooo`3o0000o`003@3oool30000o`80oooo00<0003o0?ooo`3o
ool0403oool80?l000l0oooo00<0003o0?ooo`3oool04P3oool00`3o0000
oooo0?ooo`0b0?ooo`008@3oooo`0000oeH0oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00D0o`00
3@3oool00`000?l0oooo0?ooo`030?ooo`@0003o2`3oool20?l000L0oooo
0P000?l50?ooo`0:0?l0003oool0oooo0000o`3oool0003o0?ooo`000000
o`000?ooo`80003o0`3o000020000?l0oooo0?ooo`3o0000oooo0000o`3o
ool0003o0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00D0oooo0`3o000;0?ooo`@0003o1@3oool00`000?l0oooo0?ooo`0:0?oo
o`H0o`000P3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo
0180oooo00<0o`000?ooo`3oool0<P3oool00240oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0E03oool50000o`l0oooo00<0003o0?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`050?ooo`D0o`00203oool00`000?l0
oooo0?ooo`070?ooo`<0003o203oool0103o0000oooo0?l0003o00070?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`000?l00P3oool01000
0?l000000?ooo`3o00020?ooo`<0003o00<0oooo0?l0003o00000P3oool0
10000?l0oooo0?ooo`000?l20?l000@0oooo0P000?l60?ooo`80o`0000<0
oooo0?l0003oool0203oool30000o`T0oooo00<0003o0?ooo`3oool01@3o
ool50?l000P0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?oo
o`0=0?ooo`H0003o=03oool00240oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool0D`3oool00`3o0000oooo0?ooo`030?ooo`/0003o103oool0
0`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00/0oooo1P3o0002
0?ooo`030000o`3oool0oooo00X0oooo0`000?l50?ooo`040?l0003oool0
oooo0?ooo`80o`001P3oool20000o`@0oooo00D0o`000?ooo`3oool0oooo
000000020000o`030?ooo`3o0000o`0000@0o`000`3oool01@000?l0oooo
0?ooo`3oool0o`0000D0oooo00<0003o0?ooo`3oool0103oool20?l000@0
oooo00<0o`000?ooo`3oool00`3oool30000o``0oooo00<0003o0?ooo`3o
ool01@3o000=0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o
ool00`3oool:0000o`D0oooo00<0o`000?ooo`3oool0<P3oool00240oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool0D`3oool00`3o0000oooo
0?ooo`0>0?oooa80003o1`3oool00`3o0000oooo0?ooo`0A0?ooo`@0o`00
3P3oool40000o`030?ooo`3o0000oooo00@0oooo0P3o00060?ooo`80003o
0P3oool00`000?l0o`000?l000040?ooo`80003o0P3oool0103o0000oooo
0?ooo`3oool20000o`80oooo0P3o000010000?l0oooo0?ooo`3oool20000
o`D0oooo0P3o00060?ooo`030?l0003oool0003o00<0003o3P3oool40?l0
0180oooo00<0o`000?ooo`3oool01@3ooolC0000o`l0oooo00<0o`000?oo
o`3oool0<P3oool00240oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool0D`3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00/0
oooo1@000?l20?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3o
00000P3o000?0?ooo`80003o1`3oool20?l000H0oooo0`000?l20?ooo`03
0?l0003oool0oooo00<0oooo1P000?l20?ooo`80o`000P3oool010000?l0
oooo0000o`000?l50?ooo`80o`001`3oool30000o`l0oooo0`3o00000`3o
ool0003o0?ooo`0C0?ooo`030?l0003oool0oooo00D0003o3@3oool00`00
0?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo0380oooo000Q0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo05<0oooo00<0o`000?ooo`3o
ool04P3oool00`000?l0oooo0?ooo`0@0?ooo`P0003o3`3oool00`000?l0
oooo0?ooo`030?ooo`@0o`002`3oool0103o0000oooo0000o`000?l70?oo
o`80o`001P3oool010000?l0oooo0?ooo`3oool30?l000@0oooo00@0o`00
0?ooo`3oool0oooo0P3o00050?ooo`030000o`3oool0oooo00<0oooo0P3o
00070?ooo`80003o0P3oool00`3o0000oooo0?ooo`090?ooo`@0o`00103o
ool00`000?l0oooo0?ooo`0>0?ooo`L0003o4P3oool00`000?l0oooo0?oo
o`0B0?ooo`030?l0003oool0oooo0380oooo000Q0?oooo00o`00E@3oool5
0?l00100oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`03
0?ooo`P0003o1`3oool00`000?l0oooo0?ooo`070?ooo`<0o`00203oool0
103o0000oooo0?ooo`3oool20000o`L0oooo0P3o00030?ooo`040000o`3o
ool0003o0000o`@0oooo203o00050?ooo`<0003o0`3oool20?l000L0oooo
0P000?l40?ooo`030?l0003oool0oooo00H0oooo0`3o00080?ooo`030000
o`3oool0oooo00H0oooo20000?l40?ooo`030?l0003oool0oooo0180oooo
00<0003o0?ooo`3oool03P3oool50?l003@0oooo000Q0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo05<0oooo00<0o`000?ooo`3oool00P3o
ool;0?l000D0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?oo
o`0;0?ooo`D0003o0P3oool00`000?l0oooo0?ooo`0:0?ooo`<0o`001@3o
ool00`3o0000oooo0?ooo`030?ooo`80003o1`3oool20?l000030?ooo`00
0?l0oooo0080oooo0P000?l60?ooo`030?l0003oool0oooo00@0oooo0P00
0?l30?ooo`030000o`3o0000o`0000L0oooo0P000?l60?ooo`030?l0003o
ool0oooo00<0oooo0`3o000;0?ooo`030000o`3oool0oooo00H0003o303o
ool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00@0oooo2P3o
00040?ooo`030?l0003oool0oooo0380oooo000Q0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo05<0oooo00<0o`000?ooo`3oool03@3oool;
0?l000l0oooo00<0o`000?ooo`3oool0403oool40000o`h0oooo1@3o0008
0?ooo`80003o1`3oool00`3o0000oooo0?ooo`040?ooo`<0003o0`3oool0
103o0000oooo0?ooo`3oool30000o`D0oooo00<0o`000?ooo`3oool01@3o
ool20000o`P0oooo00<0o`000?ooo`3o00000`3o000<0?ooo`D0003o4`3o
ool00`3o0000oooo0?ooo`0>0?ooo`X0o`003P3oool00`3o0000oooo0?oo
o`0b0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`1C
0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool00`3oool:
0?l000D0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0000o`02
0000o`l0oooo0`3o00080?ooo`80003o1@3oool00`000?l0o`000?l00007
0?ooo`L0003o1P3oool20?l000030000o`3oool0oooo00<0oooo0P000?l9
0?ooo`<0o`00303oool40000o`<0oooo00<0003o0?ooo`3oool04P3oool0
0`3o0000oooo0?ooo`030?ooo`/0o`00103oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0380oooo000Q0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo05<0oooo00<0o`000?ooo`3oool04P3oool00`00
0?l0oooo0?ooo`0=0?ooo`X0o`00403oool00`000?l0oooo0?ooo`020?oo
o`@0003o2`3oool00`3o0000oooo0?ooo`020?l000P0oooo0P000?l30?oo
o`030000o`3oool0oooo00<0o`001`3oool00`3o0000oooo0?ooo`050?oo
o`80o`000P3oool010000?l0oooo0?ooo`3oool20000o`P0oooo0`3o0000
0`3oool0o`000?ooo`080?ooo`@0003o1`3oool00`000?l0oooo0?ooo`0>
0?ooo`X0o`003`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0380oooo000Q0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`090?oo
o`D000000`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`1C0?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool04P3oool00`3o0000oooo0?ooo`020?ooo`P0o`00203oool00`00
0?l0oooo0?ooo`060?ooo`<0003o203oool00`3o0000oooo0?ooo`020?oo
o`<0o`001`3oool20000o`030?ooo`000?l0oooo00@0oooo1@3o00020?oo
o`030?l0003oool0oooo00D0o`001@3oool30000o`L0oooo0`3o00050?oo
o`030?l0003oool0oooo00<0oooo0`000?l;0?ooo`030000o`3oool0oooo
00H0oooo203o00040?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0b0?ooo`008@3oooo`0000oeD0
oooo40000?l50?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3o
ool02P3oool50?l000<0oooo00<0003o0?ooo`3oool02@3oool30000o`D0
oooo00<0o`000?ooo`3oool01@3oool30?l000H0oooo0`000?l90?ooo`H0
o`00203oool20000o`H0oooo0`3o00080?ooo`030?l0003oool0003o00<0
003o3P3oool010000?l0oooo0?ooo`3oool50?l000`0oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`030?ooo`l0003o=03oool00240
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo00/0oooo00<000000?ooo`3o
ool00`3oool00`3o000000000?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`1C0?ooo`030?l0003oool0oooo00d0oooo2`000?l?0?ooo`03
0?l0003oool0oooo00l0oooo1@3o000=0?ooo`@0003o00<0oooo0?l0003o
ool02@3oool20?l000@0oooo00<0003o0?ooo`3oool00`000?l80?ooo`03
0?l0003oool0oooo00D0oooo10000?l00`3oool0003o0?ooo`030?ooo`80
o`002P3oool30000oa40oooo1@3o000A0?ooo`030?l0003oool0oooo00d0
oooo2`000?l>0?ooo`030?l0003oool0oooo0380oooo000Q0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
D`3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00<0oooo
2P000?l50?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o0000
1@3o000;0?ooo`<0003o2`3oool30?l000030?ooo`000?l0oooo00@0oooo
1P000?l20?ooo`040?l0003oool0oooo0?ooo`@0003o1@3oool00`000?l0
oooo0?l000020?l000T0oooo0`000?l00`3oool0o`000?ooo`0<0?ooo`D0
o`0000<0oooo0000o`3oool04`3oool00`3o0000oooo0?ooo`030?ooo`X0
003o1@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0380
oooo000Q0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0;0?ooo`030000
003oool0oooo00<0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool0D`3oool00`3o0000oooo0?ooo`0B0?ooo`030000
o`3oool0oooo00d0oooo2P000?l?0?ooo`030000o`3oool0oooo00H0oooo
103o00070?ooo`030?l0003oool0oooo00@0003o2P3oool30?l000T0oooo
1`000?l80?ooo`<0o`002@3oool30000o`@0oooo00<0o`000?ooo`3oool0
1`3oool40?l000H0oooo00<0003o0?ooo`3oool03@3oool;0000o`l0oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0b0?ooo`008@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool02P3oool2000000D0oooo00<0
o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0D`3o
ool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo0180oooo00<0
o`000?ooo`3oool00P3oool80000o`L0oooo00<0003o0?ooo`3oool02P3o
ool30?l000@0oooo00<0o`000?ooo`3oool0103oool40000o`L0oooo00<0
003o0?ooo`3o00000P3o00090?ooo`030?l0003oool0oooo00H0oooo0`3o
00020?ooo`030000o`3oool0oooo00@0oooo0`000?l70?ooo`030?l0003o
ool0oooo00@0oooo0`3o000:0?ooo`030000o`3oool0oooo00D0oooo2000
0?l50?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0b0?ooo`008@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`1C0?oooa00o`001@3oool00`000?l0oooo0?ooo`0B
0?ooo`030?l0003oool0oooo00X0oooo1@000?l20?ooo`030000o`3oool0
oooo00d0oooo0`3o00000`3oool0o`000?ooo`090?ooo`<0003o103oool0
0`000?l0oooo0?ooo`020?ooo`<0o`001P3oool00`3o0000oooo0?ooo`04
0?ooo`80o`001@3oool00`000?l0oooo0?ooo`020?ooo`80003o2`3oool0
0`3o0000oooo0?l000030?l000d0oooo00@0003o0?ooo`3oool0oooo1000
0?l=0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool00`3o
ool?0?l003@0oooo000Q0?oooo00o`00E@3oool00`3o0000oooo0?ooo`0=
0?ooo`X0o`003`3oool00`3o0000oooo0?ooo`0@0?ooo`D0003o403oool3
0?l000`0oooo0`000?l00`3oool0003o0?ooo`060?ooo`d0o`001`3oool0
0`000?l0oooo0000o`020000o``0oooo0`3o000@0?ooo`D0003o4@3oool0
0`3o0000oooo0?ooo`0=0?ooo`/0o`003`3oool00`3o0000oooo0?ooo`0a
0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`1C0?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool00P3oool:0?l0
00D0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`050000
o``0oooo00<0o`000?ooo`3o00000P3o000<0?ooo`<0003o303oool00`3o
0000oooo0?ooo`0:0?ooo`<0003o2`3oool40?l000030?ooo`3o0000oooo
00/0oooo1@000?l20?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool00`3oool:0?l000D0oooo00<0003o0?ooo`3oool04P3oool00`3o
0000oooo0?ooo`0a0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`1C0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o
ool0303oool;0?l000l0oooo00<0003o0?ooo`3oool01@3oool40000o`P0
oooo00<0o`000?ooo`3oool00P3oool30?l000T0oooo00<0003o0?ooo`3o
ool010000?l80?ooo`030?l0003oool0oooo00L0oooo0`000?l00`3oool0
003o0?ooo`070?ooo`@0o`001@3oool00`3o0000oooo0?ooo`050?ooo`D0
003o1`3oool00`000?l0oooo0?ooo`0=0?ooo`X0o`003`3oool00`000?l0
oooo0?ooo`0B0?ooo`030?l0003oool0oooo0340oooo000Q0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo05<0oooo00<0o`000?ooo`3oool0
4P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00<0oooo
203o00070?ooo`030000o`3oool0oooo00T0oooo0`000?l50?ooo`030?l0
003oool0oooo00D0oooo0`3o00060?ooo`030000o`3oool0oooo00@0oooo
4P000?l40?ooo`030000o`3oool0oooo00<0oooo0`3o00090?ooo`030?l0
003oool0oooo00D0003o303oool00`000?l0oooo0?ooo`050?ooo`P0o`00
103oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo0180oooo
00<0o`000?ooo`3oool0<@3oool00240oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0D`3oool@0000o`D0oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0;0?ooo`@0o`000`3oool00`000?l0oooo0?oo
o`0<0?ooo`@0003o00<0o`000?ooo`3oool02@3oool40?l00080oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0o`000080o`002`3oool40000oa40oooo00<0003o0?ooo`3oool01@3o
000<0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool00`3o
ool@0000oc<0oooo000Q0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo06<0oooo2P000?l?0?ooo`030?l0003oool0oooo00l0oooo1@3o000A
0?ooo`<0003o3@3oool40?l000d0oooo00<0o`000?ooo`3oool02`3oool3
0?l000`0oooo0P000?l00`3oool0o`000?ooo`0@0?ooo`D0o`004@3oool0
0`3o0000oooo0?ooo`0=0?ooo`/0003o@`3oool00240ooool0000?m_0?oo
o`X0003o1@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
00H0o`002`3oool00`3o0000oooo0?ooo`040000o`/0oooo00<0003o0?oo
o`3o00001P3o00060?ooo`030?l0003oool0oooo00@0oooo1`3o00000`3o
ool0003o0?ooo`090?ooo`<0003o0`3oool00`3o0000oooo0?ooo`0:0?oo
o`D0o`000P3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo
0080oooo2P000?m>0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`1g0?ooo`X0003o3`3oool00`000?l0oooo0?ooo`060?ooo`D0
o`001P3oool00`3o0000oooo0?ooo`040?ooo`@0003o1`3oool00`000?l0
oooo0?ooo`060?ooo`d0o`00203oool00`000?l0oooo0?ooo`040?ooo`@0
003o1`3oool00`3o0000oooo0?ooo`040?ooo`D0o`001`3oool00`000?l0
oooo0?ooo`0=0?ooo`X0003oF03oool00240oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool0P@3oool80000o`L0oooo00<0003o0?ooo`3oool0
2`3oool40?l00080oooo00<0o`000?ooo`3oool0203oool50000o`030?oo
o`000?l0oooo00h0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`040000o`/0oooo00<0o`000?ooo`3oool0103o000<0?ooo`030000
o`3oool0oooo00D0oooo20000?mR0?ooo`008@3oool00`3o0000oooo0?oo
o`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`290?ooo`D0003o0P3oool00`000?l0oooo0?oo
o`0?0?ooo`D0o`003@3oool40000o`d0oooo00<0o`000?ooo`3oool0203o
ool70000o`d0oooo1@3o000A0?ooo`030000o`3oool0oooo00@0003oJP3o
ool00240oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0SP3oool5
0000oa00oooo00@0o`000?ooo`3oool0oooo103o000:0?ooo`030000o`3o
ool0oooo01P0003o103oool00`000?l0oooo0?ooo`090?ooo`@0o`000P3o
ool00`3o0000oooo0?ooo`0?0?ooo`D0003oKP3oool00240oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0T`3oool50000o`/0oooo00<0o`00
0?ooo`3oool01@3oool40?l000H0oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00@0oooo103o0006
0?ooo`030?l0003oool0oooo00X0oooo1@000?mc0?ooo`008@3oooo`0?l0
09X0oooo1@000?l60?ooo`030?l0003oool0oooo00T0oooo103o00020?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`040?l000X0oooo00<0o`000?ooo`3oool00`3oool70000
ogP0oooo000Q0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo09d0
oooo1@000?l00`3oool0o`000?ooo`0>0?ooo`P0o`002P3oool00`3o0000
oooo0?ooo`080?ooo`P0o`003@3oool70000ogl0oooo000Q0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo0:80oooo1P000?l=0?ooo`030000
o`3oool0oooo00<0oooo5@3o00050?ooo`030000o`3oool0oooo00T0oooo
10000?n60?ooo`008@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`2X0?ooo`H0003o1`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool0103oool50000ohX0oooo000Q
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0:h0oooo1@000?l2
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`040000ohl0oooo000Q0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo0;<0oooo20000?l:0?ooo`030?l0003oool0oooo
00P0oooo20000?nC0?ooo`008@3oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`2k0?oooaD0003oV`3oool00240ooool0000?o70?ooo`030000
003oool0oooo0:<0oooo002I0?ooo`030000003oool0oooo0?l0oooo?@3o
ool00`000000oooo0?ooo`2S0?ooo`00V@3oool00`000000oooo0?ooo`3o
0?ooocd0oooo00<000000?ooo`3oool0X`3oool009T0oooo00<000000?oo
o`3oool0o`3ooolm0?ooo`030000003oool0oooo0:<0oooo003o0?ooool0
ooooP03oool00?l0ooooo`3ooon00?ooo`00o`3ooooo0?oooh00oooo003o
0?ooool0ooooP03oool00?l0ooooo`3ooon00?ooo`00o`3ooooo0?oooh00
oooo003o0?ooool0ooooP03oool00?l0ooooo`3ooon00?ooo`00U`3oool2
00000?l0ooooiP3oool009P0oooo00<000000?ooo`3oool0o`3ooooT0?oo
o`00V@3oool00`000000oooo0?ooo`3o0?oooc`0oooo0P00002U0?ooo`00
V03oool00`000000oooo0000003o0?ooocd0oooo0P00002U0?ooo`00U`3o
ool010000000oooo0?ooo`00003o0?oooc`0oooo00@000000?ooo`3oool0
0000Y03oool009H0oooo0`0000000`3oool000000000003o0?ooocX0oooo
0P0000020?ooo`800000X`3oool00?l0ooooo`3ooon00?ooo`00o`3ooooo
0?oooh00oooo003o0?ooool0ooooP03oool00?l0ooooo`3ooon00?ooo`00
\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{638, 127},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The function  ",
  Cell[BoxData[
      \(Z\  = \ z\^2 - 1\)],
    AspectRatioFixed->True],
  "  maps the upper half-plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  one-to-one and onto the ",
  StyleBox["Z",
    FontFamily->"Courier New"],
  "-plane slit along the ray  ",
  Cell[BoxData[
      \(Y = 0, X = \(-1\)\)]],
  ".  Then the function  ",
  Cell[BoxData[
      \(w\  = \ Z\^\(1\/2\)\)]],
  "  maps the slit plane onto the slit half-plane, as shown in Figure 10.13."
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 10.13",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/mapelementaryfun/\
MapElementaryFunFigures/mat1013.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The composite transformation  ",
  Cell[BoxData[
      \(w = \((z\^2 - 1)\)\^\(1\/2\)\)],
    AspectRatioFixed->True],
  "  and the intermediate steps  ",
  Cell[BoxData[
      \(Z = z\^2 - 1\)]],
  "  and  ",
  Cell[BoxData[
      \(w = Z\^\(1\/2\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 10.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f \((z)\) = \@\(z\^2\  - \ 1\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(w = \(z = 0\); \ Remove[w, z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, solset];\)\ \), "\n", 
    \(\(f[z_]\  = \ \@\(z\^2\  - \ 1\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To show  w = f(z) = ",
  Cell[BoxData[
      SqrtBox[
        RowBox[{
          StyleBox[\(z\^2\),
            FontSize->14], " ", "-", " ", "1"}]]]],
  "  is one-to-one conformal we need to find the inverse function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_]\  = \ \@\(z\^2\  - \ 1\);\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ Solve[w\  \[Equal] \ f[z], z];\)\ \), "\n", 
    \(\(g[w_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(Print["\<g[w] = \>", g[w]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<f[g[w]] = \>", f[g[w]], "\< = \>", 
        PowerExpand[f[g[w]]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", g[f[z]], "\< = \>", 
        PowerExpand[g[f[z]]]];\)\ \), "\n", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "However, in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  the branch cut for square root is along the negative x-axis.  For \
graphing purposes, we need the version of the function f(z) with a branch cut \
along the positive x-axis  ",
  Cell[BoxData[
      \(f \((z)\) = \[ImaginaryI] \@\( 1 - z\^2\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[
          z_]\  = \ \ \[ImaginaryI]\ \@\(1\  - \ z\^2\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", \@\(z\^2\  - \ 1\)];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The branch we will use for graphing\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["The image is traced using a graph.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f, z];\)\ \), "\n", 
    \(\(f[z_]\  = \ \ \[ImaginaryI]\ \@\(1\  - \ z\^2\);\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Identity, {\(-3\), 3, 0.5}, {0.00005, 1.35005, 
          0.09}, \[IndentingNewLine]PlotRange \[Rule] {{\(-3\), 3}, {0, 
              1.4}}, AspectRatio \[Rule] 
          1\/3, \[IndentingNewLine]Ticks \[Rule] {Range[\(-3\), 3, 1], 
            Range[0, 1, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The upper half-plane Im[z] > 0.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(CartesianMap[f, {\(-3\), 3, 0.5}, {\(-0.00005\), 1.35005, 0.09}, 
        PlotRange \[Rule] {{\(-3\), 3}, {0, 1.75}}, AspectRatio \[Rule] 1\/3, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[0, 2, 1]}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Red, Blue}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image is the upper-half plane Im[w] > 0,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<slit along the segment u = 0, 0 < v \[LessEqual] 1,\>"];\)\ \
\), "\n", 
    \(\(Print["\<under the mapping  w = \>", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe see that the transformation  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \[ImaginaryI]\ \@\(1\  - \ z\^2\)\)\)],
    AspectRatioFixed->True],
  "  maps the upper half-plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  one-to-one and onto the upper-half plane  ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  "  slit along the segment  ",
  Cell[BoxData[
      \(u = 0, 0 < v \[LessEqual] 1\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark 10.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  The images of the horizontal lines ",
  Cell[BoxData[
      \(y = b\)]],
  " are curves in the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane that bend around the segment from  ",
  Cell[BoxData[
      RowBox[{"0", "  ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "\[ImaginaryI]"}]]],
  ".  The curves represent the streamlines of a fluid flowing across the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane. We discuss fluid flows in more detail in Section 10.7.  "
}], "Text"],

Cell[TextData[{
  StyleBox["10.3.1  The Mapping",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(w = \((z\^2 - 1)\)\^\(1/2\)\)],
    AspectRatioFixed->True,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "\tThe double-valued function  ",
  Cell[BoxData[
      \(f \((z)\) = \((z\^2 - 1)\)\^\(1\/2\)\)],
    AspectRatioFixed->True],
  "  has a branch that is continuous for values of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " distant from the origin.  This feature is motivated by our desire for the \
approximation  ",
  Cell[BoxData[
      \(\((z\^2 - 1)\)\^\(1\/2\)\ \  \[TildeTilde] \ \ z\)],
    AspectRatioFixed->True],
  "  to hold for values of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " distant from the origin.  We begin by expressing ",
  Cell[BoxData[
      \(\((z\^2 - 1)\)\^\(1\/2\)\)],
    AspectRatioFixed->True],
  " as  \n\n",
  StyleBox["(10-22)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(w\ \  = \ \ \(\(f\_1\) \((z)\)\ \  = \ \ \(\((z - 
                    1)\)\^\(1\/2\)\) \((z + 1)\)\^\(1\/2\)\)\)],
    AspectRatioFixed->True],
  ",  \n\nwhere the principal branch of the square root function is used in \
both factors.  We claim that the mapping  ",
  Cell[BoxData[
      \(w\ \  = \ \ \(f\_1\) \((z)\)\)],
    AspectRatioFixed->True],
  "  is a one-to-one conformal mapping from the domain set ",
  Cell[BoxData[
      \(D\_1\)],
    AspectRatioFixed->True],
  ", consisting of the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane slit along the segment  ",
  Cell[BoxData[
      \(\(-1\) \[LessEqual] x \[LessEqual] 1, y = 0\)]],
  ",  onto the range set ",
  Cell[BoxData[
      \(H\_1\)],
    AspectRatioFixed->True],
  ", consisting of the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane \nslit along the segment  ",
  Cell[BoxData[
      \(u = 0, \(-1\) \[LessEqual] v \[LessEqual] 1\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tTo verify this claim, we investigate the two formulas on the right side \
of Equation ",
  StyleBox["(10-22)",
    FontColor->RGBColor[0, 0, 1]],
  " and express them in the form  \n\n\t\t\t",
  Cell[BoxData[
      \(\((z - 1)\)\^\(1\/2\)\ \  = \ \ \(\@r\_1\) \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Theta]\_1/2\)\)],
    AspectRatioFixed->True],
  "  \n\n    where  ",
  Cell[BoxData[
      \(r\_1\  = \ \(\(|\)\(z - 1\)\(|\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Theta]\_1\  = \ Arg \((z - 1)\)\)]],
  ",  and  \n    \n    \t\t\t",
  Cell[BoxData[
      \(\((z + 1)\)\^\(1\/2\)\ \  = \ \ \(\@r\_2\) \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Theta]\_2/2\)\)],
    AspectRatioFixed->True],
  "  \n\n    where  ",
  Cell[BoxData[
      \(r\_2\  = \ \(\(|\)\(z + 1\)\(|\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\[Theta]\_2\  = \ Arg \((z + 1)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe discontinuities of  ",
  Cell[BoxData[
      RowBox[{\(\[Theta]\_1\), "Arg", \((z - 1)\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", "Arg", \((z + 1)\)}]]],
  "  are points on the real axis such that  ",
  Cell[BoxData[
      RowBox[{"x", "\[LessEqual]", 
        RowBox[{"1", "  ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", "x"}], 
        "\[LessEqual]", \(-1\)}]]],
  ",  respectively.  We now show that ",
  Cell[BoxData[
      \(\(f\_1\) \((z)\)\)],
    AspectRatioFixed->True],
  " is continuous on the ray  ",
  Cell[BoxData[
      \(x < \(-1\), y = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe let  ",
  Cell[BoxData[
      \(z\_0\  = \ x\_0\  + \ \[ImaginaryI]\ y\_0\)]],
  "  denote a point on the ray  ",
  Cell[BoxData[
      \(x < \(-1\), y = 0\)]],
  "  and then obtain the following limit as ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " approaches ",
  Cell[BoxData[
      \(z\_0\)]],
  " from the upper half-plane:   \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\(\(lim\+\ \)\+\(x \[Rule] x\_0\)\)\+\(Im\ z\  > \ 0\)\ \(f\_1\) \
\((z)\)\ \ \  = \ \ \(\(lim\+\ \)\+\(x \[Rule] x\_0\)\)\+\(Im\ z\  > \ 0\)\ \
\(\@r\_1\) \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\_1/
                    2\)\) \(\@r\_2\) \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\_2/2\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\(\(lim\+\ \)\+\(r \[Rule] \(\(|\)\(x\_0 - 1\)\(|\)\)\)\)\+\(\[Theta]\_1 \
\[Rule] \[Pi]\)\ \(\@r\_1\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\_1/2\)\
\ \(\(\(lim\+\ \)\+\(r \[Rule] \(\(|\)\(x\_0 + 1\)\(|\)\)\)\)\+\(\[Theta]\_2 \
\[Rule] \[Pi]\)\ \(\@r\_2\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\_2/2\)\
\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\(\@\(\(|\)\(x\_0 - 
                  1\)\(|\)\)\) \[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/2\)\ \
\(\@\(\(|\)\(x\_0 + 
                  1\)\(|\)\)\) \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Pi]/2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\(\@\(\(|\)\(x\_0 - 1\)\(|\)\)\) \((\[ImaginaryI])\)\ \(\@\(\(|\)\(x\_0 + 
                  1\)\(|\)\)\) \((\[ImaginaryI])\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\(\[ImaginaryI]\^2\) \(\@\(\(|\)\(x\_0 - 
                  
                  1\)\(|\)\)\) \@\(\(|\)\(x\_0 + 1\)\(|\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(-\ \@\(\(|\)\(x\_0 - 1 || x\_0 + 1\)\(|\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\
\(-\ \@\(\(|\)\(x\_0\%2 - 1\)\(|\)\)\)\)\)}]],
  "    "
}], "Text"],

Cell[TextData[{
  "\tWe let  ",
  Cell[BoxData[
      \(z\_0\  = \ x\_0\  + \ \[ImaginaryI]\ y\_0\)]],
  "  denote a point on the ray  ",
  Cell[BoxData[
      \(x < \(-1\), y = 0\)]],
  "  and then obtain the following limits as ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " approaches ",
  Cell[BoxData[
      \(z\_0\)]],
  " from the lower half-plane:  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\(\(lim\+\ \)\+\(x \[Rule] x\_0\)\)\+\(Im\ z\  < \ 0\)\ \(f\_1\) \
\((z)\)\ \ \  = \ \ \(\(lim\+\ \)\+\(x \[Rule] x\_0\)\)\+\(Im\ z\  < \ 0\)\ \
\(\@r\_1\) \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\_1/
                    2\)\) \(\@r\_2\) \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\_2/2\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\(\(lim\+\ \)\+\(r \[Rule] \(\(|\)\(x\_0 - 1\)\(|\)\)\)\)\+\(\[Theta]\_1 \
\[Rule] \(-\[Pi]\)\)\ \(\@r\_1\) \[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\_1/2\)\ \(\(\(lim\+\ \)\+\(r \[Rule] \(\(|\)\(x\_0 + \
1\)\(|\)\)\)\)\+\(\[Theta]\_2 \[Rule] \(-\[Pi]\)\)\ \(\@r\_2\) \
\[ExponentialE]\^\(\[ImaginaryI]\ \
\[Theta]\_2/2\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\(\@\(\(|\)\(x\_0 - 
                  1\)\(|\)\)\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/2\
\)\ \(\@\(\(|\)\(x\_0 + 
                  1\)\(|\)\)\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Pi]/2\
\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\(\@\(\(|\)\(x\_0 - 
                  1\)\(|\)\)\) \((\(-\[ImaginaryI]\))\)\ \(\@\(\(|\)\(x\_0 + 
                  1\)\(|\)\)\) \((\(-\[ImaginaryI]\))\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(\(\((\(-\[ImaginaryI]\))\)\^2\) \(\@\(\(|\)\(x\_0 - 
                  1\)\(|\)\)\) \@\(\(|\)\(x\_0 + 1\)\(|\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \
\)\(-\ \@\(\(|\)\(x\_0 - 1 || x\_0 + 1\)\(|\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\
\(-\ \@\(\(|\)\(x\_0\%2 - 1\)\(|\)\)\)\)\)}]],
  "      "
}], "Text"],

Cell[TextData[{
  "\tWe can easily find the inverse mapping and express it similarly:  \n\n\t\
\t\t",
  Cell[BoxData[
      \(z\ \  = \ \ \(\(g\_1\) \((w)\)\ \  = \ \ \(\((w\^2 + 1)\)\^\(1\/2\)\ \
\  = \ \ \(\((w + \[ImaginaryI])\)\^\(1\/2\)\) \((w - \
\[ImaginaryI])\)\^\(1\/2\)\)\)\)]],
  ",  \n\n    where the branches of the square root function are given by  \n \
   \n    \t\t\t",
  Cell[BoxData[
      \(\((w + \[ImaginaryI])\)\^\(1\/2\)\ \  = \ \ \(\@\[Rho]\_1\) \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\_1/2\)\)],
    AspectRatioFixed->True],
  "  \n\n    where  ",
  Cell[BoxData[
      \(\[Rho]\_1\  = \ \(\(|\)\(w + \[ImaginaryI]\)\(|\)\)\)]],
  ",  ",
  Cell[BoxData[
      \(\[Phi]\_1\  = \ \(arg\_\(\(-\[Pi]\)/
                2\)\) \((w + \[ImaginaryI])\)\)]],
  ",  and  ",
  Cell[BoxData[
      \(\(-\(\[Pi]\/2\)\) < \(arg\_\(\(-\[Pi]\)/
                2\)\) \((w + \[ImaginaryI])\) < \(3  \[Pi]\)\/2\)]],
  ",  \n    \n    \t\t\t",
  Cell[BoxData[
      \(\((w - \[ImaginaryI])\)\^\(1\/2\)\ \  = \ \ \(\@\[Rho]\_2\) \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\_2/2\)\)],
    AspectRatioFixed->True],
  "  \n\n    where  ",
  Cell[BoxData[
      \(\[Rho]\_2\  = \ \(\(|\)\(w - \[ImaginaryI]\)\(|\)\)\)]],
  ",  ",
  Cell[BoxData[
      \(\[Phi]\_2\  = \ \(arg\_\(\(-\[Pi]\)/
                2\)\) \((w - \[ImaginaryI])\)\)]],
  ",  and  ",
  Cell[BoxData[
      \(\(-\(\[Pi]\/2\)\) < \(arg\_\(\(-\[Pi]\)/
                2\)\) \((w - \[ImaginaryI])\) < \(3  \[Pi]\)\/2\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tA similar argument shows that  ",
  Cell[BoxData[
      \(\(g\_1\) \((w)\)\)]],
  "  is continuous for all ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " except those points that lie on the segment  ",
  Cell[BoxData[
      \(u = 0, \(-1\) \[LessEqual] v \[LessEqual] 1\)]],
  ".  Verification that  \n\n\t\t\t",
  Cell[BoxData[
      \(\(g\_1\) \((\(f\_1\) \((z)\))\)\  = \ z\)]],
  "   and   ",
  Cell[BoxData[
      \(\(f\_1\) \((\(g\_1\) \((w)\))\)\  = \ w\)]],
  "\n\nhold for z in ",
  Cell[BoxData[
      \(D\_1\)]],
  " and ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " in ",
  Cell[BoxData[
      \(H\_1\)],
    AspectRatioFixed->True],
  ", respectively, is straightforward.  Therefore we conclude that  ",
  Cell[BoxData[
      \(w\ \  = \ \ \(\(f\_1\) \((z)\)\ \  = \ \ \(\((z - 
                    1)\)\^\(1\/2\)\) \((z + 1)\)\^\(1\/2\)\)\)],
    AspectRatioFixed->True],
  "  is a one-to-one mapping from ",
  Cell[BoxData[
      \(D\_1\)]],
  " onto ",
  Cell[BoxData[
      \(H\_1\)],
    AspectRatioFixed->True],
  ".  Verifying that ",
  Cell[BoxData[
      \(\(f\_1\) \((z)\)\)],
    AspectRatioFixed->True],
  " is also ",
  StyleBox["analytic",
    FontColor->RGBColor[0, 0, 1]],
  " on the ray  ",
  Cell[BoxData[
      \(x < \(-1\), y = 0\)]],
  ",  is tedious.  We leave it as a challenging exercise.  "
}], "Text"],

Cell[TextData[{
  StyleBox["10.3.2  The Riemann Surface for  ",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(w = \((z\^2 - 1)\)\^\(1/2\)\)],
    AspectRatioFixed->True,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  "\tUsing the other branch of the square root, we find that ",
  Cell[BoxData[
      \(w = \(\(f\_2\) \((z)\) = \(-f\_1\) \((z)\)\)\)]],
  ", is a one-to-one conformal mapping from the domain set ",
  Cell[BoxData[
      \(D\_2\)]],
  " consisting of the z-plane slit along the segment ",
  Cell[BoxData[
      \(\(-1\) \[LessEqual] x \[LessEqual] 1, y = 0\)]],
  ", onto the range set ",
  Cell[BoxData[
      \(H\_2\)]],
  " consisting of the w-plane slit along the segment ",
  Cell[BoxData[
      \(u = 0, \(-1\) \[LessEqual] v \[LessEqual] 1\)]],
  ".  The sets ",
  Cell[BoxData[
      \(D\_1\)]],
  " and ",
  Cell[BoxData[
      \(H\_1\)]],
  " for ",
  Cell[BoxData[
      \(\(f\_1\) \((z)\)\)]],
  " and ",
  Cell[BoxData[
      \(D\_2\)]],
  " and ",
  Cell[BoxData[
      \(H\_2\)]],
  " form the ",
  StyleBox[ButtonBox["Riemann surface",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/RiemannSurface.html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " for the mapping, as shown in Figure 10.14.  "
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 10.14",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/mapelementaryfun/\
MapElementaryFunFigures/mat1014.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The mappings  ",
  Cell[BoxData[
      \(w\  = \ \(f\_1\) \((z)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(w\  = \ \(f\_2\) \((z)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tWe obtain the Riemann surface for  ",
  Cell[BoxData[
      \(w\  = \ \((z\^2 - 1)\)\^\(1\/2\)\)],
    AspectRatioFixed->True],
  "  by gluing the edges of ",
  Cell[BoxData[
      RowBox[{\(D\_1\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " "}]]],
  Cell[BoxData[
      \(D\_2\)]],
  " together and the edges of ",
  Cell[BoxData[
      RowBox[{\(H\_1\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(H\_2\)}]]],
  " together.  In the domain set, we glue edges  ",
  Cell[BoxData[
      RowBox[{"A", " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "a"}]]],
  ",  ",
  Cell[BoxData[
      RowBox[{"B", " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "b"}]]],
  ",  ",
  Cell[BoxData[
      RowBox[{"C", " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "c"}]]],
  ",  and  ",
  Cell[BoxData[
      RowBox[{"D", " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "d"}]]],
  ".  In the image set, we glue edges  ",
  Cell[BoxData[
      RowBox[{\(A'\), " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(a'\)}]]],
  ",  ",
  Cell[BoxData[
      RowBox[{\(B'\), " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(b'\)}]]],
  ",  ",
  Cell[BoxData[
      RowBox[{\(C'\), " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(c'\)}]]],
  ",  and   ",
  Cell[BoxData[
      RowBox[{\(D'\), " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(d'\)}]]],
  ".  The result is a Riemann domain surface and Riemann image surface for \
the mapping, as illustrated in Figures 10.15(a) and 10.15(b), respectively. "
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 10.15",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/mapelementaryfun/\
MapElementaryFunFigures/mat1015.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The Riemann surfaces for the mapping  ",
  Cell[BoxData[
      \(w\  = \ \((z\^2\  - \ 1)\)\^\(1/2\)\)],
    AspectRatioFixed->True],
  "."
}], "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Conformal Mapping",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ConformalMappingBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Exponential Function",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ExponentialFunBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Logarithms",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/LogarithmFunBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Mobius - Bilinear Transformation",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/MobiusTranformationBib.\
html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Smith Chart",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/SmithChartBib.html"], None},
  
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Quasiconformal Mapping",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/QuasiConformalMappingBib.\
html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Riemann Surfaces",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/RiemannSurfaceBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
CellGrouping->Manual,
WindowSize->{965, 634},
WindowMargins->{{12, Automatic}, {Automatic, 2}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 356996, 6629}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 134, 2, 33, "Text"],
Cell[2239, 66, 1908, 56, 128, "Text"],
Cell[4150, 124, 476, 16, 33, "Text"],
Cell[4629, 142, 160, 3, 33, "Text"],
Cell[4792, 147, 774, 24, 56, "Text",
  Evaluatable->False],
Cell[5569, 173, 80608, 1324, 146, 80494, 1320, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[86180, 1499, 1601, 52, 98, "Text"],
Cell[87784, 1553, 581, 18, 37, "Text"],

Cell[CellGroupData[{
Cell[88390, 1575, 112, 2, 33, "Text"],
Cell[88505, 1579, 219, 7, 37, "Text"],
Cell[88727, 1588, 366, 8, 125, "Input"],
Cell[89096, 1598, 315, 9, 37, "Text",
  Evaluatable->False],
Cell[89414, 1609, 794, 17, 250, "Input"],
Cell[90211, 1628, 98, 2, 33, "Text",
  Evaluatable->False],
Cell[90312, 1632, 1383, 26, 325, "Input"],
Cell[91698, 1660, 458, 15, 56, "Text",
  Evaluatable->False]
}, Closed]],
Cell[92171, 1678, 788, 25, 56, "Text",
  Evaluatable->False],
Cell[92962, 1705, 74236, 1220, 146, 74122, 1216, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[167201, 2927, 1522, 48, 102, "Text"],
Cell[168726, 2977, 531, 17, 36, "Text"],

Cell[CellGroupData[{
Cell[169282, 2998, 112, 2, 33, "Text"],
Cell[169397, 3002, 169, 6, 36, "Text"],
Cell[169569, 3010, 306, 6, 124, "Input"],
Cell[169878, 3018, 266, 8, 36, "Text",
  Evaluatable->False],
Cell[170147, 3028, 792, 17, 250, "Input"],
Cell[170942, 3047, 98, 2, 33, "Text",
  Evaluatable->False],
Cell[171043, 3051, 1456, 29, 346, "Input"],
Cell[172502, 3082, 445, 14, 55, "Text",
  Evaluatable->False]
}, Closed]],
Cell[172962, 3099, 907, 25, 75, "Text",
  Evaluatable->False],
Cell[173872, 3126, 83073, 1365, 146, 82959, 1361, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[256948, 4493, 1295, 41, 81, "Text"],
Cell[258246, 4536, 531, 17, 36, "Text"],

Cell[CellGroupData[{
Cell[258802, 4557, 113, 2, 33, "Text"],
Cell[258918, 4561, 169, 6, 40, "Text"],
Cell[259090, 4569, 305, 6, 130, "Input"],
Cell[259398, 4577, 343, 9, 40, "Text",
  Evaluatable->False],
Cell[259744, 4588, 778, 17, 250, "Input"],
Cell[260525, 4607, 98, 2, 33, "Text",
  Evaluatable->False],
Cell[260626, 4611, 1223, 24, 318, "Input"],
Cell[261852, 4637, 506, 17, 78, "Text",
  Evaluatable->False]
}, Closed]],
Cell[262373, 4657, 1238, 43, 79, "Text",
  Evaluatable->False],
Cell[263614, 4702, 65249, 1073, 141, 65135, 1069, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[328866, 5777, 526, 18, 56, "Text"],
Cell[329395, 5797, 649, 23, 37, "Text"],

Cell[CellGroupData[{
Cell[330069, 5824, 113, 2, 33, "Text"],
Cell[330185, 5828, 149, 6, 33, "Text"],
Cell[330337, 5836, 291, 6, 113, "Input"],
Cell[330631, 5844, 298, 10, 33, "Text",
  Evaluatable->False],
Cell[330932, 5856, 743, 16, 233, "Input"],
Cell[331678, 5874, 435, 13, 52, "Text",
  Evaluatable->False],
Cell[332116, 5889, 384, 9, 117, "Input"],
Cell[332503, 5900, 98, 2, 33, "Text",
  Evaluatable->False],
Cell[332604, 5904, 1421, 26, 324, "Input"],
Cell[334028, 5932, 438, 15, 71, "Text"]
}, Closed]],
Cell[334481, 5950, 841, 25, 49, "Text"],
Cell[335325, 5977, 338, 12, 33, "Text"],
Cell[335666, 5991, 1731, 54, 178, "Text"],
Cell[337400, 6047, 893, 28, 193, "Text"],
Cell[338296, 6077, 1093, 33, 52, "Text"],
Cell[339392, 6112, 2443, 51, 362, "Text"],
Cell[341838, 6165, 2490, 53, 362, "Text"],
Cell[344331, 6220, 1512, 41, 279, "Text"],
Cell[345846, 6263, 1378, 49, 132, "Text"],
Cell[347227, 6314, 276, 9, 33, "Text"],
Cell[347506, 6325, 1092, 38, 71, "Text"],
Cell[348601, 6365, 534, 19, 33, "Text"],
Cell[349138, 6386, 3828, 119, 75, "Text"],
Cell[352969, 6507, 528, 17, 33, "Text"],
Cell[353500, 6526, 290, 7, 33, "Text"],
Cell[353793, 6535, 291, 7, 33, "Text"],
Cell[354087, 6544, 292, 7, 33, "Text"],
Cell[354382, 6553, 288, 7, 33, "Text"],
Cell[354673, 6562, 306, 7, 33, "Text"],
Cell[354982, 6571, 277, 7, 33, "Text"],
Cell[355262, 6580, 298, 7, 33, "Text"],
Cell[355563, 6589, 288, 7, 33, "Text"],
Cell[355854, 6598, 257, 5, 33, "Text"],
Cell[356114, 6605, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

