(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    136479,       2519]*)
(*NotebookOutlinePosition[    137512,       2556]*)
(*  CellTagsIndexPosition[    137435,       2550]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 11  Applications of Harmonic Functions",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[StyleBox["11.1  Preliminaries",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Overview",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tA wide variety of problems in engineering and physics involve \
harmonic functions, which are the real or imaginary part of an analytic \
function.  The standard applications are two dimensional steady state \
temperatures, electrostatics, fluid flow and complex potentials.  The \
techniques of conformal mapping and integral representation can be used to \
construct a harmonic function with prescribed boundary values.  Noteworthy \
methods include Poisson's integral formulae; the Joukowski transformation; \
and Schwarz-Christoffel transformation.  Modern computer software is capable \
of implemeting these complex analysis methods."
}], "Text"],

Cell[TextData[{
  "\tIn most applications involving harmonic functions, a ",
  ButtonBox["harmonic function",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/HarmonicFunction.html"], None},
    ButtonStyle->"Hyperlink"],
  " that takes on prescribed values along certain contours must be found.  ",
  "In presenting the material in this chapter, we assume that you are \
familiar with the material covered in Sections 2.5, 3.3, 5.1, and 5.2.  If \
you aren't, please review it before proceeding. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 11.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the function ",
  StyleBox["u(x,y)",
    FontFamily->"Courier New"],
  " that is harmonic in the vertical strip ",
  Cell[BoxData[
      \(a < Re \((z)\) < b\)]],
  " and takes on the boundary values\n\n\t\t\t",
  Cell[BoxData[
      \(u \((a, y)\)\  = \ U\_1\)]],
  "    for all  ",
  StyleBox["y",
    FontFamily->"Courier New"],
  ",  and\n\t\t\t",
  Cell[BoxData[
      \(u \((b, y)\)\  = \ U\_2\)]],
  "    for all  ",
  StyleBox["y",
    FontFamily->"Courier New"],
  ", \n\nalong the vertical lines  ",
  Cell[BoxData[
      RowBox[{"x", "=", 
        RowBox[{
          RowBox[{"a", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "x"}], "=", "b"}]}]]],
  ",  respectively."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004`0000`R000`400?l0
0000o`00003oo`3ooola0?ooo`00o`3ooola0?ooo`00o`3ooola0?ooo`00
o`3ooola0?ooo`00o`3ooola0?ooo`00o`3ooola0?ooo`00o`3ooola0?oo
o`00o`3ooola0?ooo`00o`3ooola0?ooo`00o`3ooola0?ooo`00o`3ooola
0?ooo`00o`3ooola0?ooo`00o`3ooola0?ooo`00Q`3oool5000001@0oooo
1@0000020?ooo`8000000`3oool4000000l0oooo1@0000020?ooo`800000
1@3oool3000000h0oooo1@0000020?ooo`8000000`3oool300000100oooo
1@0000020?ooo`800000103oool2000001H0oooo1000000:0?ooo`00R@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool01`3oool010000000oooo0?oo
o`00000A0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
00005@3oool00`000000oooo0?ooo`0;0?ooo`00R@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`070?ooo`D00000403oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3o
ool01`3oool010000000oooo0?ooo`00000F0?ooo`030000003oool0oooo
00X0oooo00290?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`070?oo
o`<000004P3oool00`000000oooo0?ooo`080?ooo`800000603oool00`00
0000oooo0?ooo`090?ooo`00R@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool000004@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool000000140oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00L0oooo00@000000?ooo`3oool000005@3oool010000000oooo0?ooo`00
000:0?ooo`00R03oool2000001L0oooo0P00000:0?ooo`8000004@3oool2
000000/0oooo0P00000@0?ooo`8000002P3oool300000100oooo0P00000:
0?ooo`8000005`3oool2000000/0oooo003o0?oooc40oooo003o0?oooc40
oooo003o0?oooc40oooo003o0?oooc40oooo00260?oooj800000203oool0
08H0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`040000003oool0oooo000000P0oooo001o0?ooo`D000000P3oool0
0`000000oooo0?ooo`2N0?ooo`030000003oool0oooo00H0oooo00210?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?ooo`80
000000<0oooo0000003oool07@3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0L0?ooo`040000003oool00000000000P0oooo001i0?ooo`@0
0000103oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
01h0o`2L00<0000005<0o`1C0?l0701C0?l00`0000000;co002lo`0L002l
o`0300000000oc@00?ld01`00?ld00<000000=_o003Ko`00703Ko`001000
0000oooo0?ooo`0000080?ooo`00P@3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l0
0`0000000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<00000
0=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00P03oool2
000000@0oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0
o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000
oc@00`000000fol00=_o000L0=_o00040000003oool0oooo000000P0oooo
00260?ooo`040000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0
701C0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld
00<000000=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00
QP3oool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0
D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L003o=003
0000003Ko`00fol001`0fol000@000000?ooo`3oool00000203oool008H0
oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L05<0
o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000oc@00`00
0000fol00=_o000L0=_o00040000003oool0oooo000000P0oooo00260?oo
o`040000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l0
0`0000000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<00000
0=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3oool0
10000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o00<0
0000002lo`00_?l07000_?l00`0000000?ld003o=00L003o=0030000003K
o`00fol001`0fol000@000000?ooo`3oool00000203oool008H0oooo00@0
00000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L05<0o`030000
0000_?l00;co01`00;co00<00000003o=000oc@07000oc@00`000000fol0
0=_o000L0=_o00040000003oool0oooo000000P0oooo00260?ooo`040000
003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`000000
0;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<000000=_o003K
o`00703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3oool010000000
oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o00<00000002l
o`00_?l07000_?l00`0000000?ld003o=00L003o=0030000003Ko`00fol0
01`0fol000@000000?ooo`3oool00000203oool008H0oooo00@000000?oo
o`3oool000007P3o09`00`000000D`3o05<0o`0L05<0o`0300000000_?l0
0;co01`00;co00<00000003o=000oc@07000oc@00`000000fol00=_o000L
0=_o00040000003oool0oooo000000P0oooo00260?ooo`040000003oool0
oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`0000000;co002l
o`0L002lo`0300000000oc@00?ld01`00?ld00<000000=_o003Ko`00703K
o`0010000000oooo0?ooo`0000080?ooo`00QP3oool010000000oooo0?oo
o`00000N0?l0W0030000001C0?l0D`3o01`0D`3o00<00000002lo`00_?l0
7000_?l00`0000000?ld003o=00L003o=0030000003Ko`00fol001`0fol0
00@000000?ooo`3oool00000203oool008H0oooo00@000000?ooo`3oool0
00007P3o09`00`000000D`3o05<0o`0L05<0o`0300000000_?l00;co01`0
0;co00<00000003o=000oc@07000oc@00`000000fol00=_o000L0=_o0004
0000003oool0oooo000000P0oooo00260?ooo`040000003oool0oooo0000
01h0o`2L00<0000005<0o`1C0?l0701C0?l00`0000000;co002lo`0L002l
o`0300000000oc@00?ld01`00?ld00<000000=_o003Ko`00703Ko`001000
0000oooo0?ooo`0000080?ooo`00QP3oool010000000oooo0?ooo`00000N
0?l0W0030000001C0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l0
0`0000000?ld003o=00L003o=0030000003Ko`00fol001`0fol000@00000
0?ooo`3oool00000203oool008H0oooo00@000000?ooo`3oool000007P3o
09`00`000000D`3o05<0o`0L05<0o`0300000000_?l00;co01`00;co00<0
0000003o=000oc@07000oc@00`000000fol00=_o000L0=_o00040000003o
ool0oooo000000P0oooo00260?ooo`040000003oool0oooo000001h0o`2L
00<0000005<0o`1C0?l0701C0?l00`0000000;co002lo`0L002lo`030000
0000oc@00?ld01`00?ld00<000000=_o003Ko`00703Ko`0010000000oooo
0?ooo`0000080?ooo`00QP3oool010000000oooo0?ooo`00000N0?l0W003
0000001C0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`000000
0?ld003o=00L003o=0030000003Ko`00fol001`0fol000@000000?ooo`3o
ool00000203oool008H0oooo00@000000?ooo`3oool000007P3o09`00`00
0000D`3o05<0o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o
=000oc@07000oc@00`000000fol00=_o000L0=_o00040000003oool0oooo
000000P0oooo00260?ooo`040000003oool0oooo000001h0o`2L00<00000
05<0o`1C0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000oc@0
0?ld01`00?ld00<000000=_o003Ko`00703Ko`0010000000oooo0?ooo`00
00080?ooo`00QP3oool010000000oooo0?ooo`00000N0?l0W0030000001C
0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o
=00L003o=0030000003Ko`00fol001`0fol000@000000?ooo`3oool00000
203oool008H0oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o
05<0o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o=000oc@0
7000oc@00`000000fol00=_o000L0=_o00040000003oool0oooo000000P0
oooo00260?ooo`040000003oool0oooo000001h0o`2L00<0000005<0o`1C
0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld01`0
0?ld00<000000=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?oo
o`00QP3oool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o
01`0D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L003o
=0030000003Ko`00fol001`0fol000@000000?ooo`3oool00000203oool0
08H0oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L
05<0o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000oc@0
0`000000fol00=_o000L0=_o00040000003oool0oooo000000P0oooo0026
0?ooo`040000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C
0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<0
00000=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3o
ool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o
00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L003o=0030000
003Ko`00fol001`0fol000@000000?ooo`3oool00000203oool008H0oooo
00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L05<0o`03
00000000_?l00;co01`00;co00<00000003o=000oc@07000oc@00`000000
fol00=_o000L0=_o00040000003oool0oooo000000P0oooo00260?ooo`04
0000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`00
00000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<000000=_o
003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3oool01000
0000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o00<00000
002lo`00_?l07000_?l00`0000000?ld003o=00L003o=0030000003Ko`00
fol001`0fol000@000000?ooo`3oool00000203oool008H0oooo00@00000
0?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L05<0o`0300000000
_?l00;co01`00;co00<00000003o=000oc@07000oc@00`000000fol00=_o
000L0=_o00040000003oool0oooo000000P0oooo00260?ooo`040000003o
ool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`0000000;co
002lo`0L002lo`0300000000oc@00?ld01`00?ld00<000000=_o003Ko`00
703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3oool010000000oooo
0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o00<00000002lo`00
_?l07000_?l00`0000000?ld003o=00L003o=0030000003Ko`00fol001`0
fol000@000000?ooo`3oool00000203oool007@0oooo0P0000040?ooo`80
0000103oool2000000@0oooo00@000000?ooo`3oool000007P3o09`00`00
0000D`3o05<0o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o
=000oc@07000oc@00`000000fol00=_o000L0=_o00040000003oool0oooo
000000P0oooo001c0?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000`3oool010000000oooo0?ooo`00000N0?l0W0030000
001C0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`0000000?ld
003o=00L003o=0030000003Ko`00fol001`0fol000@000000?ooo`3oool0
0000203oool007<0oooo00@000000?ooo`3oool000002`3oool010000000
oooo0?ooo`3oool2000000030?ooo`000000o`2L01d0o`2L00<0000005<0
o`1C0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld
01`00?ld00<000000=_o003Ko`00703Ko`0010000000oooo000000000008
0?ooo`00K@3oool400000080oooo00@000000?ooo`3oool000002@3oool2
000000@0oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0
o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000
oc@00`000000fol00=_o000L0=_o00040000003oool0oooo000000P0oooo
001c0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0
D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L003o=003
0000003Ko`00fol001`0fol000@000000?ooo`3oool00000203oool007@0
oooo0P00000:0?ooo`<000000`3oool010000000oooo0?ooo`00000N0?l0
W0030000001C0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`00
00000?ld003o=00L003o=0030000003Ko`00fol001`0fol000@000000?oo
o`3oool00000203oool008H0oooo00@000000?ooo`3oool000007P3o09`0
0`000000D`3o05<0o`0L05<0o`0300000000_?l00;co01`00;co00<00000
003o=000oc@07000oc@00`000000fol00=_o000L0=_o00040000003oool0
oooo000000P0oooo00260?ooo`040000003oool0oooo000001h0o`2L00<0
000005<0o`1C0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000
oc@00?ld01`00?ld00<000000=_o003Ko`00703Ko`0010000000oooo0?oo
o`0000080?ooo`00QP3oool010000000oooo0?ooo`00000N0?l0W0030000
001C0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`0000000?ld
003o=00L003o=0030000003Ko`00fol001`0fol000@000000?ooo`3oool0
0000203oool008H0oooo00@000000?ooo`3oool000007P3o09`00`000000
D`3o05<0o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o=000
oc@07000oc@00`000000fol00=_o000L0=_o00040000003oool0oooo0000
00P0oooo00260?ooo`040000003oool0oooo000001h0o`2L00<0000005<0
o`1C0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld
01`00?ld00<000000=_o003Ko`00703Ko`0010000000oooo0?ooo`000008
0?ooo`00QP3oool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0
D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L
003o=0030000003Ko`00fol001`0fol000@000000?ooo`3oool00000203o
ool008H0oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0
o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000
oc@00`000000fol00=_o000L0=_o00040000003oool0oooo000000P0oooo
00260?ooo`040000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0
701C0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld
00<000000=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00
QP3oool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0
D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L003o=003
0000003Ko`00fol001`0fol000@000000?ooo`3oool00000203oool008H0
oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L05<0
o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000oc@00`00
0000fol00=_o000L0=_o00040000003oool0oooo000000P0oooo00260?oo
o`040000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l0
0`0000000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<00000
0=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3oool0
10000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o00<0
0000002lo`00_?l07000_?l00`0000000?ld003o=00L003o=0030000003K
o`00fol001`0fol000@000000?ooo`3oool00000203oool008H0oooo00@0
00000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L05<0o`030000
0000_?l00;co01`00;co00<00000003o=000oc@07000oc@00`000000fol0
0=_o000L0=_o00040000003oool0oooo000000P0oooo00260?ooo`040000
003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`000000
0;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<000000=_o003K
o`00703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3oool010000000
oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o00<00000002l
o`00_?l07000_?l00`0000000?ld003o=00L003o=0030000003Ko`00fol0
01`0fol000@000000?ooo`3oool00000203oool008H0oooo00@000000?oo
o`3oool000007P3o09`00`000000D`3o05<0o`0L05<0o`0300000000_?l0
0;co01`00;co00<00000003o=000oc@07000oc@00`000000fol00=_o000L
0=_o00040000003oool0oooo000000P0oooo00260?ooo`040000003oool0
oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`0000000;co002l
o`0L002lo`0300000000oc@00?ld01`00?ld00<000000=_o003Ko`00703K
o`0010000000oooo0?ooo`0000080?ooo`00QP3oool010000000oooo0?oo
o`00000N0?l0W0030000001C0?l0D`3o01`0D`3o00<00000002lo`00_?l0
7000_?l00`0000000?ld003o=00L003o=0030000003Ko`00fol001`0fol0
00@000000?ooo`3oool00000203oool008H0oooo00@000000?ooo`3oool0
00007P3o09`00`000000D`3o05<0o`0L05<0o`0300000000_?l00;co01`0
0;co00<00000003o=000oc@07000oc@00`000000fol00=_o000L0=_o0004
0000003oool0oooo000000P0oooo00260?ooo`040000003oool0oooo0000
01h0o`2L00<0000005<0o`1C0?l0701C0?l00`0000000;co002lo`0L002l
o`0300000000oc@00?ld01`00?ld00<000000=_o003Ko`00703Ko`001000
0000oooo0?ooo`0000080?ooo`00QP3oool010000000oooo0?ooo`00000N
0?l0W0030000001C0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l0
0`0000000?ld003o=00L003o=0030000003Ko`00fol001`0fol000@00000
0?ooo`3oool00000203oool008H0oooo00@000000?ooo`3oool000007P3o
09`00`000000D`3o05<0o`0L05<0o`0300000000_?l00;co01`00;co00<0
0000003o=000oc@07000oc@00`000000fol00=_o000L0=_o00040000003o
ool0oooo000000P0oooo00260?ooo`040000003oool0oooo000001h0o`2L
00<0000005<0o`1C0?l0701C0?l00`0000000;co002lo`0L002lo`030000
0000oc@00?ld01`00?ld00<000000=_o003Ko`00703Ko`0010000000oooo
0?ooo`0000080?ooo`00QP3oool010000000oooo0?ooo`00000N0?l0W003
0000001C0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`000000
0?ld003o=00L003o=0030000003Ko`00fol001`0fol000@000000?ooo`3o
ool00000203oool008H0oooo00@000000?ooo`3oool000007P3o09`00`00
0000D`3o05<0o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o
=000oc@07000oc@00`000000fol00=_o000L0=_o00040000003oool0oooo
000000P0oooo00260?ooo`040000003oool0oooo000001h0o`2L00<00000
05<0o`1C0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000oc@0
0?ld01`00?ld00<000000=_o003Ko`00703Ko`0010000000oooo0?ooo`00
00080?ooo`00QP3oool010000000oooo0?ooo`00000N0?l0W0030000001C
0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o
=00L003o=0030000003Ko`00fol001`0fol000@000000?ooo`3oool00000
203oool008H0oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o
05<0o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o=000oc@0
7000oc@00`000000fol00=_o000L0=_o00040000003oool0oooo000000P0
oooo00260?ooo`040000003oool0oooo000001h0o`2L00<0000005<0o`1C
0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld01`0
0?ld00<000000=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?oo
o`00QP3oool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o
01`0D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L003o
=0030000003Ko`00fol001`0fol000@000000?ooo`3oool00000203oool0
08H0oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L
05<0o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000oc@0
0`000000fol00=_o000L0=_o00040000003oool0oooo000000P0oooo0026
0?ooo`040000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C
0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<0
00000=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3o
ool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o
00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L003o=0030000
003Ko`00fol001`0fol000@000000?ooo`3oool00000203oool00800oooo
0P0000040?ooo`040000003oool0oooo000001h0o`2L00<0000005<0o`1C
0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld01`0
0?ld00<000000=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?oo
o`00O`3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo
000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`0000000;co002lo`0L
002lo`0300000000oc@00?ld01`00?ld00<000000=_o003Ko`00703Ko`00
10000000oooo0?ooo`0000080?ooo`00O`3oool010000000oooo0?ooo`00
00030?ooo`80000000<0oooo0000003o09`07@3o09`00`000000D`3o05<0
o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000
oc@00`000000fol00=_o000L0=_o00040000003oool00000000000P0oooo
001o0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool0
00007P3o09`00`000000D`3o05<0o`0L05<0o`0300000000_?l00;co01`0
0;co00<00000003o=000oc@07000oc@00`000000fol00=_o000L0=_o0004
0000003oool0oooo000000P0oooo001o0?ooo`040000003oool0oooo0000
00<0oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L
05<0o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000oc@0
0`000000fol00=_o000L0=_o00040000003oool0oooo000000P0oooo0020
0?ooo`800000103oool010000000oooo0?ooo`00000N0?l0W0030000001C
0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o
=00L003o=0030000003Ko`00fol001`0fol000@000000?ooo`3oool00000
203oool008H0oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o
05<0o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o=000oc@0
7000oc@00`000000fol00=_o000L0=_o00040000003oool0oooo000000P0
oooo00260?ooo`040000003oool0oooo000001h0o`2L00<0000005<0o`1C
0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld01`0
0?ld00<000000=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?oo
o`00QP3oool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o
01`0D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L003o
=0030000003Ko`00fol001`0fol000@000000?ooo`3oool00000203oool0
08H0oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L
05<0o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000oc@0
0`000000fol00=_o000L0=_o00040000003oool0oooo000000P0oooo0026
0?ooo`040000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C
0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<0
00000=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3o
ool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o
00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L003o=0030000
003Ko`00fol001`0fol000@000000?ooo`3oool00000203oool008H0oooo
00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L05<0o`03
00000000_?l00;co01`00;co00<00000003o=000oc@07000oc@00`000000
fol00=_o000L0=_o00040000003oool0oooo000000P0oooo00260?ooo`04
0000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`00
00000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<000000=_o
003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3oool01000
0000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o00<00000
002lo`00_?l07000_?l00`0000000?ld003o=00L003o=0030000003Ko`00
fol001`0fol000@000000?ooo`3oool00000203oool008H0oooo00@00000
0?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L05<0o`0300000000
_?l00;co01`00;co00<00000003o=000oc@07000oc@00`000000fol00=_o
000L0=_o00040000003oool0oooo000000P0oooo00260?ooo`040000003o
ool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`0000000;co
002lo`0L002lo`0300000000oc@00?ld01`00?ld00<000000=_o003Ko`00
703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3oool010000000oooo
0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o00<00000002lo`00
_?l07000_?l00`0000000?ld003o=00L003o=0030000003Ko`00fol001`0
fol000@000000?ooo`3oool00000203oool008H0oooo00@000000?ooo`3o
ool000007P3o09`00`000000D`3o05<0o`0L05<0o`0300000000_?l00;co
01`00;co00<00000003o=000oc@07000oc@00`000000fol00=_o000L0=_o
00040000003oool0oooo000000P0oooo00260?ooo`040000003oool0oooo
000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`0000000;co002lo`0L
002lo`0300000000oc@00?ld01`00?ld00<000000=_o003Ko`00703Ko`00
10000000oooo0?ooo`0000080?ooo`00QP3oool010000000oooo0?ooo`00
000N0?l0W0030000001C0?l0D`3o01`0D`3o00<00000002lo`00_?l07000
_?l00`0000000?ld003o=00L003o=0030000003Ko`00fol001`0fol000@0
00000?ooo`3oool00000203oool008H0oooo00@000000?ooo`3oool00000
7P3o09`00`000000D`3o05<0o`0L05<0o`0300000000_?l00;co01`00;co
00<00000003o=000oc@07000oc@00`000000fol00=_o000L0=_o00040000
003oool0oooo000000P0oooo00260?ooo`040000003oool0oooo000001h0
o`2L00<0000005<0o`1C0?l0701C0?l00`0000000;co002lo`0L002lo`03
00000000oc@00?ld01`00?ld00<000000=_o003Ko`00703Ko`0010000000
oooo0?ooo`0000080?ooo`00QP3oool010000000oooo0?ooo`00000N0?l0
W0030000001C0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`00
00000?ld003o=00L003o=0030000003Ko`00fol001`0fol000@000000?oo
o`3oool00000203oool008H0oooo00@000000?ooo`3oool000007P3o09`0
0`000000D`3o05<0o`0L05<0o`0300000000_?l00;co01`00;co00<00000
003o=000oc@07000oc@00`000000fol00=_o000L0=_o00040000003oool0
oooo000000P0oooo00260?ooo`040000003oool0oooo000001h0o`2L00<0
000005<0o`1C0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000
oc@00?ld01`00?ld00<000000=_o003Ko`00703Ko`0010000000oooo0?oo
o`0000080?ooo`00QP3oool010000000oooo0?ooo`00000N0?l0W0030000
001C0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`0000000?ld
003o=00L003o=0030000003Ko`00fol001`0fol000@000000?ooo`3oool0
0000203oool008H0oooo00@000000?ooo`3oool000007P3o09`00`000000
D`3o05<0o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o=000
oc@07000oc@00`000000fol00=_o000L0=_o00040000003oool0oooo0000
00P0oooo00260?ooo`040000003oool0oooo000001h0o`2L00<0000005<0
o`1C0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld
01`00?ld00<000000=_o003Ko`00703Ko`0010000000oooo0?ooo`000008
0?ooo`00QP3oool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0
D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L
003o=0030000003Ko`00fol001`0fol000@000000?ooo`3oool00000203o
ool008H0oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0
o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000
oc@00`000000fol00=_o000L0=_o00040000003oool0oooo000000P0oooo
00260?ooo`040000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0
701C0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld
00<000000=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00
QP3oool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0
D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L003o=003
0000003Ko`00fol001`0fol000@000000?ooo`3oool00000203oool008H0
oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L05<0
o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000oc@00`00
0000fol00=_o000L0=_o00040000003oool0oooo000000P0oooo00260?oo
o`040000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l0
0`0000000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<00000
0=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3oool0
10000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o00<0
0000002lo`00_?l07000_?l00`0000000?ld003o=00L003o=0030000003K
o`00fol001`0fol000@000000?ooo`3oool00000203oool008H0oooo00@0
00000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L05<0o`030000
0000_?l00;co01`00;co00<00000003o=000oc@07000oc@00`000000fol0
0=_o000L0=_o00040000003oool0oooo000000P0oooo00260?ooo`040000
003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`000000
0;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<000000=_o003K
o`00703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3oool010000000
oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o00<00000002l
o`00_?l07000_?l00`0000000?ld003o=00L003o=0030000003Ko`00fol0
01`0fol000@000000?ooo`3oool00000203oool007@0oooo0P0000040?oo
o`800000103oool2000000@0oooo00@000000?ooo`3oool000007P3o09`0
0`000000D`3o05<0o`0L05<0o`0300000000_?l00;co01`00;co00<00000
003o=000oc@07000oc@00`000000fol00=_o000L0=_o00040000003oool0
oooo000000P0oooo001c0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`00000N0?l0W003
0000001C0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`000000
0?ld003o=00L003o=0030000003Ko`00fol001`0fol000@000000?ooo`3o
ool00000203oool007<0oooo00@000000?ooo`3oool000002`3oool01000
0000oooo0?ooo`3oool2000000030?ooo`000000o`2L01d0o`2L00<00000
05<0o`1C0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000oc@0
0?ld01`00?ld00<000000=_o003Ko`00703Ko`0010000000oooo00000000
00080?ooo`00L`3oool010000000oooo0?ooo`0000090?ooo`800000103o
ool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o
00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L003o=0030000
003Ko`00fol001`0fol000@000000?ooo`3oool00000203oool007<0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`00
00000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<000000=_o
003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00M03oool20000
00X0oooo0`0000030?ooo`040000003oool0oooo000001h0o`2L00<00000
05<0o`1C0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000oc@0
0?ld01`00?ld00<000000=_o003Ko`00703Ko`0010000000oooo0?ooo`00
00080?ooo`00QP3oool010000000oooo0?ooo`00000N0?l0W0030000001C
0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o
=00L003o=0030000003Ko`00fol001`0fol000@000000?ooo`3oool00000
203oool008H0oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o
05<0o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o=000oc@0
7000oc@00`000000fol00=_o000L0=_o00040000003oool0oooo000000P0
oooo00260?ooo`040000003oool0oooo000001h0o`2L00<0000005<0o`1C
0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld01`0
0?ld00<000000=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?oo
o`00QP3oool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o
01`0D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L003o
=0030000003Ko`00fol001`0fol000@000000?ooo`3oool00000203oool0
08H0oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L
05<0o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000oc@0
0`000000fol00=_o000L0=_o00040000003oool0oooo000000P0oooo0026
0?ooo`040000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C
0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<0
00000=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3o
ool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o
00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L003o=0030000
003Ko`00fol001`0fol000@000000?ooo`3oool00000203oool008H0oooo
00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L05<0o`03
00000000_?l00;co01`00;co00<00000003o=000oc@07000oc@00`000000
fol00=_o000L0=_o00040000003oool0oooo000000P0oooo00260?ooo`04
0000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`00
00000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<000000=_o
003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3oool01000
0000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o00<00000
002lo`00_?l07000_?l00`0000000?ld003o=00L003o=0030000003Ko`00
fol001`0fol000@000000?ooo`3oool00000203oool008H0oooo00@00000
0?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L05<0o`0300000000
_?l00;co01`00;co00<00000003o=000oc@07000oc@00`000000fol00=_o
000L0=_o00040000003oool0oooo000000P0oooo00260?ooo`040000003o
ool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`0000000;co
002lo`0L002lo`0300000000oc@00?ld01`00?ld00<000000=_o003Ko`00
703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3oool010000000oooo
0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o00<00000002lo`00
_?l07000_?l00`0000000?ld003o=00L003o=0030000003Ko`00fol001`0
fol000@000000?ooo`3oool00000203oool008H0oooo00@000000?ooo`3o
ool000007P3o09`00`000000D`3o05<0o`0L05<0o`0300000000_?l00;co
01`00;co00<00000003o=000oc@07000oc@00`000000fol00=_o000L0=_o
00040000003oool0oooo000000P0oooo00260?ooo`040000003oool0oooo
000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`0000000;co002lo`0L
002lo`0300000000oc@00?ld01`00?ld00<000000=_o003Ko`00703Ko`00
10000000oooo0?ooo`0000080?ooo`00QP3oool010000000oooo0?ooo`00
000N0?l0W0030000001C0?l0D`3o01`0D`3o00<00000002lo`00_?l07000
_?l00`0000000?ld003o=00L003o=0030000003Ko`00fol001`0fol000@0
00000?ooo`3oool00000203oool008H0oooo00@000000?ooo`3oool00000
7P3o09`00`000000D`3o05<0o`0L05<0o`0300000000_?l00;co01`00;co
00<00000003o=000oc@07000oc@00`000000fol00=_o000L0=_o00040000
003oool0oooo000000P0oooo00260?ooo`040000003oool0oooo000001h0
o`2L00<0000005<0o`1C0?l0701C0?l00`0000000;co002lo`0L002lo`03
00000000oc@00?ld01`00?ld00<000000=_o003Ko`00703Ko`0010000000
oooo0?ooo`0000080?ooo`00QP3oool010000000oooo0?ooo`00000N0?l0
W0030000001C0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`00
00000?ld003o=00L003o=0030000003Ko`00fol001`0fol000@000000?oo
o`3oool00000203oool008H0oooo00@000000?ooo`3oool000007P3o09`0
0`000000D`3o05<0o`0L05<0o`0300000000_?l00;co01`00;co00<00000
003o=000oc@07000oc@00`000000fol00=_o000L0=_o00040000003oool0
oooo000000P0oooo00260?ooo`040000003oool0oooo000001h0o`2L00<0
000005<0o`1C0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000
oc@00?ld01`00?ld00<000000=_o003Ko`00703Ko`0010000000oooo0?oo
o`0000080?ooo`00QP3oool010000000oooo0?ooo`00000N0?l0W0030000
001C0?l0D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`0000000?ld
003o=00L003o=0030000003Ko`00fol001`0fol000@000000?ooo`3oool0
0000203oool008H0oooo00@000000?ooo`3oool000007P3o09`00`000000
D`3o05<0o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o=000
oc@07000oc@00`000000fol00=_o000L0=_o00040000003oool0oooo0000
00P0oooo00260?ooo`040000003oool0oooo000001h0o`2L00<0000005<0
o`1C0?l0701C0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld
01`00?ld00<000000=_o003Ko`00703Ko`0010000000oooo0?ooo`000008
0?ooo`00QP3oool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0
D`3o01`0D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L
003o=0030000003Ko`00fol001`0fol000@000000?ooo`3oool00000203o
ool008H0oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0
o`0L05<0o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000
oc@00`000000fol00=_o000L0=_o00040000003oool0oooo000000P0oooo
00260?ooo`040000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0
701C0?l00`0000000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld
00<000000=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00
QP3oool010000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0
D`3o00<00000002lo`00_?l07000_?l00`0000000?ld003o=00L003o=003
0000003Ko`00fol001`0fol000@000000?ooo`3oool00000203oool008H0
oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L05<0
o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000oc@00`00
0000fol00=_o000L0=_o00040000003oool0oooo000000P0oooo00260?oo
o`040000003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l0
0`0000000;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<00000
0=_o003Ko`00703Ko`0010000000oooo0?ooo`0000080?ooo`00QP3oool0
10000000oooo0?ooo`00000N0?l0W0030000001C0?l0D`3o01`0D`3o00<0
0000002lo`00_?l07000_?l00`0000000?ld003o=00L003o=0030000003K
o`00fol001`0fol000@000000?ooo`3oool00000203oool008H0oooo00@0
00000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L05<0o`030000
0000_?l00;co01`00;co00<00000003o=000oc@07000oc@00`000000fol0
0=_o000L0=_o00040000003oool0oooo000000P0oooo00260?ooo`040000
003oool0oooo000001h0o`2L00<0000005<0o`1C0?l0701C0?l00`000000
0;co002lo`0L002lo`0300000000oc@00?ld01`00?ld00<000000=_o003K
o`00703Ko`0010000000oooo0?ooo`0000080?ooo`00O`3oool500000080
oooo00@000000?ooo`3oool000007P3o09`00`000000D`3o05<0o`0L05<0
o`0300000000_?l00;co01`00;co00<00000003o=000oc@07000oc@00`00
0000fol00=_o000L0=_o00040000003oool0oooo000000P0oooo00210?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000007P3o09`0
0`000000D`3o05<0o`0L05<0o`0300000000_?l00;co01`00;co00<00000
003o=000oc@07000oc@00`000000fol00=_o000L0=_o00040000003oool0
oooo000000P0oooo00210?ooo`030000003oool0oooo0080oooo0P000000
0`3oool000000?l0W00M0?l0W0030000001C0?l0D`3o01`0D`3o00<00000
002lo`00_?l07000_?l00`0000000?ld003o=00L003o=0030000003Ko`00
fol001`0fol000@000000?ooo`0000000000203oool00840oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0
oooo00H0oooo00210?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000007P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0L
0?ooo`040000003oool0oooo000000P0oooo00200?ooo`800000103ooonR
000000P0oooo003o0?oooc40oooo003o0?oooc40oooo003o0?oooc40oooo
003o0?oooc40oooo003o0?oooc40oooo003o0?oooc40oooo003o0?oooc40
oooo003o0?oooc40oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{304, 194},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  Intuition suggests that we should seek a solution that takes on \
constant values along the vertical lines of the form ",
  Cell[BoxData[
      \(x = x\_0\)]],
  " and that ",
  StyleBox["u(x,y)",
    FontFamily->"Courier New"],
  " be a function of ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " alone; that is,\n\n\t\t\t",
  Cell[BoxData[
      \(u \((x, y)\)\  = \ P \((x)\)\)]],
  ",    for  ",
  Cell[BoxData[
      \(a \[LessEqual] x \[LessEqual] b\)]],
  "  and for all ",
  StyleBox["y",
    FontFamily->"Courier New"],
  ".\n\nLaplace's equation,  ",
  Cell[BoxData[
      \(\(u\_xx\) \((x, y)\)\  + \ \(u\_yy\) \((x, y)\)\  = \ 0\)]],
  ",  implies that  ",
  Cell[BoxData[
      \(P'' \((x)\) = 0\)]],
  ",  which implies  ",
  Cell[BoxData[
      \(P \((x)\) = m\ x\  + \ c\)]],
  ",  where ",
  StyleBox["m",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["c",
    FontFamily->"Courier New"],
  " are constants.  The stated boundary conditions  ",
  Cell[BoxData[
      \(u \((a, y)\)\  = \ \(P \((a)\)\  = \ U\_1\)\)]],
  "  and  ",
  Cell[BoxData[
      \(u \((b, y)\)\  = \ \(P \((b)\)\  = \ U\_2\)\)]],
  "  lead to the solution  \n\n\t\t\t",
  Cell[BoxData[
      \(u \((x, y)\)\  = \ 
        U\_1 + \(\(U\_2 - U\_1\)\/\(b - a\)\) \((x - a)\)\)]],
  ".  \n\nThe level curves  ",
  Cell[BoxData[
      \(u \((x, y)\)\  = \ constant\)]],
  "  are vertical lines as indicated in Figure 11.1. "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.1",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/applicationpreliminary/\
ApplicationPreliminaryFigures/mat1101.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Level curves of the harmonic function  ",
  Cell[BoxData[
      \(u \((x, y)\)\  = \ 
        U\_1 + \(\(U\_2 - U\_1\)\/\(b - a\)\) \((x - a)\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "A specific example of the general case.  Find the function ",
  StyleBox["u(x,y)",
    FontFamily->"Courier New"],
  " that is harmonic in the vertical strip ",
  Cell[BoxData[
      \(1 < x < 2\)]],
  " and takes on the boundary values \n\n\t\t\t",
  Cell[BoxData[
      \(u \((1, y)\)\  = \ 6\)]],
  "    for all  ",
  StyleBox["y",
    FontFamily->"Courier New"],
  ",  and\n\t\t\t",
  Cell[BoxData[
      \(u \((2, y)\)\  = \ 1\)]],
  "    for all  ",
  StyleBox["y",
    FontFamily->"Courier New"],
  ", \n\nalong the vertical lines  ",
  Cell[BoxData[
      RowBox[{"x", "=", 
        RowBox[{
          RowBox[{"1", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "x"}], "=", "2"}]}]]],
  ",  respectively. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Applications involving similar formulas are found in Example 11.14 and \
Example 11.18.\
\>", "Text"],

Cell[BoxData[{
    \(\(a\ \ \  = \ 1;\)\ \ \), "\n", 
    \(\(b\ \ \  = \ 2;\)\ \ \), "\n", 
    \(\(U\_1\  = \ 6;\)\ \ \), "\n", 
    \(\(U\_2\  = \ 1;\)\ \), "\n", 
    \(\(u[x_, y_]\  = \ 
        U\_1\  + \ \(\(U\_2\  - \ U\_1\)\/\(b - a\)\) \((x - 
                a)\);\)\ \), "\[IndentingNewLine]", 
    \(\(cont = {1, 2, 3, 4, 5, 6};\)\ \n\), "\[IndentingNewLine]", 
    \(\(ContourPlot[u[x, y], {x, 1, 2}, {y, \(-1\), 1}, 
        Contours\  \[Rule] \ cont, PlotPoints \[Rule] 10, 
        AspectRatio \[Rule] 1, ColorFunction \[Rule] Hue];\)\ \), "\n", 
    \(\(Print["\<Contour plot for  u[x,y] = \>", 
        u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[u[x, y], "\< = c\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<where c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the function ",
  Cell[BoxData[
      \(\[CapitalPsi] \((x, y)\)\)]],
  " that is harmonic in the sector  ",
  Cell[BoxData[
      \(0 < Arg \((z)\) < \[Alpha]\)]],
  " and takes on the boundary values \n\n\t\t\t",
  Cell[BoxData[
      \(\[CapitalPsi] \((x, 0)\)\  = \ C\_1\)]],
  "   for  x > 0,\n\t\t\t",
  Cell[BoxData[
      \(\[CapitalPsi] \((x, y)\)\  = \ C\_2\)]],
  "   for all points on the ray  ",
  Cell[BoxData[
      \(r > 0, \[Theta] = \[Alpha]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006?0000`R000`400?l0
0000o`00003oo`3ooon@0?ooo`00o`3ooon@0?ooo`00o`3ooon@0?ooo`00
o`3ooon@0?ooo`00o`3ooon@0?ooo`00o`3ooon@0?ooo`00o`3ooon@0?oo
o`00Q`3oool4000003/0oooo1@00000g0?ooo`800000?03oool5000003X0
oooo1000000<0?ooo`00Q`3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo03H0oooo00@000000?ooo`3oool00000?@3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo00d0oooo00280?ooo`030000
003oool0oooo03d0oooo00<000000?ooo`3oool0=P3oool010000000oooo
0?ooo`00000m0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0303oool00840oooo100000040?ooo`030000003oool0oooo03@0oooo
100000040?ooo`030000003oool0oooo03H0oooo00@000000?ooo`3oool0
0000?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00/0
oooo00270?ooo`040000003oool0oooo000003d0oooo00<000000?ooo`3o
ool0=P3oool010000000oooo0?ooo`00000m0?ooo`030000003oool0oooo
03X0oooo00@000000?ooo`3oool00000303oool008P0oooo0P00000m0?oo
o`800000>@3oool2000003d0oooo0P00000m0?ooo`8000003@3oool00?l0
ooooT03oool00?l0ooooT03oool00?l0ooooT03oool00?l0ooooT03oool0
0?l0ooooT03oool00840ooooo`000007000000P0oooo001j0?ooo`800000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo001i0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool007T0oooo00@000000?ooo`3oool00000103oool2000007h0oooo
1@000000103oool0000000000000001j0?ooo`<00000203oool007T0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooog/0
o`001@0000001@00ob0000000000003om`00000007H0o`001@3oool00`00
0000oooo0?ooo`060?ooo`00N@3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0080ooooN`3o000500000003003o80000000Lol0
00800000MP3o00050?ooo`030000003oool0oooo00H0oooo001j0?ooo`80
00001@3oool00`000000oooo0?ooo`020?ooogX0o`0000D0000007<0o`00
00000000002eo`0200000004003o8000000000000?og00800000M03o0005
0?ooo`030000003oool0oooo00H0oooo00210?ooo`030000003oool0oooo
0080ooooNP3o00001@000000L`3o0000000000000;Go0080000000@00?lP
0000001co`0000000P3om`0200000780o`001@3oool00`000000oooo0?oo
o`060?ooo`00P@3oool00`000000oooo0?ooo`020?ooogX0o`0000D00000
07<0o`0000000000002eo`0200000004003o80000000Lol0000000@0ooL0
0P00001`0?l000D0oooo00<000000?ooo`3oool01P3oool00840oooo00<0
00000?ooo`3oool00P3ooomj0?l000050000001c0?l0000000000000]Ol0
0P000002003o80030000001co`00000000D0ooL00`00001]0?l000D0oooo
00<000000?ooo`3oool01P3oool00840oooo00<000000?ooo`3oool00P3o
oomj0?l000050000001c0?l0000000000000]Ol00P000002003o80040000
001co`00Lol0000000L0ooL01000001Y0?l000D0oooo00<000000?ooo`3o
ool01P3oool00840oooo00<000000?ooo`3oool00P3ooomj0?l000080000
001c0?l0000000000000]Ol00000003o]@000002003o80030000001co`00
Lol0008000002@3om`03000006H0o`001@3oool00`000000oooo0?ooo`06
0?ooo`00P@3oool2000000<0ooooNP3o000020000000L`3o000000000000
0;Go00000000okD000000P00ob000`000000Lol007?o000207?o00030000
003om`00ooL000T0ooL00`00001S0?l000@0oooo0P0000080?ooo`00P@3o
ool00`000000oooo0?ooo`020?ooogX0o`0000P0000007<0o`0000000000
002eo`0000000?ne000000<00?lP00<0000007?o001co`000P1co`000`00
0000ooL00?og000;0?og00800000H@3o00050?ooo`030000003oool0oooo
00H0oooo00210?ooo`030000003oool0oooo0080ooooN@3o00000`000000
L`3o07<0o`0200000005002eo`0000000?ne003o]@0000000`00ob000`00
0000Lol007?o000207?o00030000003om`00ooL000`0ooL00`00001N0?l0
00D0oooo00<000000?ooo`3oool01P3oool00840oooo00<000000?ooo`3o
ool00P3ooomi0?l000030000001c0?l0L`3o0080000000D00;Go00000000
okD00?ne00000003003o80030000001co`00Lol000<0Lol000<000000?og
003om`003P3om`02000005`0o`001@3oool00`000000oooo0?ooo`060?oo
o`00P@3oool00`000000oooo0?ooo`020?ooogP0o`0000H0000007<0o`1c
0?l00000000Po`000002002eo`0400000000okD00?ne000000<00?lP00<0
000007?o001co`000`1co`000`000000ooL00?og000?0?og00800000FP3o
00050?ooo`030000003oool0oooo00H0oooo00210?ooo`030000003oool0
oooo0080ooooN03o00001P000000L`3o07<0o`000000023o000000800;Go
00@00000003o]@00okD000000`00ob000`000000Lol007?o000407?o0080
00004@3om`04000005H0o`001@3oool00`000000oooo0?ooo`060?ooo`00
P@3oool00`000000oooo0?ooo`020?ooogL0o`0000L0000007<0o`1c0?l0
L`3o000000008?l0000000800;Go00D00000003o]@00okD00?ne00000003
003o80030000001co`00Lol000D0Lol000<000000?og003om`004P3om`04
00000580o`001@3oool00`000000oooo0?ooo`060?ooo`00P@3oool00`00
0000oooo0?ooo`020?ooogH0o`0000<0000007<0o`1c0?l00P1c0?l00`00
0000023o00000002002eo`0500000000okD00?ne003o]@0000001000ob00
0`000000Lol007?o000507?o008000005P3om`03000004l0o`001@3oool0
0`000000oooo0?ooo`060?ooo`00P@3oool2000000<0ooooMP3o00001@00
0000L`3o07<0o`1c0?l000000080023o00@00000002eo`00]Ol000001000
okD00`0000000?lP003o8002003o80030000001co`00Lol000H0Lol000<0
00000?og003om`005P3om`02000004d0o`00103oool2000000P0oooo0021
0?ooo`030000003oool0oooo0080ooooMP3o00001@000000L`3o07<0o`1c
0?l000000080023o00D00000002eo`00]Ol00;Go00000003003o]@030000
0000ob000?lP00800?lP00<0000007?o001co`001`1co`000`000000ooL0
0?og000G0?og00800000B`3o00050?ooo`030000003oool0oooo00H0oooo
00210?ooo`030000003oool0oooo0080ooooM@3o00001@000000L`3o07<0
o`1c0?l0000000<0023o00D00000002eo`00]Ol00;Go00000004003o]@03
00000000ob000?lP00800?lP00<0000007?o001co`001`1co`02000001T0
ooL00`0000180?l000D0oooo00<000000?ooo`3oool01P3oool00840oooo
00<000000?ooo`3oool00P3ooome0?l000050000001c0?l0L`3o07<0o`00
00000`008?l01@0000000;Go002eo`00]Ol0000000@00?ne00<00000003o
8000ob000`00ob000`000000Lol007?o000807?o00030000003om`00ooL0
01T0ooL00`0000150?l000D0oooo00<000000?ooo`3oool01P3oool00840
oooo00<000000?ooo`3oool00P3ooome0?l000050000001c0?l0L`3o07<0
o`0000000`008?l01@0000000;Go002eo`00]Ol0000000@00?ne00<00000
003o8000ob001000ob000`000000Lol007?o000807?o00030000003om`00
ooL001/0ooL0100000110?l000D0oooo00<000000?ooo`3oool01P3oool0
0840oooo00<000000?ooo`3oool00P3ooomd0?l000030000001c0?l0L`3o
0080L`3o00D00000000Po`008?l0023o00000003002eo`0300000000okD0
0?ne00<00?ne00<00000003o8000ob001000ob000`000000Lol007?o0008
07?o008000007`3om`02000003l0o`001@3oool00`000000oooo0?ooo`06
0?ooo`00P@3oool00`000000oooo0?ooo`020?ooog@0o`0000D0000007<0
o`1c0?l0L`3o00000004000Po`0300000000]Ol00;Go00800;Go00<00000
003o]@00okD00P00okD00`0000000?lP003o8004003o80030000001co`00
Lol000X0Lol000<000000?og003om`007P3om`03000003`0o`001@3oool0
0`000000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?oo
og<0o`0000<0000007<0o`1c0?l00P1c0?l00`000000023o000Po`02000P
o`0300000000]Ol00;Go00800;Go00<00000003o]@00okD00`00okD00`00
00000?lP003o8004003o80030000001co`00Lol000X0Lol000<000000?og
003om`00803om`02000003X0o`001@3oool00`000000oooo0?ooo`060?oo
o`00P@3oool2000000<0ooooL`3o00000`000000L`3o07<0o`0207<0o`03
000000008?l0023o0080023o00<00000002eo`00]Ol00P00]Ol00`000000
0?ne003o]@03003o]@0300000000ob000?lP00D00?lP00<0000007?o001c
o`002P1co`000`000000ooL00?og000Q0?og00<00000=`3o00040?ooo`80
0000203oool00840oooo00<000000?ooo`3oool00P3ooomc0?l000030000
001c0?l0L`3o0080L`3o00<00000000Po`008?l00P008?l00`0000000;Go
002eo`02002eo`0300000000okD00?ne00<00?ne00<00000003o8000ob00
1P00ob000`000000Lol007?o000:07?o00030000003om`00ooL002<0ooL0
0P00000e0?l000D0oooo00<000000?ooo`3oool01P3oool00840oooo00<0
00000?ooo`3oool00P3ooomb0?l000030000001c0?l0L`3o00<0L`3o00<0
0000000Po`008?l00P008?l00`0000000;Go002eo`02002eo`0300000000
okD00?ne00@00?ne00<00000003o8000ob001@00ob000`000000Lol007?o
000;07?o008000009@3om`0300000380o`001@3oool00`000000oooo0?oo
o`060?ooo`00P@3oool00`000000oooo0?ooo`020?ooog80o`0000<00000
07<0o`1c0?l00P1c0?l00`000000023o000Po`03000Po`0300000000]Ol0
0;Go00<00;Go00<00000003o]@00okD00`00okD00`0000000?lP003o8006
003o80030000001co`00Lol000`0Lol000<000000?og003om`009@3om`04
000002h0o`001@3oool00`000000oooo0?ooo`060?ooo`00P@3oool00`00
0000oooo0?ooo`020?ooog40o`0000<0000007<0o`1c0?l00`1c0?l00`00
0000023o000Po`03000Po`0300000000]Ol00;Go00<00;Go00<00000003o
]@00okD01000okD00`0000000?lP003o8005003o80030000001co`00Lol0
00d0Lol000<000000?og003om`00:03om`03000002/0o`001@3oool00`00
0000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?ooog40
o`0000<0000007<0o`1c0?l00`1c0?l00`000000023o000Po`03000Po`03
00000000]Ol00;Go00<00;Go00<00000003o]@00okD01000okD00`000000
0?lP003o8006003o808000003P1co`02000002/0ooL00P00000Y0?l000D0
oooo00<000000?ooo`3oool01P3oool00840oooo00<000000?ooo`3oool0
0P3ooom`0?l000030000001c0?l0L`3o00@0L`3o00<00000000Po`008?l0
0`008?l00`0000000;Go002eo`03002eo`0300000000okD00?ne00@00?ne
00<00000003o8000ob001`00ob000`000000Lol007?o000>07?o00800000
:`3om`03000002H0o`001@3oool00`000000oooo0?ooo`060?ooo`00P@3o
ool00`000000oooo0?ooo`020?ooog00o`0000<0000007<0o`1c0?l0101c
0?l00`000000023o000Po`03000Po`0300000000]Ol00;Go00<00;Go00<0
0000003o]@00okD01@00okD00`0000000?lP003o8007003o80030000001c
o`00Lol000l0Lol000<000000?og003om`00:`3om`03000002<0o`001@3o
ool00`000000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`02
0?ooofl0o`0000<0000007<0o`1c0?l0101c0?l00`000000023o000Po`04
000Po`0300000000]Ol00;Go00@00;Go00<00000003o]@00okD01000okD0
0`0000000?lP003o8007003o80030000001co`00Lol00100Lol00P00000^
0?og008000008@3o00050?ooo`030000003oool0oooo00H0oooo00210?oo
o`8000000`3ooom_0?l000030000001c0?l0L`3o00@0L`3o00<00000000P
o`008?l010008?l00`0000000;Go002eo`04002eo`0300000000okD00?ne
00D00?ne00<00000003o8000ob001`00ob000`000000Lol007?o000A07?o
00030000003om`00ooL002d0ooL00P00000O0?l000@0oooo0P0000080?oo
o`00P@3oool00`000000oooo0?ooo`020?ooofh0o`0000<0000007<0o`1c
0?l01@1c0?l00`000000023o000Po`04000Po`0300000000]Ol00;Go00@0
0;Go00<00000003o]@00okD01@00okD00`0000000?lP003o8008003o8003
0000001co`00Lol00100Lol000<000000?og003om`00;`3om`04000001/0
o`001@3oool00`000000oooo0?ooo`060?ooo`00P@3oool00`000000oooo
0?ooo`020?ooofh0o`0000<0000007<0o`1c0?l01@1c0?l00`000000023o
000Po`04000Po`0300000000]Ol00;Go00@00;Go00<00000003o]@00okD0
1@00okD00`0000000?lP003o8009003o80030000001co`00Lol00100Lol0
00<000000?og003om`00<P3om`04000001L0o`001@3oool00`000000oooo
0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?ooofd0o`0000<0
000007<0o`1c0?l01P1c0?l00`000000023o000Po`04000Po`0300000000
]Ol00;Go00D00;Go00<00000003o]@00okD01@00okD00`0000000?lP003o
8009003o80030000001co`00Lol00100Lol000<000000?og003om`00=@3o
m`03000001@0o`001@3oool00`000000oooo0?ooo`060?ooo`00P@3oool0
0`000000oooo0?ooo`020?ooofd0o`0000<0000007<0o`1c0?l01P1c0?l0
0`000000023o000Po`04000Po`0300000000]Ol00;Go00D00;Go00<00000
003o]@00okD01@00okD00`0000000?lP003o8009003o80030000001co`00
Lol00140Lol00P00000h0?og008000004P3o00050?ooo`030000003oool0
oooo00H0oooo00210?ooo`030000003oool0oooo0080ooooK03o00000`00
0000L`3o07<0o`0607<0o`03000000008?l0023o00D0023o00<00000002e
o`00]Ol01@00]Ol00`0000000?ne003o]@06003o]@0300000000ob000?lP
00T00?lP0P00000C07?o00030000003om`00ooL003L0ooL00P00000@0?l0
00D0oooo00<000000?ooo`3oool01P3oool006h0oooo0P0000040?ooo`80
0000103oool2000000D0oooo00<000000?ooo`3oool00P3ooom/0?l00003
0000001c0?l0L`3o00H0L`3o00<00000000Po`008?l01@008?l00`000000
0;Go002eo`05002eo`0300000000okD00?ne00H00?ne00<00000003o8000
ob002P00ob000`000000Lol007?o000B07?o00800000>@3om`03000000d0
o`001@3oool00`000000oooo0?ooo`060?ooo`00K@3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00P3ooom/0?l000030000001c0?l0L`3o00H0L`3o00<00000000P
o`008?l01@008?l00`0000000;Go002eo`05002eo`0300000000okD00?ne
00H00?ne00<00000003o8000ob002`00ob000`000000Lol007?o000C07?o
00030000003om`00ooL003T0ooL00P00000;0?l000D0oooo00<000000?oo
o`3oool01P3oool006d0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`020?ooo`8000000`3ooom[0?l000030000001c0?l0L`3o
00L0L`3o00<00000000Po`008?l01@008?l00`0000000;Go002eo`05002e
o`0300000000okD00?ne00L00?ne00<00000003o8000ob002`00ob000`00
0000Lol007?o000C07?o00030000003om`00ooL003X0ooL00P0000090?l0
00<0oooo0`0000080?ooo`00K@3oool010000000oooo0?ooo`0000090?oo
o`8000001@3oool00`000000oooo0?ooo`020?ooof/0o`0000<0000007<0
o`1c0?l01P1c0?l00`000000023o000Po`06000Po`0300000000]Ol00;Go
00H00;Go00<00000003o]@00okD01P00okD00`0000000?lP003o800;003o
80030000001co`00Lol001@0Lol00P00000l0?og00<000001P3o00050?oo
o`030000003oool0oooo00H0oooo001]0?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
ofX0o`0000<0000007<0o`1c0?l01`1c0?l00`000000023o000Po`06000P
o`0300000000]Ol00;Go00H00;Go00<00000003o]@00okD01`00okD00`00
00000?lP003o800;003o80030000001co`00Lol001D0Lol000<000000?og
003om`00?03om`03000000<0o`001@3oool00`000000oooo0?ooo`060?oo
o`00KP3oool2000000X0oooo0`0000040?ooo`030000003oool0oooo0080
ooooJP3o00000`000000L`3o07<0o`0707<0o`03000000008?l0023o00H0
023o00<00000002eo`00]Ol01P00]Ol00`0000000?ne003o]@07003o]@03
00000000ob000?lP00`00?lP00<0000007?o001co`005@1co`000`000000
ooL00?og000n0?og00@00000103oool00`000000oooo0?ooo`060?ooo`00
P@3oool00`000000oooo0?ooo`020?ooofX0o`0000<0000007<0o`1c0?l0
1`1c0?l00`000000023o000Po`06000Po`0300000000]Ol00;Go00H00;Go
00<00000003o]@00okD02000okD00`0000000?lP003o800<003o80030000
001co`00Lol001D0Lol000<000000?og003om`00@03om`050?ooo`030000
003oool0oooo00H0oooo00210?ooo`030000003oool0oooo0080ooooJ@3o
00000`000000L`3o07<0o`0807<0o`03000000008?l0023o00H0023o00<0
0000002eo`00]Ol01P00]Ol00`0000000?ne003o]@08003o]@0300000000
ob000?lP00`00?lP00<0000007?o001co`005P1co`000`000000ooL00?og
000o0?og00D0oooo00<000000?ooo`3oool01P3oool00840oooo00<00000
0?ooo`3oool00P3ooomY0?l000030000001c0?l0L`3o00L0L`3o00<00000
000Po`008?l01`008?l00`0000000;Go002eo`07002eo`0300000000okD0
0?ne00P00?ne00<00000003o8000ob003000ob000`000000Lol007?o000F
07?o00800000?`3om`050?ooo`030000003oool0oooo00H0oooo00210?oo
o`030000003oool0oooo0080ooooJ03o00000`000000L`3o07<0o`0807<0
o`03000000008?l0023o00L0023o00<00000002eo`00]Ol01`00]Ol00`00
00000?ne003o]@08003o]@0300000000ob000?lP00`00?lP0P00000I07?o
00030000003om`00ooL003`0ooL01@3oool00`000000oooo0?ooo`060?oo
o`00P@3oool00`000000oooo0?ooo`020?ooofP0o`0000<0000007<0o`1c
0?l0201c0?l00`000000023o000Po`07000Po`0300000000]Ol00;Go00L0
0;Go00<00000003o]@00okD02@00okD00`0000000?lP003o800<003o8003
0000001co`00Lol001P0Lol000<000000?og003om`00>`3om`050?ooo`03
0000003oool0oooo00H0oooo00210?ooo`8000000`3ooomW0?l000030000
001c0?l0L`3o00T0L`3o00<00000000Po`008?l01`008?l00`0000000;Go
002eo`07002eo`0300000000okD00?ne00T00?ne00<00000003o8000ob00
3@00ob000`000000Lol007?o000H07?o00800000>`3om`040?ooo`800000
203oool00840oooo00<000000?ooo`3oool00P3ooomW0?l000030000001c
0?l0L`3o00T0L`3o00<00000000Po`008?l01`008?l00`0000000;Go002e
o`07002eo`0300000000okD00?ne00T00?ne00<00000003o8000ob003P00
ob000`000000Lol007?o000I07?o00030000003om`00ooL003P0ooL01@3o
ool00`000000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`02
0?ooofL0o`0000<0000007<0o`1c0?l0201c0?l00`000000023o000Po`08
000Po`0300000000]Ol00;Go00P00;Go00<00000003o]@00okD02@00okD0
0`0000000?lP003o800=003o80030000001co`00Lol001X0Lol000<00000
0?og003om`00=`3om`050?ooo`030000003oool0oooo00H0oooo00210?oo
o`030000003oool0oooo0080ooooIP3o00000`000000L`3o07<0o`0907<0
o`03000000008?l0023o00P0023o00<00000002eo`00]Ol02000]Ol00`00
00000?ne003o]@09003o]@0300000000ob000?lP00h00?lP00<0000007?o
001co`006P1co`02000003L0ooL01@3oool00`000000oooo0?ooo`060?oo
o`00P@3oool00`000000oooo0?ooo`020?ooofH0o`0000<0000007<0o`1c
0?l02@1c0?l00`000000023o000Po`08000Po`0300000000]Ol00;Go00P0
0;Go00<00000003o]@00okD02P00okD00`0000000?lP003o800>003o8003
0000001co`00Lol001/0Lol000<000000?og003om`00=03om`050?ooo`03
0000003oool0oooo00H0oooo00210?ooo`030000003oool0oooo0080oooo
I@3o00000`000000L`3o07<0o`0:07<0o`03000000008?l0023o00P0023o
00<00000002eo`00]Ol02000]Ol00`0000000?ne003o]@0:003o]@030000
0000ob000?lP00l00?lP00<0000007?o001co`006`1co`02000003@0ooL0
1@3oool00`000000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?oo
o`020?ooofD0o`0000<0000007<0o`1c0?l02@1c0?l00`000000023o000P
o`09000Po`0300000000]Ol00;Go00P00;Go00<00000003o]@00okD02`00
okD00`0000000?lP003o800?003o80030000001co`00Lol001`0Lol000<0
00000?og003om`00<@3om`050?ooo`030000003oool0oooo00H0oooo0021
0?ooo`030000003oool0oooo0080ooooI03o00000`000000L`3o07<0o`0:
07<0o`03000000008?l0023o00T0023o00<00000002eo`00]Ol02@00]Ol0
0`0000000?ne003o]@0:003o]@0300000000ob000?lP01000?lP00<00000
07?o001co`00701co`0200000340ooL01@3oool00`000000oooo0?ooo`06
0?ooo`00P@3oool2000000<0ooooI03o00000`000000L`3o07<0o`0:07<0
o`03000000008?l0023o00T0023o00<00000002eo`00]Ol02@00]Ol00`00
00000?ne003o]@0;003o]@0300000000ob000?lP01000?lP00<0000007?o
001co`007@1co`000`000000ooL00?og000^0?og00@0oooo0P0000080?oo
o`00P@3oool00`000000oooo0?ooo`020?ooof@0o`0000<0000007<0o`1c
0?l02P1c0?l00`000000023o000Po`09000Po`0300000000]Ol00;Go00T0
0;Go00<00000003o]@00okD02`00okD00`0000000?lP003o800A003o8003
0000001co`00Lol001d0Lol000<000000?og003om`00;@3om`050?ooo`03
0000003oool0oooo00H0oooo00210?ooo`030000003oool0oooo0080oooo
H`3o00000`000000L`3o07<0o`0;07<0o`03000000008?l0023o00T0023o
00<00000002eo`00]Ol02@00]Ol00`0000000?ne003o]@0<003o]@030000
0000ob000?lP01000?lP00<0000007?o001co`007P1co`02000002d0ooL0
1@3oool00`000000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?oo
o`020?ooof<0o`0000<0000007<0o`1c0?l02P1c0?l00`000000023o000P
o`0:000Po`0300000000]Ol00;Go00X00;Go00<00000003o]@00okD02`00
okD00`0000000?lP003o800A003o80030000001co`00Lol001l0Lol000<0
00000?og003om`00:P3om`050?ooo`030000003oool0oooo00H0oooo0021
0?ooo`030000003oool0oooo0080ooooHP3o00000`000000L`3o07<0o`0;
07<0o`03000000008?l0023o00X0023o00<00000002eo`00]Ol02P00]Ol0
0`0000000?ne003o]@0<003o]@0300000000ob000?lP01000?lP00<00000
07?o001co`00801co`000`000000ooL00?og000Y0?og00D0oooo00<00000
0?ooo`3oool01P3oool00840oooo00<000000?ooo`3oool00P3ooomR0?l0
00030000001c0?l0L`3o00/0L`3o00<00000000Po`008?l02P008?l00`00
00000;Go002eo`0:002eo`0300000000okD00?ne00`00?ne00<00000003o
8000ob004@00ob000`000000Lol007?o000P07?o00030000003om`00ooL0
02P0ooL01@3oool00`000000oooo0?ooo`060?ooo`00P@3oool00`000000
oooo0?ooo`020?ooof80o`0000<0000007<0o`1c0?l02`1c0?l00`000000
023o000Po`0:000Po`0300000000]Ol00;Go00X00;Go00<00000003o]@00
okD03000okD00`0000000?lP003o800B003o80030000001co`00Lol00200
Lol000<000000?og003om`009`3om`050?ooo`030000003oool0oooo00H0
oooo00210?ooo`030000003oool0oooo0080ooooH@3o00000`000000L`3o
07<0o`0<07<0o`03000000008?l0023o00X0023o00<00000002eo`00]Ol0
2P00]Ol00`0000000?ne003o]@0=003o]@0300000000ob000?lP01800?lP
00<0000007?o001co`00801co`000`000000ooL00?og000V0?og00D0oooo
00<000000?ooo`3oool01P3oool00840oooo0P0000030?ooof40o`0000<0
000007<0o`1c0?l02`1c0?l00`000000023o000Po`0;000Po`0300000000
]Ol00;Go00/00;Go00<00000003o]@00okD03000okD00`0000000?lP003o
800B003o80030000001co`00Lol00240Lol00P00000V0?og00@0oooo0P00
00080?ooo`00P@3oool00`000000oooo0?ooo`020?ooof00o`0000<00000
07<0o`1c0?l0301c0?l00`000000023o000Po`0;000Po`0300000000]Ol0
0;Go00/00;Go00<00000003o]@00okD03@00okD00`0000000?lP003o800B
003o80030000001co`00Lol00280Lol000<000000?og003om`008`3om`05
0?ooo`030000003oool0oooo00H0oooo00210?ooo`030000003oool0oooo
0080ooooG`3o0002000000h0L`3o00<00000000Po`008?l02`008?l00`00
00000;Go002eo`0;002eo`0300000000okD00?ne00d00?ne00<00000003o
8000ob004`00ob000`000000Lol007?o000R07?o008000008`3om`050?oo
o`030000003oool0oooo00H0oooo00210?ooo`030000003oool0oooo0080
ooooG`3o00000`000000L`3o07<0o`0=07<0o`03000000008?l0023o00/0
023o00<00000002eo`00]Ol02`00]Ol00`0000000?ne003o]@0=003o]@03
00000000ob000?lP01@00?lP00<0000007?o001co`008`1co`000`000000
ooL00?og000P0?og00D0oooo00<000000?ooo`3oool01P3oool00840oooo
00<000000?ooo`3oool00P3ooomN0?l000030000001c0?l0L`3o00h0L`3o
00<00000000Po`008?l02`008?l00`0000000;Go002eo`0;002eo`030000
0000okD00?ne00h00?ne00<00000003o8000ob005000ob000`000000Lol0
07?o000S07?o00030000003om`00ooL001l0ooL01@3oool00`000000oooo
0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?oooeh0o`0000<0
000007<0o`1c0?l03P1c0?l00`000000023o000Po`0;000Po`0300000000
]Ol00;Go00`00;Go00<00000003o]@00okD03@00okD00`0000000?lP003o
800D003o80030000001co`00Lol002@0Lol00P00000O0?og00D0oooo00<0
00000?ooo`3oool01P3oool00840oooo00<000000?ooo`3oool00P3ooomM
0?l000030000001c0?l0L`3o00l0L`3o00<00000000Po`008?l02`008?l0
0`0000000;Go002eo`0<002eo`0300000000okD00?ne00h00?ne00<00000
003o8000ob005000ob000`000000Lol007?o000U07?o00030000003om`00
ooL001`0ooL01@3oool00`000000oooo0?ooo`060?ooo`00P@3oool00`00
0000oooo0?ooo`020?oooed0o`0000<0000007<0o`1c0?l03P1c0?l20000
00d0023o00<00000002eo`00]Ol03000]Ol00`0000000?ne003o]@0>003o
]@0300000000ob000?lP01D00?lP00<0000007?o001co`009@1co`000`00
0000ooL00?og000K0?og00D0oooo00<000000?ooo`3oool01P3oool00840
oooo00<000000?ooo`3oool00P3ooomM0?l000030000001c0?l0L`3o00h0
L`3o00<00000000Po`008?l030008?l00`0000000;Go002eo`0<002eo`03
00000000okD00?ne00h00?ne00<00000003o8000ob005P00ob000`000000
Lol007?o000U07?o008000006`3om`050?ooo`030000003oool0oooo00H0
oooo00210?ooo`8000000`3ooomL0?l000030000001c0?l0L`3o00l0L`3o
00<00000000Po`008?l030008?l00`0000000;Go002eo`0<002eo`030000
0000okD00?ne00l00?ne00<00000003o8000ob005@00ob000`000000Lol0
07?o000W07?o00030000003om`00ooL001P0ooL0103oool2000000P0oooo
00210?ooo`030000003oool0oooo0080ooooG03o00000`000000L`3o07<0
o`0>07<0o`03000000008?l0023o00d0023o00<00000002eo`00]Ol03@00
]Ol00`0000000?ne003o]@0>003o]@0300000000ob000?lP01H00?lP00<0
000007?o001co`009`1co`000`000000ooL00?og000G0?og00D0oooo00<0
00000?ooo`3oool01P3oool00840oooo00<000000?ooo`3oool00P3ooomK
0?l000030000001c0?l0L`3o00l0L`3o00<00000000Po`008?l03@008?l0
0`0000000;Go002eo`0=002eo`0300000000okD00?ne00l00?ne00<00000
003o8000ob005@00ob000`000000Lol007?o000X07?o008000005`3om`05
0?ooo`030000003oool0oooo00H0oooo00210?ooo`030000003oool0oooo
0080ooooF`3o00000`000000L`3o07<0o`0?07<0o`03000000008?l0023o
00d0023o00<00000002eo`00]Ol03@00]Ol00`0000000?ne003o]@0?003o
]@0300000000ob000?lP01H00?lP0P00000Z07?o00030000003om`00ooL0
01@0ooL01@3oool00`000000oooo0?ooo`060?ooo`00P@3oool00`000000
oooo0?ooo`020?oooe/0o`0000<0000007<0o`1c0?l03`1c0?l00`000000
023o000Po`0=000Po`0300000000]Ol00;Go00d00;Go00<00000003o]@00
okD04000okD00`0000000?lP003o800F003o80030000001co`00Lol002T0
Lol000<000000?og003om`004`3om`050?ooo`030000003oool0oooo00H0
oooo00210?ooo`030000003oool0oooo0080ooooFP3o00000`000000L`3o
07<0o`0@07<0o`03000000008?l0023o00d0023o00<00000002eo`00]Ol0
3@00]Ol00`0000000?ne003o]@0@003o]@0300000000ob000?lP01L00?lP
00<0000007?o001co`00:@1co`000`000000ooL00?og000B0?og00D0oooo
00<000000?ooo`3oool01P3oool007T0oooo1@0000030?ooo`030000003o
ool0oooo0080ooooFP3o00000`000000L`3o07<0o`0@07<0o`0300000000
8?l0023o00d0023o00<00000002eo`00]Ol03P00]Ol00`0000000?ne003o
]@0@003o]@0300000000ob000?lP01H00?lP00<0000007?o001co`00:P1c
o`0200000180ooL01@3oool00`000000oooo0?ooo`060?ooo`00N`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080ooooF@3o0000
0`000000L`3o07<0o`0A07<0o`03000000008?l0023o00d0023o00<00000
002eo`00]Ol03P00]Ol00`0000000?ne003o]@0@003o]@0300000000ob00
0?lP01L00?lP00<0000007?o001co`00:`1co`000`000000ooL00?og000?
0?og00D0oooo00<000000?ooo`3oool01P3oool007/0oooo00<000000?oo
o`3oool00`3oool2000000<0ooooF@3o00000`000000L`3o07<0o`0A07<0
o`03000000008?l0023o00d0023o00<00000002eo`00]Ol03P00]Ol00`00
00000?ne003o]@0A003o]@0300000000ob000?lP01L00?lP00<0000007?o
001co`00:`1co`000`000000ooL00?og000>0?og00<0oooo0`0000080?oo
o`00N`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
ooooF03o00000`000000L`3o07<0o`0B07<0o`03000000008?l0023o00d0
023o00<00000002eo`00]Ol03P00]Ol00`0000000?ne003o]@0A003o]@03
00000000ob000?lP01P00?lP00<0000007?o001co`00:`1co`000`000000
ooL00?og000=0?og00D0oooo00<000000?ooo`3oool01P3oool007/0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oooeP0o`00
00<0000007<0o`1c0?l04P1c0?l00`000000023o000Po`0=000Po`030000
0000]Ol00;Go00h00;Go00<00000003o]@00okD04@00okD00`0000000?lP
003o800I003o80030000001co`00Lol002/0Lol000<000000?og003om`00
303om`050?ooo`030000003oool0oooo00H0oooo001j0?ooo`8000001@3o
ool00`000000oooo0?ooo`020?oooeP0o`0000<0000007<0o`1c0?l04@1c
0?l00`000000023o000Po`0>000Po`0300000000]Ol00;Go00l00;Go00<0
0000003o]@00okD04@00okD00`0000000?lP003o800H003o80030000001c
o`00Lol002`0Lol000<000000?og003om`002`3om`050?ooo`030000003o
ool0oooo00H0oooo00210?ooo`030000003oool0oooo0080ooooE`3o0000
0`000000L`3o07<0o`0B07<0o`03000000008?l0023o00h0023o00<00000
002eo`00]Ol03`00]Ol00`0000000?ne003o]@0A003o]@0300000000ob00
0?lP01T00?lP00<0000007?o001co`00;01co`02000000/0ooL01@3oool0
0`000000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?oo
oeL0o`0000<0000007<0o`1c0?l04P1c0?l00`000000023o000Po`0>000P
o`0300000000]Ol00;Go00l00;Go00<00000003o]@00okD04P00okD00`00
00000?lP003o800I003o80030000001co`00Lol002d0Lol000<000000?og
003om`00203om`050?ooo`030000003oool0oooo00H0oooo00210?ooo`03
0000003oool0oooo0080ooooE`3o00000`000000L`3o07<0o`0B07<0o`03
000000008?l0023o00h0023o00<00000002eo`00]Ol03`00]Ol00`000000
0?ne003o]@0B003o]@0300000000ob000?lP01X00?lP00<0000007?o001c
o`00;@1co`02000000P0ooL01@3oool00`000000oooo0?ooo`060?ooo`00
P@3oool00`000000oooo0?ooo`020?oooeH0o`0000<0000007<0o`1c0?l0
4`1c0?l00`000000023o000Po`0>000Po`0300000000]Ol00;Go00l00;Go
00<00000003o]@00okD04`00okD00`0000000?lP003o800I003o80030000
001co`00Lol002l0Lol000<000000?og003om`001@3om`050?ooo`030000
003oool0oooo00H0oooo00210?ooo`8000000`3ooomF0?l000030000001c
0?l0L`3o0180L`3o00<00000000Po`008?l03`008?l00`0000000;Go002e
o`0@002eo`0300000000okD00?ne01800?ne00<00000003o8000ob006P00
ob000`000000Lol007?o000_07?o00030000003om`00ooL000@0ooL0103o
ool2000000P0oooo00210?ooo`030000003oool0oooo0080ooooE@3o0000
0`000000L`3o07<0o`0C07<0o`03000000008?l0023o00l0023o00<00000
002eo`00]Ol04000]Ol00`0000000?ne003o]@0C003o]@0300000000ob00
0?lP01T00?lP00<0000007?o001co`00<01co`02000000@0ooL01@3oool0
0`000000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?oo
oeD0o`0000<0000007<0o`1c0?l04`1c0?l00`000000023o000Po`0?000P
o`0300000000]Ol00;Go01000;Go00<00000003o]@00okD04`00okD00`00
00000?lP003o800J003o80030000001co`00Lol00340Lol000@000000?og
003om`00ooL01@3oool00`000000oooo0?ooo`060?ooo`00P@3oool00`00
0000oooo0?ooo`020?oooeD0o`0000<0000007<0o`1c0?l04`1c0?l00`00
0000023o000Po`0?000Po`0300000000]Ol00;Go01000;Go00<00000003o
]@00okD04`00okD00`0000000?lP003o800K003o80030000001co`00Lol0
0340Lol000<000000?og003om`001@3oool00`000000oooo0?ooo`060?oo
o`00P@3oool00`000000oooo0?ooo`020?oooe@0o`0000<0000007<0o`1c
0?l0501c0?l00`000000023o000Po`0?000Po`0300000000]Ol00;Go0100
0;Go00<00000003o]@00okD05000okD00`0000000?lP003o800K003o8003
0000001co`00Lol00340Lol00P0000050?ooo`030000003oool0oooo00H0
oooo00210?ooo`030000003oool0oooo0080ooooE03o00000`000000L`3o
07<0o`0C07<0o`03000000008?l0023o0100023o00<00000002eo`00]Ol0
4@00]Ol00`0000000?ne003o]@0C003o]@0300000000ob000?lP01/00?lP
00<0000007?o001co`00<`1co`000`000000oooo0?ooo`020?ooo`030000
003oool0oooo00H0oooo00210?ooo`030000003oool0oooo0080ooooD`3o
00000`000000L`3o07<0o`0D07<0o`03000000008?l0023o0100023o00<0
0000002eo`00]Ol04@00]Ol00`0000000?ne003o]@0D003o]@0300000000
ob000?lP01/00?lP00<0000007?o001co`00<P1co`050?ooo`030000003o
ool0oooo00H0oooo00210?ooo`030000003oool0oooo0080ooooD`3o0000
0`000000L`3o07<0o`0D07<0o`03000000008?l0023o0100023o00<00000
002eo`00]Ol04@00]Ol00`0000000?ne003o]@0D003o]@0300000000ob00
0?lP01`00?lP00<0000007?o001co`00<@1co`050?ooo`030000003oool0
oooo00H0oooo00210?ooo`030000003oool0oooo0080ooooDP3o00000`00
0000L`3o07<0o`0E07<0o`03000000008?l0023o0100023o00<00000002e
o`00]Ol04@00]Ol00`0000000?ne003o]@0D003o]@0300000000ob000?lP
01d00?lP00<0000007?o001co`00<01co`050?ooo`030000003oool0oooo
00H0oooo00210?ooo`8000000`3ooomB0?l000030000001c0?l0L`3o01D0
L`3o00<00000000Po`008?l040008?l00`0000000;Go002eo`0A002eo`03
00000000okD00?ne01D00?ne00<00000003o8000ob007@00ob000`000000
Lol007?o000_07?o00@0oooo0P0000080?ooo`00P@3oool00`000000oooo
0?ooo`020?oooe40o`0000<0000007<0o`1c0?l05@1c0?l00`000000023o
000Po`0A000Po`0300000000]Ol00;Go01800;Go00<00000003o]@00okD0
5000okD00`0000000?lP003o800M003o80030000001co`00Lol002l0Lol0
1@3oool00`000000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?oo
o`020?oooe40o`0000<0000007<0o`1c0?l05@1c0?l00`000000023o000P
o`0A000Po`0300000000]Ol00;Go01800;Go00<00000003o]@00okD05@00
okD00`0000000?lP003o800M003o80030000001co`00Lol002h0Lol01@3o
ool00`000000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`02
0?oooe40o`0000<0000007<0o`1c0?l05@1c0?l00`000000023o000Po`0A
000Po`0300000000]Ol00;Go01800;Go00<00000003o]@00okD05@00okD0
0`0000000?lP003o800N003o80030000001co`00Lol002d0Lol01@3oool0
0`000000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?oo
oe00o`0000<0000007<0o`1c0?l05P1c0?l00`000000023o000Po`0A000P
o`0300000000]Ol00;Go01800;Go00<00000003o]@00okD05@00okD00`00
00000?lP003o800O003o80030000001co`00Lol002`0Lol01@3oool00`00
0000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?oooe00
o`0000<0000007<0o`1c0?l05P1c0?l00`000000023o000Po`0A000Po`03
00000000]Ol00;Go01800;Go00<00000003o]@00okD05P00okD00`000000
0?lP003o800O003o80030000001co`00Lol002/0Lol01@3oool00`000000
oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?ooodl0o`00
00<0000007<0o`1c0?l05P1c0?l00`000000023o000Po`0B000Po`030000
0000]Ol00;Go01<00;Go00<00000003o]@00okD05@00okD00`0000000?lP
003o800O003o80030000001co`00Lol002/0Lol01@3oool00`000000oooo
0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?ooodl0o`0000<0
000007<0o`1c0?l05P1c0?l00`000000023o000Po`0B000Po`0300000000
]Ol00;Go01<00;Go00<00000003o]@00okD05P00okD00`0000000?lP003o
800O003o80800000:`1co`050?ooo`030000003oool0oooo00H0oooo0021
0?ooo`8000000`3ooom>0?l000030000001c0?l0L`3o01L0L`3o00<00000
000Po`008?l04P008?l00`0000000;Go002eo`0C002eo`0300000000okD0
0?ne01H00?ne00<00000003o8000ob008000ob000`000000Lol007?o000Y
07?o00@0oooo0P0000080?ooo`00P@3oool00`000000oooo0?ooo`020?oo
odh0o`0000<0000007<0o`1c0?l05P1c0?l00`000000023o000Po`0C000P
o`0300000000]Ol00;Go01<00;Go00<00000003o]@00okD05P00okD00`00
00000?lP003o800Q003o80030000001co`00Lol002P0Lol01@3oool00`00
0000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?ooodd0
o`0000<0000007<0o`1c0?l05`1c0?l00`000000023o000Po`0C000Po`03
00000000]Ol00;Go01<00;Go00<00000003o]@00okD05`00okD00`000000
0?lP003o800P003o80030000001co`00Lol002P0Lol01@3oool00`000000
oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?ooodd0o`00
00<0000007<0o`1c0?l05`1c0?l00`000000023o000Po`0C000Po`030000
0000]Ol00;Go01<00;Go00<00000003o]@00okD05`00okD00`0000000?lP
003o800Q003o80030000001co`00Lol002L0Lol01@3oool00`000000oooo
0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?oood`0o`0000<0
000007<0o`1c0?l0601c0?l00`000000023o000Po`0C000Po`0300000000
]Ol00;Go01@00;Go00<00000003o]@00okD05`00okD00`0000000?lP003o
800P003o80030000001co`00Lol002L0Lol01@3oool00`000000oooo0?oo
o`060?ooo`00P@3oool00`000000oooo0?ooo`020?oood`0o`0000<00000
07<0o`1c0?l0601c0?l00`000000023o000Po`0C000Po`0300000000]Ol0
0;Go01@00;Go00<00000003o]@00okD05`00okD00`0000000?lP003o800Q
003o80030000001co`00Lol002H0Lol01@3oool00`000000oooo0?ooo`06
0?ooo`00P@3oool00`000000oooo0?ooo`020?oood`0o`0000<0000007<0
o`1c0?l0601c0?l00`000000023o000Po`0C000Po`0300000000]Ol00;Go
01@00;Go00<00000003o]@00okD05`00okD00`0000000?lP003o800R003o
80030000001co`00Lol002D0Lol01@3oool00`000000oooo0?ooo`060?oo
o`00P@3oool00`000000oooo0?ooo`020?oood/0o`0000<0000007<0o`1c
0?l06@1c0?l00`000000023o000Po`0C000Po`0300000000]Ol00;Go01@0
0;Go00<00000003o]@00okD06000okD00`0000000?lP003o800R003o8003
0000001co`00Lol002@0Lol01@3oool00`000000oooo0?ooo`060?ooo`00
P@3oool00`000000oooo0?ooo`020?oood/0o`0000<0000007<0o`1c0?l0
601c0?l00`000000023o000Po`0D000Po`0300000000]Ol00;Go01D00;Go
00<00000003o]@00okD05`00okD00`0000000?lP003o800R003o80030000
001co`00Lol002@0Lol01@3oool00`000000oooo0?ooo`060?ooo`00P@3o
ool2000000<0ooooBP3o00000`000000L`3o07<0o`0I07<0o`0300000000
8?l0023o01@0023o00<00000002eo`00]Ol05@00]Ol00`0000000?ne003o
]@0H003o]@0300000000ob000?lP02800?lP0P00000T07?o00@0oooo0P00
00080?ooo`00P@3oool00`000000oooo0?ooo`020?ooodX0o`0000<00000
07<0o`1c0?l06@1c0?l00`000000023o000Po`0D000Po`0300000000]Ol0
0;Go01D00;Go00<00000003o]@00okD06000okD00`0000000?lP003o800S
003o80030000001co`00Lol00280Lol01@3oool00`000000oooo0?ooo`06
0?ooo`00P@3oool00`000000oooo0?ooo`020?ooodX0o`0000<0000007<0
o`1c0?l06@1c0?l00`000000023o000Po`0D000Po`0300000000]Ol00;Go
01D00;Go00<00000003o]@00okD06@00okD00`0000000?lP003o800S003o
80030000001co`00Lol00240Lol01@3oool00`000000oooo0?ooo`060?oo
o`00P@3oool00`000000oooo0?ooo`020?ooodT0o`0000<0000007<0o`1c
0?l06@1c0?l00`000000023o000Po`0E000Po`0300000000]Ol00;Go01D0
0;Go00<00000003o]@00okD06P00okD00`0000000?lP003o800S003o8003
0000001co`00Lol00200Lol01@3oool00`000000oooo0?ooo`060?ooo`00
P@3oool00`000000oooo0?ooo`020?ooodT0o`0000<0000007<0o`1c0?l0
6@1c0?l00`000000023o000Po`0E000Po`0300000000]Ol00;Go01H00;Go
00<00000003o]@00okD06@00okD00`0000000?lP003o800T003o80030000
001co`00Lol001l0Lol01@3oool00`000000oooo0?ooo`060?ooo`00P@3o
ool00`000000oooo0?ooo`020?ooodP0o`0000<0000007<0o`1c0?l06P1c
0?l00`000000023o000Po`0E000Po`0300000000]Ol00;Go01H00;Go00<0
0000003o]@00okD06P00okD00`0000000?lP003o800T003o80030000001c
o`00Lol001h0Lol01@3oool00`000000oooo0?ooo`060?ooo`00K@3oool5
00000080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooodP0o`0000<0000007<0o`1c0?l06P1c0?l00`000000023o000Po`0E
000Po`0300000000]Ol00;Go01H00;Go00<00000003o]@00okD06P00okD0
0`0000000?lP003o800U003o80030000001co`00Lol001d0Lol01@3oool0
0`000000oooo0?ooo`060?ooo`00K`3oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3ooom7
0?l000030000001c0?l0L`3o01/0L`3o00<00000000Po`008?l05@008?l0
0`0000000;Go002eo`0F002eo`0300000000okD00?ne01/00?ne00<00000
003o8000ob009000ob000`000000Lol007?o000M07?o00D0oooo00<00000
0?ooo`3oool01P3oool006l0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`8000000`3ooom70?l000030000001c0?l0L`3o
01X0L`3o00<00000000Po`008?l05P008?l00`0000000;Go002eo`0G002e
o`0300000000okD00?ne01X00?ne00<00000003o8000ob009@00ob000`00
0000Lol007?o000L07?o00<0oooo0`0000080?ooo`00K`3oool00`000000
oooo0?ooo`080?ooo`8000001@3oool00`000000oooo0?ooo`020?ooodH0
o`0000<0000007<0o`1c0?l06`1c0?l00`000000023o000Po`0F000Po`03
00000000]Ol00;Go01L00;Go00<00000003o]@00okD06`00okD00`000000
0?lP003o800T003o80030000001co`00Lol001`0Lol01@3oool00`000000
oooo0?ooo`060?ooo`00K`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3ooom60?l000030000
001c0?l0L`3o01/0L`3o00<00000000Po`008?l05P008?l00`0000000;Go
002eo`0G002eo`0300000000okD00?ne01/00?ne00<00000003o8000ob00
9@00ob02000001`0Lol01@3oool00`000000oooo0?ooo`060?ooo`00KP3o
ool2000000X0oooo0`0000040?ooo`030000003oool0oooo0080ooooAP3o
00000`000000L`3o07<0o`0K07<0o`03000000008?l0023o01H0023o00<0
0000002eo`00]Ol05`00]Ol00`0000000?ne003o]@0K003o]@0300000000
ob000?lP02H00?lP00<0000007?o001co`006P1co`050?ooo`030000003o
ool0oooo00H0oooo00210?ooo`030000003oool0oooo0080ooooA@3o0000
0`000000L`3o07<0o`0L07<0o`03000000008?l0023o01H0023o00<00000
002eo`00]Ol05`00]Ol00`0000000?ne003o]@0L003o]@0300000000ob00
0?lP02H00?lP00<0000007?o001co`006@1co`050?ooo`030000003oool0
oooo00H0oooo00210?ooo`030000003oool0oooo0080ooooA@3o00000`00
0000L`3o07<0o`0K07<0o`03000000008?l0023o01L0023o00<00000002e
o`00]Ol06000]Ol00`0000000?ne003o]@0K003o]@0300000000ob000?lP
02H00?lP00<0000007?o001co`006@1co`050?ooo`030000003oool0oooo
00H0oooo00210?ooo`030000003oool0oooo0080ooooA03o00000`000000
L`3o07<0o`0L07<0o`03000000008?l0023o01L0023o00<00000002eo`00
]Ol06000]Ol00`0000000?ne003o]@0L003o]@0300000000ob000?lP02H0
0?lP00<0000007?o001co`00601co`050?ooo`030000003oool0oooo00H0
oooo00210?ooo`030000003oool0oooo0080ooooA03o00000`000000L`3o
07<0o`0L07<0o`03000000008?l0023o01L0023o00<00000002eo`00]Ol0
6000]Ol00`0000000?ne003o]@0L003o]@0300000000ob000?lP02L00?lP
00<0000007?o001co`005`1co`050?ooo`030000003oool0oooo00H0oooo
00210?ooo`8000000`3ooom30?l000030000001c0?l0L`3o01d0L`3o00<0
0000000Po`008?l05`008?l00`0000000;Go002eo`0H002eo`0300000000
okD00?ne01`00?ne00<00000003o8000ob00:000ob000`000000Lol007?o
000F07?o00@0oooo0P0000080?ooo`00P@3oool00`000000oooo0?ooo`02
0?oood<0o`0000<0000007<0o`1c0?l07@1c0?l00`000000023o000Po`0G
000Po`0300000000]Ol00;Go01P00;Go00<00000003o]@00okD07000okD0
0`0000000?lP003o800Y003o80030000001co`00Lol001D0Lol01@3oool0
0`000000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?oo
od80o`0000<0000007<0o`1c0?l07@1c0?l00`000000023o000Po`0H000P
o`0300000000]Ol00;Go01T00;Go00<00000003o]@00okD07000okD00`00
00000?lP003o800X003o80030000001co`00Lol001D0Lol01@3oool00`00
0000oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?oood80
o`0000<0000007<0o`1c0?l07@1c0?l00`000000023o000Po`0H000Po`03
00000000]Ol00;Go01T00;Go00<00000003o]@00okD07000okD00`000000
0?lP003o800Y003o80030000001co`00Lol001@0Lol01@3oool00`000000
oooo0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?oood80o`00
00<0000007<0o`1c0?l07@1c0?l00`000000023o000Po`0H000Po`030000
0000]Ol00;Go01T00;Go00<00000003o]@00okD07@00okD00`0000000?lP
003o800Y003o80030000001co`00Lol001<0Lol01@3oool00`000000oooo
0?ooo`060?ooo`00P@3oool00`000000oooo0?ooo`020?oood80o`0000<0
000007<0o`1c0?l07@1c0?l00`000000023o000Po`0H000Po`0300000000
]Ol00;Go01T00;Go00<00000003o]@00okD07@00okD00`0000000?lP003o
800Z003o80030000001co`00Lol00180Lol01@3oool00`000000oooo0?oo
o`060?ooo`00P@3oool00`000000oooo0?ooo`020?oood40o`0000<00000
07<0o`1c0?l07P1c0?l00`000000023o000Po`0H000Po`0300000000]Ol0
0;Go01T00;Go00<00000003o]@00okD07P00okD00`0000000?lP003o800Y
003o80030000001co`00Lol00180Lol01@3oool00`000000oooo0?ooo`06
0?ooo`00P@3oool00`000000oooo0?ooo`020?oood40o`0000<0000007<0
o`1c0?l07@1c0?l00`000000023o000Po`0I000Po`0300000000]Ol00;Go
01X00;Go00<00000003o]@00okD07@00okD00`0000000?lP003o800Z003o
80030000001co`00Lol00140Lol01@3oool00`000000oooo0?ooo`060?oo
o`00P@3oool00`000000oooo0?ooo`020?oood00o`0000<0000007<0o`1c
0?l07P1c0?l00`000000023o000Po`0I000Po`0300000000]Ol00;Go01X0
0;Go00<00000003o]@00okD07P00okD00`0000000?lP003o800Y003o8003
0000001co`00Lol00140Lol01@3oool00`000000oooo0?ooo`060?ooo`00
P@3oool2000000<0oooo@03o00000`000000L`3o07<0o`0N07<0o`030000
00008?l0023o01T0023o00<00000002eo`00]Ol06P00]Ol00`0000000?ne
003o]@0N003o]@0300000000ob000?lP02X00?lP00<0000007?o001co`00
401co`040?ooo`800000203oool00840oooo00<000000?ooo`3oool00P3o
oolo0?l000030000001c0?l0L`3o01l0L`3o00<00000000Po`008?l06@00
8?l00`0000000;Go002eo`0J002eo`0300000000okD00?ne01h00?ne00<0
0000003o8000ob00:`00ob000`000000Lol007?o000?07?o00D0oooo00<0
00000?ooo`3oool01P3oool00840oooo00<000000?ooo`3oool00P3ooolo
0?l000030000001c0?l0L`3o01h0L`3o00<00000000Po`008?l06P008?l0
0`0000000;Go002eo`0J002eo`0300000000okD00?ne01l00?ne00<00000
003o8000ob00:`00ob000`000000Lol007?o000>07?o00D0oooo00<00000
0?ooo`3oool01P3oool00840oooo00<000000?ooo`3oool00P3oooln0?l0
00030000001c0?l0L`3o01l0L`3o00<00000000Po`008?l06P008?l00`00
00000;Go002eo`0K002eo`0300000000okD00?ne01h00?ne00<00000003o
8000ob00:`00ob000`000000Lol007?o000>07?o00D0oooo00<000000?oo
o`3oool01P3oool00840oooo00<000000?ooo`3oool00P3oooln0?l00003
0000001c0?l0L`3o01l0L`3o00<00000000Po`008?l06P008?l00`000000
0;Go002eo`0K002eo`0300000000okD00?ne01l00?ne00<00000003o8000
ob00:`00ob000`000000Lol007?o000=07?o00D0oooo00<000000?ooo`3o
ool01P3oool00840oooo00<000000?ooo`3oool00P3ooolm0?l000030000
001c0?l0L`3o0200L`3o00<00000000Po`008?l06P008?l00`0000000;Go
002eo`0K002eo`0300000000okD00?ne01l00?ne00<00000003o8000ob00
;000ob000`000000Lol007?o000<07?o00D0oooo00<000000?ooo`3oool0
1P3oool00840oooo00<000000?ooo`3oool00P3ooolm0?l000030000001c
0?l0L`3o0200L`3o00<00000000Po`008?l06P008?l00`0000000;Go002e
o`0K002eo`0300000000okD00?ne01l00?ne00<00000003o8000ob00;@00
ob000`000000Lol007?o000;07?o00D0oooo00<000000?ooo`3oool01P3o
ool00840oooo00<000000?ooo`3oool00P3oooll0?l000030000001c0?l0
L`3o0240L`3o00<00000000Po`008?l06P008?l00`0000000;Go002eo`0K
002eo`0300000000okD00?ne02000?ne00<00000003o8000ob00;@00ob00
0`000000Lol007?o000:07?o00D0oooo00<000000?ooo`3oool01P3oool0
0840oooo0P0000030?oooc`0o`0000<0000007<0o`1c0?l0801c0?l00`00
0000023o000Po`0K000Po`0300000000]Ol00;Go01`00;Go00<00000003o
]@00okD07`00okD00`0000000?lP003o800]003o80030000001co`00Lol0
00X0Lol0103oool2000000P0oooo00210?ooo`030000003oool0oooo0080
oooo>`3o00000`000000L`3o07<0o`0Q07<0o`03000000008?l0023o01/0
023o00<00000002eo`00]Ol07000]Ol00`0000000?ne003o]@0P003o]@03
00000000ob000?lP02d00?lP00<0000007?o001co`002@1co`050?ooo`03
0000003oool0oooo00H0oooo00210?ooo`030000003oool0oooo0080oooo
>`3o00000`000000L`3o07<0o`0Q07<0o`03000000008?l0023o01/0023o
00<00000002eo`00]Ol07000]Ol00`0000000?ne003o]@0P003o]@030000
0000ob000?lP02h00?lP00<0000007?o001co`00201co`050?ooo`030000
003oool0oooo00H0oooo00210?ooo`030000003oool0oooo0080oooo>`3o
00000`000000L`3o07<0o`0Q07<0o`03000000008?l0023o01/0023o00<0
0000002eo`00]Ol07000]Ol00`0000000?ne003o]@0Q003o]@0300000000
ob000?lP02h00?lP00<0000007?o001co`001`1co`050?ooo`030000003o
ool0oooo00H0oooo00210?ooo`030000003oool0oooo0080oooo>P3o0000
0`000000L`3o07<0o`0R07<0o`03000000008?l0023o01/0023o00<00000
002eo`00]Ol07000]Ol00`0000000?ne003o]@0Q003o]@0300000000ob00
0?lP02h00?lP00<0000007?o001co`001`1co`050?ooo`030000003oool0
oooo00H0oooo00210?ooo`030000003oool0oooo0080oooo>P3o00000`00
0000L`3o07<0o`0Q07<0o`03000000008?l0023o01`0023o00<00000002e
o`00]Ol07@00]Ol00`0000000?ne003o]@0Q003o]@0300000000ob000?lP
02h00?lP00<0000007?o001co`001P1co`050?ooo`030000003oool0oooo
00H0oooo00210?ooo`030000003oool0oooo0080oooo>@3o00000`000000
L`3o07<0o`0R07<0o`03000000008?l0023o01`0023o00<00000002eo`00
]Ol07@00]Ol00`0000000?ne003o]@0Q003o]@0300000000ob000?lP02h0
0?lP00<0000007?o001co`001P1co`050?ooo`030000003oool0oooo00H0
oooo00210?ooo`030000003oool0oooo0080oooo>@3o00000`000000L`3o
07<0o`0R07<0o`03000000008?l0023o01`0023o00<00000002eo`00]Ol0
7@00]Ol00`0000000?ne003o]@0R003o]@0300000000ob000?lP02h00?lP
0P00000607?o00D0oooo00<000000?ooo`3oool01P3oool00840oooo0P00
00030?ooocT0o`0000<0000007<0o`1c0?l08P1c0?l00`000000023o000P
o`0L000Po`0300000000]Ol00;Go01d00;Go00<00000003o]@00okD08P00
okD00`0000000?lP003o800_003o80030000001co`00Lol000@0Lol0103o
ool2000000P0oooo00210?ooo`030000003oool0oooo0080oooo>03o0000
0`000000L`3o07<0o`0S07<0o`03000000008?l0023o01`0023o00<00000
002eo`00]Ol07@00]Ol00`0000000?ne003o]@0S003o]@0300000000ob00
0?lP02l00?lP00<0000007?o001co`000`1co`050?ooo`030000003oool0
oooo00H0oooo00210?ooo`030000003oool0oooo0080oooo>03o00000`00
0000L`3o07<0o`0R07<0o`03000000008?l0023o01d0023o00<00000002e
o`00]Ol07P00]Ol00`0000000?ne003o]@0R003o]@0300000000ob000?lP
02l00?lP00<0000007?o001co`000`1co`050?ooo`030000003oool0oooo
00H0oooo00210?ooo`030000003oool0oooo0080oooo=`3o00000`000000
L`3o07<0o`0S07<0o`03000000008?l0023o01d0023o00<00000002eo`00
]Ol07P00]Ol00`0000000?ne003o]@0S003o]@0300000000ob000?lP02l0
0?lP00<0000007?o001co`000P1co`050?ooo`030000003oool0oooo00H0
oooo00210?ooo`030000003oool0oooo0080oooo=`3o00000`000000L`3o
07<0o`0S07<0o`03000000008?l0023o01d0023o00<00000002eo`00]Ol0
7P00]Ol00`0000000?ne003o]@0S003o]@0300000000ob000?lP03000?lP
00@0000007?o001co`00Lol01@3oool00`000000oooo0?ooo`060?ooo`00
P@3oool00`000000oooo0?ooo`020?ooocL0o`0000<0000007<0o`1c0?l0
8`1c0?l00`000000023o000Po`0M000Po`0300000000]Ol00;Go01h00;Go
00<00000003o]@00okD08`00okD00`0000000?lP003o800a003o80030000
001co`00Lol000D0oooo00<000000?ooo`3oool01P3oool00840oooo00<0
00000?ooo`3oool00P3ooolf0?l000030000001c0?l0L`3o02@0L`3o00<0
0000000Po`008?l07@008?l00`0000000;Go002eo`0N002eo`0300000000
okD00?ne02@00?ne00<00000003o8000ob00<@00ob000`000000Lol00?oo
o`040?ooo`030000003oool0oooo00H0oooo001i0?ooo`@00000103oool0
0`000000oooo0?ooo`020?ooocH0o`0000<0000007<0o`1c0?l08`1c0?l0
0`000000023o000Po`0N000Po`0300000000]Ol00;Go01l00;Go00<00000
003o]@00okD08`00okD00`0000000?lP003o800a003o80030000001co`00
oooo00@0oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooocD0o`0000<0000007<0
o`1c0?l0901c0?l00`000000023o000Po`0N000Po`0300000000]Ol00;Go
01l00;Go00<00000003o]@00okD09000okD00`0000000?lP003o800a003o
80800000103oool00`000000oooo0?ooo`060?ooo`00NP3oool00`000000
oooo0?ooo`040?ooo`8000000`3ooole0?l000030000001c0?l0L`3o02@0
L`3o00<00000000Po`008?l07P008?l00`0000000;Go002eo`0O002eo`03
00000000okD00?ne02@00?ne00<00000003o8000ob00<P00ob000`000000
oooo0?ooo`03000000P0oooo001k0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool007T0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo
001j0?ooo`8000001@3ooooo000000L00000203oool00?l0ooooT03oool0
0001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{399, 194},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  Recalling that the function  ",
  Cell[BoxData[
      \(Arg\ z\)]],
  "  is harmonic and takes on constant values along rays emanating from the \
origin, we see that a solution has the form  \n\n\t\t\t",
  Cell[BoxData[
      \(\[CapitalPsi] \((x, y)\)\  = \ a\  + \ b\ Arg\ z\)]],
  ",  \n\nwhere ",
  StyleBox["a",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["b",
    FontFamily->"Courier New"],
  " are constants.  The boundary conditions lead to  \n\n\t\t\t",
  Cell[BoxData[
      \(\[CapitalPsi] \((x, y)\)\  = \ 
        C\_1 + \(\(C\_2 - C\_1\)\/\[Alpha]\) Arg\ z\)]],
  ".  \n\nThe level curves  ",
  Cell[BoxData[
      \(\[CapitalPsi] \((x, y)\)\  = \ constant\)]],
  "  are rays emanating from the origin as indicated in Figure 11.2. "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.2",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/applicationpreliminary/\
ApplicationPreliminaryFigures/mat1102.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Level curves of the harmonic function  ",
  Cell[BoxData[
      \(\[CapitalPsi] \((x, y)\)\  = \ 
        C\_1 + \(\(C\_2 - C\_1\)\/\[Alpha]\) Arg\ z\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "A specific example of the general case. Find the function ",
  Cell[BoxData[
      \(\[CapitalPsi] \((x, y)\)\)]],
  " that is harmonic in the sector ",
  Cell[BoxData[
      \(0 < Arg \((z)\) < \(2  \[Pi]\)\/3\)]],
  " and takes on the boundary values \n\n\t\t\t",
  Cell[BoxData[
      \(\[CapitalPsi] \((x, 0)\)\  = \ 1\)]],
  "   for  x > 0,\n\t\t\t",
  Cell[BoxData[
      \(\[CapitalPsi] \((x, y)\)\  = \ 9\)]],
  "   for all points on the ray  ",
  Cell[BoxData[
      \(r > 0, \[Theta] = \(2  \[Pi]\)\/3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(a\ \ \  = \ \(2  \[Pi]\)\/3;\)\ \ \), "\n", 
    \(\(c\_1\  = \ 1;\)\ \ \), "\n", 
    \(\(c\_2\  = \ 9;\)\ \), "\n", 
    \(\(u[x_, y_]\  = \ 
        c\_1\  + \ \(c\_2\  - \ c\_1\)\/a\ ArcTan[x, 
              y];\)\ \), "\[IndentingNewLine]", 
    \(\(cont = {2, 3, 4, 5, 6, 7, 8, 9};\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[u[x, y], {x, \(-2\), 2}, {y, 0.0001, 2}, 
        Contours\  \[Rule] \ cont, PlotPoints \[Rule] 35, 
        AspectRatio \[Rule] 2\/3, ColorFunction \[Rule] Hue];\)\ \), "\n", 
    \(\(Print["\<Contour plot for  u[x,y] = \>", 
        u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<for  0 < Arg(z) <\!\(\(\(\\\ \)\(2  \
\[Pi]\)\)\/3\)\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[u[x, y], "\< = c\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<where c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the function ",
  Cell[BoxData[
      \(\[CapitalPhi] \((x, y)\)\)]],
  " that is harmonic in the annulus  ",
  Cell[BoxData[
      \(\(\(1\)\(<\)\) | z | \(\(<\)\(\ \)\(R\)\)\)]],
  "  and takes on the boundary values  \n\n\t\t\t",
  Cell[BoxData[
      \(\[CapitalPhi] \((x, y)\)\  = \ K\_1\)]],
  "   when  ",
  Cell[BoxData[
      \(\(\(\ \)\(\(\(|\)\(z\)\(|\)\)\  = 1\)\)\)]],
  ",  and  \n\t\t\t",
  Cell[BoxData[
      \(\[CapitalPhi] \((x, y)\)\  = \ K\_2\)]],
  "   when  ",
  Cell[BoxData[
      \(\(\(\ \)\(\(\(|\)\(z\)\(|\)\)\  = R\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004`0000`R000`400?l0
0000o`00003oo`3ooola0?ooo`00o`3ooola0?ooo`00o`3ooola0?ooo`00
o`3ooola0?ooo`00o`3ooola0?ooo`00o`3ooola0?ooo`00o`3ooola0?oo
o`00o`3ooola0?ooo`00Q03oool3000002<0oooo1000000R0?ooo`800000
903oool4000002H0oooo0`00000=0?ooo`00Q@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo0280oooo00@000000?ooo`3oool00000
8`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00`0oooo
00220?ooo`D00000903oool00`000000oooo0?ooo`0Q0?ooo`040000003o
ool0oooo000002@0oooo00<000000?ooo`3oool0903oool5000000d0oooo
001l0?ooo`@000000P3oool010000000oooo0?ooo`00000N0?ooo`@00000
103oool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo000002D0
oooo00<000000?ooo`3oool08`3oool010000000oooo0?ooo`00000>0?oo
o`00P`3oool00`000000oooo0000000T0?ooo`040000003oool0oooo0000
0240oooo00@000000?ooo`3oool000008`3oool010000000oooo0?ooo`00
000U0?ooo`030000003oool0000000h0oooo00240?ooo`8000009@3oool2
000002<0oooo0P00000U0?ooo`8000009`3oool2000000h0oooo003o0?oo
oc40oooo003o0?oooc40oooo003o0?oooc40oooo003o0?oooc40oooo001j
0?ooojh00000203oool007X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool007X0
oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`060?ooo`00
NP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo00H0oooo
001j0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool01P3o
ool007X0oooo00<000000?ooo`3oool0Y`3o00030?ooo`030000003oool0
oooo00H0oooo001e0?ooo`<000000P3oool00`000000oooo0?ooo`2W0?l0
00<0oooo00<000000?ooo`3oool01P3oool007H0oooo00D000000?ooo`3o
ool0oooo000000020?ooojL0o`000`3oool00`000000oooo0?ooo`060?oo
o`00L`3oool500000080oooo0P0000000`3oool0o`000?l000180?l001@0
0000B@3o00020?ooo`800000203oool006d0oooo100000020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0@`3o0007000001@0
c`3o1`0000120?l000<0oooo00<000000?ooo`3oool01P3oool007@0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`0o0?l000@00000
8P3?0?l4000003h0o`000`3oool00`000000oooo0?ooo`060?ooo`00M@3o
ool2000000<0oooo00<000000?ooo`3oool0?@3o0002000002X0c`3o0P00
000l0?l000<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<00000
0?ooo`3oool0>P3o0003000002h0c`3o0`00000i0?l000<0oooo00<00000
0?ooo`3oool01P3oool007X0oooo00<000000?ooo`3oool0=`3o00030000
03@0c`3o0`00000f0?l000<0oooo00<000000?ooo`3oool01P3oool007X0
oooo00<000000?ooo`3oool0=@3o0002000003X0c`3o0P00000d0?l000<0
oooo00<000000?ooo`3oool01P3oool007X0oooo00<000000?ooo`3oool0
<`3o0002000003h0c`3o0P00000b0?l000<0oooo00<000000?ooo`3oool0
1P3oool007X0oooo00<000000?ooo`3oool0<03o000300000480c`3o0`00
000_0?l000<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<00000
0?ooo`3oool0;@3o0003000004P0c`3o0`00000/0?l000<0oooo00<00000
0?ooo`3oool01P3oool007X0oooo00<000000?ooo`3oool0:`3o00020000
04h0c`3o0P00000Z0?l000<0oooo00<000000?ooo`3oool01P3oool007X0
oooo00<000000?ooo`3oool0:P3o00000`000000c`3o0<l0o`1@0<l0o`03
0000003o0000o`0002L0o`000`3oool00`000000oooo0?ooo`060?ooo`00
NP3oool00`000000oooo0?ooo`0X0?l000800000E03?0?l2000002L0o`00
0`3oool00`000000oooo0?ooo`060?ooo`00NP3oool00`000000oooo0?oo
o`0W0?l000030000003?0?l0c`3o05H0c`3o00<000000?l0003o0000903o
00030?ooo`030000003oool0oooo00H0oooo001j0?ooo`030000003oool0
oooo02H0o`0000<000000<l0o`3?0?l0F03?0?l00`000000o`000?l0000S
0?l000<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<000000?oo
o`3oool0903o0002000005`0c`3o0P00000S0?l000<0oooo00<000000?oo
o`3oool01P3oool007X0oooo00<000000?ooo`3oool08`3o00000`000000
c`3o0<l0o`1N0<l0o`8000008@3o00030?ooo`030000003oool0oooo00H0
oooo001j0?ooo`030000003oool0oooo0280o`0000<000000<l0o`3?0?l0
H@3?0?l00`000000o`000?l0000N0?l000<0oooo00<000000?ooo`3oool0
1P3oool007X0oooo00<000000?ooo`3oool08@3o00000`000000c`3o0<l0
o`1S0<l0o`030000003o0000o`0001d0o`000`3oool00`000000oooo0?oo
o`060?ooo`00NP3oool00`000000oooo0?ooo`0O0?l000800000:@3?0?lD
000002X0c`3o00<000000?l0003o0000703o00030?ooo`030000003oool0
oooo00H0oooo001j0?ooo`030000003oool0oooo01h0o`0000<000000<l0
o`3?0?l0903?0?l5000001@001So1@00000V0<l0o`030000003o0000o`00
01/0o`000`3oool00`000000oooo0?ooo`060?ooo`00NP3oool00`000000
oooo0?ooo`0M0?l000030000003?0?l0c`3o02<0c`3o0P00000N000Ho`80
00009@3?0?l00`000000o`000?l0000J0?l000<0oooo00<000000?ooo`3o
ool01P3oool007X0oooo00<000000?ooo`3oool0703o00000`000000c`3o
0<l0o`0R0<l0o`8000008P006?l2000002@0c`3o00<000000?l0003o0000
6@3o00030?ooo`030000003oool0oooo00H0oooo001j0?ooo`030000003o
ool0oooo01/0o`0000<000000<l0o`3?0?l07P3?0?l5000002H001So1@00
000P0<l0o`030000003o0000o`0001P0o`000`3oool00`000000oooo0?oo
o`060?ooo`00NP3oool00`000000oooo0?ooo`0J0?l000030000003?0?l0
c`3o01h0c`3o00<00000000Ho`006?l0;P006?l00`000000c`3o0<l0o`0N
0<l0o`030000003o0000o`0001L0o`000`3oool00`000000oooo0?ooo`06
0?ooo`00NP3oool00`000000oooo0?ooo`0I0?l000030000003?0?l0c`3o
01d0c`3o0P00000b000Ho`8000007`3?0?l00`000000o`000?l0000F0?l0
00<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<000000?ooo`3o
ool0603o00000`000000c`3o0<l0o`0M0<l0o`03000000006?l001So03@0
01So00<000000<l0o`3?0?l07@3?0?l00`000000o`000?l0000E0?l000<0
oooo00<000000?ooo`3oool01P3oool007X0oooo00<000000?ooo`3oool0
603o00000`000000c`3o0<l0o`0K0<l0o`800000>0006?l2000001d0c`3o
00<000000?l0003o00005@3o00030?ooo`030000003oool0oooo00H0oooo
001j0?ooo`030000003oool0oooo01L0o`0000<000000<l0o`3?0?l06P3?
0?l2000003`001So0P00000L0<l0o`030000003o0000o`0001@0o`000`3o
ool00`000000oooo0?ooo`060?ooo`00NP3oool00`000000oooo0?ooo`0F
0?l000030000003?0?l0c`3o01T0c`3o0P000010000Ho`8000006`3?0?l0
0`000000o`000?l0000C0?l000<0oooo00<000000?ooo`3oool01P3oool0
07X0oooo00<000000?ooo`3oool05@3o00000`000000c`3o0<l0o`0H0<l0
o`800000A0006?l2000001X0c`3o00<000000?l0003o00004P3o00030?oo
o`030000003oool0oooo00H0oooo001j0?ooo`030000003oool0oooo01@0
o`0000<000000<l0o`3?0?l0603?0?l00`00000001So000Ho`16000Ho`03
0000003?0?l0c`3o01P0c`3o00<000000?l0003o00004@3o00030?ooo`03
0000003oool0oooo00H0oooo001j0?ooo`030000003oool0oooo01@0o`00
00<000000<l0o`3?0?l05`3?0?l00`00000001So000Ho`18000Ho`030000
003?0?l0c`3o01L0c`3o00<000000?l0003o00004@3o00030?ooo`030000
003oool0oooo00H0oooo001j0?ooo`030000003oool0oooo01<0o`0000<0
00000<l0o`3?0?l05`3?0?l00`00000001So000Ho`0Q000Ho`H000008`00
6?l00`000000c`3o0<l0o`0G0<l0o`030000003o0000o`000100o`000`3o
ool00`000000oooo0?ooo`060?ooo`00NP3oool00`000000oooo0?ooo`0B
0?l000030000003?0?l0c`3o01L0c`3o00<00000000Ho`006?l07@006?l5
000000H00?oo1@00000O000Ho`030000003?0?l0c`3o01L0c`3o00<00000
0?l0003o00003`3o00030?ooo`030000003oool0oooo00H0oooo001j0?oo
o`030000003oool0oooo0140o`0000<000000<l0o`3?0?l05`3?0?l00`00
000001So000Ho`0J000Ho`@000004000ool4000001`001So00<000000<l0
o`3?0?l05`3?0?l00`000000o`000?l0000>0?l000<0oooo00<000000?oo
o`3oool01P3oool007X0oooo00<000000?ooo`3oool04@3o00000`000000
c`3o0<l0o`0F0<l0o`03000000006?l001So01L001So1000000H003oo`@0
00006@006?l00`000000c`3o0<l0o`0F0<l0o`030000003o0000o`0000h0
o`000`3oool00`000000oooo0?ooo`060?ooo`00L`3oool4000000<0oooo
00<000000?ooo`3oool0403o00000`000000c`3o0<l0o`0E0<l0o`800000
5`006?l3000002000?oo0`00000G000Ho`8000005`3?0?l00`000000o`00
0?l0000=0?l000<0oooo00<000000?ooo`3oool01P3oool007<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?l000030000003?
0?l0c`3o01D0c`3o00<00000000Ho`006?l05@006?l2000002H00?oo0P00
000G000Ho`030000003?0?l0c`3o01@0c`3o00<000000?l0003o00003@3o
00030?ooo`030000003oool0oooo00H0oooo001d0?ooo`030000003oool0
oooo00<0oooo0P0000000`3oool0o`000?l0000=0?l000030000003?0?l0
c`3o01D0c`3o00<00000000Ho`006?l04`006?l2000002X00?oo0P00000E
000Ho`030000003?0?l0c`3o01D0c`3o00<000000?l0003o0000303o0002
0?ooo`800000203oool006d0oooo100000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool03P3o00000`000000c`3o0<l0o`0E0<l0
o`03000000006?l001So01<001So00<00000003oo`00ool0;000ool00`00
000001So000Ho`0C000Ho`030000003?0?l0c`3o01@0c`3o00<000000?l0
003o0000303o00030?ooo`030000003oool0oooo00H0oooo001c0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool03P3o00000`00
0000c`3o0<l0o`0D0<l0o`03000000006?l001So01<001So00<00000003o
o`00ool0;P00ool00`00000001So000Ho`0C000Ho`030000003?0?l0c`3o
01@0c`3o00<000000?l0003o00002`3o00030?ooo`030000003oool0oooo
00H0oooo001d0?ooo`800000103oool00`000000oooo0?ooo`0=0?l00003
0000003?0?l0c`3o01@0c`3o00<00000000Ho`006?l04P006?l200000380
0?oo0P00000D000Ho`030000003?0?l0c`3o01@0c`3o00<000000?l0003o
00002P3o00030?ooo`030000003oool0oooo00H0oooo001j0?ooo`030000
003oool0oooo00d0o`0000<000000<l0o`3?0?l0503?0?l00`00000001So
000Ho`0A000Ho`0300000000ool00?oo03@00?oo00<00000000Ho`006?l0
4@006?l00`000000c`3o0<l0o`0D0<l0o`030000003o0000o`0000X0o`00
0`3oool00`000000oooo0?ooo`060?ooo`00NP3oool00`000000oooo0?oo
o`0<0?l000030000003?0?l0c`3o01<0c`3o0P00000B000Ho`8000006@00
ool6000001T00?oo0P00000B000Ho`8000005@3?0?l00`000000o`000?l0
00090?l000<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<00000
0?ooo`3oool0303o00000`000000c`3o0<l0o`0B0<l0o`03000000006?l0
01So014001So00<00000003oo`00ool05000ool5000000H00?lH1@00000F
003oo`03000000006?l001So014001So00<000000<l0o`3?0?l04P3?0?l0
0`000000o`000?l000090?l000<0oooo00<000000?ooo`3oool01P3oool0
07X0oooo00<000000?ooo`3oool02`3o00000`000000c`3o0<l0o`0C0<l0
o`03000000006?l001So010001So00<00000003oo`00ool04@00ool40000
01000?lH1000000C003oo`03000000006?l001So010001So00<000000<l0
o`3?0?l04`3?0?l00`000000o`000?l000080?l000<0oooo00<000000?oo
o`3oool01P3oool007X0oooo00<000000?ooo`3oool02`3o00000`000000
c`3o0<l0o`0B0<l0o`03000000006?l001So010001So00<00000003oo`00
ool04000ool2000001P00?lH0P00000B003oo`03000000006?l001So0100
01So00<000000<l0o`3?0?l04P3?0?l00`000000o`000?l000080?l000<0
oooo00<000000?ooo`3oool01P3oool007X0oooo00<000000?ooo`3oool0
2P3o00000`000000c`3o0<l0o`0C0<l0o`03000000006?l001So00l001So
00<00000003oo`00ool03`00ool2000001`00?lH0P00000A003oo`030000
00006?l001So00l001So00<000000<l0o`3?0?l04`3?0?l00`000000o`00
0?l000070?l000<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<0
00000?ooo`3oool02P3o00000`000000c`3o0<l0o`0B0<l0o`0300000000
6?l001So00l001So00<00000003oo`00ool03P00ool2000002000?lH0P00
000@003oo`03000000006?l001So00l001So00<000000<l0o`3?0?l04P3?
0?l00`000000o`000?l000070?l000<0oooo00<000000?ooo`3oool01P3o
ool007X0oooo00<000000?ooo`3oool02@3o00000`000000c`3o0<l0o`0C
0<l0o`03000000006?l001So00h001So00<00000003oo`00ool03@00ool2
000002@00?lH0P00000?003oo`03000000006?l001So00h001So00<00000
0<l0o`3?0?l04`3?0?l00`000000o`000?l000060?l000<0oooo00<00000
0?ooo`3oool01P3oool007X0oooo00<000000?ooo`3oool02@3o00000`00
0000c`3o0<l0o`0B0<l0o`03000000006?l001So00h001So00<00000003o
o`00ool03@00ool00`0000000?lH003o600V003o600300000000ool00?oo
00d00?oo00<00000000Ho`006?l03P006?l00`000000c`3o0<l0o`0B0<l0
o`030000003o0000o`0000H0o`000`3oool00`000000oooo0?ooo`060?oo
o`00NP3oool00`000000oooo0?ooo`090?l000030000003?0?l0c`3o0180
c`3o00<00000000Ho`006?l03@006?l00`0000000?oo003oo`0=003oo`03
00000000oaP00?lH02P00?lH00<00000003oo`00ool03@00ool00`000000
01So000Ho`0=000Ho`030000003?0?l0c`3o0180c`3o00<000000?l0003o
00001P3o00030?ooo`030000003oool0oooo00H0oooo001j0?ooo`030000
003oool0oooo00P0o`0000<000000<l0o`3?0?l04P3?0?l00`00000001So
000Ho`0>000Ho`0300000000ool00?oo00`00?oo00<00000003o6000oaP0
4@00oaP6000001<00?lH00<00000003oo`00ool03000ool00`00000001So
000Ho`0>000Ho`030000003?0?l0c`3o0180c`3o00<000000?l0003o0000
1@3o00030?ooo`030000003oool0oooo00H0oooo001j0?ooo`030000003o
ool0oooo00P0o`0000<000000<l0o`3?0?l04P3?0?l00`00000001So000H
o`0=000Ho`0300000000ool00?oo00`00?oo00<00000003o6000oaP03@00
oaP5000000H0col01@00000?003o600300000000ool00?oo00`00?oo00<0
0000000Ho`006?l03@006?l00`000000c`3o0<l0o`0B0<l0o`030000003o
0000o`0000D0o`000`3oool00`000000oooo0?ooo`060?ooo`00NP3oool0
0`000000oooo0?ooo`080?l000030000003?0?l0c`3o0140c`3o00<00000
000Ho`006?l03P006?l00`0000000?oo003oo`0;003oo`0300000000oaP0
0?lH00`00?lH0P00000@0<oo008000003P00oaP00`0000000?oo003oo`0;
003oo`03000000006?l001So00h001So00<000000<l0o`3?0?l04@3?0?l0
0`000000o`000?l000050?l000<0oooo00<000000?ooo`3oool01P3oool0
07X0oooo00<000000?ooo`3oool01`3o00000`000000c`3o0<l0o`0B0<l0
o`03000000006?l001So00d001So00<00000003oo`00ool02`00ool00`00
00000?lH003o600;003o60800000503?o`02000000d00?lH00<00000003o
o`00ool02`00ool00`00000001So000Ho`0=000Ho`030000003?0?l0c`3o
0180c`3o00<000000?l0003o0000103o00030?ooo`030000003oool0oooo
00H0oooo001j0?ooo`030000003oool0oooo00L0o`0000<000000<l0o`3?
0?l04@3?0?l00`00000001So000Ho`0>000Ho`0300000000ool00?oo00X0
0?oo00<00000003o6000oaP02P00oaP2000001P0col00P00000<003o6003
00000000ool00?oo00X00?oo00<00000000Ho`006?l03@006?l00`000000
c`3o0<l0o`0B0<l0o`030000003o0000o`0000@0o`000`3oool00`000000
oooo0?ooo`060?ooo`00NP3oool00`000000oooo0?ooo`070?l000030000
003?0?l0c`3o0140c`3o00<00000000Ho`006?l03@006?l00`0000000?oo
003oo`0:003oo`0300000000oaP00?lH00T00?lH0P00000L0<oo00800000
2`00oaP00`0000000?oo003oo`0:003oo`03000000006?l001So00d001So
00<000000<l0o`3?0?l04@3?0?l00`000000o`000?l000040?l000<0oooo
00<000000?ooo`3oool01P3oool007X0oooo00<000000?ooo`3oool01`3o
00000`000000c`3o0<l0o`0A0<l0o`03000000006?l001So00`001So00<0
0000003oo`00ool02P00ool00`0000000?lH003o6009003o60030000003?
o`00col000/0col01P00000=0<oo000300000000oaP00?lH00T00?lH00<0
0000003oo`00ool02@00ool00`00000001So000Ho`0=000Ho`030000003?
0?l0c`3o0140c`3o00<000000?l0003o0000103o00030?ooo`030000003o
ool0oooo00H0oooo001j0?ooo`030000003oool0oooo00H0o`0000<00000
0<l0o`3?0?l04@3?0?l00`00000001So000Ho`0=000Ho`0300000000ool0
0?oo00X00?oo00<00000003o6000oaP02000oaP00`000000col00<oo0008
0<oo00@000001P3o0004000000X0col000<00000003o6000oaP02000oaP0
0`0000000?oo003oo`0:003oo`03000000006?l001So00d001So00<00000
0<l0o`3?0?l04@3?0?l00`000000o`000?l000030?l000<0oooo00<00000
0?ooo`3oool01P3oool007X0oooo00<000000?ooo`3oool01P3o00000`00
0000c`3o0<l0o`0A0<l0o`03000000006?l001So00d001So00<00000003o
o`00ool02@00ool00`0000000?lH003o6008003o60030000003?o`00col0
00L0col00P00000>0?l0008000002@3?o`000`0000000?lH003o6008003o
600300000000ool00?oo00T00?oo00<00000000Ho`006?l03@006?l00`00
0000c`3o0<l0o`0A0<l0o`030000003o0000o`0000<0o`000`3oool00`00
0000oooo0?ooo`060?ooo`00NP3oool00`000000oooo0?ooo`060?l00003
0000003?0?l0c`3o0140c`3o00<00000000Ho`006?l030006?l00`000000
0?oo003oo`0:003oo`0300000000oaP00?lH00L00?lH00<000000<oo003?
o`001`3?o`000`000000o`000?l0000@0?l000030000003?o`00col000L0
col000<00000003o6000oaP01`00oaP00`0000000?oo003oo`0:003oo`03
000000006?l001So00`001So00<000000<l0o`3?0?l04@3?0?l00`000000
o`000?l000030?l000<0oooo00<000000?ooo`3oool01P3oool007X0oooo
00<000000?ooo`3oool01P3o00000`000000c`3o0<l0o`0A0<l0o`030000
00006?l001So00`001So00<00000003oo`00ool02@00ool00`0000000?lH
003o6007003o60030000003?o`00col000L0col000<000000?l0003o0000
4P3o00000`000000col00<oo00070<oo000300000000oaP00?lH00L00?lH
00<00000003oo`00ool02@00ool00`00000001So000Ho`0<000Ho`030000
003?0?l0c`3o0140c`3o00<000000?l0003o00000`3o00030?ooo`030000
003oool0oooo00H0oooo001j0?ooo`030000003oool0oooo00D0o`0000<0
00000<l0o`3?0?l04@3?0?l00`00000001So000Ho`0<000Ho`0300000000
ool00?oo00X00?oo00<00000003o6000oaP01P00oaP00`000000col00<oo
00060<oo008000005P3o0002000000P0col000<00000003o6000oaP01P00
oaP00`0000000?oo003oo`0:003oo`03000000006?l001So00`001So00<0
00000<l0o`3?0?l04@3?0?l00`000000o`000?l000020?l000<0oooo00<0
00000?ooo`3oool01P3oool007X0oooo00<000000?ooo`3oool01@3o0000
0`000000c`3o0<l0o`0A0<l0o`03000000006?l001So00`001So00<00000
003oo`00ool02@00ool00`0000000?lH003o6006003o60030000003?o`00
col000D0col00P00000J0?l0008000001`3?o`000`0000000?lH003o6006
003o600300000000ool00?oo00T00?oo00<00000000Ho`006?l030006?l0
0`000000c`3o0<l0o`0A0<l0o`030000003o0000o`000080o`000`3oool0
0`000000oooo0?ooo`060?ooo`00NP3oool00`000000oooo0?ooo`050?l0
00030000003?0?l0c`3o0140c`3o00<00000000Ho`006?l030006?l00`00
00000?oo003oo`09003oo`0300000000oaP00?lH00H00?lH00<000000<oo
003?o`00103?o`000`000000o`000?l0000L0?l000030000003?o`00col0
00@0col000<00000003o6000oaP01P00oaP00`0000000?oo003oo`09003o
o`03000000006?l001So00`001So00<000000<l0o`3?0?l04@3?0?l00`00
0000o`000?l000020?l000<0oooo00<000000?ooo`3oool01P3oool007X0
oooo00<000000?ooo`3oool01@3o00000`000000c`3o0<l0o`0A0<l0o`03
000000006?l001So00/001So00<00000003oo`00ool02@00ool00`000000
0?lH003o6006003o60030000003?o`00col000D0col000<000000?l0003o
0000703o00000`000000col00<oo00050<oo000300000000oaP00?lH00H0
0?lH00<00000003oo`00ool02@00ool00`00000001So000Ho`0;000Ho`03
0000003?0?l0c`3o0140c`3o00<000000?l0003o00000P3o00030?ooo`03
0000003oool0oooo00H0oooo001j0?ooo`030000003oool0oooo00D0o`00
00<000000<l0o`3?0?l04@3?0?l00`00000001So000Ho`0;000Ho`030000
0000ool00?oo00T00?oo00<00000003o6000oaP01P00oaP00`000000col0
0<oo00040<oo00030000003o0000o`0001h0o`0000<000000<oo003?o`00
103?o`000`0000000?lH003o6006003o600300000000ool00?oo00T00?oo
00<00000000Ho`006?l02`006?l00`000000c`3o0<l0o`0A0<l0o`030000
003o0000o`000080o`000`3oool00`000000oooo0?ooo`060?ooo`00NP3o
ool00`000000oooo0?ooo`040?l000030000003?0?l0c`3o0140c`3o00<0
0000000Ho`006?l030006?l00`0000000?oo003oo`09003oo`0300000000
oaP00?lH00D00?lH00<000000<oo003?o`001@3?o`000`000000o`000?l0
000N0?l000030000003?o`00col000D0col000<00000003o6000oaP01@00
oaP00`0000000?oo003oo`09003oo`03000000006?l001So00`001So00<0
00000<l0o`3?0?l04@3?0?l010000000o`000?l0003o00030?ooo`030000
003oool0oooo00H0oooo001j0?ooo`030000003oool0oooo00@0o`0000<0
00000<l0o`3?0?l04@3?0?l00`00000001So000Ho`0<000Ho`0300000000
ool00?oo00T00?oo00<00000003o6000oaP01@00oaP00`000000col00<oo
00040<oo00030000003o0000o`000200o`0000<000000<oo003?o`00103?
o`000`0000000?lH003o6005003o600300000000ool00?oo00T00?oo00<0
0000000Ho`006?l030006?l00`000000c`3o0<l0o`0A0<l0o`040000003o
0000o`000?l000<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<0
00000?ooo`3oool0103o00000`000000c`3o0<l0o`0A0<l0o`0300000000
6?l001So00/001So00<00000003oo`00ool02@00ool00`0000000?lH003o
6005003o60030000003?o`00col000D0col000<000000?l0003o0000803o
00000`000000col00<oo00050<oo000300000000oaP00?lH00D00?lH00<0
0000003oo`00ool02@00ool00`00000001So000Ho`0;000Ho`030000003?
0?l0c`3o0140c`3o00@000000?l0003o0000o`000`3oool00`000000oooo
0?ooo`060?ooo`00NP3oool00`000000oooo0?ooo`040?l000030000003?
0?l0c`3o0140c`3o00<00000000Ho`006?l02`006?l00`0000000?oo003o
o`09003oo`0300000000oaP00?lH00D00?lH00<000000<oo003?o`00103?
o`000`000000o`000?l0000R0?l000030000003?o`00col000@0col000<0
0000003o6000oaP01@00oaP00`0000000?oo003oo`09003oo`0300000000
6?l001So00/001So00<000000<l0o`3?0?l04@3?0?l010000000o`000?l0
003o00030?ooo`030000003oool0oooo00H0oooo001j0?ooo`030000003o
ool0oooo00@0o`0000<000000<l0o`3?0?l04@3?0?l00`00000001So000H
o`0;000Ho`0300000000ool00?oo00T00?oo00<00000003o6000oaP01@00
oaP00`000000col00<oo00040<oo00030000003o0000o`000280o`0000<0
00000<oo003?o`00103?o`000`0000000?lH003o6005003o600300000000
ool00?oo00T00?oo00<00000000Ho`006?l02`006?l00`000000c`3o0<l0
o`0A0<l0o`040000003o0000o`000?l000<0oooo00<000000?ooo`3oool0
1P3oool007X0oooo00<000000?ooo`3oool0103o00000`000000c`3o0<l0
o`0A0<l0o`03000000006?l001So00/001So00<00000003oo`00ool02@00
ool00`0000000?lH003o6005003o60030000003?o`00col000@0col000<0
00000?l0003o00008P3o00000`000000col00<oo00040<oo000300000000
oaP00?lH00D00?lH00<00000003oo`00ool02@00ool00`00000001So000H
o`0;000Ho`030000003?0?l0c`3o0140c`3o00@000000?l0003o0000o`00
0`3oool00`000000oooo0?ooo`060?ooo`00NP3oool00`000000oooo0?oo
o`040?l000030000003?0?l0c`3o0140c`3o00<00000000Ho`006?l02`00
6?l00`0000000?oo003oo`09003oo`0300000000oaP00?lH00D00?lH00<0
00000<oo003?o`00103?o`000`000000o`000?l0000R0?l000030000003?
o`00col000@0col000<00000003o6000oaP01@00oaP00`0000000?oo003o
o`09003oo`03000000006?l001So00/001So00<000000<l0o`3?0?l04@3?
0?l010000000o`000?l0003o00030?ooo`030000003oool0oooo00H0oooo
001j0?ooo`030000003oool0oooo00@0o`0000<000000<l0o`3?0?l0403?
0?l00`00000001So000Ho`0<000Ho`0300000000ool00?oo00P00?oo00<0
0000003o6000oaP01@00oaP00`000000col00<oo00040<oo00030000003o
0000o`0002@0o`0000<000000<oo003?o`00103?o`000`0000000?lH003o
6005003o600300000000ool00?oo00P00?oo00<00000000Ho`006?l03000
6?l00`000000c`3o0<l0o`0@0<l0o`040000003o0000o`000?l000<0oooo
00<000000?ooo`3oool01P3oool007@0oooo0P0000040?ooo`030000003o
ool0oooo00@0o`0000<000000<l0o`3?0?l0403?0?l00`00000001So000H
o`0<000Ho`0300000000ool00?oo00P00?oo00<00000003o6000oaP01@00
oaP00`000000col00<oo00040<oo00030000003o0000o`0002@0o`0000<0
00000<oo003?o`00103?o`000`0000000?lH003o6005003o600300000000
ool00?oo00P00?oo00<00000000Ho`006?l030006?l00`000000c`3o0<l0
o`0@0<l0o`040000003o0000o`000?l000<0oooo00<000000?ooo`3oool0
1P3oool007<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0?ooo`040?l000030000003?0?l0c`3o0100c`3o00<00000000Ho`006?l0
30006?l00`0000000?oo003oo`08003oo`0300000000oaP00?lH00D00?lH
00<000000<oo003?o`00103?o`000`000000o`000?l0000T0?l000030000
003?o`00col000@0col000<00000003o6000oaP01@00oaP00`0000000?oo
003oo`08003oo`03000000006?l001So00`001So00<000000<l0o`3?0?l0
403?0?l010000000o`000?l0003o00030?ooo`030000003oool0oooo00H0
oooo001c0?ooo`040000003oool0oooo000000<0oooo0P0000000`3oool0
o`000?l000020?l000030000003?0?l0c`3o0100c`3o00<00000000Ho`00
6?l030006?l00`0000000?oo003oo`08003oo`0300000000oaP00?lH00D0
0?lH00<000000<oo003?o`00103?o`000`000000o`000?l0000T0?l00003
0000003?o`00col000@0col000<00000003o6000oaP01@00oaP00`000000
0?oo003oo`08003oo`03000000006?l001So00`001So00<000000<l0o`3?
0?l0403?0?l010000000o`000?l0003o00020?ooo`800000203oool007<0
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?l0
00030000003?0?l0c`3o0100c`3o00<00000000Ho`006?l030006?l00`00
00000?oo003oo`08003oo`0300000000oaP00?lH00D00?lH00<000000<oo
003?o`00103?o`000`000000o`000?l0000T0?l000030000003?o`00col0
00@0col000<00000003o6000oaP01@00oaP00`0000000?oo003oo`08003o
o`03000000006?l001So00`001So00<000000<l0o`3?0?l0403?0?l01000
0000o`000?l0003o00030?ooo`030000003oool0oooo00H0oooo001c0?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103o0000
0`000000c`3o0<l0o`0@0<l0o`03000000006?l001So00`001So00<00000
003oo`00ool02000ool00`0000000?lH003o6005003o60030000003?o`00
col000@0col000<000000?l0003o0000903o00000`000000col00<oo0004
0<oo000300000000oaP00?lH00D00?lH00<00000003oo`00ool02000ool0
0`00000001So000Ho`0<000Ho`030000003?0?l0c`3o0100c`3o00@00000
0?l0003o0000o`000`3oool00`000000oooo0?ooo`060?ooo`00M03oool2
000000@0oooo00<000000?ooo`3oool0103o00000`000000c`3o0<l0o`0@
0<l0o`03000000006?l001So00`001So00<00000003oo`00ool02000ool0
0`0000000?lH003o6005003o60030000003?o`00col000@0col000<00000
0?l0003o0000903o00000`000000col00<oo00040<oo000300000000oaP0
0?lH00D00?lH00<00000003oo`00ool02000ool00`00000001So000Ho`0<
000Ho`030000003?0?l0c`3o0100c`3o00@000000?l0003o0000o`000`3o
ool00`000000oooo0?ooo`060?ooo`00NP3oool00`000000oooo0?ooo`04
0?l000030000003?0?l0c`3o0140c`3o00<00000000Ho`006?l02`006?l0
0`0000000?oo003oo`09003oo`0300000000oaP00?lH00D00?lH00<00000
0<oo003?o`00103?o`000`000000o`000?l0000R0?l000030000003?o`00
col000@0col000<00000003o6000oaP01@00oaP00`0000000?oo003oo`09
003oo`03000000006?l001So00/001So00<000000<l0o`3?0?l04@3?0?l0
10000000o`000?l0003o00030?ooo`030000003oool0oooo00H0oooo001j
0?ooo`030000003oool0oooo00@0o`0000<000000<l0o`3?0?l04@3?0?l0
0`00000001So000Ho`0;000Ho`0300000000ool00?oo00T00?oo00<00000
003o6000oaP01@00oaP00`000000col00<oo00040<oo00030000003o0000
o`000280o`0000<000000<oo003?o`00103?o`000`0000000?lH003o6005
003o600300000000ool00?oo00T00?oo00<00000000Ho`006?l02`006?l0
0`000000c`3o0<l0o`0A0<l0o`040000003o0000o`000?l000<0oooo00<0
00000?ooo`3oool01P3oool007X0oooo00<000000?ooo`3oool0103o0000
0`000000c`3o0<l0o`0A0<l0o`03000000006?l001So00/001So00<00000
003oo`00ool02@00ool00`0000000?lH003o6005003o60030000003?o`00
col000@0col000<000000?l0003o00008P3o00000`000000col00<oo0004
0<oo000300000000oaP00?lH00D00?lH00<00000003oo`00ool02@00ool0
0`00000001So000Ho`0;000Ho`030000003?0?l0c`3o0140c`3o00@00000
0?l0003o0000o`000`3oool00`000000oooo0?ooo`060?ooo`00NP3oool0
0`000000oooo0?ooo`040?l000030000003?0?l0c`3o0140c`3o00<00000
000Ho`006?l02`006?l00`0000000?oo003oo`09003oo`0300000000oaP0
0?lH00D00?lH00<000000<oo003?o`00103?o`000`000000o`000?l0000R
0?l000030000003?o`00col000@0col000<00000003o6000oaP01@00oaP0
0`0000000?oo003oo`09003oo`03000000006?l001So00/001So00<00000
0<l0o`3?0?l04@3?0?l010000000o`000?l0003o00030?ooo`030000003o
ool0oooo00H0oooo001j0?ooo`030000003oool0oooo00@0o`0000<00000
0<l0o`3?0?l04@3?0?l00`00000001So000Ho`0;000Ho`0300000000ool0
0?oo00T00?oo00<00000003o6000oaP01@00oaP00`000000col00<oo0005
0<oo00030000003o0000o`000200o`0000<000000<oo003?o`001@3?o`00
0`0000000?lH003o6005003o600300000000ool00?oo00T00?oo00<00000
000Ho`006?l02`006?l00`000000c`3o0<l0o`0A0<l0o`040000003o0000
o`000?l000<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<00000
0?ooo`3oool0103o00000`000000c`3o0<l0o`0A0<l0o`03000000006?l0
01So00`001So00<00000003oo`00ool02@00ool00`0000000?lH003o6005
003o60030000003?o`00col000@0col000<000000?l0003o0000803o0000
0`000000col00<oo00040<oo000300000000oaP00?lH00D00?lH00<00000
003oo`00ool02@00ool00`00000001So000Ho`0<000Ho`030000003?0?l0
c`3o0140c`3o00@000000?l0003o0000o`000`3oool00`000000oooo0?oo
o`060?ooo`00NP3oool00`000000oooo0?ooo`040?l000030000003?0?l0
c`3o0140c`3o00<00000000Ho`006?l030006?l00`0000000?oo003oo`09
003oo`0300000000oaP00?lH00D00?lH00<000000<oo003?o`001@3?o`00
0`000000o`000?l0000N0?l000030000003?o`00col000D0col000<00000
003o6000oaP01@00oaP00`0000000?oo003oo`09003oo`03000000006?l0
01So00`001So00<000000<l0o`3?0?l04@3?0?l010000000o`000?l0003o
00030?ooo`030000003oool0oooo00H0oooo001j0?ooo`030000003oool0
oooo00D0o`0000<000000<l0o`3?0?l04@3?0?l00`00000001So000Ho`0;
000Ho`0300000000ool00?oo00T00?oo00<00000003o6000oaP01P00oaP0
0`000000col00<oo00040<oo00030000003o0000o`0001h0o`0000<00000
0<oo003?o`00103?o`000`0000000?lH003o6006003o600300000000ool0
0?oo00T00?oo00<00000000Ho`006?l02`006?l00`000000c`3o0<l0o`0A
0<l0o`030000003o0000o`000080o`000`3oool00`000000oooo0?ooo`06
0?ooo`00NP3oool00`000000oooo0?ooo`050?l000030000003?0?l0c`3o
0140c`3o00<00000000Ho`006?l02`006?l00`0000000?oo003oo`09003o
o`0300000000oaP00?lH00H00?lH00<000000<oo003?o`001@3?o`000`00
0000o`000?l0000L0?l000030000003?o`00col000D0col000<00000003o
6000oaP01P00oaP00`0000000?oo003oo`09003oo`03000000006?l001So
00/001So00<000000<l0o`3?0?l04@3?0?l00`000000o`000?l000020?l0
00<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<000000?ooo`3o
ool01@3o00000`000000c`3o0<l0o`0A0<l0o`03000000006?l001So00`0
01So00<00000003oo`00ool02@00ool00`0000000?lH003o6006003o6003
0000003?o`00col000@0col000<000000?l0003o0000703o00000`000000
col00<oo00040<oo000300000000oaP00?lH00H00?lH00<00000003oo`00
ool02@00ool00`00000001So000Ho`0<000Ho`030000003?0?l0c`3o0140
c`3o00<000000?l0003o00000P3o00030?ooo`030000003oool0oooo00H0
oooo001j0?ooo`030000003oool0oooo00D0o`0000<000000<l0o`3?0?l0
4@3?0?l00`00000001So000Ho`0<000Ho`0300000000ool00?oo00T00?oo
00<00000003o6000oaP01P00oaP00`000000col00<oo00050<oo00800000
6P3o0002000000L0col000<00000003o6000oaP01P00oaP00`0000000?oo
003oo`09003oo`03000000006?l001So00`001So00<000000<l0o`3?0?l0
4@3?0?l00`000000o`000?l000020?l000<0oooo00<000000?ooo`3oool0
1P3oool007X0oooo00<000000?ooo`3oool01@3o00000`000000c`3o0<l0
o`0A0<l0o`03000000006?l001So00`001So00<00000003oo`00ool02P00
ool00`0000000?lH003o6006003o60030000003?o`00col000H0col00P00
000F0?l000800000203?o`000`0000000?lH003o6006003o600300000000
ool00?oo00X00?oo00<00000000Ho`006?l030006?l00`000000c`3o0<l0
o`0A0<l0o`030000003o0000o`000080o`000`3oool00`000000oooo0?oo
o`060?ooo`00NP3oool00`000000oooo0?ooo`060?l000030000003?0?l0
c`3o0140c`3o00<00000000Ho`006?l030006?l00`0000000?oo003oo`09
003oo`0300000000oaP00?lH00L00?lH00<000000<oo003?o`001`3?o`00
0`000000o`000?l0000B0?l000030000003?o`00col000L0col000<00000
003o6000oaP01`00oaP00`0000000?oo003oo`09003oo`03000000006?l0
01So00`001So00<000000<l0o`3?0?l04@3?0?l00`000000o`000?l00003
0?l000<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<000000?oo
o`3oool01P3o00000`000000c`3o0<l0o`0A0<l0o`03000000006?l001So
00`001So00<00000003oo`00ool02P00ool00`0000000?lH003o6007003o
60030000003?o`00col000L0col000<000000?l0003o0000403o00000`00
0000col00<oo00070<oo000300000000oaP00?lH00L00?lH00<00000003o
o`00ool02P00ool00`00000001So000Ho`0<000Ho`030000003?0?l0c`3o
0140c`3o00<000000?l0003o00000`3o00030?ooo`030000003oool0oooo
00H0oooo001j0?ooo`030000003oool0oooo00H0o`0000<000000<l0o`3?
0?l04@3?0?l00`00000001So000Ho`0=000Ho`0300000000ool00?oo00T0
0?oo00<00000003o6000oaP02000oaP00`000000col00<oo00070<oo0080
00003P3o0002000000T0col000<00000003o6000oaP02000oaP00`000000
0?oo003oo`09003oo`03000000006?l001So00d001So00<000000<l0o`3?
0?l04@3?0?l00`000000o`000?l000030?l000<0oooo00<000000?ooo`3o
ool01P3oool007X0oooo00<000000?ooo`3oool01P3o00000`000000c`3o
0<l0o`0A0<l0o`03000000006?l001So00d001So00<00000003oo`00ool0
2P00ool00`0000000?lH003o6008003o60030000003?o`00col000P0col0
100000070?l000<000002P3?o`000`0000000?lH003o6008003o60030000
0000ool00?oo00X00?oo00<00000000Ho`006?l03@006?l00`000000c`3o
0<l0o`0A0<l0o`030000003o0000o`0000<0o`000`3oool00`000000oooo
0?ooo`060?ooo`00NP3oool00`000000oooo0?ooo`070?l000030000003?
0?l0c`3o0140c`3o00<00000000Ho`006?l030006?l00`0000000?oo003o
o`0:003oo`0300000000oaP00?lH00T00?lH00<000000<oo003?o`002`3?
o`07000000`0col000<00000003o6000oaP02@00oaP00`0000000?oo003o
o`09003oo`03000000006?l001So00d001So00<000000<l0o`3?0?l04@3?
0?l00`000000o`000?l000040?l000<0oooo00<000000?ooo`3oool01P3o
ool007X0oooo00<000000?ooo`3oool01`3o00000`000000c`3o0<l0o`0A
0<l0o`03000000006?l001So00d001So00<00000003oo`00ool02P00ool0
0`0000000?lH003o6009003o60030000003?o`00col001`0col000<00000
003o6000oaP02@00oaP00`0000000?oo003oo`0:003oo`03000000006?l0
01So00d001So00<000000<l0o`3?0?l04@3?0?l00`000000o`000?l00004
0?l000<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<000000?oo
o`3oool01`3o00000`000000c`3o0<l0o`0A0<l0o`03000000006?l001So
00h001So00<00000003oo`00ool02P00ool00`0000000?lH003o6009003o
60<00000603?o`03000000/00?lH00<00000003oo`00ool02P00ool00`00
000001So000Ho`0=000Ho`030000003?0?l0c`3o0180c`3o00<000000?l0
003o0000103o00030?ooo`030000003oool0oooo00H0oooo001j0?ooo`03
0000003oool0oooo00L0o`0000<000000<l0o`3?0?l04P3?0?l00`000000
01So000Ho`0=000Ho`0300000000ool00?oo00/00?oo00<00000003o6000
oaP02`00oaP2000001@0col00P00000=003o600300000000ool00?oo00/0
0?oo00<00000000Ho`006?l03@006?l00`000000c`3o0<l0o`0B0<l0o`03
0000003o0000o`0000@0o`000`3oool00`000000oooo0?ooo`060?ooo`00
NP3oool00`000000oooo0?ooo`080?l000030000003?0?l0c`3o0140c`3o
00<00000000Ho`006?l03P006?l00`0000000?oo003oo`0;003oo`030000
0000oaP00?lH00`00?lH0P00000@0<oo008000003P00oaP00`0000000?oo
003oo`0;003oo`03000000006?l001So00h001So00<000000<l0o`3?0?l0
4@3?0?l00`000000o`000?l000050?l000<0oooo00<000000?ooo`3oool0
1P3oool007X0oooo00<000000?ooo`3oool0203o00000`000000c`3o0<l0
o`0B0<l0o`03000000006?l001So00d001So00<00000003oo`00ool03000
ool00`0000000?lH003o600=003o60D000001`3?o`04000000l00?lH00<0
0000003oo`00ool03000ool00`00000001So000Ho`0=000Ho`030000003?
0?l0c`3o0180c`3o00<000000?l0003o00001@3o00030?ooo`030000003o
ool0oooo00H0oooo001j0?ooo`030000003oool0oooo00P0o`0000<00000
0<l0o`3?0?l04P3?0?l00`00000001So000Ho`0>000Ho`0300000000ool0
0?oo00`00?oo00<00000003o6000oaP04@00oaP7000001800?lH00<00000
003oo`00ool03000ool00`00000001So000Ho`0>000Ho`030000003?0?l0
c`3o0180c`3o00<000000?l0003o00001@3o00030?ooo`030000003oool0
oooo00H0oooo001j0?ooo`030000003oool0oooo00T0o`0000<000000<l0
o`3?0?l04P3?0?l00`00000001So000Ho`0=000Ho`0300000000ool00?oo
00d00?oo00<00000003o6000oaP0:000oaP00`0000000?oo003oo`0=003o
o`03000000006?l001So00d001So00<000000<l0o`3?0?l04P3?0?l00`00
0000o`000?l000060?l000<0oooo00<000000?ooo`3oool01P3oool007X0
oooo00<000000?ooo`3oool02@3o00000`000000c`3o0<l0o`0B0<l0o`03
000000006?l001So00h001So00<00000003oo`00ool03@00ool00`000000
0?lH003o600V003o600300000000ool00?oo00d00?oo00<00000000Ho`00
6?l03P006?l00`000000c`3o0<l0o`0B0<l0o`030000003o0000o`0000H0
o`000`3oool00`000000oooo0?ooo`060?ooo`00NP3oool00`000000oooo
0?ooo`090?l000030000003?0?l0c`3o01<0c`3o00<00000000Ho`006?l0
3P006?l00`0000000?oo003oo`0=003oo`8000009000oaP2000000l00?oo
00<00000000Ho`006?l03P006?l00`000000c`3o0<l0o`0C0<l0o`030000
003o0000o`0000H0o`000`3oool00`000000oooo0?ooo`060?ooo`00NP3o
ool00`000000oooo0?ooo`0:0?l000030000003?0?l0c`3o0180c`3o00<0
0000000Ho`006?l03`006?l00`0000000?oo003oo`0>003oo`8000008000
oaP2000001000?oo00<00000000Ho`006?l03`006?l00`000000c`3o0<l0
o`0B0<l0o`030000003o0000o`0000L0o`000`3oool00`000000oooo0?oo
o`060?ooo`00NP3oool00`000000oooo0?ooo`0:0?l000030000003?0?l0
c`3o01<0c`3o00<00000000Ho`006?l03`006?l00`0000000?oo003oo`0?
003oo`8000007000oaP2000001400?oo00<00000000Ho`006?l03`006?l0
0`000000c`3o0<l0o`0C0<l0o`030000003o0000o`0000L0o`000`3oool0
0`000000oooo0?ooo`060?ooo`00NP3oool00`000000oooo0?ooo`0;0?l0
00030000003?0?l0c`3o0180c`3o00<00000000Ho`006?l040006?l00`00
00000?oo003oo`0@003oo`8000006000oaP2000001800?oo00<00000000H
o`006?l040006?l00`000000c`3o0<l0o`0B0<l0o`030000003o0000o`00
00P0o`000`3oool00`000000oooo0?ooo`060?ooo`00NP3oool00`000000
oooo0?ooo`0;0?l000030000003?0?l0c`3o01<0c`3o00<00000000Ho`00
6?l040006?l00`0000000?oo003oo`0A003oo`@000004000oaP4000001<0
0?oo00<00000000Ho`006?l040006?l00`000000c`3o0<l0o`0C0<l0o`03
0000003o0000o`0000P0o`000`3oool00`000000oooo0?ooo`060?ooo`00
NP3oool00`000000oooo0?ooo`0<0?l000030000003?0?l0c`3o0180c`3o
00<00000000Ho`006?l04@006?l00`0000000?oo003oo`0D003oo`D00000
1`00oaP4000001H00?oo00<00000000Ho`006?l04@006?l00`000000c`3o
0<l0o`0B0<l0o`030000003o0000o`0000T0o`000`3oool00`000000oooo
0?ooo`060?ooo`00NP3oool00`000000oooo0?ooo`0<0?l000030000003?
0?l0c`3o01<0c`3o00<00000000Ho`006?l04@006?l00`0000000?oo003o
o`0H003oo`L000006@00ool00`00000001So000Ho`0A000Ho`030000003?
0?l0c`3o01<0c`3o00<000000?l0003o00002@3o00030?ooo`030000003o
ool0oooo00H0oooo001j0?ooo`030000003oool0oooo00`0o`0000<00000
0<l0o`3?0?l0503?0?l00`00000001So000Ho`0A000Ho`800000=P00ool2
000001<001So00<000000<l0o`3?0?l04`3?0?l00`000000o`000?l0000:
0?l000<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<000000?oo
o`3oool03@3o00000`000000c`3o0<l0o`0D0<l0o`03000000006?l001So
018001So0P00000b003oo`80000050006?l00`000000c`3o0<l0o`0D0<l0
o`030000003o0000o`0000X0o`000`3oool00`000000oooo0?ooo`060?oo
o`00L`3oool4000000<0oooo00<000000?ooo`3oool03@3o00000`000000
c`3o0<l0o`0E0<l0o`03000000006?l001So01<001So00<00000003oo`00
ool0;P00ool00`00000001So000Ho`0C000Ho`030000003?0?l0c`3o01@0
c`3o00<000000?l0003o00002`3o00030?ooo`030000003oool0oooo00H0
oooo001c0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
3P3o00000`000000c`3o0<l0o`0D0<l0o`03000000006?l001So01@001So
00<00000003oo`00ool0;000ool00`00000001So000Ho`0C000Ho`030000
003?0?l0c`3o01D0c`3o00<000000?l0003o00002`3o00030?ooo`030000
003oool0oooo00H0oooo001d0?ooo`030000003oool0oooo00<0oooo0P00
00000`3oool0o`000?l0000=0?l000030000003?0?l0c`3o01@0c`3o00<0
0000000Ho`006?l050006?l2000002X00?oo0P00000F000Ho`030000003?
0?l0c`3o01@0c`3o00<000000?l0003o0000303o00020?ooo`800000203o
ool007D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0?
0?l000030000003?0?l0c`3o01D0c`3o00<00000000Ho`006?l05@006?l0
0`0000000?oo003oo`0V003oo`03000000006?l001So01D001So00<00000
0<l0o`3?0?l05@3?0?l00`000000o`000?l0000<0?l000<0oooo00<00000
0?ooo`3oool01P3oool007<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`0@0?l000030000003?0?l0c`3o01D0c`3o00<00000
000Ho`006?l05@006?l3000002800?oo0`00000G000Ho`030000003?0?l0
c`3o01D0c`3o00<000000?l0003o00003@3o00030?ooo`030000003oool0
oooo00H0oooo001d0?ooo`800000103oool00`000000oooo0?ooo`0A0?l0
00030000003?0?l0c`3o01D0c`3o00<00000000Ho`006?l05`006?l20000
01h00?oo0P00000I000Ho`030000003?0?l0c`3o01D0c`3o00<000000?l0
003o00003P3o00030?ooo`030000003oool0oooo00H0oooo001j0?ooo`03
0000003oool0oooo0140o`0000<000000<l0o`3?0?l05P3?0?l00`000000
01So000Ho`0H000Ho`D000005000ool5000001X001So00<000000<l0o`3?
0?l05P3?0?l00`000000o`000?l0000>0?l000<0oooo00<000000?ooo`3o
ool01P3oool007X0oooo00<000000?ooo`3oool04P3o00000`000000c`3o
0<l0o`0F0<l0o`03000000006?l001So01`001So1`000007003oo`H00000
7P006?l00`000000c`3o0<l0o`0F0<l0o`030000003o0000o`0000l0o`00
0`3oool00`000000oooo0?ooo`060?ooo`00NP3oool00`000000oooo0?oo
o`0C0?l000030000003?0?l0c`3o01H0c`3o00<00000000Ho`006?l08P00
6?l7000002<001So00<000000<l0o`3?0?l05P3?0?l00`000000o`000?l0
000@0?l000<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<00000
0?ooo`3oool0503o00000`000000c`3o0<l0o`0F0<l0o`800000BP006?l2
000001P0c`3o00<000000?l0003o00004@3o00030?ooo`030000003oool0
oooo00H0oooo001j0?ooo`030000003oool0oooo01@0o`0000<000000<l0
o`3?0?l0603?0?l00`00000001So000Ho`16000Ho`030000003?0?l0c`3o
01P0c`3o00<000000?l0003o00004@3o00030?ooo`030000003oool0oooo
00H0oooo001j0?ooo`030000003oool0oooo01D0o`0000<000000<l0o`3?
0?l0603?0?l2000004@001So0P00000J0<l0o`030000003o0000o`000180
o`000`3oool00`000000oooo0?ooo`060?ooo`00NP3oool00`000000oooo
0?ooo`0F0?l000030000003?0?l0c`3o01T0c`3o0P000010000Ho`800000
6`3?0?l00`000000o`000?l0000C0?l000<0oooo00<000000?ooo`3oool0
1P3oool007X0oooo00<000000?ooo`3oool05`3o00000`000000c`3o0<l0
o`0J0<l0o`03000000006?l001So03`001So00<000000<l0o`3?0?l06P3?
0?l00`000000o`000?l0000D0?l000<0oooo00<000000?ooo`3oool01P3o
ool007X0oooo00<000000?ooo`3oool0603o00000`000000c`3o0<l0o`0J
0<l0o`03000000006?l001So03X001So00<000000<l0o`3?0?l06P3?0?l0
0`000000o`000?l0000E0?l000<0oooo00<000000?ooo`3oool01P3oool0
07X0oooo00<000000?ooo`3oool0603o00000`000000c`3o0<l0o`0K0<l0
o`800000>0006?l2000001d0c`3o00<000000?l0003o00005@3o00030?oo
o`030000003oool0oooo00H0oooo001j0?ooo`030000003oool0oooo01T0
o`0000<000000<l0o`3?0?l0703?0?l00`00000001So000Ho`0d000Ho`03
0000003?0?l0c`3o01`0c`3o00<000000?l0003o00005P3o00030?ooo`03
0000003oool0oooo00H0oooo001j0?ooo`030000003oool0oooo01X0o`00
00<000000<l0o`3?0?l0703?0?l20000038001So0P00000N0<l0o`030000
003o0000o`0001L0o`000`3oool00`000000oooo0?ooo`060?ooo`00NP3o
ool00`000000oooo0?ooo`0K0?l000030000003?0?l0c`3o01d0c`3o0`00
000/000Ho`<000007`3?0?l00`000000o`000?l0000H0?l000<0oooo00<0
00000?ooo`3oool01P3oool007X0oooo00<000000?ooo`3oool0703o0000
0`000000c`3o0<l0o`0O0<l0o`<000009P006?l300000240c`3o00<00000
0?l0003o00006@3o00030?ooo`030000003oool0oooo00H0oooo001j0?oo
o`030000003oool0oooo01d0o`0000<000000<l0o`3?0?l08@3?0?l40000
01h001So1000000S0<l0o`030000003o0000o`0001X0o`000`3oool00`00
0000oooo0?ooo`060?ooo`00NP3oool00`000000oooo0?ooo`0N0?l00003
0000003?0?l0c`3o02@0c`3o1@00000D000Ho`D000009P3?0?l00`000000
o`000?l0000K0?l000<0oooo00<000000?ooo`3oool01P3oool007X0oooo
00<000000?ooo`3oool07`3o0002000002T0c`3o5000000Z0<l0o`030000
003o0000o`0001`0o`000`3oool00`000000oooo0?ooo`060?ooo`00NP3o
ool00`000000oooo0?ooo`0Q0?l000030000003?0?l0c`3o06<0c`3o00<0
00000?l0003o00007@3o00030?ooo`030000003oool0oooo00H0oooo001j
0?ooo`030000003oool0oooo0280o`0000<000000<l0o`3?0?l0H@3?0?l0
0`000000o`000?l0000N0?l000<0oooo00<000000?ooo`3oool01P3oool0
07X0oooo00<000000?ooo`3oool08`3o00000`000000c`3o0<l0o`1N0<l0
o`8000008@3o00030?ooo`030000003oool0oooo00H0oooo001j0?ooo`03
0000003oool0oooo02@0o`000P00001L0<l0o`8000008`3o00030?ooo`03
0000003oool0oooo00H0oooo001j0?ooo`030000003oool0oooo02H0o`00
00<000000<l0o`3?0?l0F03?0?l00`000000o`000?l0000S0?l000<0oooo
00<000000?ooo`3oool01P3oool007X0oooo00<000000?ooo`3oool09`3o
00000`000000c`3o0<l0o`1F0<l0o`030000003o0000o`0002@0o`000`3o
ool00`000000oooo0?ooo`060?ooo`00NP3oool00`000000oooo0?ooo`0X
0?l000800000E03?0?l2000002L0o`000`3oool00`000000oooo0?ooo`06
0?ooo`00NP3oool00`000000oooo0?ooo`0Z0?l000030000003?0?l0c`3o
0500c`3o00<000000?l0003o00009`3o00030?ooo`030000003oool0oooo
00H0oooo001j0?ooo`030000003oool0oooo02/0o`000P00001>0<l0o`80
0000:P3o00030?ooo`030000003oool0oooo00H0oooo001j0?ooo`030000
003oool0oooo02d0o`0000<000000<l0o`3?0?l0BP3?0?l00`000000o`00
0?l0000Z0?l000<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<0
00000?ooo`3oool0;P3o0002000004P0c`3o0P00000]0?l000<0oooo00<0
00000?ooo`3oool01P3oool007X0oooo00<000000?ooo`3oool0<03o0003
00000480c`3o0`00000_0?l000<0oooo00<000000?ooo`3oool01P3oool0
07X0oooo00<000000?ooo`3oool0<`3o0002000003h0c`3o0P00000b0?l0
00<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<000000?ooo`3o
ool0=@3o0002000003X0c`3o0P00000d0?l000<0oooo00<000000?ooo`3o
ool01P3oool007X0oooo00<000000?ooo`3oool0=`3o0003000003@0c`3o
0`00000f0?l000<0oooo00<000000?ooo`3oool01P3oool007X0oooo00<0
00000?ooo`3oool0>P3o0003000002h0c`3o0`00000i0?l000<0oooo00<0
00000?ooo`3oool01P3oool007X0oooo00<000000?ooo`3oool0?@3o0006
00000280c`3o1P00000l0?l000<0oooo00<000000?ooo`3oool01P3oool0
07D0oooo0`0000020?ooo`030000003oool0oooo04<0o`001`00000D0<l0
o`L00000@P3o00030?ooo`030000003oool0oooo00H0oooo001f0?ooo`05
0000003oool0oooo0?ooo`0000000P3ooom:0?l000L000001`3?0?l60000
04T0o`000`3oool00`000000oooo0?ooo`060?ooo`00L`3oool500000080
oooo0P0000000`3oool0o`000?l0001?0?l000L00000C`3o00020?ooo`80
0000203oool007<0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`2W0?l000<0oooo00<000000?ooo`3oool01P3oool007@0oooo
00<000000?ooo`0000000`3oool00`000000oooo0?ooo`2W0?l000<0oooo
00<000000?ooo`3oool01P3oool007D0oooo0P0000030?ooo`030000003o
ool0oooo0:L0o`000`3oool00`000000oooo0?ooo`060?ooo`00NP3oool0
0`000000oooo0?ooo`2W0?l000<0oooo00<000000?ooo`3oool01P3oool0
07X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`060?oo
o`00NP3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`060?ooo`00NP3ooon^000000P0oooo
003o0?oooc40oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{304, 194},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  This problem is a companion to the one in Example 11.2.  Here \
we use the fact that  ",
  Cell[BoxData[
      \(ln | z | \)]],
  "  is a harmonic function, for all  ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ".  The solution is \n\n\t\t\t",
  Cell[BoxData[
      \(\[CapitalPhi] \((x, y)\)\  = \ 
        K\_1\  + \ \(\(K\_2 - K\_1\)\/\(ln\ R\)\) ln | z | \)]],
  ",   \n\nand the level curves  ",
  Cell[BoxData[
      \(\[CapitalPhi] \((x, y)\) = constant\)]],
  "  are concentric circles, as illustrated in Figure 11.3. "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.3",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/applicationpreliminary/\
ApplicationPreliminaryFigures/mat1103.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Level curves of the harmonic function\t",
  Cell[BoxData[
      \(\[CapitalPhi] \((x, y)\)\  = \ 
        K\_1\  + \ \(\(K\_2 - K\_1\)\/\(ln\ R\)\) ln | z | \)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "A specific example of the general case.  Find the function ",
  Cell[BoxData[
      \(\[CapitalPhi] \((x, y)\)\)]],
  " that is harmonic in the annulus  ",
  Cell[BoxData[
      \(\(\(1\)\(<\)\) | z | \(\(<\)\(\ \)\(4\)\)\)]],
  "  and takes on the boundary values \n\n\t\t\t",
  Cell[BoxData[
      \(\[CapitalPhi] \((x, y)\)\  = \ 1\)]],
  "   when  ",
  Cell[BoxData[
      \(\(\(\ \)\(\(\(|\)\(z\)\(|\)\)\  = 1\)\)\)]],
  ",  and  \n\t\t\t",
  Cell[BoxData[
      \(\[CapitalPhi] \((x, y)\)\  = \ 6\)]],
  "   when  ",
  Cell[BoxData[
      \(\(\(\ \)\(\(\(|\)\(z\)\(|\)\)\  = 4\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Applications involving similar formulas will be found in Example 11.19.\
\>", "Text"],

Cell[BoxData[{
    \(\(R\ \ \  = \ 4;\)\ \ \), "\n", 
    \(\(k\_1\  = \ 1;\)\ \ \), "\n", 
    \(\(k\_2\  = \ 6;\)\ \), "\n", 
    \(\(u[x_, \ y_]\  = \ 
        k\_1\  + \ \((k\_2\  - \ k\_1)\) 
            Log[\@\(x\^2\  + \ y\^2\)]\/Log[R];\)\ \), "\[IndentingNewLine]", \

    \(\(cont = {1, 2, 3, 4, 5, 6};\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[u[x, y], {x, \(-4.2\), 4.2}, {y, \(-4.2\), 4.2}, 
        Contours\  \[Rule] cont, PlotPoints \[Rule] 25, 
        AspectRatio \[Rule] 1, ColorFunction \[Rule] Hue];\)\ \), "\n", 
    \(\(Print["\<Contour plot for u[x,y] = \>", 
        u[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[u[x, y], "\< = c\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<where c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Dirichlet Problem",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/DirichletProblemBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Electrostatics",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ElectrostaticsBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Steady State Temperature",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/TemperaturesBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1000, 614},
WindowMargins->{{1, Automatic}, {Automatic, 3}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 137314, 2542}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 136, 2, 33, "Text"],
Cell[2241, 66, 109, 2, 33, "Text"],
Cell[2353, 70, 758, 13, 128, "Text"],
Cell[3114, 85, 568, 12, 52, "Text",
  Evaluatable->False],
Cell[3685, 99, 1120, 38, 128, "Text",
  Evaluatable->False],
Cell[4808, 139, 32272, 532, 208, 32158, 528, "GraphicsData", "Bitmap", "Text",
  
  Evaluatable->False],
Cell[37083, 673, 1466, 49, 207, "Text"],
Cell[38552, 724, 487, 15, 36, "Text"],

Cell[CellGroupData[{
Cell[39064, 743, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[39228, 749, 1059, 35, 128, "Text",
  Evaluatable->False],
Cell[40290, 786, 111, 3, 33, "Text"],
Cell[40404, 791, 900, 18, 284, "Input"]
}, Closed]],
Cell[41319, 812, 645, 22, 87, "Text",
  Evaluatable->False],
Cell[41967, 836, 44696, 736, 208, 44582, 732, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[86666, 1574, 799, 22, 188, "Text"],
Cell[87468, 1598, 494, 15, 36, "Text"],

Cell[CellGroupData[{
Cell[87987, 1617, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[88151, 1623, 603, 19, 96, "Text",
  Evaluatable->False],
Cell[88757, 1644, 1040, 20, 323, "Input"]
}, Closed]],
Cell[89812, 1667, 733, 25, 87, "Text",
  Evaluatable->False],
Cell[90548, 1694, 41235, 679, 208, 41121, 675, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[131786, 2375, 574, 16, 113, "Text"],
Cell[132363, 2393, 502, 15, 37, "Text"],

Cell[CellGroupData[{
Cell[132890, 2412, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[133054, 2418, 678, 22, 90, "Text",
  Evaluatable->False],
Cell[133735, 2442, 95, 2, 33, "Text"],
Cell[133833, 2446, 932, 19, 277, "Input"]
}, Closed]],
Cell[134780, 2468, 290, 7, 30, "Text"],
Cell[135073, 2477, 291, 7, 33, "Text"],
Cell[135367, 2486, 286, 7, 33, "Text"],
Cell[135656, 2495, 294, 7, 33, "Text"],
Cell[135953, 2504, 257, 5, 33, "Text"],
Cell[136213, 2511, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

