(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    366848,       6724]*)
(*NotebookOutlinePosition[    367948,       6763]*)
(*  CellTagsIndexPosition[    367871,       6757]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["11.3  Poisson's Integral Formula for the Upper \
Half-Plane",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tThe Dirichlet problem for the upper half-plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  is to find a function ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  " that is harmonic in the upper half plane and has the boundary values ",
  Cell[BoxData[
      \(\[Phi] \((x, 0)\) = U \((x)\)\)]],
  ",  where  ",
  Cell[BoxData[
      \(U \((x)\)\)]],
  ",  is a real-valued function of the real variable ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ".  An important method for solving this problem is our next result which \
is attributed to the French mathematician ",
  ButtonBox["Sim\[EAcute]on Poisson",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Poisson.\
html"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 11.3 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Poisson's Integral Formula",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/PoissonIntegral.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["U",
    FontFamily->"Courier New"],
  " be a real-valued function that is piecewise continuous and bounded for \
all real ",
  StyleBox["t",
    FontFamily->"Courier New"],
  ".  The function  \n\n",
  StyleBox["(11-12)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{\(\[Phi] \((x, y)\)\), " ", "=", " ", 
        RowBox[{\(y\/\[Pi]\), " ", 
          RowBox[{
            SubsuperscriptBox["\[Integral]", 
              InterpretationBox[\(-\[Infinity]\),
                DirectedInfinity[ -1]], 
              InterpretationBox["\[Infinity]",
                DirectedInfinity[ 
                1]]], \(\(\(U \((t)\)\)\/\(\((x\  - \ t)\)\^2\  + \ 
                    y\^2\)\) \[DifferentialD]t\)}]}]}]]],
  "  \n\nis  harmonic in the upper half plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  " and has the boundary values  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Phi] \((x, 0)\)\  = \ U \((x)\)\)]],
  "  \n\nwherever ",
  Cell[BoxData[
      \(U \((x)\)\)]],
  " is continuous. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 11.3 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the function ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  " that is harmonic in the upper half-plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  ", which takes on the boundary values  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(\[Phi] \((x, 0)\) = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "    ", "-", "1"}], " ", 
            "\[LessEqual]", " ", "x", " ", "\[LessEqual]", " ", "1"}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}], "\[IndentingNewLine]", 
      RowBox[{\(\[Phi] \((x, 0)\) = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          StyleBox["for",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "    ", "|", "x", "|", 
          RowBox[{">", 
            RowBox[{"1", 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000d2000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD
0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3o
oonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00j@3oool200000:P0oooo003W0?oo
o`<0000000<0oooo000000000000YP3oool00>H0oooo00<000000?ooo`00
00000`0000000`3oool000000000002T0?ooo`00i03oool2000000040?oo
o`000000ocD000000080ocD00P0000000`3oool000000000002R0?ooo`00
h`3oool010000000oooo0?ooo`0000020?le00050000003o=@00ocD00000
003o=`000P0000000`3oool000000000002P0?ooo`00hP3oool010000000
oooo0000000000030?le00<00000103o=`000`000000oooo0?ooo`020000
09h0oooo003P0?ooo`80000000<0oooo0000003o=@00103o=@000`000000
ocL00?lg00030?lg00040000003o>`00000000000080oooo0P00000G0?oo
o`D00000603oool2000000030?ooo`000000000006<0oooo003O0?ooo`04
0000003oool0oooo000000D0ocD00P0000040?lg00030000003o>`00oc/0
0080oc/00`0000000`3oool000000000000G0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`000000I03oool00=d0oooo0P0000020?ooo`03
0000003o=@00ocD00080ocD00P0000000`3o=`0000000?lg00020?lg0003
0000003o>`00oc/000<0oc/000<000000?lo003o?`001P00000D0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0H`3oool00=`0oooo
00H000000?ooo`3oool0oooo0000003oE@02000000030?le00000000ocL0
0080ocL000@000000?lg0000000000001@3o>`000`000000ocl00?lo0002
0?lo00050000003oA@0000000000003oool00P00000:0?ooo`@00000103o
ool00`000000oooo0?ooo`0H0?ooo`80000000<0oooo000000000000H`3o
ool00=X0oooo0P0000030?ooo`030000003oE@00oeD00080oeD000<00000
0?lg003o=`000P3o=`02000000H0oc/000<000000?lo003o?`000P3o?`00
0`000000odD00?m500020?m500030000003oool0oooo00800000403oool0
0`000000oooo0?ooo`200?ooo`00f@3oool00`000000oooo0?ooo`020?oo
o`030000003oE@00oeD00080oeD000@000000?mM0000000000000P3o=`00
0`000000oc/00?lk00030?lk00800000103o?`000`000000odD00?m50002
0?m500040000003oCP00000000000080oooo0P00000=0?ooo`800000PP3o
ool00=P0oooo00@000000?ooo`3oool0oooo0P0000040?mE00030000003o
G@00oed00080oed00`0000040?lk00030000003o?`00ocl000<0ocl000<0
00000?m5003oA@000P3oA@000`000000odh00?m>00020?m>00<0000000<0
oooo000000000000S`3oool00=H0oooo0P0000030?ooo`030000003oE@00
oeD000<0oeD000<000000?mM003oG@000`3oG@0010000000ofL000000000
00020?lk00030000003o?`00ocl000<0ocl000<000000?m5003oA@000P3o
A@000`000000odh00?m>00030?m>00030000003oG000oe`000D00000S@3o
ool00=D0oooo00<000000?ooo`3oool00P3oool00`000000oeD00?mE0002
0?mE008000001@3oG@001@000000ofL00?mW00000000ofL0008000001@3o
?`000`000000odD00?m500020?m500030000003oCP00odh000<0odh000<0
00000?mL003oG0000P3oG0000`000000ogD000000003000008/0oooo003C
0?ooo`800000103oool00`000000oeD00?mE00020?mE00030000003oG@00
oed000@0oed000P000000?mW003oI`00ofL00000003oI`0000000?mc0080
00000P3o?`000`000000odD00?m500030?m500030000003oCP00odh00080
odh000<000000?mL003oG0000P3oG0000`000000ogD00?me00020?me0004
0000003oool00000000008T0oooo003B0?ooo`030000003oool0oooo00<0
oooo00H000000?md0000000000000?mE000000050?mM00800000103oI`02
000000@0og<00P0000050?m500030000003oCP00odh00080odh000<00000
0?mL003oG0000`3oG0001P000000ogD00?me003oM@0000000?n[00800000
00@0oooo0000000000000000QP3oool00=00oooo0P0000050?ooo`030000
003oM000og@00080og@000<000000?mM003oG@000`3oG@000`000000ofL0
0?mW00040?mW00030000003oL`00og<000<0og<000<000000?n500000000
0`3oA@000`000000odh00?m>00030?m>00030000003oG000oe`00080oe`0
00<000000?me003oM@000P3oM@0010000000oj/00?n[003oZ`0200000080
oooo0P0000240?ooo`00c`3oool00`000000oooo0?ooo`040?ooo`030000
003oM000og@00080og@000@000000?n10000000000000P3oG@000`000000
ofL00?mW00030?mW00<00000103oL`001`000000ohD00?n5003oQ@000000
0?m5000000001@3oCP000`000000oe`00?mL00020?mL00030000003oM@00
ogD00080ogD000<000000?n[003oZ`000`3oZ`001@000000oooo0?ooo`00
0000oooo00800000PP3oool00<d0oooo0P0000050?ooo`800000103oM000
0`000000oh400?n100020?n1008000001@3oI`0010000000og<00?mc0000
00030?mc00030000003oQ@00ohD000<0ohD000<000000?m>003oCP000`3o
CP000`000000oe`00?mL00020?mL00030000003oM@00ogD000<0ogD000<0
00000?n[003oZ`000P3oZ`0200000080oooo00@000000?ooo`3oool0oooo
0P0000200?ooo`00c03oool00`000000oooo0?ooo`040?ooo`030000003o
M000og@000<0og@000<000000?n1003oP@000`3oP@0010000000oi000000
000000020?mW00050000003oL`00og<00?mc000000000P3oL`000`000000
ohD00?n500030?n500040000003oW@00000000000080odh000<000000?mL
003oG0000P3oG0000`000000ogD00?me00030?me00030000003oZ`00oj/0
00<0oj/00P0000080?ooo`800000OP3oool00:l0oooo0P0000040?ooo`80
0000103oool2000000h0oooo00<000000?ooo`3oool0103oool00`000000
og@00?md00030?md00030000003oP@00oh4000<0oh4000<000000?n@003o
T0000P3oT002000000@0og<000<000000?mc000000001@3oQ@000`000000
oid00?nM00020?nM00800000103oG0000`000000ogD00?me00040?me0003
0000003oZ`00oj/00080oj/000<0000001go000000002P3oool2000007`0
oooo002^0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000002`3oool2000000H0oooo00<000000?md003oM0000`3oM0000`00
0000oh400?n100030?n100030000003oT000oi0000<0oi0000<000000?nS
000000000`3oL`02000000D0ohD000<000000?nM003oW@000`3oW@000`00
0000ol<0000000030?mL00030000003oM@00ogD000<0ogD000<000000?n[
003oZ`000`3oZ`00100000007Ol001go0000000;0?ooo`8000005@3oool2
000006<0oooo002^0?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`040000003oT@00
000000000080og@000<000000?n1003oP@000P3oP@02000000D0oi0000@0
00000?nS003oX`00oj<00P0000000`3oL`0000000?n500040?n500030000
003oW@00oid000<0oid000L000000?o3003o``00ol<00000003oG0000000
00D0ogD000<000000?n[003oZ`000`3oZ`001@0000007Ol001go000Mo`00
000000d0oooo0`00000A0?ooo`040000003oool0oooo00000680oooo002^
0?ooo`040000003oool0oooo000000T0oooo0P0000090?ooo`8000001P3o
ool2000000@0oi400P0000040?n100030000003oT000oi0000@0oi0000<0
00000?nS003oX`00103oX`02000000@0ohD000<000000?nM003oW@000`3o
W@000`000000ol<00?o300030?o300030000003oM@00ogD000@0ogD000<0
00000?n[003oZ`000`3oZ`001@0000007Ol001go000Mo`0000000100oooo
0P00000?0?ooo`040000003oool0oooo00000680oooo002^0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`050?ooo`030000003oT@00oi4000@0oi4000H000000?nQ0000
000000000?n1000000050?n@008000001P3oX`000`000000okd000000003
0?n500030000003oW@00oid000<0oid000<000000?o3003o``000`3o``00
0`000000ool0000000040?me00030000003oZ`00oj/000@0oj/000D00000
01go000Mo`007Ol00000000B0?ooo`8000003@3oool010000000oooo0?oo
o`00001R0?ooo`00V03oool2000001D0oooo0P00000:0?ooo`<000001@3o
ool2000000L0oooo00<000000?nA003oT@000`3oT@02000000@0oj4000<0
00000?n@003oT0000`3oT0000`000000oj<00?nS00050?nS00030000003o
_@00okd00080000000<0ohD00000003oW@001@3oW@000`000000ol<00?o3
00020?o300050000003oo`00ool00?oo000000000`3oM@000`000000oj/0
0?n[00030?n[00030000000Mo`007Ol000807Ol000<000000?ooo`3oool0
4P3oool2000000/0oooo00@000000?ooo`3oool00000HP3oool009T0oooo
00<000000?ooo`3oool09P3oool3000000D0oooo0P0000050?nA00030000
003oX@00oj4000<0oj4000@000000?nd0000000000000P3oT0000`000000
oj<00?nS00050?nS00070000003o_@00okd00?nm00000000okd000000006
0?nM00030000003o``00ol<000<0ol<000D000000?oo003oo`00ool00000
00020?me00030000003oZ`00oj/000@0oj/000<0000001go000Mo`000P0M
o`000`000000oooo0?ooo`0D0?ooo`8000002P3oool2000006<0oooo002J
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01@3oool0
0`000000oi400?nA00040?nA00030000003oX@00oj4000<0oj4000<00000
0?nd003o]0000P3o]002000000H0oj<00P0000040?nm0080000000<0on40
0000003oW@000`3oW@000`000000ol<00?o300030?o300030000003oo`00
ool000<0ool000<000000?me000000001@3oZ`000`0000007Ol001go0003
01go00030000003oool0oooo01H0oooo0P00001]0?ooo`00V@3oool00`00
0000oooo0000000S0?ooo`8000001`3oool010000000oj`0000000000002
0?nA00800000103oX@02000000D0ok@000<000000?o=00000000103oX`00
0`000000okd00?nm00040?nm00040000003oh@00on400?oQ0080000000<0
oid00000003o``00103o``000`000000ool00?oo00050?oo00030000003o
Z`00oj/000@0oj/000<0000001go000Mo`000`0Mo`000`000000oooo0?oo
o`0H0?ooo`800000J`3oool009P0oooo00@000000?ooo`3oool000008P3o
ool00`000000oooo0?ooo`060?ooo`030000003o[000oj`00080oj`00P00
00050?nQ00030000003o]000ok@000@0ok@000@000000?o=003oc@00old0
0P0000000`3oX`0000000?nm00050?nm008000001@3oh@000`000000ol<0
0?o300030?o300030000003oo`00ool000D0ool000<0000008ko00000000
1@3oZ`000`0000007Ol001go000401go00030000003oool0oooo01T0oooo
0P00001Y0?ooo`00U`3oool3000000030?ooo`000000000001l0oooo0P00
00070?ooo`8000001@3o[00010000000okh00000000000020?nQ00030000
003o]000ok@000@0ok@000<000000?o=003oc@00103oc@000`000000okd0
0?nm00030?nm0080000000<0on400000003oh@000`3oh@000`000000k?l0
000000030?o300030000003oo`00ool000D0ool000@0000008ko002>o`00
0000103oZ`000`0000007Ol001go000501go00030000003oool0oooo01/0
oooo0`00001V0?ooo`00^`3oool00`000000oooo0?ooo`060?ooo`030000
003o[000oj`000@0oj`000<000000?nn003o_P000P3o_P02000000D0ok@0
0P0000060?o=00030000003ok@00000000<0okd000D000000?oQ003oh@00
on40000000030?oQ00040000003/o`00k?l0000000<0ol<000<000000?oo
003oo`001@3oo`001@000000S_l008ko002>o`00000000<0oj/000<00000
01go000Mo`001@0Mo`000`000000oooo0?ooo`0N0?ooo`800000I03oool0
0;T0oooo0P0000080?ooo`030000003o[000oj`000<0oj`00P0000050?nn
00030000003oe000000000<0ok@000<000000?o=003oc@001@3oc@001`00
0000ond00?o]003ok@0000000?nm00000000103oh@0010000000on400?oQ
000000040>co00030000003o``00000000L0ool000<0000008ko002>o`00
0P2>o`0010000000oj/00?n[0000000801go00030000003oool0oooo0200
oooo0P00001R0?ooo`00^03oool00`000000oooo0?ooo`070?ooo`030000
003o[000oj`000<0oj`000<000000?nn003o_P00103o_P001`000000om@0
0?oD003oe00000000?nd000000001`3oc@000`000000ond00?o]00030?o]
00030000003oh@00on400080on4000@000000?oQ0000000000001P3/o`00
0`000000ool00?oo00050?oo00030000002>o`00S_l000@0S_l000<00000
0?n[00000000200Mo`000`000000oooo0?ooo`0P0?ooo`040000003oool0
000000000600oooo002f0?ooo`8000002@3oool010000000ol<000000000
00020?n/00030000003o_P00okh000@0okh000<000000?oD003oe0000`3o
e0000`000000old00?o=00040?o=008000001@3ok@000`000000jOl00000
00030?oQ008000001`3/o`000`000000XOl0000000050?oo00030000002>
o`00S_l000D0S_l00P00000901go00030000003oool0oooo0240oooo00<0
00000?ooo`3oool00P00001N0?ooo`00]@3oool00`000000oooo0?ooo`08
0?ooo`030000003o``00ol<00080ol<00P0000050?nn008000001@3oe000
0`000000oo00000000040?o=00030000003ok@00ond000@0ond000@00000
0>Wo003Yo`00jOl00P0000000`3oh@0000000>co00060>co00050000002Q
o`00XOl00:7o000000000`3oo`000`000000S_l008ko000708ko00030000
000Mo`007Ol000L07Ol000<000000?ooo`3oool09P3oool2000005`0oooo
002d0?ooo`030000003oool0oooo00L0oooo0P0000050?o300030000003o
e`00000000<0okh000<000000?oD003oe000103oe00010000000oo000?o`
003ol002000000030?o=00000000ond000D0ond000<000000>Wo003Yo`00
103Yo`02000000H0k?l000<000000:7o002Qo`000P2Qo`001@000000ool0
0?oo003oo`00000000P0S_l00P00000901go00030000003oool0oooo02P0
oooo0P00000D0?ooo`D00000@@3oool00;80oooo0P0000090?ooo`030000
003o``00ol<000<0ol<00P0000030?oG00030000003o_P00000000D0om@0
0P0000060?o`00030000003ok@00ond000@0ond000<000000>Wo003Yo`00
103Yo`000`000000/_l0000000050>co00030000002Qo`00XOl000@0XOl0
00<000000?oo000000002@2>o`02000000X07Ol000<000000?ooo`3oool0
:@3oool2000001@0oooo00<000000?ooo`3oool0@@3oool00;40oooo00<0
00000?ooo`3oool0203oool00`000000ol<00?o300030?o300030000003o
e`00omL000@0omL000<000000?oD003oe0000`3oe0000`000000oo000?o`
00050?o`00030000003]o`00000000@0ond000<000000>Wo003Yo`00103Y
o`000`000000/_l00;;o0002000000@0k?l000<000000:7o002Qo`001@2Q
o`000`000000S_l008ko000708ko000400000000od`00?m<000000T07Ol0
00<000000?ooo`3oool0:`3oool300000140oooo00<000000?ooo`3oool0
@@3oool00:l0oooo0P00000:0?ooo`030000003o``00ol<000<0ol<000<0
00000?oG003oe`000`3oe`02000000030?o_0000000000000080om@000<0
00000?o`003ol000103ol002000000<0kOl00P0000000`3ok@0000000>Wo
00050>Wo00040000002bo`00/_l00;;o008000000`3/o`000`000000XOl0
0:7o00050:7o00800000202>o`001@0000000?m<003oC000od`0000000T0
7Ol000<000000?ooo`3oool0;P3oool2000000l0oooo00<000000?ooo`3o
ool0@@3oool00:h0oooo00<000000?ooo`3oool0203oool2000000040?oG
0000000000000?o3008000001@3oe`000`000000onl00?o_00030?o_0080
00001P3ol0000`000000kOl00>go00050>go00030000003Yo`00jOl000<0
jOl00P0000040;;o00050000002bo`0000000>co000000001`2Qo`001000
0000<Ol0037o0000000608ko000300000000od`00?m<00800?m<00<00000
01go000Mo`001`0Mo`000`000000oooo0?ooo`0`0?ooo`8000003@3oool0
0`000000oooo0?ooo`110?ooo`00[03oool2000000X0oooo00<000000?oG
003oe`000`3oe`000`000000omL00?oG00040?oG00030000003ok`00onl0
00@0onl000<000000??o00000000103ol0000`000000kOl00>go00050>go
000300000032o`00000000<0jOl000<000000;;o002bo`00102bo`001000
0000/_l00;;o000000070:7o00050000000ao`00<Ol0037o000000001P2>
o`000`0000000?m<003oC002003oC0030000000Mo`007Ol000L07Ol000<0
00000?ooo`3oool0<P3oool2000000X0oooo0P0000130?ooo`00Z`3oool0
0`000000oooo0?ooo`080?ooo`8000001@3oe`0010000000on`000000000
00020?oG008000001P3ok`001P000000lol00??o003co`0000000?o`0080
00001P3]o`02000000<0`_l000<000000>Wo000000001`2bo`001@000000
/_l00000001Xo`00000000D0XOl000<00000037o000ao`000`0ao`000`00
0000S_l008ko000208ko000300000000od`00?m<00<00?m<00<0000001go
000Mo`001`0Mo`000`000000oooo0?ooo`0d0?ooo`800000C@3oool00:T0
oooo0P0000090?ooo`8000001P3oe`000`000000on`00?o/00020?o/0080
00001P3ok`02000000D0lol000<000000>go003]o`001@3]o`000`000000
`_l00<;o00040<;o00030000002bo`00/_l000H0/_l00P00000206So0003
0000002Qo`00XOl00080XOl000<00000037o000ao`00100ao`001@000000
S_l008ko002>o`00000000H00?m<00<0000001go000Mo`001`0Mo`000`00
0000oooo0?ooo`0f0?ooo`800000B`3oool009P0oooo1@00000;0?ooo`03
0000003oool0oooo00P0oooo00<000000?oG003oe`00103oe`02000000D0
on`000<000000?[o00000000103ok`000`000000lol00??o00040??o0003
0000003@o`00000000D0kOl000<000000<;o0032o`001032o`000`000000
Rol0000000070;;o00030000001Xo`00J?l00080J?l000@000000:7o002Q
o`000000200ao`000`000000S_l000000008003oC0030000000Mo`007Ol0
00H07Ol000<000000?ooo`3oool0>03oool2000004T0oooo002J0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool00`000000
onL0000000040?oG00030000003ok000on`000@0on`000@000000?[o003j
o`00n_l00P0000000`3ok`0000000??o00050??o00040000003@o`00d?l0
0=3o0080000000<0kOl00000000000001P32o`001@000000Rol008_o002;
o`00000000@0/_l00`00000406So00030000002Qo`00000000T0<Ol000<0
000008ko000000002000od`00`0000007Ol001go000701go00030000003o
ool0oooo03T0oooo0P0000170?ooo`00VP3oool00`000000oooo0?ooo`08
0?ooo`8000002P3oool010000000onL00?oW003oi`02000000030?oG0000
0000on`000@0on`00P0000060?[o00030000003co`00lol000<0lol00P00
00060=3o000300000032o`00`_l000D0`_l000<0000008_o002;o`000P2;
o`001@000000/_l00;;o002bo`0000000080J?l000<0000006So001Xo`00
0`1Xo`000`000000<Ol0037o0009037o000300000000od`00?m<00L00?m<
00<0000001go000Mo`001`0Mo`000`000000oooo0?ooo`0k0?ooo`<00000
A03oool009X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?ooo`8000001P3oi`000`000000on`00?o/00030?o/00030000003j
o`00n_l000D0n_l000<000000=go000000000`3co`000`000000d?l00=3o
00050=3o00030000002Vo`00000000D0`_l000<0000008_o002;o`00102;
o`000`000000/_l00000000306So00030000001Xo`00J?l00080J?l000<0
000000Oo000000002@0ao`02000000T00?m<00<0000001go000Mo`001`0M
o`000`000000oooo0?ooo`0n0?ooo`800000@P3oool009X0oooo00<00000
0?ooo`3oool01@3oool2000000X0oooo00<000000?oW003oi`00103oi`02
000000030?om0000000000000080on`000<000000?[o003jo`00103jo`02
000000<0gOl000<000000??o000000001`3@o`001@000000Y_l00:Ko002V
o`00000000<0`_l000<0000008_o002;o`001P2;o`000`000000J?l006So
000206So00030000001Xo`00J?l0008000000P07o`000`000000<Ol0037o
0005037o008000000P00of`00`0000000?m<003oC006003oC0030000000M
o`007Ol000H07Ol00P0000100?ooo`040000003oool0000000000400oooo
002I0?ooo`8000001P3oool00`000000oooo0?ooo`090?ooo`030000003o
i`00onL000@0onL000<000000?om003oo@000`3oo@02000000H0n_l000<0
00000=go003Mo`00103Mo`000`000000d?l00=3o00040=3o008000001@2V
o`000`000000`_l00000000708_o0080000000<0Aol00000001Xo`000P1X
o`000`000000J?l00000000500Oo00030000000ao`00<Ol000<0<Ol000<0
0000003oK000of`00P00of`00`0000000?m<003oC006003oC0030000000M
o`007Ol000@07Ol00P0000000`060?l000000?ooo`0o0?ooo`040000003o
ool0oooo0?ooo`800000?P3oool009l0oooo0`00000:0?ooo`030000003o
i`00onL000@0onL000<000000?om003oo@000`3oo@02000000030>Wo0000
0000n_l000<0n_l000<000000=go003Mo`000`3Mo`02000000030;_o0000
0000d?l000<0d?l000<000000:Ko002Vo`001P2Vo`000`000000Rol008_o
000508_o000500000017o`00Aol004Oo000000000`1Xo`02000000L01ol0
00D00000037o000ao`00<Ol000000005003oK00300000000od`00?m<00L0
0?m<00@0000001go000Mo`007Ol00P00000300H0o`030000003oool0oooo
0440oooo0P0000000`3oool000000000000l0?ooo`00WP3oool00`000000
oooo0?ooo`0:0?ooo`040000003om@00000000000080onL00P0000050?om
00030000003Yo`00jOl00080jOl000@000000?[o0000000000001@3Mo`00
0`000000^ol00;_o00020;_o0080000000<0d?l00000002Vo`001P2Vo`02
0000000307;o00000000Rol000<0Rol00P00000504Oo00040000001Xo`00
0000000000P01ol000@00000037o0000000000001P00of`00`0000000?m<
003oC007003oC0040000000Mo`000000000000D01P3o00<000000?ooo`3o
ool0@@3oool01@000000oj/0000000000000oooo00800000>P3oool009d0
oooo00<000000?ooo`3oool02P3oool00`000000ooD00?oe00020?oe0080
00001P3oo@000`000000jOl00>Wo00040>Wo00030000003Mo`00gOl000@0
gOl000<000000;_o002ko`001@2ko`000`000000Y_l00:Ko00050:Ko0003
0000001bo`00L_l00080L_l000@0000008_o0000000000002017o`000`00
00001ol00000000900Oo000300000000of`00?m/00L00?m/00<00000003o
C000od`01P00od`2000000L01P3o00<000000?ooo`3oool0@03oool20000
00030?n[00000000ogD00080000000<0oooo000000000000>03oool009/0
oooo0P00000;0?ooo`800000103om@02000000030?Co0000000000000080
ood00P0000050>Wo0080000000<0cOl00000000000000P3Mo`02000000H0
^ol00P0000000`2Bo`0000000:Ko00030:Ko008000001P1bo`000`000000
Aol004Oo000704Oo000400000000o`X00000000000P01ol00P000009003o
K00300000000od`00?m<00@00?m<0`00000900H0o`030000003oool0oooo
03l0oooo0P0000000`3oZ`0000000?me00020?me0080000000@0oooo0000
000000000000=@3oool009X0oooo00<000000?ooo`3oool02P3oool00`00
0000ooD00?oe00030?oe00030000003do`00m?l000<0m?l00P0000060>Wo
00030000003=o`00cOl000<0cOl00P0000070;_o00030000002Bo`00T_l0
0080T_l000@000000:Ko0000000000001`1bo`000`000000=_l000000007
04Oo000300000000o`X00?l:008000001P07o`02000000800?m_00<00000
003oK000of`01P00of`00`0000000?m<003oC002003oC08000000P00T_l0
0`0000001P3o00H0o`0700H0o`030000003oool0oooo03h0oooo00@00000
01go0000000000000`3oM@000`000000oe`00?mL0003000000030?ooo`00
0000000003<0oooo002H0?ooo`800000303oool00`000000ooD00?oe0003
0?oe00030000003do`00m?l000<0m?l00P0000000`3Lo`0000000>Wo0003
0>Wo00030000003=o`00cOl000<0cOl00P0000000`2[o`0000000;_o0003
0;_o008000001P2Bo`000`000000L_l007;o000607;o00050000000fo`00
=_l003Ko000000001017o`02000000@00?l:00<0000000Oo0007o`000`07
o`000`0000000?m_003oK`02003oK`0300000000of`00?m/00L00?m/00@0
0000003oC000000000001@00T_l00`0000001P3o00H0o`0600H0o`030000
003oool0oooo03h0oooo00@0000001go0000000000000P3oM@000`000000
oe`00?mL00020?mL00050000003oCP0000000000003oool00P00000a0?oo
o`00U`3oool00`000000oooo0?ooo`0:0?ooo`80000000@0o_l000000000
0000ooD00P0000050?Co00030000003Lo`00g?l00080g?l000@000000>Wo
0000000000001@3=o`000`000000Zol00:_o00020:_o00040000002ko`00
0000000000H0T_l00P0000000`1So`00000007;o000407;o00800000100f
o`001@000000Aol004Oo0017o`00000000H00?l:0P00000300Oo00030000
0000ofl00?m_00<00?m_00<00000003oK000of`01`00of`2000000L009;o
00<0000000H0o`060?l01P060?l00`000000oooo0?ooo`0n0?ooo`030000
000Mo`0000000080ogD000<000000?mL003oG0000P3oG0001@000000odh0
0?m>00000000odD00080000000<0oooo0000000000003P3oool2000001l0
oooo002E0?ooo`800000303oool00`000000o_l00?ko00030?ko00030000
003do`00m?l000@0m?l000<000000=co003Lo`00103Lo`000`000000cOl0
0<go00040<go00030000002[o`00Zol000@0Zol000<0000009;o002Bo`00
1@2Bo`000`000000Hol006?o000206?o00050000001bo`00L_l007;o0000
00001`0fo`000`000000Aol000000007003o2P80000000<01ol000000000
00001`00ofl00`0000000?m/003oK004003oK0<000002000T_l00`000000
1P3o00H0o`0600H0o`030000003oool0oooo03d0oooo00H0000001go000M
o`0000000?me000000040?mL00040000003oCP00odh0000000@0odD00P00
00000`3oool000000000000;0?ooo`040000003oool0oooo000001h0oooo
002D0?ooo`030000003oool0oooo00/0oooo00<000000?ko003no`000`3n
o`0010000000jOl00000000000020?Co008000001@3Lo`02000000030<3o
0000000000000080cOl00P0000050:_o0080000000<0QOl00000002Bo`00
102Bo`000`000000Hol006?o000406?o00030000001bo`00000000T0=_l0
00<00000003o2P00o`X01P00o`X00`0000000?l:00000009003oK`030000
0000of`00?m/00800?m/0P000003003Oo`0300000000T_l009;o00D009;o
00<0000000H0o`060?l01P060?l00`000000oooo0?ooo`0m0?ooo`060000
000Mo`007Ol00000003oM@0000000P3oG00200000080odh000<000000?m5
003oA@000P3oA@000`000000ocl00?lo0002000000030?ooo`0000000000
00T0oooo00@000000?ooo`3oool000007P3oool00980oooo0P00000<0?oo
o`8000001@3no`000`000000jOl00>Wo00020>Wo008000001P3Lo`000`00
0000`?l00<3o00030<3o008000001P2[o`000`000000QOl008Go000208Go
0080000000<0T_l0000000000000201So`000`000000=_l003Ko000603Ko
0080000000<00?l?00000000o`X01P00o`X3000000X00?m_00@00000003o
K000000000001@00gol00`00000009;o002Bo`06002Bo`03000000060?l0
1P3o00D01P3o00<000000?ooo`3oool0?03oool0100000007Ol001go000M
o`0200000080oe`000D000000?m>003oCP00odh0000000040?m500060000
003o?`00ocl00?lo00000000oc/00P0000000`3oool00000000000070?oo
o`040000003oool0oooo000001h0oooo002A0?ooo`030000003oool0oooo
00/0oooo00<000000?ko003no`000`3no`02000000@0jOl00P0000000`3B
o`0000000=co00030=co000300000030o`00`?l000<0`?l00P0000000`2Q
o`0000000:_o00030:_o000300000025o`00QOl000D0QOl000<0000006?o
001So`001P1So`020000000302go00000000=_l000D0=_l000D00000003o
3`00o`l00?l?00000006003o2P8000000P00ofL00`0000000?m_003oK`07
003oK`8000001`00gol00`00000009;o002Bo`06002Bo`03000000060?l0
1P3o00D01P3o00<000000?ooo`3oool0?03oool01@0000007Ol001go000M
o`0000000080oe`000D000000?m>003oCP00odh0000000040?m500050000
003o?`00ocl00?lo00000000103o>`02000000030?ooo`000000000000D0
oooo00@000000?ooo`3oool000007P3oool00900oooo00<000000?ooo`3o
ool02P3oool2000000030?Go0000000000000080o_l000<000000>Wo003Y
o`000`3Yo`000`000000d_l00=;o00020=;o00040000003Lo`0000000000
00D0`?l000<000000:7o002Qo`000P2Qo`0010000000Zol0000000000006
08Go0080000000<0Fol00000001So`001@1So`001@000000;Ol002go000]
o`00000000@0=_l00P000005003o3`0400000000o`X00?l:003o2P800000
00D00?mW00000000ofL00?mW00000007003oK`<000002@00gol00`000000
09;o002Bo`05002Bo`03000000060?l01P3o00H01P3o00<000000?ooo`3o
ool0>`3oool01`0000007Ol001go000Mo`0000000?mL000000000`3oCP00
10000000odD00?m5003oA@02000000<0ocl000<000000?lk003o>`000P3o
>`000`000000ocL00?lg0005000000@0oooo0P00000O0?ooo`00SP3oool2
000000`0oooo00<000000?Go003eo`000`3eo`02000000D0jOl000<00000
0=;o003Bo`00103Bo`000`000000`?l00<3o00040<3o00030000002Qo`00
XOl000@0XOl000<0000008Go0025o`001@25o`000`000000Fol005_o0002
05_o00030000001So`00Hol00080Hol000<0000002go000]o`000`0]o`00
10000000=_l0000000000007003o3`0400000000o`X00000000000<00?mW
00D00000003oI`00ofL00?mW00000004003oK`8000000`00onl00`000000
0=oo003Oo`06003Oo`0300000000T_l009;o00D009;o00<0000000H0o`06
0?l01P060?l00`000000oooo0?ooo`0j0?ooo`030000000Mo`007Ol00080
7Ol00`0000020?m>00050000003oA@00odD00?m5000000000`3o?`020000
00<0oc/00P0000030?lg00030000003o=@00ocD0008000009@3oool008d0
oooo00<000000?ooo`3oool02`3oool00`000000mOl00?Go00030?Go0080
000000@0hOl0000000000000jOl00P0000060=;o00040000002go`000000
00000080`?l00P0000050:7o0080000000<0O_l000000025o`001025o`00
0`000000Fol005_o000405_o00040000001So`000000000000L0;Ol000<0
0000003o3`00o`l02000o`l00`0000000?mW003oI`03003oI`0500000000
ofL00?mW003oI`0000000P00ofl2000000D00?o_00<00000003Oo`00gol0
1`00gol00`00000009;o002Bo`04002Bo`03000000060?l01P3o00H01P3o
00<000000?ooo`3oool0>P3oool00`0000007Ol001go000201go00030000
003oW@00oid000<000000P3oA@001@000000ocl00?lo003o?`00000000@0
oc/000@000000?lg003o=`00ocL00P0000030?le008000009@3oool008/0
oooo0P00000<0?ooo`8000001@3eo`000`000000hOl00>7o00030>7o0003
0000003Bo`00d_l000D0d_l000<000000;Oo002go`000P2go`02000000H0
XOl000<0000007ko001no`000P1no`020000000308Go00000000000000P0
Fol000<0000002go000]o`001@0]o`0200000003003o3@0000000?l?00H0
0?l?0P0000000`00oe/00000003oI`03003oI`0300000000ofL00?mW0080
0?mW0P000008003ok`0300000000gol00=oo00H00=oo00<00000002Bo`00
T_l01@00T_l00`0000001P3o00H0o`0500H0o`030000003oool0oooo03X0
oooo00D0000001go000Mo`007Ol0000000030?nM00030000003oQ@00ohD0
00<000000P3o?`000`000000oc/00?lk00020?lk00050000003o=`00ocL0
0?lg000000000`3o=@02000000030?ooo`000000oooo02@0oooo002:0?oo
o`030000003oool0oooo00/0oooo00<000000?Go003eo`00103eo`000`00
0000hOl00>7o00030>7o00030000003:o`00000000@0d_l00P0000040;Oo
0080000000<0V_l00000002Qo`000`2Qo`000`000000O_l007ko000507ko
00030000001Ko`00Fol000H0Fol00P0000000`0[o`00000002go000302go
008000001000o`d00`0000000?l?003o3`02003o3`8000001000oe/01@00
00000?mW003oI`00ofL0000000800?mW0P0000000`00olT00000003ok`07
003ok`0300000000gol00=oo00H00=oo00<00000002Bo`00T_l01@00T_l0
0`0000001P3o00H0o`0500H0o`030000003oool0oooo03T0oooo00<00000
01go000Mo`000P0Mo`0010000000oid00?nM000000030?n500030000003o
L`00og<000<000000P3o>`02000000<0ocL000D000000?le003o=@00ocD0
000000030?ooo`030000003oool0oooo02<0oooo001]0?ooo`D000000P3o
ool2000000@0oooo0P00000<0?ooo`800000303oool2000000030>ko0000
000000000080mOl00P0000050>7o00040000003:o`00b_l00<[o00800000
00<0d_l00000002go`00102go`000`000000V_l009[o000209[o00040000
002Qo`000000000000H0O_l00P0000000`1Go`00000005_o000405_o0080
0000100[o`0010000000;Ol0000000000007003o3@0400000000o`l00000
000000H00?mK00@00000003oI`00ofL00?mW0`000003003ob@0300000000
onl00?o_00L00?o_00<00000003Oo`00gol01P00gol00`00000009;o002B
o`04002Bo`03000000060?l01P3o00D01P3o00<000000?ooo`3oool0>@3o
ool00`0000007Ol001go000201go00030000003oW@0000000080ohD00P00
00030?mc00030000003oI`00ofL000<000000P3o=`02000000<0ocD000<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0S0?ooo`00K`3oool0
0`000000oooo0?ooo`070?ooo`040000003oool0oooo000000X0oooo00<0
00000?ooo`3oool02`3oool00`000000k_l00>ko00030>ko008000001@3Q
o`02000000H0b_l000<000000;Oo002go`000`2go`000`000000V_l009[o
000409[o00030000001no`00O_l000D0O_l000<0000005Oo001Go`000P1G
o`000`000000Fol005_o0002000000L0:ol000<00000003o3@00o`d02000
o`d00`0000000?mK003oF`07003oF`0300000000ofL00000008000001@00
olT00`0000000?o_003ok`06003ok`0300000000gol00=oo00<00=oo1@00
0005002Bo`03000000060?l01P3o00D01P3o00<000000?ooo`3oool0>03o
ool00`0000007Ol001go000301go008000000P3oQ@0010000000og<00?mc
003oL`0200000080ofL00P0000020?mM00<000000P3o=@02000000D0oooo
00<000000?ooo`3oool08`3oool006l0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo0P00
00050>ko0080000000<0f_l00000000000000P3Qo`000`000000b_l00<[o
00040<[o0080000000@0/Ol0000000000000]ol00P00000609[o00030000
001jo`00000000D0O_l000<0000005Oo001Go`00101Go`02000000L0:ol0
0P0000000`00o`L00000003o3@06003o3@80000000<00?m=00000000oe/0
1`00oe/3000000800?o90P000004003ob@0300000000onl00?o_00D00?o_
1P0000030013o`04000000170?l00000000000@009;o00<0000000H0o`06
0?l010060?l00`000000oooo0?ooo`0g0?ooo`8000001@0Mo`0010000000
ohD00?n5000000030?mc00050000003oI`00ofL00?mW000000000`3oG@02
00000080oeD00P0000080?ooo`030000003oool0oooo0280oooo001_0?oo
o`030000003oool0oooo00P0oooo0P0000080?ooo`800000303oool00`00
0000k_l00>ko00040>ko00030000003Jo`00f_l000<0f_l00P0000050<[o
008000001@2ao`000`000000V_l009[o000509[o00040000001jo`00N_l0
07[o0080000000<0O_l00000000000001@1Go`020000000302go00000000
:ol000D0:ol000D00000003o1`00o`L00?l700000005003o3@8000000`00
odd00`0000000?mK003oF`04003oF`<0000000<00?nZ00000000olT00`00
olT300000003003ob@0000000?o_00800?o_100000000`00V_l000000013
o`070013o`03000000170?l0A`3o00<0000000<009;o000000060?l01@06
0?l00`000000oooo0?ooo`0f0?ooo`<000001@0Mo`03000000<0og<000<0
00000?mW003oI`000P0000030?mM00040000003oE@00oeD00?mE00800000
2@3oool00`000000oooo0?ooo`0R0?ooo`00K`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3o
ool010000000jOl00000000000020>ko008000001@3Jo`02000000040<Go
0000000000000<[o008000001@2ao`020000000309Ko00000000V_l000<0
V_l00P00000607[o00030000001Go`00Eol000@0Eol000<0000002go000]
o`000P0]o`000`000000:ol002_o000202_o000300000000o`L00?l700<0
0?l700<00000003o3@00o`d00P000006003oC@0300000000oe/00?mK00@0
00000`00ojX00`0000000?o9003ob@05003ob@D000001P00V_l00`000000
04?o0013o`050013o`03000000170?l0A`3o00<0A`3o0P00000700H0o`03
0000003oool0oooo03@0oooo0P0000000`00od`0000001go000401go0080
00000P3oL`02000000030?mW00000000000000<0oed00P0000030?mE0003
0000003oool0oooo00T0oooo00<000000?ooo`3oool08P3oool006h0oooo
0P00000:0?ooo`<00000103oool2000000d0oooo00<000000>Wo003Yo`00
0P3Yo`02000000D0f_l00P0000050<Go00030000002ao`00/Ol000@0/Ol0
00<0000009Ko002Fo`000P2Fo`020000000309[o00000000N_l000D0N_l0
0P0000000`1Go`00000005Oo000305Oo00030000000]o`00;Ol000@0;Ol0
00@0000002_o0000000000001`00o`L2000000T00?m=0P0000000`00ojX0
000000000005003oZP0300000000olT00?o900<00?o90P0000001000fOl0
0000000000000006002Jo`0300000000@ol004?o00H004?o00<0000004L0
o`170?l00`170?l2000000H01P3o00<000000?ooo`3oool0=03oool01000
00000?m<003oC000000501go00030000003oX`00000000D000000P3oG@02
000000<0oeD00P00000<0?ooo`030000003oool0oooo0280oooo00200?oo
o`<000002`3oool2000000@0jOl00P000000103Fo`0000000000003Jo`02
000000H0aOl000@000000:ko0000000000000P2ao`02000000L0U_l000<0
000007[o001jo`000`1jo`02000000@0Eol000@0000005Oo000000000000
200]o`000`0000000?l7003o1`05003o1`80000000<00?lm00000000odd0
1P00odd200000003003oS@000000000000L00?nZ00<00000003ob@00olT0
0`000004003Io`0400000000V_l00000000000D009[o00<000000013o`00
@ol01@00@ol00`000000A`3o04L0o`0404L0o`03000000060?l01P3o00@0
1P3o00<000000?ooo`3oool0<`3oool0100000000?m<003oC000000601go
00<000000P3oT0000`000000oh400?n1000300000080oeD00P00000>0?oo
o`030000003oool0oooo0280oooo00200?ooo`030000003oool000000080
0000203oool00`000000jOl00>Wo00030>Wo00030000003Fo`00e_l000<0
e_l000<000000<Go0035o`001@35o`000`000000[_l00:ko00020:ko0080
00001`2Fo`020000000407Wo00000000000007[o008000001`1Go`000`00
0000;Ol002go000602go0080000000<00?l000000000o`L00`00o`L20000
00@00?lm00<00000003oC@00odd00P00odd2000000800?n=00<00000003o
S@0000001`00ojX3000000P00=Wo00<00000002Jo`00V_l00`000002002J
o`0300000000@ol004?o00H004?o00<0000004L0o`170?l00`170?l20000
00D01P3o00<000000?ooo`3oool0<P3oool2000000800?m<00<0000001go
000Mo`00100Mo`000`000000oi000?n@0002000000<0oh4000<000000?md
003oM0000P00000@0?ooo`030000003oool0oooo0280oooo00200?ooo`03
0000003oool0oooo0080oooo0`0000040?ooo`030000003Yo`00jOl000<0
jOl000<000000=Ko003Fo`000`3Fo`000`000000`_l0000000040<Go0080
0000102^o`020000000309Co00000000U_l000<0U_l00P00000507Wo0003
0000001Go`00Eol000D0Eol00P0000000`0ao`00000002go000402go0080
00001000o`00100000000?l7000000000007003o?@0400000000odd00000
000000800?n=0P000003003oS@0300000000ojX00?nZ00@000000P00ooD0
0`0000000=Wo003Io`06003Io`0300000000V_l009[o00<009[o20000003
0013o`03000000170?l0A`3o00@0A`3o0P00000400H0o`030000003oool0
oooo0340oooo0P000003003oC0030000000Mo`007Ol000@07Ol000<00000
0?n@000000000`3oP@0200000080og@00P00000A0?ooo`030000003oool0
oooo0280oooo00200?ooo`030000003oool0oooo00D0oooo10000000103U
o`0000000000003Yo`02000000D0e_l000@000000<;o0032o`00`_l00P00
00000`35o`0000000:ko00040:ko00030000002Do`00U?l00080U?l000@0
000009Ko0000000000001@1io`020000000305Wo00000000Eol000@0Eol0
00<00000037o000ao`000P0ao`020000000302go00000000000000L00?l0
00<00000003o?@00ocd01`00ocd2000000800?n=0P000005003oS@<00000
1`00ooD00`0000000=Wo003Io`05003Io`H000000P00>ol3000000<0:`3o
1P00000404L0o`030000003o0<80000000<01P3o00<000000?ooo`3oool0
;`3oool3000000@00?m<00<0000001go000Mo`00100Mo`02000000<0oh40
00D000000?md003oM000og@00000000C0?ooo`030000003oool0oooo0280
oooo00200?ooo`030000003oool0oooo00H0oooo00<000000>Go003Uo`00
0`3Uo`000`000000e_l00=Ko00030=Ko008000001P32o`000`000000[_l0
0:ko00030:ko00030000002Do`00U?l000@0U?l000<0000007Wo001io`00
101io`000`000000FOl005Wo000205Wo0080000000<0Eol0000000000000
1`0ao`000`0000000?l0003o0005003o0080000000<00?l]00000000ocd0
1@00ocd2000000800?mc0P000005003oS@8000000P00ol`00`0000000?oe
003om@06003om@0300000000fOl00=Wo00@000000P00ROl00`00000003_o
000ko`05000ko`<000001P0[0?l3000000<0A`3o0P00000300H0o`030000
003oool0oooo02h0oooo0`000005003oC0030000000Mo`007Ol000@07Ol0
00D000000?n1003oP@00oh40000000020?md00800000503oool00`000000
oooo0?ooo`0R0?ooo`00P03oool00`000000oooo0?ooo`040?ooo`800000
103Uo`02000000030=?o0000000000000080e_l000<000000<;o0032o`00
1032o`02000000040:co0000000000000:ko008000001@2Do`0200000003
07[o0000000000000080NOl00P00000705Wo00030000000ao`00<Ol000D0
<Ol00P0000000`0:o`000000003o0003003o008000001000obd200000080
0?lm0P000003003oL`<000000P00ohd3000000@00?o<00<00000003om@00
ooD01P00ooD3000000L008Wo00<00000000ko`00>ol01@00>ol010000000
:`3o00000000000402/0o`030000002h0?l0^03o00@0000000D0o`320000
00060?l01P3o0000000_0?ooo`<000001P00od`00`0000007Ol001go0004
01go00050000003oP@0000000000003oM0000P00000F0?ooo`030000003o
ool0oooo0280oooo00200?ooo`030000003oool0oooo00<0oooo00<00000
0>Go003Uo`000`3Uo`000`000000dol00=?o00030=?o008000001@32o`02
000000D0[?l000<0000009Co002Do`00102Do`000`000000N_l007[o0003
07[o008000001`1Io`020000000303So00000000<Ol000<0<Ol00P000004
00[o000400000000o`000000000000P00?l]0P000003003oL`8000000`00
og<2000000P00?o<00@00000003om@00ooD00?oe100000020037o`030000
0000ROl008Wo00D008Wo00<00000000ko`00>ol01P00>ol00`000000:`3o
02/0o`0300000080:`3o00<000000;P0o`2h0?l00P2h0?l2000000050?l0
`P0000001P3o00H0o`000000;@3oool010000000<Ol0000000000005003o
C0030000000Mo`007Ol000@07Ol01P00000H0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool02`3oool00800oooo00@000000?ooo`3o
ool0oooo0P000000103Ro`0000000000003Uo`02000000D0dol00P000000
1030o`00000000000032o`02000000D0[?l00P0000000`2Eo`0000000000
000209Co008000001@1jo`020000000305go00000000FOl000<0FOl00P00
000403So00040000000ao`000000000000L02_l000<00000003o;@00obd0
1P00obd200000005003oF`0000000?mc003oL`0000000`00og<200000003
003oZ00000000?o<00L00?o<100000060037o`0300000000ROl008Wo00H0
08Wo00<00000000ko`00>ol00`00>ol70000000402/0o`00000000000000
00H0^03o0`0000000`060?l000000?ooo`0[0?ooo`@000001P00od`00`00
00007Ol001go000201go0080000000<01P3o0000003oT@000P00000I0?oo
o`030000003oool0oooo01@0oooo0`00000;0?ooo`00O`3oool01@000000
oooo0?ooo`3oool0000000D0h_l000<000000=?o003Co`00103Co`000`00
0000`?l00<3o00030<3o00030000002/o`00[?l000@0[?l000<0000009Go
002Eo`000`2Eo`02000000D0N_l00P00000405go00040000001Io`000000
000000H0>?l00P00000700[o0080000000<00?lM00000000obd01000obd2
000000<00?mK0`000002003oL`8000001000ojP00`0000000?o<003oc003
003oc08000000P00n_l00`0000000<Oo0037o`060037o`0300000000ROl0
08Wo00<008Wo2000000400`0o`030000001d0?l0M03o00L00000102h0?l2
0000000300H0o`000000oooo02X0oooo0P000002003oK00300000000od`0
0?m<00@00?m<00<0000001go000000000P00000300H0o`800000703oool0
0`000000oooo0?ooo`0B0?ooo`050000003oool000000?ooo`0000002P3o
ool007l0oooo00@000000?ooo`0000000000103Ro`02000000030=7o0000
000000000080dol00P0000040<3o0080000000<0[?l00000000000000P2/
o`02000000D0UOl00P000000101lo`0000000000001jo`02000000L0GOl0
00<0000003So000ho`00100ho`02000000805Ol00P00000300[o00800000
1000oad200000003003o;@000000000000@00?mK0`0000000`00og<00000
00000007003oZ00300000000ol`00?o<008000001@00n_l00`0000000<Oo
0037o`050037o`H000001000B?l00`000000303o00`0o`0500`0o`030000
001d0?l0M03o00D0M03o1P000000102h0?l0000000000000000Y0?ooo`<0
00000P00of`00`0000000?m<003oC004003oC0<000001P060?l00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo0180oooo00D000000?ooo`00
0000oooo0000000:0?ooo`00O`3oool2000000D0h_l000<000000=7o003A
o`000`3Ao`02000000D0`?l000<000000:co002/o`000`2/o`02000000D0
UOl00P00000507co00030000001Mo`00GOl000D0GOl00P0000000`0oo`00
00000000000203So008000001P0Eo`03000000L00?lM0P000005003oF`03
00000000oe/00?mK008000002@00ojP3000000P00?[o00<000000037o`00
aol010000002002=o`0300000000B?l004So00D004So00<0000000`0o`0<
0?l01P0<0?l00`000000M03o07@0o`0507@0o`030000003d0?l0000000L0
00009`3oool3000000<00?m/00<00000003oC000od`00P00od`200000003
002Bo`0000001P3o00H01P3o00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0B0?ooo`050000003oool000000?ooo`0000002P3oool007l0
oooo00D000000?ooo`00000000000>;o0002000000D0dOl00P0000001030
o`00000000000030o`02000000D0[?l00P000000102Fo`0000000000002E
o`02000000D0O?l00P0000000`1Ro`00000005go000405go00030000000o
o`00?ol000<0?ol00P00000701Go0080000000<00?l=00000000oad01000
oad2000000800?m500<00000003oF`00oe/00P0000000`00oe/000000000
0002003oR00300000000ojP00?nX00@00?nX0P000002003of@0300000000
n_l00?[o00H00?[o0`000007002=o`0300000000B?l004So00D004So00<0
000000`0o`0<0?l00`0<0?l8000000<0M03o00@000000?@0o`3d0?l0m03o
0P0000000`3d0?l0000000000002000002<0oooo0`000005003oK0030000
0000od`00?m<008000000`00T_l00`0000001P3o00H0o`0500H0o`030000
003oool0oooo01/0oooo00<000000?ooo`3oool04`3oool3000000/0oooo
001o0?ooo`050000003oool0oooo0?ooo`0000001P3Ao`000`000000`?l0
0<3o00030<3o00030000002/o`00[?l000@0[?l000<0000009Ko002Fo`00
0`2Fo`000`000000O?l007co000407co00030000001Ro`00H_l00080H_l0
0P0000000`1Mo`0000000000000403oo0080000000<08Ol00000000Eo`00
100Eo`02000000@00?l=00<00000003o7@00oad00P000005003oA@800000
00<00?mK0000000000001@00ohP2000000800?nX0P000005003of@040000
0000n_l00?[o003jo`@000000P00b?l00`00000008go002=o`06002=o`03
00000000B?l004So008004So200000040400o`040000002T0?l0Y03o0:@0
o`P0000000D0m03o00000000000000000?l0M003000001l0oooo10000005
003oK00400000000od`00000000000@009;o00<0000000H0o`060?l01P06
0?l00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool02@3oool007l0oooo00<000000?ooo`3oool00P3oool2
00000080dOl00P0000040<3o0080000000<0[Ol00000000000000P2/o`02
000000@0U_l00P0000000`20o`0000000000000207co008000001P1Ro`02
000000D0?ol000<00000027o000Qo`000P0Qo`020000000301Go00000000
000000H00?l=0`000006003oA@@000002000ohP3000000L00?oI10000006
0038o`0300000000SOl008go00H008go1@000004000Eo`03000000100?l0
@03o00H0@03o00<000000:@0o`2T0?l01@2T0?l00`000000o`3W0?l0i`07
000000030?l0M0000000000001`0oooo00D0000000Oo000000000?m_0000
0004003oK0<000001P00T_l00`0000001P3o00H0o`0600H0o`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P00
00040?ooo`8000004@3oool007l0oooo00<000000?ooo`3oool0103oool2
000000D0`?l000<000000:go002]o`000`2]o`02000000D0U_l000<00000
083o0020o`000`20o`02000000H0H_l00P00000204Oo0080000000<0?ol0
0000000000001P0Qo`02000000H00?l=0P000002003o<00300000000odD0
0?m500800?m50`000002003oK00300000000ohP00?n800@00?n80P000002
003o/P0300000000omT00?oI00<00?oI0P000002003ko`0300000000b?l0
0<So00H00<So00@00000002=o`00SOl008go10000002001Oo`0300000000
5Ol001Go00D001Go0P0000070400o`030000002T0?l0Y03o00D0Y03o00<0
00000?l0i`3o0>L0103o0>L7000001P0oooo100000000`00ofl00000003o
K002003oK080000000<00=oo00000000T_l01P00T_l00`0000001P3o00H0
o`0600H0o`030000003oool0oooo01/0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0
0000403oool007l0oooo00<000000?ooo`3oool01P3oool2000000030<3o
00000000000000D0[Ol00P000000102Io`0000000000002Fo`02000000D0
P?l00P0000000`1Xo`0000000000000206;o008000001P17o`000`000000
8Ol0027o0004027o008000000P02o`02000000800?l=0P000005003o<003
00000000odD00000008000001@00of`2000000800?n80P000005003o/P03
00000000omT00?oI008000001@00nol2000000@00<So1P000007001Oo`03
000000005Ol001Go00<001Go8`00000D0?ooo`<000000`00ofl400000080
0=oo00<00000002Bo`00T_l01P00T_l00`0000001P3o00H0o`0600H0o`03
0000003oool0oooo01/0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool007l0
oooo00<000000?ooo`3oool0203oool00`000000[Ol00:go00040:go0003
0000002Io`00VOl000<0VOl000<00000083o0020o`000`20o`02000000D0
J?l00P00000604Oo0080000000<0;?l00000000000000P0Qo`02000000H0
0_l00P000008003o<08000002000of`3000000L00?nb0`000008003ko`D0
00001000W_l00`00000005oo001Oo`06001Oo`H00000100@0?l00`000000
I@3o06D0o`0506D0o`8000001P350?l2000000L0o`3@2P00000>0?ooo`<0
00000`00ofl3000000D00=oo00<00000002Bo`00T_l01@00T_l00`000000
1P3o00H0o`0700H0o`030000003oool0oooo01/0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00L0oooo0P00000A0?oo
o`00O`3oool00`000000oooo0?ooo`090?ooo`8000000P2]o`02000000@0
VOl00P0000001024o`00000000000020o`02000000D0J?l00P0000000`1@
o`00000004Oo000404Oo00030000000/o`00;?l000<0;?l00P00000600;o
0080000000<00?lL00000000oc001@00oc0200000003003oD@0000000000
00<00?m/10000002003oT08000000P00ok84000000800?oH00<00000003k
o`00nol01000nol2000000800=Ko00<00000002No`00W_l01@00W_l20000
008005oo10000002000ko`030000000@0?l0403o00H0403o00<0000006D0
o`1U0?l00`1U0?lN000000X0oooo10000002003oK`<000001P00gol00`00
000009;o002Bo`06002Bo`03000000060?l01P3o00L01P3o00<000000?oo
o`3oool06`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0@0?ooo`00O`3oool00`00
0000oooo0?ooo`0;0?ooo`8000001@2Io`000`000000Q?l008Co000308Co
00030000001Xo`00J?l000@0J?l000<00000053o001@o`000P1@o`020000
000304Oo00000000000000@0;?l00P0000000`0Ao`00000000;o000400;o
000300000000oa`00?lL00800?lL0P000002003o<08000001@00oe430000
00L00?n@0`000007003of00300000000nol00?_o00<000001@00e_l00`00
000009ko002No`03002No`D000001`00>ol2000000@0403o2000000407l0
o`8000001`3K0?l2000000H0o`310P0000020?l0F@8000000`3o05T20000
00L0oooo1`0000000`00onl00000003Oo`06003Oo`0300000000T_l009;o
00H009;o00<0000000H0o`060?l01`060?l00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0080oooo0P00000:0?ooo`<00000403oool007l0
oooo00<000000?ooo`3oool03@3oool20000000309Wo00000000000000@0
Q?l00P0000000`1_o`0000000000000206So008000001P1@o`02000000D0
;?l000<00000017o000Ao`000P0Ao`020000000300;o00000000000000H0
0?lL0`000005003oD@8000000P00og400`0000000?n@003oT003003oT080
00000P00ok400`0000000?oH003of005003of0<000002000e_l6000000@0
07go0P000005000ko`L00000100[0?l2000000H0O`3o7`0000020?ooo`H0
00001000onl00`0000000=oo003Oo`04003Oo`0300000000T_l009;o00L0
09;o00<0000000H0o`060?l01`060?l00`000000oooo0?ooo`0K0?ooo`80
00008P3oool007l0oooo00<000000?ooo`3oool03`3oool00`000000Q?l0
08Co000308Co00030000001_o`00Kol000<0Kol00P000006053o00800000
0P0ho`020000000302co00000000000000H04Ol00P000006003o70H00000
0P00oe42000000D00?ma00<00000003oT000oi000P000005003o/@030000
0000omP00?oH00@000000P00ooT2000000<00=Ko10000002002go`030000
0000OOl007go00H007go1P000004000Oo`8000001@0[0?l8000000@0T03o
0P0000060>T0o`8000001`3o0;P2000000<0o`1F2`000004003ok`/00000
2000T_l00`0000001P3o00H0o`0700H0o`030000003oool0oooo01X0oooo
0P00000S0?ooo`00O`3oool00`000000oooo0?ooo`0@0?ooo`80000000<0
Q?l00000000000001@1_o`020000000305[o0000000000000080D?l00P00
000603So00030000000Ao`004Ol000@04Ol00P000002003o2@8000000P00
oa`4000000<00?li0`000007003oL@<000001`00ok43000000P00?oi0`00
0007002go`8000000P00OOl40000008006?o0P000005000Oo`P00000100n
0?l2000000D0T03o700000020?l0E0<0000000<00?o_0000000000000`00
00080013o`03000000170?l00000008000001000T_l00`0000001P3o00H0
o`0700H0o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0803o
ool007l0oooo00<000000?ooo`3oool04P3oool00`000000Kol006oo0004
06oo00030000001Jo`00F_l000<0F_l00P00000603So0080000000<08?l0
0000000000000P0Ao`02000000H00?l90P0000000`00ocT00000003o>@02
003o>@8000000P00oe@00`0000000?ma003oL@03003oL@8000000P00ohd2
000000<00?na0`000002003ocP8000000`00ooT4000000800>_o0P000005
002go`D000001`00Hol6000000@000co0P00000503h0o`P00000102K0?l2
000000H0lP3o5`000002002Jo`0300000000@ol004?o00H004?o00<00000
04L0o`170?l00`170?l300000003002Bo`0000001P3o00P01P3o00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0P0?ooo`00OP3oool00`00
0000oooo0?ooo`0D0?ooo`8000000P1_o`02000000@0F_l00P0000000`14
o`0000000000000303So008000001@0Po`02000000H00?l90P0000000`00
ob80000000000002003o>@8000001@00oe@00`0000000?ma003oL@020000
00H00?n=0`000007003ocP<000001`00jol6000000@009oo0P000002001S
o`@000000P00D?l2000000D000co2000000404/0o`8000001P2K0?l80000
00@0mP3o0P0000060?l0[`h000002000@ol00`000000A`3o04L0o`0604L0
o`8000002@060?l00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
0200oooo001n0?ooo`030000003oool0oooo01H0oooo0P00000505[o0003
00000014o`00A?l000<0A?l00`000005023o0080000000<02?l000000000
00000`00o`T200000003003o8P000000000000800?lR0P000008003oE080
00001P00ohd2000000800?nW00<00000003ocP00olh00`00olh200000080
0?oV0P000002003[o`@000000P00eOl00`00000009oo002Oo`06002Oo`<0
00002000D?l5000000@0003o0P00000604/0o`P000000`2Q0?lA000000@0
o`2_0P0000030?l0D`8000000P3o05<4000000@004?o00<0000004L0o`17
0?l01`170?l00`000000o`320000000800H0o`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0803oool007h0oooo00<000000?ooo`3oool0
603oool20000000305[o00000000000000D0A?l00P0000000`0^o`000000
00000002023o008000001@08o`03000000800?lR00<00000003o8P00ob80
0P0000000`00oc/00000003oE005003oE080000000<00?m^000000000000
0`00ohd2000000D00?nW00<00000003ocP00olh00P000005003oiP<00000
1`00eOl20000008009oo10000002002=o`8000000`00D?l40000008004Co
0P0000050000o`P000000`1@0?l8000000@0X@3o0P0000060?H0oa`00000
20170?l010000000o`320?l0`P00000700H0o`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0803oool007h0oooo00<000000?ooo`3oool0
6P3oool00`000000A?l004Co000404Co00030000000^o`00;_l000<0;_l0
0P00000500So008000000P00o`h300000003003o8P000000000000@00?lk
0P000002003oE08000001@00ofh3000000L00?nW0`000005003oiP800000
0P00ooT2000000D00=Go1@000005002=o`H000001@00A?l8000000<01P3o
200000030500oa4000000`3b0?lG00000080^03o0P00000504L0o`050000
003o0<80o`320?l0`P0000001`060?l00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0200oooo001n0?ooo`030000003oool0oooo01/0oooo
0P00000204Co00800000100^o`020000000301Wo00000000000000802?l0
0P000004003o3P0400000000o`h00000000000L00?lk0`000005003oKP80
00000P00oh@2000000800?nW10000002003o_08000000P00onH2000000H0
0?oi1@0000050035o`D000001@00P_l6000000D003ko1P00000400H0o`L0
0000101;0?lY00000080^03o0`00000204L0o`030000003o0<80o`320080
o`3200<0000000H0o`060?l010060?l00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo0200oooo001n0?ooo`030000003oool0oooo01d0oooo
0P00000502ko00030000000Io`006Ol000<06Ol00P000004003o3P@00000
00<00?lS0000000000000P00oc/4000000800?mA0P000002003oKP800000
1@00oh@3000000L00?nl0`000006003on@80000000<00?Oo000000000000
0`00aOl4000000800;[o0P0000030022o`@000000P00O?l20000008003ko
10000003000no`L000000`000?l8000000<0?P3o9@0000000`3o05T00000
000000030;P0o`8000001P3o0<800`0000001P3o00H0o`0300H0o`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0803oool007h0oooo00<0
00000?ooo`3oool07`3oool20000000302ko00000000000000@06Ol00P00
00001005o`00000000000000o`h4000000D00?lS0P000007003oD@<00000
1@00oh@2000000800?nG0P000002003o_0@000000P00olh2000000<00?oi
0P000005003go`<000001`00^_l4000000D007co1@000004000no`@00000
0`00A?l6000000<000co500000020<3o00/000001P3oool<00000080o`2=
0P0000050?l0`P03000000060?l01P3o00801P3o00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0P0?ooo`00OP3oool00`000000oooo0?oo
o`0Q0?ooo`8000000`0Io`02000000D01Ol00`000005003o8`80000000<0
0?lf0000000000000`00oe43000000800?mT0P000002003oQ08000001@00
oiL3000000P00?o>0`000003003go`@000000P00kOl2000000800;[o1000
0003002eo`H000000`00O?l6000000<004Co100000000`00D?l000000000
000A0000000405Oo00000000000007ko00<000000`30o`02000000040=co
0000000000000?Co0080000000<0ooD00000000000003`3oool700000003
0?l0S@000000000000@0o`3200D0000000H0o`060?l01P3o0000000O0?oo
o`030000003oool0oooo0200oooo001n0?ooo`030000003oool0oooo02<0
oooo0`00000500Go00<0000000<00?l=0000000000000P00ob<2000000D0
0?lf0`000006003oI0<000001000oiL3000000800?nV0P000003003ocP@0
00000`00om/3000000L00>go0`000004002eo`@000000`00]Ol5000000@0
08;o2P000002001So`l0000000@0Eol0000000000000O_l00P000000102Q
o`0000000<3o0030o`02000000040=co0000000000000?Co0080000000<0
ooD00000000000004`3oool200000080oooo0`0000000`3o08d000000?l0
`P030?l0`P04000000060?l01P3o000001l0oooo00<000000?ooo`3oool0
803oool007h0oooo00<000000?ooo`3oool09@3oool2000000801Ol00`00
0005003o3@8000001@00ocH2000000800?m80P000002003oI0<000000`00
ogD4000000L00?nV0`000003003of`@000000P00on@2000000800>go1000
0003003Xo`@000000`00]Ol4000000<00;[o1P0000000`00SOl000000000
000200000003002Oo`000000000000/0000000<00?l]0000000000000`00
0000101Go`0000000000001no`02000000040:7o0000000000000<3o0080
000000@0g?l0000000000000m?l00P0000000`3om@0000000000000G0?oo
o`<0000000<0oooo0000000000000`0000020?l0`P04000000060?l01P3o
000001l0oooo00<000000?ooo`3oool0803oool007h0oooo00<000000?oo
o`3oool09`3oool3000000D00?l=0P0000000`00oah0000000000002003o
=P8000001P00odP2000000D00?me0P000002003oP`8000000P00ojH40000
00<00?nb0`000007003oi0<000000`00j?l4000000<00>So10000003002j
o`@000000`00aOl900000003002go`000000000000P0000000<00?l]0000
000000006000000L0?ooo`80000000<0oooo0000000000000`000000103o
0<80000000H0o`00000P0?ooo`030000003oool0oooo01l0oooo001n0?oo
o`030000003oool0oooo02H0oooo0P0000000`3oool0000000000002003o
3@8000001@00oah2000000H00?m80P0000000`00oeL0000000000002003o
M@8000001@00oh<3000000D00?nb0P000002003o^P8000000P00on@40000
00<00?oX0`000004003Xo`@000000`00kOl3000000<00<Go200000000`00
jol000000000000?00000003037o0000000000000080000000@0N_l00000
00000000V_l00P0000000`2go`000000000000020=;o0080000000<0jOl0
0000000000000P00000P0?ooo`<0000000<0oooo0000000000001000000P
0?ooo`030000003oool0oooo01l0oooo001n0?ooo`030000003oool0oooo
02@0oooo0P0000050?ooo`8000001@00oah200000003003o;@0000000000
00<00?m80P000004003oE`<000001000oh<3000000800?n=0P000002003o
/P8000001@00okX3000000@00?oX0`000003003oj0@000000`00kOl40000
00<00?Oo300000000`00ooT000000000000700000003003o7@0000000000
0080000000<0<Ol00000000000000P000000101jo`0000000000002Jo`02
000000030;Oo0000000000000080d_l00P0000000`3Yo`00000000000002
000002D0oooo0P0000030?ooo`800000803oool00`000000oooo0?ooo`0O
0?ooo`00OP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00H0oooo0P000002003o7P8000001@00obd3000000<00?mG0`000003003o
H`@000001P00ohd3000000@00?nj0`000003003o_P@000000`00onP40000
00<00?oT0`000003003go`L000000P00onH2000000<00?o>0`0000001000
oi00000000000000of`300000003003o7@00000000000080000000<0<Ol0
0000000000002`0000020=;o0080000000<0jOl00000000000000P00000Y
0?ooo`<000008P3oool00`000000oooo0?ooo`0O0?ooo`00OP3oool00`00
0000oooo0?ooo`0Q0?ooo`8000002`3oool2000000<00?l]10000003003o
>`<000001@00of<2000000800?m/0P000002003oS@<000000`00oi@40000
00<00?nn10000003003o_P<000000`00on@4000000<00?oK1P000003003o
iP<0000000<00?o>0000000000000`0000001000oi00000000000000of`=
0000000407Wo00000000000009Ko0080000000<0/Ol00000000000000P3:
o`07000002h0oooo0P00000P0?ooo`030000003oool0oooo01l0oooo001m
0?ooo`030000003oool0oooo0200oooo0P00000?0?ooo`<000001P00oc/2
00000003003oA@000000000000800?mS0P000005003oK0<000000`00oi@4
000000<00?nH0`000003003o_P@000000`00okX3000000<00?oK1`000003
003o_100000000@00?l=0000000000005Ol00P0000000`0ho`0000000000
00020000000407Wo00000000000009Ko0080000000<0/Ol0000000000000
0P3:o`02000000040>7o0000000000000?Go00800000<@3oool3000001d0
oooo00<000000?ooo`3oool07`3oool007d0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0A0?ooo`8000000`00oc/2000000@00?m5
0`000003003oK0@000000`00og83000000<00?nH10000003003oV0<00000
0`00okX4000000<00?nb1P000004003o_140000000@00?l=000000000000
5Ol00P0000000`0ho`000000000000020000000407Wo00000000000009Ko
0080000000<0/Ol00000000000000P3:o`02000000040>7o000000000000
0?Go00800000=P3oool2000001/0oooo00<000000?ooo`3oool07`3oool0
07d0oooo00<000000?ooo`3oool07@3oool2000001H0oooo0`000003003o
A@<000000`00odh3000000H00?mb0P000002003oMP<000000`00oiP40000
00<00?nD0`000003003o/P@000000P00ojH2000000800?nG:`000000103Q
o`0000000000003eo`02000003X0oooo0`00000H0?ooo`030000003oool0
oooo01l0oooo001m0?ooo`030000003oool0oooo01/0oooo0P00000K0?oo
o`<000001@00odh200000003003oD`000000000000<00?mb0P000003003o
MP8000000P00ogH3000000@00?nD0`000003003oS@<000001000ojH20000
0003003oU`000000000000D0000000@00?m^0000000000000?mD0P000000
1000ocT0000000000000oa`20000000400;o000000000000027o00800000
00@0?ol0000000000000GOl00P0000000`1jo`0000000000000209Co0080
000000@0[_l0000000000000aOl00P0000000`3Jo`000000000000030000
03l0oooo0P00000F0?ooo`030000003oool0oooo01l0oooo001m0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool07@3oool200000080
0?m>0P000005003oD`<000000`00ogH2000000<00?mf0P000002003oLP@0
00000`00ohd3000000<00?n32P000003003oKP80000000@00?mD00000000
00000?li0P0000001000oa`0000000000002o`0200000004027o00000000
000003oo0080000000@0GOl0000000000000N_l00P00000209Co00800000
00@0[_l0000000000000aOl00P0000020=[o0080000000<0k_l000000000
0000@P3oool3000001<0oooo00<000000?ooo`3oool07`3oool007d0oooo
00<000000?ooo`3oool0603oool200000280oooo0P000003003oD`@00000
0`00oeH3000000<00?mf0P000003003oLP8000000`00of`3000000<00?n3
1`0000000`00of@0000000000003003oDA/000000P2Do`02000000040:ko
0000000000000<Go008000000P3Jo`02000000030>ko00000000000004L0
oooo0P00000A0?ooo`030000003oool0oooo0080oooo1@00000H0?ooo`00
O@3oool00`000000oooo0?ooo`0F0?ooo`8000009P3oool3000000@00?mF
0`000003003oEP<000000`00og82000000<00?m/0P000003003oH`H00000
0`00of@200000003003oD@00000000000080000000<00?lk000000000000
0P00ob8200000004003o2@0000000000017o0080000000@0;?l000000000
0000Aol01000000207co008000000P2Eo`0<000000030>ko000000000000
04/0oooo0P00000?0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0603oool007d0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0Y0?ooo`@000000`00oeH3000000<00?mC0`000003003oK080
00000P00of<3000000800?mG0P000002003oB0H000000`00oc/200000080
0?lR0P0000001000o`T000000000000Ao`020000000402co000000000000
04Oo00@000000P1lo`0200000080UOl00P000000102/o`00000000000032
o`0200000080e_l00P0000000`3Yo`0000000000001?0?ooo`<000003@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo001m
0?ooo`030000003oool0oooo01<0oooo0P00000`0?ooo`<000000`00oe<3
000000<00?m>1`000003003oE`80000000@00?m800000000000000000P00
ocH2000000800?lS5@00000207co008000000P2Eo`02000000040:co0000
000000000<;o008000000P3Fo`0200000080jOl00P00001C0?ooo`800000
2`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo
001m0?ooo`030000003oool0oooo0140oooo0P00000e0?ooo`<000000`00
odh3000000800?m50P000003003o>`H000000`00ocH200000004003o8`00
00000000000000800?l>0P0000001008o`0000000000000Po`0200000004
03So000000000000053o0080000000<0J?l00000000000000P20o`0<0000
0080e_l00P0000020>Wo00800000E`3oool3000000P0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`00O@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo03P0oooo0`000003003oA@80
000000<00?lk0000000000000P0000000`00obd0000000000003003o7PH0
00000`00o`h20000000400So000000000000023o0080000000@0>?l00000
00000000D?l00P00000206So000400000020o`00P?l0083o0080000000@0
U_l0000000000000[?l00P0000000`30o`000000000000020=?o00H00000
G03oool2000000H0oooo00<000000?ooo`3oool00P3oool2000001X0oooo
001m0?ooo`030000003oool0oooo00h0oooo0P00000n0?ooo`H000000`00
obd200000003003o7P0000000000008000000P00o`d2000000801Ol03`00
000206So008000000P20o`020000000309Ko0000000000000080[?l000@0
00000<3o0030o`0000000P3Co`0200000080iOl00P00001P0?ooo`<00000
0`3oool00`000000oooo0?ooo`0N0?ooo`00O@3oool00`000000oooo0?oo
o`0<0?ooo`800000AP3oool6000000@00?l=0P0000001005o`0000000000
0000000201Wo0080000000@0;_l0000000000000A?l00P0000000`1Jo`00
00000000000206oo00T000000P2/o`02000000040<3o0000000000000=?o
008000000P3Uo`02000006D0oooo1000000P0?ooo`00O@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo04`0oooo1`00000301Wo0080
000000@0;_l0000000000000A?l00P0000000`1Jo`0000000000000206oo
0080000000@0Q?l0000000000000VOl00P0000030:go00P000000P3Uo`02
000006T0oooo0P00000P0?ooo`00O@3oool00`000000oooo0?ooo`090?oo
o`800000EP3oool<00000080Kol00P0000001024o`0000000000002Io`02
000000<0[Ol00P0000001030o`0000000000003Ao`0200000080h_l00P00
001Y0?ooo`8000008P3oool007`0oooo00<000000?ooo`3oool0203oool2
000006<0oooo2@0000030:go0080000000<0`?l00000000000000P3Ao`00
10000000h_l00>;o003Ro`02000006P0oooo0P00000T0?ooo`00O03oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo06`0oooo1P000002
0=7o008000000P3Ro`02000006L0oooo0`00000V0?ooo`00O03oool00`00
0000oooo0?ooo`050?ooo`800000M@3oool6000006L0oooo0P00000Y0?oo
o`00O03oool00`000000oooo0?ooo`030?ooo`800000N`3oool00`000000
oooo0?ooo`1T0?ooo`800000:`3oool007`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0640oooo
0`00000]0?ooo`00O03oool00`000000oooo0?ooo`02000007h0oooo00<0
00000?ooo`3oool0G`3oool200000300oooo001l0?ooo`<00000P03oool0
0`000000oooo0?ooo`1M0?ooo`800000<P3oool007`0oooo0P0000210?oo
o`030000003oool0oooo05X0oooo0`00000d0?ooo`00OP3oool3000007h0
oooo00<000000?ooo`3oool0F03oool2000003L0oooo00210?ooo`@00000
NP3oool00`000000oooo0?ooo`1F0?ooo`800000>@3oool008D0oooo0`00
001g0?ooo`030000003oool0oooo05<0oooo0`00000k0?ooo`00R03oool3
000007@0oooo00<000000?ooo`3oool0D@3oool2000003h0oooo002;0?oo
o`@00000L03oool00`000000oooo0?ooo`1>0?ooo`<00000@03oool008l0
oooo0`00001]0?ooo`030000003oool0oooo04`0oooo0P0000130?ooo`00
TP3oool3000006X0oooo00<000000?ooo`3oool0BP3oool2000004D0oooo
002E0?ooo`<00000I`3oool00`000000oooo0?ooo`170?ooo`<00000A`3o
ool009P0oooo1000001S0?ooo`030000003oool0oooo04D0oooo0P00001:
0?ooo`00W03oool300000600oooo00<000000?ooo`3oool0@`3oool20000
04`0oooo002O0?ooo`<00000G@3oool00`000000oooo0?ooo`100?ooo`<0
0000CP3oool00:80oooo0`00001J0?ooo`030000003oool0oooo03h0oooo
0P00001A0?ooo`00Y@3oool4000005H0oooo00<000000?ooo`3oool0?03o
ool2000005<0oooo002Y0?ooo`<00000D`3oool00`000000oooo0?ooo`0i
0?ooo`<00000E@3oool00:`0oooo0`00001@0?ooo`030000003oool0oooo
03L0oooo0P00001H0?ooo`00[`3oool4000004`0oooo00<000000?ooo`3o
ool0=@3oool2000005X0oooo002c0?ooo`<00000B@3oool00`000000oooo
0?ooo`0b0?ooo`<00000G03oool00;H0oooo0`0000160?ooo`030000003o
ool0oooo0300oooo0P00001O0?ooo`00^@3oool3000004<0oooo00<00000
0?ooo`3oool0;P3oool200000640oooo002l0?ooo`@00000?`3oool00`00
0000oooo0?ooo`0[0?ooo`<00000H`3oool00<00oooo0`00000l0?ooo`03
0000003oool0oooo02T0oooo0P00001V0?ooo`00``3oool3000003T0oooo
00<000000?ooo`3oool09`3oool2000006P0oooo00360?ooo`<00000=P3o
ool00`000000oooo0?ooo`0T0?ooo`<00000JP3oool00<T0oooo1000000b
0?ooo`030000003oool0oooo0280oooo0P00001]0?ooo`00c@3oool30000
02l0oooo00<000000?ooo`3oool0803oool2000006l0oooo003@0?ooo`<0
0000;03oool00`000000oooo0?ooo`0M0?ooo`<00000L@3oool00=<0oooo
1000000X0?ooo`030000003oool0oooo01/0oooo0P00001d0?ooo`00e`3o
ool3000002D0oooo00<000000?ooo`3oool0603oool3000007H0oooo003J
0?ooo`<000008P3oool00`000000oooo0?ooo`0F0?ooo`800000N@3oool0
0=d0oooo0`00000O0?ooo`030000003oool0oooo01@0oooo0P00001k0?oo
o`00h03oool4000001/0oooo00<000000?ooo`3oool04@3oool3000007d0
oooo003T0?ooo`<00000603oool00`000000oooo0?ooo`0?0?ooo`800000
P03oool00>L0oooo0`00000E0?ooo`030000003oool0oooo00d0oooo0P00
00220?ooo`00jP3oool300000180oooo00<000000?ooo`3oool02P3oool3
000008@0oooo003]0?ooo`@000003P3oool00`000000oooo0?ooo`080?oo
o`800000Q`3oool00?40oooo0`00000;0?ooo`030000003oool0oooo00H0
oooo0P0000290?ooo`00m03oool3000000P0oooo00<000000?ooo`3oool0
0`3oool3000008/0oooo003g0?ooo`@00000103oool010000000oooo0?oo
o`3oool2000008h0oooo003k0?ooo`<0000000<0oooo0000003oool00P00
002@0?ooo`00oP3oool300000980oooo003o0?oooi@0oooo003o0?oooi@0
oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oo
oi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o
0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo
003o0?oooi@0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 208},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution. Using Equation ",
  StyleBox["(11-12)",
    FontColor->RGBColor[0, 0, 1]],
  ", we obtain  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Phi] \((x, 
            y)\)\ \  = \ \ y\/\[Pi]\ \(\[Integral]\_\(-1\)\%1\( 
                  1\/\(\((x - t)\)\^2 + y\^2\)\) \[DifferentialD]t\)\)]],
  "\n\nUsing techniques from calculus we have the integration formula  ",
  Cell[BoxData[
      \(\[Integral]\(y\/\(\((x - t)\)\^2 + 
                  y\^2\)\) \[DifferentialD]t\ \  = \ \ Arctan \((y\/\(x - \
t\))\)\)]],
  ".  We obtain the solution as follows \n\n\t\t\t",
  Cell[BoxData[
      \(\[Phi] \((x, 
            y)\)\ \  = \ \ \(\(\(\(1\/\[Pi]\) \((Arctan 
                 y\/\(x - t\))\)\)\( | \+\(t = \(\(-1\)\(\ \)\)\)\%\(t - 
                1\)\)\)\ \ \[IndentingNewLine]\[IndentingNewLine]
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \ \)\(\(1\/\[Pi]\) 
              Arctan \((y\/\(x - 1\))\)\ \  - \ \ \(1\/\[Pi]\) 
              Arctan \((y\/\(x + 1\))\)\)\)\)\)]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "The solution is similar to Example 11.7, but the method of solution is \
different.\n\nEnter the function U[t] and use the Poisson integral to \
construct  ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(z = \(y = \(x = 0\)\); \ Remove[x, y, z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[t, \[Phi]];\)\ \), "\n", 
    \(\(U[t_]\  = \ 1;\)\ \), "\n", 
    \(\(G[t_] = \(G[t_] = 
          y\/\[Pi]\ \(\[Integral]\(U[t]\/\(\((x - t)\)\^2 + 
                      y\^2\)\) \[DifferentialD]t\)\);\)\), "\
\[IndentingNewLine]", 
    \(\(\[Phi][x_, y_]\  = \ 
        Apart[Together[G[1] - G[\(-1\)]]];\)\ \), "\[IndentingNewLine]", 
    \(\(v[x_, y_]\  = \ 
        ReplaceAll[\[Phi][x, y], 
          ArcTan[z_] \[Rule] \(-ArcTan[1\/z]\)];\)\ \), "\n", 
    \(\(Print["\<  U[t]  =  \>", U[t]];\)\ \ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\[Phi][x,y]  =  \!\(y\/\[Pi]\) \
\!\(\[Integral]\_\(-1\)\%1\)\!\(U[t]\/\(\((x - t)\)\^2 + y\^2\)\)\
\[DifferentialD]t\>\""];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y]  =  \>", \[Phi][x, y]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y]  =  \>", 
        v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Using the trigonometric identity  ",
  Cell[BoxData[
      \(\(\(\ \)\(arctan \((\(-t\))\) = \(-arctan\) \((t)\)\)\)\)]],
  ", the above result can be written as  ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\) = \(1\/\[Pi]\) 
            arctan \((y\/\(x - 1\))\) - \(1\/\[Pi]\) 
            arctan \((y\/\(x + 1\))\)\)]],
  ".  We can verify some of the boundary values by taking limits."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<     \[Phi][x,y] = \>", \[Phi][x, y]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) \[Phi][-2,y] = \>\"", 
        Limit[\[Phi][\(-2\), y], \ y \[Rule] 0]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) \[Phi][\!\(\(-1\)\/2\),y] = \
\>\"", Limit[\[Phi][\(-1\)\/2, y], \ 
          y \[Rule] 0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) \[Phi][0,y] = \>\"", 
        Limit[\[Phi][0, y], \ y \[Rule] 0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) \[Phi][\!\(1\/2\),y] = \
\>\"", Limit[\[Phi][1\/2, y], \ y \[Rule] 0]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) \[Phi][2,y] = \>\"", 
        Limit[\[Phi][2, y], \ y \[Rule] 0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(cont = Table[k, {k, 0, 1, 1\/10}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Phi][x, y], {x, \(-2\), 2}, {y, 0.000001, 2}, 
        Contours \[Rule] cont, PlotPoints \[Rule] 35, 
        AspectRatio \[Rule] 1\/2, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[Phi][x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Then use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[\[Phi][x, y], {x, \(-2\), 2}, {y, 0.00001, 1.5}, 
        PlotPoints \[Rule] {41, 16}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\[Phi]\>"}, 
        ColorFunction \[Rule] Hue, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 1.5, 0.5], 
            Range[\(-1\), 3, 0.5]}, ViewPoint \[Rule] {\(-2.5\), \(-3\), 2}, 
        AxesEdge \[Rule] {{\(-1\), \(-1\)}, {\(-1\), \(-1\)}, {1, \
\(-1\)}}];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Therefore, the function  ",
  Cell[BoxData[
      \(\[Phi][x, 
          y] = \(1\/\[Pi]\) ArcTan[\(1 - x\)\/y] + \(1\/\[Pi]\) 
            ArcTan[\(1 + x\)\/y]\)]],
  "  is harmonic in the upper half-plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  ",  and takes on the desired boundary values."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the function ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  " that is harmonic in the upper half-plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  ", which takes on the boundary values  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(\[Phi] \((x, 0)\) = x\^2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "    ", "-", "1"}], " ", 
            "\[LessEqual]", " ", "x", " ", "\[LessEqual]", " ", "1"}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}], "\[IndentingNewLine]", 
      RowBox[{\(\[Phi] \((x, 0)\) = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "     ", 
        RowBox[{
          StyleBox["for",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "    ", "|", "x", "|", 
          RowBox[{"\[GreaterEqual]", " ", 
            RowBox[{"1", 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000d2000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD
0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3o
oonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00j@3oool200000:P0oooo003W0?oo
o`<0000000<0oooo000000000000YP3oool00>H0oooo00@000000?ooo`3o
ool000000`3oool200000:@0oooo003T0?ooo`8000000`3oool00`000000
oooo0?ooo`030?ooo`800000XP3oool00><0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`800000X03oool00>80oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`800000WP3o
ool00>00oooo0P0000070?ooo`030000003oool0oooo00T0oooo0P00000G
0?ooo`D00000603oool2000000030?ooo`000000000006<0oooo003O0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool20000
01L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0000001T0?oo
o`00g@3oool2000000X0oooo00<000000?ooo`3oool03@3oool3000001@0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1S0?ooo`00
g03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo
0P00000:0?ooo`@00000103oool00`000000oooo0?ooo`0H0?ooo`800000
00<0oooo000000000000H`3oool00=X0oooo0P00000=0?ooo`030000003o
ool0oooo0180oooo0P00000@0?ooo`030000003oool0oooo0800oooo003I
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0503oool2
000000d0oooo0P0000220?ooo`00f03oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo01H0oooo0P00002?0?ooo`00eP3oool200000140
oooo00<000000?ooo`3oool0603oool2000008d0oooo003E0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool06P3oool2000008/0oooo
003C0?ooo`800000503oool00`000000oooo0?ooo`0L0?ooo`800000R@3o
ool00=80oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0N
0?ooo`<00000QP3oool00=00oooo0P00000G0?ooo`030000003oool0oooo
0240oooo0P0000240?ooo`00c`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo0240oooo00@000000?ooo`0000000000PP3oool00<d0
oooo0P00000J0?ooo`030000003oool0oooo0240oooo00@000000?ooo`3o
ool0oooo0P0000200?ooo`00c03oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo02L0oooo0P00001n0?ooo`00[`3oool2000000@0oooo
0P0000040?ooo`8000003P3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo02T0oooo0P00001l0?ooo`00[P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000/0oooo0P00000N0?ooo`03
0000003oool0oooo02/0oooo0P00000E0?ooo`800000H`3oool00:h0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0;@3oool300000140
oooo00@000000?ooo`3oool00000HP3oool00:h0oooo00@000000?ooo`3o
ool000002@3oool2000000T0oooo0P00000Q0?ooo`030000003oool0oooo
0300oooo0P00000?0?ooo`040000003oool0oooo00000680oooo002^0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0380oooo0P00000=
0?ooo`040000003oool0oooo00000680oooo002H0?ooo`8000005@3oool2
000000X0oooo0`0000050?ooo`800000903oool00`000000oooo0?ooo`0d
0?ooo`8000002`3oool010000000oooo0?ooo`00001R0?ooo`00V@3oool0
0`000000oooo0?ooo`0V0?ooo`<00000903oool00`000000oooo0?ooo`0f
0?ooo`8000002P3oool2000006<0oooo002J0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0h0?oo
o`800000K@3oool009T0oooo00<000000?ooo`0000008`3oool2000002P0
oooo00<000000?ooo`3oool0>P3oool2000006/0oooo002H0?ooo`040000
003oool0oooo00000280oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`0l0?ooo`800000J@3oool009L0oooo0`0000000`3oool00000
0000000O0?ooo`800000:`3oool00`000000oooo0?ooo`0n0?ooo`<00000
IP3oool00;/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`110?ooo`800000I03oool00;T0oooo0P00000^0?ooo`030000003oool0
oooo04<0oooo0P00001R0?ooo`00^03oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo03d0oooo200000000`3oool000000000001P0?oo
o`00]P3oool200000300oooo00<000000?ooo`3oool0>`3oool300000080
oi`000H000000?n1003oP@0000000?n1000000020?ooo`800000GP3oool0
0;D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0j0?oo
o`040000003od`00om<000000080oi`000@000000?n1003oP@0000000P3o
P@0200000080oooo0P00001L0?ooo`00]03oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo03P0oooo0`0000001@3od`0000000?nL003o
W00000000080oh4000<000000?n1003oP@000`3oP@0010000000oooo0?oo
o`3oool2000001@0oooo1@0000110?ooo`00/P3oool2000003@0oooo00<0
00000?ooo`3oool0=`3oool01@000000f_l00000003od`0000000080oi`0
00@000000?n1003oP@0000001@3oP@000`000000oi`0000000040?ooo`80
0000503oool00`000000oooo0?ooo`110?ooo`00/@3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo03H0oooo00D000000=[o00000000
om<0000000020?nL00050000003oP@00oh400?n1000000001@3oP@001000
0000oi`00?nL000000050?ooo`<000004@3oool00`000000oooo0?ooo`11
0?ooo`00[`3oool2000003L0oooo00<000000?ooo`3oool0=@3oool30000
0080om<000@000000?nL003oW00000000P3oP@000`000000oh400?n10003
0?n100030000003oW000oi`00080oi`000<000000?ooo`3oool01@3oool2
000000l0oooo00<000000?ooo`3oool0@@3oool00:h0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0e0?ooo`050000003Jo`000000
0?oC000000000P3oW00010000000oh400?n1000000050?n100030000003o
W000oi`00080oi`000<000000?oC00000000203oool2000000d0oooo00<0
00000?ooo`3oool0@@3oool00:`0oooo0P00000j0?ooo`030000003oool0
oooo03@0oooo00D000000=[o00000000om<0000000020?nL00050000003o
P@00oh400?n100000000103oP@000`000000oi`00?nL00030?nL00040000
003od`00om<0000000T0oooo0P00000:0?ooo`800000@`3oool00:/0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0c0?ooo`050000
003Jo`0000000?oC000000000P3oW0001@000000oh400?n1003oP@000000
00D0oh4000<000000?nL003oW0000P3oW0000`000000om<00?oC00020?oC
00030000003oool0oooo00P0oooo0P00001=0?ooo`00Z@3oool2000003d0
oooo00<000000?ooo`3oool0<P3oool300000080om<000@000000?nL003o
W00000000P3oP@000`000000oh400?n100030?n100030000003oW000oi`0
0080oi`000<000000?oC003od`00103od`000`000000oooo0?ooo`090?oo
o`800000B`3oool009P0oooo1@00000;0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0<P3oool00`000000f_l00000000600000080
oh4000<000000?n1003oP@000P3oP@000`000000oi`00?nL00020?nL0003
0000003od`00om<000@0om<00P00000=0?ooo`800000B@3oool009X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo0340oooo1@0000020<So00030000003Oo`00gol000800000
103oP@000`000000oi`00?nL00030?nL00030000003od`00om<000<0om<0
00@000000=[o003Jo`0000003P3oool2000004L0oooo002J0?ooo`030000
003oool0oooo00P0oooo0P0000110?ooo`030000003oool0oooo0300oooo
0`00000209Wo000400000038o`00b?l000000080gol000@000000=oo0000
000000000P3oP@000`000000oi`00?nL00020?nL00030000003od`00om<0
00@0om<000@000000=[o003Jo`000000403oool3000004@0oooo002J0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0_0?ooo`<000000P2Io`0010000000b?l00<So00000003
0=oo00040000003Oo`00gol00=oo00800000103oW0000`000000om<00?oC
00040?oC00030000003Jo`00f_l00080f_l000<000000?ooo`3oool0403o
ool200000480oooo002J0?ooo`030000003oool0oooo00D0oooo0P000014
0?ooo`030000003oool0oooo02h0oooo100000001@2Io`0000000<So0038
o`00000000<0gol000<000000=oo003Oo`000P3Oo`000`000000b?l00000
00020?nL00030000003od`00om<000@0om<000<000000=[o003Jo`000`3J
o`000`000000oooo0?ooo`0@0?ooo`040000003oool0000000000400oooo
002I0?ooo`8000001P3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo02h0oooo0`0000001@2Io`0000000<So0038o`00000000<0gol0
00<000000=oo003Oo`000`3Oo`001P000000b?l00<So00000000oi`00000
00D0om<000<000000=[o003Jo`001@3Jo`000`000000oooo0?ooo`0?0?oo
o`040000003oool0oooo0?ooo`800000?P3oool009l0oooo0`0000160?oo
o`030000003oool0oooo02d0oooo00<00000003o^@0000000P2Io`001000
0000b?l00<So000000020=oo00030000003Oo`00gol000<0gol000<00000
0<So0038o`000P38o`000`000000om<00?oC00030?oC00030000003Jo`00
f_l000D0f_l00P00000G0?ooo`800000?03oool009h0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`0/0?ooo`<000000P2Io`001000
0000b?l00<So000000030=oo00030000003Oo`00gol00080gol000<00000
0<So0038o`000P38o`000`000000VOl0000000030?oC00030000003Jo`00
f_l000D0f_l000@0000006go001]o`000000603oool2000003X0oooo002M
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0:`3oool2
00000004003o^@000000VOl000000080b?l000D000000=oo003Oo`00gol0
000000040=oo000300000038o`00b?l000<0b?l000<0000009Wo00000000
0`3od`000`000000f_l00=[o00050=[o00040000001]o`00KOl0000001X0
oooo0P00000h0?ooo`00V`3oool2000004/0oooo00<000000?ooo`3oool0
:P3oool200000004003o^@000000VOl000000080b?l000D000000=oo003O
o`00gol0000000050=oo000300000038o`00b?l00080b?l000L0000009Wo
002Io`00VOl00000003od`00000000L0f_l000<0000006go001]o`000P1]
o`000`000000oooo0?ooo`0I0?ooo`<00000=@3oool009X0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0Y0?ooo`80000000D00?ni
000000000000VOl0000000020<So00040000003Oo`00gol0000000D0gol0
00<000000<So0038o`000P38o`000`000000VOl009Wo000309Wo00030000
003Jo`00f_l000D0f_l000<0000006go001]o`000`1]o`000`000000oooo
0?ooo`0L0?ooo`800000<`3oool009P0oooo0P00001>0?ooo`030000003o
ool0oooo02P0oooo0P0000000`00okT000000000000600000080gol000<0
00000=oo003Oo`000P3Oo`000`000000b?l00<So00020<So00030000002I
o`00VOl000<0VOl000<0000005;o000000001@3Jo`000`000000KOl006go
000506go00030000003oool0oooo01d0oooo0P00000a0?ooo`00U`3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo02P0oooo0`000000
0`00S_l000000000000204Co00030000001Io`00FOl000800000103Oo`00
0`000000b?l00<So00030<So00030000002Io`00VOl00080VOl000D00000
05;o001Bo`00D_l0000000030=[o00030000001]o`00KOl000H0KOl000<0
00000?ooo`3oool07`3oool2000000h0oooo0P00000O0?ooo`00U@3oool2
00000540oooo00<000000?ooo`3oool09`3oool20000008008ko0P000002
04Co00060000001Io`00FOl005Wo00000000FOl00P0000020=oo00030000
0038o`00b?l00080b?l000<0000009Wo002Io`000`2Io`001@000000D_l0
05;o001Bo`00000000<0f_l000<0000006go001]o`001@1]o`02000002<0
oooo0P00000;0?ooo`040000003oool0oooo000001h0oooo002D0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool09P3oool2000000<0
08ko00D0000004Co0014o`00A?l00000000205Wo00030000001Io`00FOl0
0080FOl00P0000040<So00030000002Io`00VOl000<0VOl000<0000005;o
001Bo`000`1Bo`000`000000f_l00000000706go000400000000oaT00?lI
000002@0oooo0P0000090?ooo`040000003oool0oooo000001h0oooo002B
0?ooo`800000E03oool00`000000oooo0?ooo`0T0?ooo`<000000`00S_l0
1@000000A?l004Co0014o`00000000<0FOl000<0000005Wo001Io`000P1I
o`000`000000A?l0000000020<So00030000002Io`00VOl000<0VOl000<0
000005;o001Bo`001@1Bo`000`000000KOl006go000506go000500000000
oaT00?lI003o6@0000009P3oool2000000L0oooo00@000000?ooo`3oool0
00007P3oool00940oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0S0?ooo`0300000000ooh0000000@008ko00@0000004Co0014o`00
00000`1Io`000`000000FOl005Wo000205Wo000700000014o`00A?l004Co
00000000b?l00000000409Wo00030000001Bo`00D_l000D0D_l00P000006
06go000300000000oaT00?lI00<00?lI00<000000?ooo`3oool09@3oool2
000000D0oooo00@000000?ooo`3oool000007P3oool00900oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0R0?ooo`0300000000ooh0
000000@008ko0P0000000`14o`00000005Wo000205Wo00030000001Io`00
FOl00080FOl000<0000004Co0014o`000`14o`000`000000VOl009Wo0002
09Wo00030000001Bo`00D_l000D0D_l000@00000003o2@00o`T000001@1]
o`000`0000000?lI003o6@03003o6@030000003oool0oooo02L0oooo0P00
00040?ooo`8000007`3oool008h0oooo0P00001H0?ooo`030000003oool0
oooo0240oooo00@00000003ooP00000000000P00S_l30000000304Co0000
0000FOl00080FOl000<0000005Wo001Io`000P1Io`000`000000A?l004Co
000304Co00030000000Lo`00000000<0VOl000<0000005;o001Bo`001@1B
o`00100000000?l9003o2@00000406go000300000000oaT00?lI00D00?lI
00<000000?ooo`3oool09@3oool3000002D0oooo002=0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0803oool0100000000?on0000
00000002002>o`060000000l0?l0?03o00000014o`0000000P1Io`000`00
0000FOl005Wo000305Wo000300000014o`00A?l00080A?l000L0000001co
000Lo`007?l00000002Io`00000000L0D_l000<00000003o2@00o`T00P00
o`T010000000KOl006go00000008003o6@030000003oool0oooo02<0oooo
0P0000000`3oool000000000000U0?ooo`00R`3oool2000005/0oooo00<0
00000?ooo`3oool07`3oool300000004001_o`00000008ko000000<0?03o
0P00000305Wo00030000001Io`00FOl00080FOl000<0000004Co0014o`00
0P14o`000`0000007?l001co000301co00030000001Bo`00D_l000D0D_l0
00<00000003o2@00o`T00`00o`T00`000000KOl00000000:003o6@030000
003oool0oooo0200oooo0P0000040?ooo`030000003oool0oooo02<0oooo
002:0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool07P3o
ool20000008006oo0`00000303`0o`<000000P1Io`000`000000FOl005Wo
000205Wo000300000014o`00A?l00080A?l000<0000001co000Lo`000`0L
o`000`0000000?lN0000000505;o000300000000o`T00?l900D00?l900<0
0000003o6@00oaT02000oaT200000200oooo0P0000060?ooo`030000003o
ool0oooo02<0oooo001]0?ooo`D000000P3oool2000000@0oooo0P00000<
0?ooo`800000G03oool5000001d0oooo0P000003001_o`030000000l0?l0
?03o00<0?03o00<00000003o6@00oaT00`00000305Wo000300000014o`00
A?l000<0A?l000<0000001co000Lo`000P0Lo`001@0000000?lN003o7P00
oah0000000<0D_l000<00000003o2@00o`T01@00o`T00`0000000?mj0000
0008003o6@0400000000okT00?ni000001d0oooo0P0000080?ooo`030000
003oool0oooo02<0oooo001_0?ooo`030000003oool0oooo00L0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`1J0?ooo`800000
0P3o02h2000000040?l0;P0000000000000001P0oooo0`000002001_o`80
00001P0l0?l0100000000?lI003o6@000002003o6@<000001@14o`000`00
00007?l001co000201co000300000000oah00?lN00800?lN00D0000005;o
001Bo`00D_l000000006003o2@0400000000ogX00?mj000000L00?lI00D0
0000003o^@00okT00?ni0000000K0?ooo`8000002P3oool00`000000oooo
0?ooo`0S0?ooo`00K`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0F@3oool200000080o`0^0P00
00020?l0;P8000000P3o02l3000001@0oooo00@00000003;o`00000006oo
0P0000000`0W0?l0000003`0o`0503`0o`0300000000oaT0000000@00?lI
00<00000003o:P0000000`14o`000`0000007?l001co000201co00030000
0000oah00?lN00@00?lN00<0000005;o000000001P00o`T00`0000000?mj
003oNP02003oNP0300000000oaT00?lI00<00?lI00<00000003o^@00okT0
0`00okT00`000000oooo0?ooo`0F0?ooo`8000003@3oool00`000000oooo
0?ooo`0R0?ooo`00K`3oool00`000000oooo0?ooo`080?ooo`800000203o
ool2000005X0oooo0P0000020?l0;P8000000P3o02h200000080o`0_1000
00000`3o034000000000000A0?ooo`D000000P0W0?l00`000000?03o03`0
o`0403`0o`0300000000oaT0000000@00?lI00L00000003o:P00obX00?lZ
00000014o`00000000D07?l000<00000003o7P00oah01@00oah00`000000
0?l9003o2@04003o2@0300000000ogX00?mj00<00?mj00<00000003o6@00
oaT00P00oaT00`0000000?ni003o^@04003o^@030000003oool0oooo01@0
oooo0P00000?0?ooo`030000003oool0oooo0280oooo001_0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`1H0?ooo`80000000@0o`1100000000000000000P3o02h2000000@0
o`0_0P0000000`3o03400000000000020?l0<@8000003P3oool4000000<0
9`3o00<0000003`0o`0l0?l00`0l0?l4000000@00?lI00<00000003o:P00
obX00`00obX00`0000007?l001co000301co000300000000oah00?lN00D0
0?lN00<00000003oK00000001@00o`T00`0000000?mj003oNP04003oNP04
00000000oaT00?lI000000P00?ni00<000000?ooo`3oool04@3oool20000
0140oooo00<000000?ooo`3oool08P3oool006h0oooo0P00000:0?ooo`<0
0000103oool2000005T0oooo0P0000030?l0@@D00000103o02l2000000D0
o`0a0`0000000`3o03<000000000000;0?ooo`<000001@0W0?l00`000000
?03o0000000300000080o`3_0P000003003o6@0300000000obX00?lZ00<0
0?lZ00<00000003oC00000000`0Lo`000`0000000?lN003o7P05003o7P04
00000000of`00?m/000000@00?l900<00000003oNP00ogX01@00ogX00`00
00000?lI00000009003o^@030000003oool0oooo00l0oooo0P00000C0?oo
o`030000003oool0oooo0280oooo00200?ooo`<00000E`3oool2000000<0
o`11100000030?l0A@@000001@3o0342000000<0o`0c0P000000103o03<0
00000000000000070?ooo`<00000100W0?l4000000D0o`3_0P000004003o
6@0300000000obX00?lZ00800?lZ00L00000003oC000od`00?m<0000000L
o`00000000L00?lN00<00000003oK000of`00P00of`0100000000?l9003o
2@000009003oNP0300000000okT00?ni00T00?ni00<000000?ooo`3oool0
303oool2000001D0oooo00<000000?ooo`3oool08P3oool00800oooo00<0
00000?ooo`0000000P00001C0?ooo`800000103o0443000000@0o`150P00
00020?l0BP8000000P3o0342000000D0o`0c1@000000103o03H000000000
000000030?ooo`<000000`0W0?l3000000P0o`3_00<00000003o6@00oaT0
0P00oaT00`0000000?lZ003o:P02003o:P0300000000od`00?m<00<00?m<
00<00000003o7P00oah01@00oah00`0000000?m/003oK003003oK0030000
0000o`T0000000T00?mj0P00000;003o^@030000003oool0oooo00X0oooo
0P00000G0?ooo`030000003oool0oooo0280oooo00200?ooo`030000003o
ool0oooo0080oooo0`00001?0?ooo`8000000`3o0443000000@0o`150P00
00050?l0BP<00000103o03<3000000@0o`0f0`0000020?l0>@@0000000<0
6`3o0000000000000P0000020;<0o`030000003o0>l0o`3_00H0o`3_00D0
0000003o6@00oaT00?lI00000004003o:P0300000000od`00?m<00<00?m<
00<00000003oOP0000001@00oah00`0000000?m/003oK005003oK0030000
0000ogX00?mj00L00?mj00@00000003ooP00ooh000002@00okT2000000X0
oooo0P00000I0?ooo`030000003oool0oooo0280oooo00200?ooo`030000
003oool0oooo00D0oooo0P00001;0?ooo`8000000P3o05@4000000@0o`15
0P0000050?l0BP8000000`3o0504000000@0o`0f0`0000030?l0>@800000
00<0o`0i0000000000000`0000040;<0o`030000003o0>l0o`3_00H0o`3_
0`0000000`00oaT00000003o:P03003o:P0300000000od`00?m<00<00?m<
00D00000003oOP00ogh00?mn00000003003o7P0300000000of`00?m/00D0
0?m/00<00000003ob@0000001`00ogX01@0000000?on003ooP00ooh00000
00L00?ni0P000002002>o`030000003oool0oooo00D0oooo0P00000K0?oo
o`030000003oool0oooo0280oooo00200?ooo`030000003oool0oooo00L0
oooo0`0000160?ooo`800000103o05@200000080o`1J100000040?l0BP<0
0000103o0502000000<0o`1H100000050?l0>@H0000000@0o`0n00000000
000000000`2c0?l00`000000o`3_0?l0k`060?l0k`0400000000ogX00?mj
000000@00?lZ00<00000003oC000od`00`00od`00`0000000?mn003oOP03
003oOP0300000000oah0000000L00?m/00@00000003ob@00olT000001P00
ogX00`0000000?on003ooP02003ooP0300000000okT00?ni00@00?ni00<0
0000002>o`00S_l00P00S_l00`000000oooo0?ooo`030?ooo`8000007@3o
ool00`000000oooo0?ooo`0R0?ooo`00P03oool00`000000oooo0?ooo`0:
0?ooo`<00000@@3oool2000000@0o`1D0P0000040?l0FP8000000P3o0684
000000@0o`1@0`0000040?l0F08000000`3o0685000000@0o`0n10000002
0?l0AP<00000203o0>l01@0000000?mj003oNP0000000?n90080000000<0
0?lZ00000000od`01000od`00`0000000?mn003oOP05003oOP0300000000
of`00?m/00D00?m/00<00000003ob@00olT00P00olT00`0000000?mj003o
NP02003oNP0300000000ooh00?on00@00?on00<00000003o^@00okT00P00
okT00`00000008ko002>o`03002>o`040000003oool0oooo0?ooo`800000
7`3oool00`000000oooo0?ooo`0R0?ooo`00P03oool00`000000oooo0?oo
o`0=0?ooo`<00000?03oool2000000@0o`1D0P0000040?l0FP800000103o
068200000080o`1[100000040?l0F0<00000103o0682000000<0o`1a1@00
00040?l0APL000001P3o0>l00`0000000?mj00000004003oR@0300000000
od`00?m<00@00?m<00<00000003oOP00ogh01000ogh00`0000000?nn0000
0004003oK08000001P00olT0100000000?mj003oNP000007003ooP030000
0000okT00?ni008000001P00S_l010000000oooo00000000000Q0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool02`3oool00800oooo
00<000000?ooo`3oool0403oool3000003L0oooo0P0000020?l0I@@00000
103o05X2000000@0o`1R0P0000040?l0J`8000000P3o07L4000000@0o`1R
0`0000030?l0L@<000000`3o08H?000000<0o`3_0P000004003oR@030000
0000ojD0000000@00?m<00<00000003oOP00ogh01000ogh0100000000?nn
003o_P000003003oK00300000000olT00?o900H00?o900<00000003oNP00
00002@00ooh2000000T008ko00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0D0?ooo`<000002`3oool007l0oooo00<000000?ooo`3oool0
503oool2000003<0oooo0P0000040?l0I@<0000000<0o`1^000000000000
0P0000040?l0HP800000103o06/2000000@0o`1g0P0000020?l0Q`@00000
0`3o074300000080o`261`000002003oY@0400000000ohT00?n9003oR@X0
00001000ohT0100000000?nU003oY@00ojD200000003003oC00000000?mn
00D00?mn00<00000003o_P00okh00P00okh00`0000000?m/0000000:003o
b@0300000000ooh00?on00P00?on00<00000002>o`00S_l02000S_l00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0180oooo00D000000?oo
o`000000oooo0000000:0?ooo`00O`3oool00`000000oooo0?ooo`0F0?oo
o`<00000;P3oool2000000@0o`1U0`0000030?l0KP8000000P3o07P40000
00@0o`1[0P0000040?l0M`8000000P3o08L3000000<0o`2M200000000`00
o?l000000000000;000000800?mj0`0000000`00ogX0000000000004003o
R@0300000000ojD00?nU00@00?nU00<00000003oOP00ogh01000ogh00`00
00000?nn003o_P04003o_P0300000000olT00?o900L00?o90`000009003o
oP8000002P00S_l00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0180oooo00D000000?ooo`000000oooo0000000:0?ooo`00O`3oool00`00
0000oooo0?ooo`0I0?ooo`<00000:P3oool2000000<0o`1U0`0000030?l0
KP800000103o07P200000080o`24100000040?l0M`80000000@0o`270000
000000000000103o09d<000000800>co00@00000003ol@00oo4000000`00
omT00`0000000?o=003oc@02000000<00?mj0`000003003oR@0300000000
ojD00?nU00@00?nU00<00000003ocP0000001000ogh00`0000000?nn003o
_P04003o_P0300000000m?l0000000L00?o900D00000003;o`00bol00<_o
00000006003ooP8000000P00Kol00`00000008ko002>o`07002>o`030000
003oool0oooo0280oooo00<000000?ooo`3oool04P3oool01@000000oooo
0000003oool0000000X0oooo001o0?ooo`030000003oool0oooo01`0oooo
0`00000U0?ooo`8000000P3o07D500000080o`1^0P0000040?l0N0800000
103o08@200000080o`2C1`0000040?l0W@/000000P00`?l0100000000>co
003/o`000002003ol@0500000000omT00?oI003of@0000000`00old01P00
00000?o=0000000000000?mj000000800?n90P0000000`00ohT00000003o
Y@04003oY@0400000000olh00?o>000000<00?mn00<00000003o_P00okh0
1000okh0100000000?Co003do`000005003ob@8000001000bol00`000000
0?on003ooP03003ooP0300000000Kol006oo008006oo00<00000002>o`00
S_l02000S_l00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01<0
oooo0`00000;0?ooo`00O`3oool00`000000oooo0?ooo`0O0?ooo`<00000
803oool2000000<0o`1e200000040?l0N0800000103o08@2000000<0o`2C
0P0000020?l0Y`8000000P3o0<45000000030?40o`000000000000@00000
00D008co00000000`?l00<3o00000002003/o`0400000000oo400?oa0000
00<00?oI00D00000003oc@00old00?o=00000004003oc@0300000000ohT0
0?n900<00?n90`000003003oY@0300000000olh00?o>00800?o>00<00000
003oOP0000001P00okh00`0000000?Co003do`02003do`0500000000olT0
0?o9003ob@0000001`00bol01@0000000?on003ooP00ooh0000000H006oo
00<00000002>o`00S_l01`00S_l00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool02@3oool007l0oooo00<0
00000?ooo`3oool08P3oool3000001/0oooo0P0000030?l0M@80000000@0
o`1o0000003o07l0o`1o0P0000020?l0R`@00000103o08@200000080o`2C
0`0000020?l0Y`8000000`3o0<44000000030?40o`000000000000800000
00<005?o0000000000000P0000001000`?l0000000000000k?l200000080
0?oa00<00000003of@00omT00P000003003oc@0300000000old00?o=0080
0?o=00@00000003of@00000000000P00ohT0100000000?nU003oY@00ojD3
000000H00?o>00<00000003o_P00okh00`00okh2000000D00?Co00@00000
003ob@00000000002000bol0100000000?on000000000007001_o`030000
0000S_l008ko00D008ko0`00000S0?ooo`030000003oool0oooo0080oooo
0P0000040?ooo`800000103oool200000140oooo001o0?ooo`030000003o
ool0oooo02D0oooo0P00000G0?ooo`8000000`3o07D2000000040?l0O`00
000000000?l0O`8000000`3o08/2000000<0o`2J200000030?l0Y`800000
0P3o0<4;00000004001Co`00000008co000000800<3o00@00000003/o`00
k?l000000`00oo40100000000?oI003of@000003003oc@8000001000old0
0`0000000?oI003of@02003of@8000001000ojD00`0000000?o>00000002
000000<00?o>00<00000003lo`0000000`00okh00`0000000?Co003do`06
003do`0300000000bol00<_o00T00<_o00<00000001_o`00Kol02000Kol0
0`00000008ko002>o`02002>o`8000000`0l0?l00`000000oooo0?ooo`0P
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`060?ooo`040000003oool0oooo00000100oooo001o0?ooo`030000003o
ool0oooo02L0oooo0`00000B0?ooo`8000000P3o08@6000000030?l0O`00
000000000080o`2;0`0000040?l0VP8000000`3o0:/200000080o`312@00
00000`3F0?l000000000000500000004001Co`00000008co000000800<3o
00@00000003/o`00k?l000000`00oo40100000000?oI003of@000003003o
c@0300000000old00?o=00<00?o=00<00000003of@00omT00`00omT01P00
00000?oa0000000000000?nU000000D00?o>0`000003003lo`0300000000
okh0000000P00?Co00<00000002No`0000002@00bol2000000X006oo00<0
0000002>o`00S_l00P00000503`0o`030000003oool0oooo0200oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool03P3oool007l0oooo00<000000?ooo`3oool0:P3o
ool3000000d0oooo0P0000040?l0Q080000000<0o`2?0000000000001P00
00040?l0VP<000000`3o0:/2000000<0o`310P000000103o0=`000000000
003o0?l70000000402H0o`0000000000001Coa8000000P00old00`000000
0?o=003oc@03003oc@0300000000omT00?oI00<00?oI00<00000003ol@00
oo400P00oo400`0000000?o>003ocP05003ocP<000000`00o?l00`000000
0?Co003do`06003do`0400000000W_l009ko000000L00<_o0P000002001H
o`0300000000Kol006oo00P006oo0P00000703`0o`030000003oool0oooo
0200oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00L0oooo0P00000A0?ooo`00O`3oool00`000000oooo0?ooo`0]0?oo
o`<00000203oool2000000@0o`240P000000103o08l000000000003o08l2
000000030?l0W000000000000080o`2/100000040?l0Z`8000000P3o0<43
000000040?l0g000000000000?l0o`L0000000<09P3o0000000000001P00
0002002=o`0400000000/Ol00;7o000000<00<go00@00000003Qo`00hOl0
00000P00jol2000000D00?o=00<00000003of@00omT00`00omT00`000000
0?oa003ol@02003ol@0300000000k?l0000000@00?o>0P000003003lo`<0
000000<00;co00000000m?l01@00m?l00`00000009ko002No`02002No`03
00000000bol00<_o00<00<_o00<00000001Ho`00F?l00P00F?l00`000000
06oo001_o`06001_o`<000002@0l0?l00`000000oooo0?ooo`0O0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0100oooo001o0?ooo`030000003oool0oooo0300
oooo0`0000030?ooo`800000103o08@2000000040?l0S`00000000000?l0
S`80000000<0o`2L000000000000103o0:`200000080o`2o4@0000000`2F
0?l000000600o`0700000003001Ro`0000000000008008go00@00000002a
o`00/Ol000000P00cOl2000000800>7o00H00000003[o`00jol00>_o0000
0000jol2000000800?o=00<00000003of@00omT00P00omT2000000@00?oa
00@00000003/o`00k?l000000`00olh00`0000000?co003lo`04003lo`04
00000000_?l00000000000@00?Co0P000006002No`0500000000bol00<_o
003;o`0000001P00F?l00`00000006oo001_o`03001_o`8000000`0W0?l0
0`000000?03o03`0o`0603`0o`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool00P3oool2000000X0oooo0`00000@0?ooo`00O`3oool00`00
0000oooo0?ooo`0c0?ooo`<000000P3o094400000080o`2?00D000000?l0
S`00000000000?l0W002000000@0o`2/0P0000030?l0_`8000000`3o0=H2
00000080o`3a0P0000000`3/0?l00000000000020000000309H0o`000000
000000H0000000@003;o00000000H_l000000P00SOl200000003002ao`00
0000000000800<go00D00000003Qo`00hOl00>7o00000003003[o`030000
0000jol00>_o00800>_o0P000004003of@0300000000oo400?oa00<00?oa
00<00000003/o`00k?l00P00k?l00`0000000?o>00000006003lo`030000
0000_?l00;co00800;co10000008002No`0400000000bol00000000000L0
05So00@00000001_o`00Kol006oo0P00000502L0o`030000000l0?l0?03o
00L0?03o00<000000?ooo`3oool07P3oool200000280oooo001o0?ooo`03
0000003oool0oooo0380oooo0P0000040?l0T@8000000P3o09d8000000<0
o`2/0P0000030?l0_`8000000`3o0=H200000080o`3a0P0000000`3/0?l0
0000000000020000000309H0o`000000000000@0000000<0003o00000000
<_l00P0000001@00H_l00000002=o`00SOl0000000800;7o00D00000003=
o`00cOl00<go00000003003Qo`0500000000jol00>_o003[o`0000001@00
jol01P0000000>7o0000000000000?oI000000@00?oa0P000006003/o`03
00000000o?l00?co00<00?co0P000005002lo`0300000000m?l000000080
00002000W_l00`00000005So001Ho`08001Ho`<000001`0W0?l00`000000
?03o03`0o`0703`0o`030000003oool0oooo01d0oooo0P00000S0?ooo`00
O`3oool00`000000oooo0?ooo`0`0?ooo`800000103o094200000080o`2M
0`0000030?l0Z`8000000P3o0;`8000000<0o`3F0P0000020?l0l@800000
00<0k03o0000000000002@0000001P000?l0000000000000<_l00000001R
o`8000000P00SOl0100000000;7o002ao`000002003=o`8000000`00hOl0
1@0000000>_o003[o`00jol0000000D00>_o00<00000003Qo`00hOl00P00
hOl00`0000000?oa003ol@02003ol@0300000000k?l00>co00D00>co00<0
00000030o`0000000`00o?l00`0000000;co002lo`06002lo`0400000000
W_l009ko002No`<000000`00W_l2000000030012o`00000005So00P005So
00<0000002L0o`0W0?l0200W0?l00`000000?03o03`0o`0603`0o`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0803oool007l0oooo00<0
00000?ooo`3oool0;`3oool2000000<0o`2A0P0000030?l0W@8000000`3o
0:/2000000@0o`2l0P0000020?l0c`8000000P3o0>H<00000080T@3o1000
0000100b0?l00000000000000002000bo`h000000`00hOl01@0000000>_o
003[o`00jol0000000D00>_o00<00000003Qo`00hOl00P00hOl01P000000
0<go0000000000000?oa000000H00>co0P0000030030o`0300000000o?l0
000000P00;co00<00000001fo`0000001@00W_l3000000<004;o00<00000
001Ho`00F?l01@00F?l20000000301/0o`0000009`3o00P09`3o00<00000
03`0o`0l0?l01`0l0?l00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo0200oooo001n0?ooo`030000003oool0oooo02h0oooo0P0000020?l0
W0P000000`3o0:/2000000@0o`2l0P0000020?l0c`8000000P3o0>H20000
0080oP3o0P0000020=l0o`@000000P2A0?l4000000030380o`0000000000
00L000000`00Gol01000000007ko001no`000002002Eo`0300000000Y_l0
0:Ko00@000000P00jol00`0000000>_o003[o`02003[o`8000000`00hOl2
000000@00<go00<00000003/o`00k?l01000k?l00`0000000<3o0030o`04
0030o`0300000000_?l00;co00H00;co00D00000001fo`00M_l007Ko0000
0004002No`D000000P00@_l00`00000005So001Ho`02001Ho`8000000`0K
0?l00`0000009`3o02L0o`0702L0o`030000000l0?l0?03o00D0?03o0`00
000P0?ooo`030000003oool0oooo0200oooo001n0?ooo`030000003oool0
oooo02`0oooo0P0000030?l0W08000000`3o0:T200000080o`2g10000003
0?l0_08000000P3o0<l200000080o`3V0P0000020?h0o`80000000<0g`3o
0000000000000`0000020940o`T000000P005?l200000004000lo`000000
05oo001Oo`8000000P00O_l01000000009Go002Eo`000004002Vo`030000
0000[_l00:ko008000001000jol00`0000000>7o003Qo`02003Qo`030000
0000cOl00<go00<00<go00<00000002ao`0000001000k?l00`0000000<3o
0030o`040030o`0300000000S?l0000000D00;co0P000005001fo`040000
0000W_l00000000000D004;o0`000002001Ho`8000001P0K0?l00`000000
9`3o02L0o`0702L0o`030000000l0?l0?03o00@000000P3o0>l00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo0200oooo001n0?ooo`030000
003oool0oooo02X0oooo0P0000030?l0W08000000`3o0:T2000000@0o`2g
0P0000020?l0b1/000000P0o0?l3000000<001Co00@00000000lo`000000
00000P00Gol00`00000007ko001no`020000008009Go00@00000002Vo`00
Y_l00:Ko0P000003002^o`0600000000[_l0000000000000jol000001000
hOl00`0000000<go003=o`03003=o`0600000000/Ol00;7o002ao`000000
0>co0P0000060030o`0500000000S?l008co002<o`0000000`00_?l00`00
000007Ko001fo`06001fo`0300000000@_l004;o00L004;o0`00000801/0
o`030000000W0?l09`3o00H09`3o100000070?l0k`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0803oool007h0oooo00<000000?ooo`3o
ool0:03oool7000000<0o`2Y0`0000030?l0]`8000000P3o0<P2000000<0
o`3K0P0000020?l0lP8000000P3c0?l2000000030=H0o`00000000000080
]@3o0P0000001@2@0?l000000000001Y0?l0000000<0?`3o00<0000001@0
o`0000000P005?l200000003000lo`00000005oo008005oo00@00000001n
o`00O_l000000`00UOl01@0000000:Ko002Vo`00Y_l0000000@00:ko00<0
0000002^o`00[_l00P00[_l2000000800>7o0P000005003=o`0300000000
/Ol00;7o00<00;7o00<000000030o`00`?l01000`?l2000000D008co00<0
0000002lo`0000002000M_l00`00000002co000000070012o`<0000000<0
6`3o0000000000001`0K0?l00`0000009`3o02L0o`0302L0o`8000000P2c
0?l00`000000o`3_0?l0k`060?l0k`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0803oool007h0oooo00<000000?ooo`3oool09P3oool2
000000<0o`2V0P0000020?l0/`@000000`3o0;L200000080o`380P000003
0?l0f`8000000P3o0?8200000080l`3o0P0000000`3F0?l0000000000002
0;D0o`80000000<0T03o0000000000000P1Y0?l00`000000?`3o03l0o`04
00000003000Do`0000000000008003co00<00000001Oo`00Gol00P000002
001no`0500000000UOl009Go002Eo`0000000`00Y_l0100000000:ko002^
o`00[_l2000000@00:ko00<00000002Vo`00Y_l00P000006003=o`030000
0000/Ol00;7o00<00;7o00<00000002=o`0000001000`?l00`00000008co
002<o`06002<o`0300000000M_l007Ko00D007Ko0P000002000/o`030000
0000@_l004;o00@004;o00D0000001T0o`0I0?l06@3o0000000201/0o`<0
0000100K0?l00`0000009`3o02L0o`03000000@0/`3o00<000000?l0k`3o
0>l01P3o0>l00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0200
oooo001n0?ooo`030000003oool0oooo02@0oooo0P0000030?l0YP800000
103o0;<3000000030?l0`@000000000000D000000`3o0=/200000080o`3b
0P0000020?<0o`80000000<0eP3o0000000000000P2e0?l2000000030900
o`00000000000080J@3o0P0000000`0o0?l000000000000A0000008009Go
00<00000002Vo`00Y_l00P000003002^o`0300000000[_l00:ko00<00:ko
00L00000002Vo`00Y_l00:Ko00000000UOl0000000@00<go00<00000002a
o`00/Ol00`00/Ol01000000008go002=o`00SOl2000000030030o`000000
08co00H008co0P0000000`00Dol00000001fo`04001fo`0300000000;?l0
02co00<002co00@000000012o`00@_l004;o0P00000401T0o`030000000K
0?l06`3o00<06`3o0P00000201/0o`<00000202c0?l00`000000o`3_0?l0
k`050?l0k`030000003oool0oooo01d0oooo00<000000?ooo`3oool0803o
ool007h0oooo00<000000?ooo`3oool08P3oool2000000<0o`2V0P000004
0?l0/`<000000P3o0<4200000080o`3B0P0000020?l0iAl0000000<01P3o
0000000000000P006_l200000003000ho`000000000000<0057o00<00000
001Uo`00IOl01P000003002^o`0300000000[_l00:ko00800:ko0P000003
002Vo`0400000000UOl009Go002Eo`80000000<00<go00000000/Ol00`00
/Ol2000000H008go00<00000002<o`00S?l01@00S?l01@00000005?o001C
o`00Dol0000000@007Ko00<00000000/o`00;?l01000;?l01000000004;o
00000000000701T0o`030000000K0?l06`3o00<06`3o100000000`260?l0
00000;<0o`070;<0o`030000003o0>l0o`3_00H0o`3_00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0P0?ooo`00OP3oool00`000000oooo
0?ooo`0P0?ooo`8000000P3o0:h4000000<0o`2c0`0000020?l0`@800000
0P3o0=82000000@0o`3U0P0000020?l0nP80000000<0k@3o000000000000
0P3A0?l200000080]03o0P0000000`2C0?l00000000000020740o`800000
00D0C@3o000000000000:@3o0000000200H0o`05000000006_l001[o000J
o`0000000P00>?l010000000057o001Ao`00DOl20000008006Go0P000002
001bo`0300000000NOl007Wo00<000001000[_l00`0000000:Ko002Vo`02
002Vo`0300000000UOl009Go00@009Go00<00000002ao`00/Ol00P00/Ol0
0`00000008go002=o`05002=o`0300000000H_l0000000@008co0P000005
001Co`0400000000M_l00000000000P002co00<0000001T0o`0I0?l01`0I
0?l00`0000006`3o01/0o`03000000@0QP3o0P0000090;<0o`030000003o
0>l0o`3_00D0o`3_00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0P0?ooo`00OP3oool00`000000oooo0?ooo`0N0?ooo`800000103o0:h2
00000080o`2k1@0000000`3o0<400000000000020?l0dP800000103o0>D2
00000080o`3j0P0000000`3]0?l00000000000020=40o`8000000P2d0?l2
0000000309<0o`00000000000080L@3o0P0000000`1=0?l0000000000002
02T0o`04000000060?l01P3o000000<001[o00@00000000ho`00>?l00000
0`00DOl01@00000006Go001Uo`00IOl0000000<007;o00<00000001io`00
NOl00P00NOl01P00000007Wo0000000000000:ko000000@00:Ko00<00000
002Eo`00UOl00`00UOl200000005001no`0000000000002ao`0000001P00
SOl2000000<006;o00@00000002<o`00000000002000Dol00`00000002co
000/o`06000/o`80000000<07@3o0000000I0?l01`0I0?l3000000T0QP3o
0P0000070;<0o`030000003o0>l0o`3_00D0o`3_00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0P0?ooo`00OP3oool00`000000oooo0?oo
o`0L0?ooo`800000103o0:h2000000@0o`2k0`0000000`3o0<T000000000
0005000000<0o`3U0P0000020?l0nP80000000<0k@3o0000000000000P3A
0?l200000080]03o0P0000000`2C0?l00000000000020740o`80000000<0
C@3o0000000000000P0Y0?l20000000300H0o`0000000000008001[o0P00
00000`00>?l0000000000003001Ao`0500000000IOl006Go001Uo`000000
0P00L_l2000000<007Wo0P000004001io`0300000000Y_l00:Ko00800:Ko
00<00000002Eo`00UOl00`00UOl00`00000007ko001no`03001no`030000
0000SOl008go00@008go00<00000001Ro`00H_l01000H_l00`00000005?o
001Co`06001Co`80000000<001Ko00000000;?l01000;?l2000000<07@3o
00<0000001T0o`0I0?l0100I0?l200000080KP3o00<0000008H0o`260?l0
1`260?l00`000000/`3o00000002000000030;<0o`000000000000<00000
1`3o0>l00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0200oooo
001n0?ooo`030000003oool0oooo01/0oooo0P0000030?l0[P800000103o
0;/300000080o`390P0000020?l0fP8000000P3o0>`[00000080057o0P00
0002001Uo`8000000P00L_l00`00000007Wo001io`02001io`0300000000
NOl007Wo00<007Wo00H00000001bo`0000000000002Vo`000004002Eo`80
00001@00O_l00`00000005oo00000004002=o`0300000000H_l006;o00<0
06;o0P0000000`00<_l00000001Co`05001Co`03000000005_l001Ko0080
01Ko00<00000000/o`00;?l00P00000601d0o`030000000I0?l06@3o00<0
00001@1^0?l00`000000QP3o08H0o`0608H0o`L00000103o0>D2000000D0
o`3_00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0O0?ooo`00
OP3oool00`000000oooo0?ooo`0I0?ooo`8000000P3o0;D4000000<0o`2k
100000000`3o0<T00000000000020?l0fP800000103o0>`200000080o`3o
0P0000000`3X0?l00000000000020=00o`8000000P2e0?l00`000000V03o
09P0o`0200000080NP3o0P0000000`1K0?l000000000000203`0o`800000
00<07`3o0000000000000P030?l20000008001Go00<00000000Zo`00:_l0
1`000002001bo`0300000000NOl007Wo008007Wo00<00000001io`00NOl0
0`00NOl00`00000007;o001bo`02001bo`8000000P00UOl2000000H007ko
00H00000001Oo`00Gol005oo00000000SOl2000000D006;o00D00000000b
o`00<_l003;o00000004001Co`8000001P005_l2000000T07@3o0P000008
06h0o`03000000260?l0QP3o00@0QP3o0P0000020=`0o`030000003o0>D0
o`3U0080o`3U0`0000000`3o0>D000000?l0L@02000000<0o`3_00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0O0?ooo`00OP3oool00`00
0000oooo0?ooo`0H0?ooo`030000003o0;D0o`2e0080o`2e0P0000020?l0
`PP000000P3o0=X2000000@0o`3/0P0000020?l0o`80000000<0j03o0000
000000000P3@0?l2000000<0]@3o00@0000009P0o`2H0?l000000`1j0?l0
10000000F`3o05/0o`00000303`0o`040000000O0?l07`3o000000<00`3o
00D00000000Eo`005Ol001Go00000002000Zo`8000000`00>_l00`000000
04Ko0016o`030000008007Wo0P000004001io`8000000`00L_l200000080
06Go0P000006001no`8000001@00Gol00`00000006;o001Ro`03001Ro`80
00001@00<_l01000000005?o000000000006000Fo`80000000<09P3o0000
000M0?l01P0M0?l20000000306<0o`000000KP3o00P0KP3o00<0000008H0
o`260?l00`0000050=`0o`030000003o0>D0o`3U00@0o`3U0`0000020?l0
L@80000000<0o`3_0000003oool07@3oool00`000000oooo0?ooo`0O0?oo
o`00OP3oool00`000000oooo0?ooo`0F0?ooo`8000000`3o0;D2000000@0
o`320`0000000`3o0=000000000000020?l0g`<000000`3o0>`200000080
o`3o0P0000000`3X0?l00000000000020=00o`8000000`2e0?l200000080
V03o00D0000007X0o`1j0?l0NP3o0000000205/0o`050000000l0?l0?03o
03`0o`0000000P0O0?l01@0000000`3o00<0o`030?l00000008001Go0P00
0002000Zo`0300000000>_l003[o008003[o00D000000016o`00A_l004Ko
00000002001<o`8000001@00NOl00`00000007;o001bo`02001bo`030000
0000IOl006Go008006Go00<00000001Ao`0000001000O_l00`00000005oo
001Oo`03001Oo`80000000@003co00000000000006;o0P000008000bo`03
000000005_l001Ko00D001Ko00D0000002H0o`0V0?l09P3o0000000501d0
o`800000101S0?l00`000000KP3o06h0o`0606h0o`<00000203L0?l00`00
0000o`3U0?l0i@060?l0i@<000000P3o0743000001d0oooo00<000000?oo
o`3oool07`3oool007h0oooo00<000000?ooo`3oool05@3oool200000080
o`2e0P0000040?l0`PH000000`3o0=l200000080o`3a3`0000030;D0o`03
0000002H0?l0V03o008000000P1j0?l20000000305/0o`00000000000080
?03o0P0000000`0O0?l000000000000200<0o`8000000P005Ol01@000000
02[o000Zo`00:_l0000000<003[o0P0000030016o`0600000000C?l004co
001<o`00000004co0P000002001io`0300000000L_l007;o008007;o00<0
0000001Uo`00IOl00P00IOl010000000057o001Ao`00DOl200000003001n
o`00000005oo00@005oo00<00000000lo`00??l00`00??l00`00000003;o
000bo`06000bo`80000000<0003o000000005_l00`005_l2000000D09P3o
00<0000001d0o`0M0?l00P00000606<0o`030000001^0?l0KP3o00@0KP3o
0P0000020;L0o`030000003L0?l0g03o00L0g03o00<000000?l0i@3o0>D0
0`3o0>D8000000030?l0L@000000000001`0oooo00<000000?ooo`3oool0
7`3oool007d0oooo00<000000?ooo`3oool0503oool200000080o`2j0`00
00030?l0`PH00000103o0=l010000000o`3a0?l0l@3o0?42000000<0n`3o
0P0000000`3W0?l00000000000020=00o`8000000P2h0?lI0000008001Go
00<00000000Zo`00:_l00P000003000jo`0400000000A_l004Ko0016o`80
00000`00C?l00`00000004co001<o`02001<o`<000000P00L_l2000000<0
06Go0P000006001Ao`0300000000Gol005oo00<005oo00<00000000lo`00
??l00`00??l00`00000001Co00000005000bo`80000010000?l010000000
01Ko00000000000802H0o`8000002@1S0?l00`000000KP3o06h0o`030000
00@0]`3o00<000000=`0o`3L0?l01P3L0?l7000000@0o`2Y00<000000?l0
E03o05@01`00000I0?ooo`030000003oool0oooo01l0oooo001m0?ooo`03
0000003oool0oooo0180oooo0P0000030?l0^P8000000P3o0<L8000000<0
o`3O0P0000020?l0l@8000000`3k0?l200000080i`3o00<000000=00o`3@
0?l00P0000040;P0o`80000000<0WP3o0000000000000P240?l200000003
06T0o`00000000000080C`3o0P0000000`0f0?l000000000000201h0o`80
00000P090?l6000000<003[o00D000000016o`00A_l004Ko00000003001<
o`8000001000C?l20000008004Ko0P000004001Uo`0300000000DOl0057o
00@0057o0P0000001000>?l0000000000000Gol2000000D003co00@00000
000Do`005?l001Co0P0000000`00<_l00000000000070000o`030000000V
0?l09P3o00H09P3o0P0000000`1P0?l0000006<0o`0806<0o`<00000202g
0?l010000000g03o0=`0o`3L0?l4000000<0o`3U00<000000?l0Z@3o0:T0
1P3o0:T2000000<0o`1D2000000E0?ooo`030000003oool0oooo01l0oooo
001m0?ooo`030000003oool0oooo0100oooo0P0000040?l0^P040000003o
0<L0o`370?l0a`80000000<0o`3D0000000000000P0000020?l0h`L00000
0`3k0?l200000080i`3o0P0000000`3@0?l00000000000040;P0o`800000
00<0WP3o0000000000000P240?l20000000306T0o`000000000000<0C`3o
00@0000003H0o`0f0?l000000`0N0?l0100000002@3o00T0o`090?l20000
00030007o`0000000000008001Go100000020016o`0500000000C?l004co
001<o`0000001@00C?l00`00000004Ko0016o`020016o`0600000000>_l0
000000000000IOl000001P00DOl00`00000003So000ho`03000ho`030000
0000??l003co00<003co0P000006000Do`03000000000?l0003o00D0003o
0P0000000`0b0?l0000002H0o`0402H0o`800000101P0?l00`000000H`3o
06<0o`0406<0o`8000000P2Q0?l00`000000]`3o0;L0o`060;L0o`@00000
203o0>D00`000000o`2Y0?l0Z@030?l0Z@`000000P3o04H3000001<0oooo
00<000000?ooo`3oool07`3oool007d0oooo00<000000?ooo`3oool03`3o
ool2000000<0o`2j0P0000020?l0a`80000000<0o`3D0000000000000P00
00040?l0h`80000000<0o`3d0000000000000P3j0?l;000000<0^03o0P00
00000`2N0?l000000000000208@0o`80000000<0J@3o000000000000101?
0?l010000000=P3o03H0o`00000301h0o`05000000090?l02@3o00T0o`00
00000P001ol00`00000001Go000Eo`02000Eo`8000000P007ol300000080
04co00<00000001<o`00C?l00`00C?l00`00000004Ko0016o`020016o`03
00000000>_l003[o008003[o00<00000001Ao`00DOl00`00DOl2000000@0
03So0P0000000`006_l00000000lo`02000lo`03000000005?l001Co00@0
01Co0P0000000`0D0?l000000000o`030000o`800000100b0?l200000003
02H0o`000000000000L0H03o00<0000006<0o`1S0?l00`0000050:40o`04
0000002g0?l0]`3o0;L0o`@000000P3a0?l00`000000o`3U0?l0i@060?l0
i@L000001@3o08H2000000<0o`16100000030?l0?P8000004@3oool00`00
0000oooo0?ooo`0O0?ooo`00O@3oool00`000000oooo0?ooo`0=0?ooo`80
00000P3o0;l700000080o`3D0`0000040?l0h`8000000P3o0?@00`000000
nP3o0?X0o`020?X0o`8000000P3V0?l2000000030=80o`00000000000080
_03o3P00000304l0o`80000000<0=P3o0000000000000P0N0?l2000000<0
2@3o00@000000007o`001ol0000010005Ol01000000001oo000Oo`007ol2
0000008002Co0`000003001<o`8000000`00A_l2000000<003[o0P000000
1000:_l0000000000000DOl2000000D003So00<00000000Jo`006_l00P00
6_l00`00000003co00000006000Do`030000000D0?l0503o0080503o00@0
00000000o`0000000000200b0?l00`000000H03o0600o`080600o`800000
202Q0?l4000000L0l@3o00@000000?l0i@3o0>D0o`3U100000030?l0^`03
0000003o08H0o`2600H0o`261@0000040?l0?PL000003`3oool00`000000
oooo0?ooo`0O0?ooo`00O@3oool00`000000oooo0?ooo`0<0?ooo`040000
003o0;l0o`2o0?l0_`8000000P3o0</200000080o`3H100000030?l0h`80
00000P3o0?@2000000<0nP3o0P0000020>H0o`80000000<0dP3o00000000
0000102l0?l2000000030:H0o`00000000000080S`3o0P00000207P0o`03
0000001Q0?l0H@3o00/000000P090?l2000000030007o`000000000000@0
01Go00D00000000Oo`007ol001oo00000003000To`8000000P009?l30000
00@004Ko00<00000000jo`00>_l00P00>_l00`00000002[o000Zo`03000Z
o`0300000000>?l003So00@003So00<00000000Jo`006_l010006_l00`00
000001Co000Do`03000Do`8000001P0D0?l00`000000<P3o0380o`060380
o`80000000<0H`3o0000001P0?l01P1P0?l20000000309H0o`000000X@3o
00D0X@3o0P0000020=H0o`030000003a0?l0l@3o00H0l@3o100000080?l0
^`040000003o08H0o`260?l0QP@000000`3o0742000000<0o`0n1P000000
0`3o03T0000000000002000000`0oooo00<000000?ooo`3oool00P3oool5
000001P0oooo001m0?ooo`030000003oool0oooo00X0oooo0P0000020?l0
_`8000000`3o0</00`000000o`3H0?l0f00400000080o`3V200000020?X0
o`8000000P3V0?l2000000030=80o`000000000000@0_03o0P0000020:H0
o`030000002?0?l0S`3o008000000`1h0?l010000000H@3o0640o`1Q0?l2
0000000304/0o`00000000000080=`3o0P00000202D0o`H000000`005Ol2
000000<001oo00D00000000To`009?l002Co00000004000To`80000000D0
01oo00000000000004Ko00000004000jo`0300000000:_l002[o008002[o
0P0000000`005Ol0000000000002000ho`8000001@006_l20000000400H0
o`0000000000000Do`8000001P0D0?l20000000303l0o`000000<P3o00@0
<P3o0P00000306<0o`030000001P0?l0H03o00<0H03o0P00000409H0o`03
0000002Q0?l0X@3o00<00000103F0?l00`000000l@3o0?40o`040?40o`80
00000P3o0>800`000000o`2k0?l0^`070?l0^`@000001`3o0745000000<0
o`0i1@0000030?l0=P<000002@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo01P0oooo001m0?ooo`030000003oool0oooo00P0oooo
1P0000030?l0b`8000000P3o0=P00`000000o`3H000000030?l0iP800000
0`3o0?D200000080n@3o2P0000030;`0o`8000000P2V0?l20000000308l0
o`000000000000<0N03o0P0000020640o`80000000<0B`3o000000000000
0`0g0?l0100000009@3o02D0o`0U0?l2000000805P3o00<0000000/0o`0;
0?l010000002000Oo`8000000`009?l00`00000002Co000To`02000To`03
000000007ol001oo00<001oo0P000002000jo`8000001000:_l00`000000
01Go000Eo`03000Eo`8000001@006_l2000000D01P3o00<0000001@0o`0D
0?l01@0D0?l00`000000?`3o03l0o`0203l0o`030000000b0?l0<P3o0080
00001P1S0?l00`000000H03o0600o`02000000L0UP3o0P0000080=H0o`03
0000003a0?l0l@3o00<000001@3o0>82000000<0o`2k100000020?l0W@80
00000`3o0744000000@0o`1R100000050?l0=P<000000`3o03<2000000P0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`00
O@3oool00`000000oooo0?ooo`060?ooo`8000000P3o0<8200000080o`3>
100000000`3o0=P000000000000200000080o`3V0P0000030?l0m@800000
0`3i0?l200000080j03o0P0000000`3E0?l00000000000020<80o`/00000
0`1h0?l00`000000H@3o0640o`020000000304/0o`000000000000@0=`3o
00<0000002D0o`0U0?l00P00000301H0o`040000000;0?l02`3o00/0o`80
00000P020?l30000008002Co0P000004000To`03000000007ol001oo0080
01oo0P000002000Eo`8000001@00:_l00`00000001Go000Eo`03000Eo`80
000000@00`3o00000000000001[o0P00000500H0o`80000000<0:@3o0000
000D0?l00`0D0?l2000000H0?`3o0P00000806<0o`<000001`2F0?l20000
00030<@0o`000000eP3o00L0eP3o0`0000080?l0hPD000001`3o09d40000
00D0o`1R0`0000020?l0F08000000P3o03H3000000<0o`0c0`0000020?l0
<@8000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01P0oooo001m0?ooo`030000003oool0oooo00@0oooo0P0000030?l0`P03
0000003o0<h0o`3>0080o`3>0P0000000`3o0=X0000000000006000000<0
o`3e0P0000040?T0o`030000003X0?l0j03o008000000P3E0?l00`000000
`P3o0<80o`020<80o`8000000P2^0?l200000080V@3o00<0000008D0o`25
0?l02P00000303L0o`80000000<09@3o0000000000000`0F0?l2000000<0
2`3o00@000000080o`020?l00P3o0P0000020001o`<000000`009?l20000
00@001oo00@00000000Eo`005Ol001Go0P00000010001ol0000000000000
:_l2000000D001Go00<0000000<0o`030?l00`030?l00`0000001P3o00H0
o`0400H0o`030000000Y0?l0:@3o0080:@3o00@0000001@0o`0000000000
1P0o0?l20000000306T0o`000000H`3o00D0H`3o0P0000020940o`030000
002F0?l0UP3o00<0UP3o0P0000040<@0o`040000003F0?l0eP3o0=H0o`@0
00000P3o0?l2000000<0o`3R100000030?l0`@8000000`3o09d400000080
o`270P0000020?l0HP<000001@3o05P4000000<0o`0c0`0000020?l0<@<0
000000@0o`0a0000000000000000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01P0oooo001m0?ooo`030000003oool0oooo0080
oooo0P0000030?l0`P800000103o0<h01@000000o`3J0?l0fP000000o`3J
0080000000<0o`3W0000000000000P3o0?H4000000<0n@3o0P0000000`3X
0?l00000000000020=D0o`8000000`320?l200000080[P3o0P00000309T0
o`04000000250?l0Q@3o08D0o`80000000<0L@3o0000000000000P1O0?l0
0`000000CP3o04h0o`07000000<05P3o00<0000000/0o`0;0?l00P0;0?l0
1@0000000P3o0080o`020?l0000000@0007o00<000000001o`000Ol00`00
0005000Oo`05000000005Ol001Go000Eo`0000001@001ol00`00000001Go
000Eo`03000Eo`80000010030?l20000000301l0o`0000001P3o00<01P3o
00<0000002T0o`0Y0?l0100Y0?l00`000000?`3o03l0o`0503l0o`030000
001Y0?l0J@3o0080J@3o00<0000006<0o`1S0?l00`0000050940o`030000
002F0?l0UP3o008000001P340?l4000000L0o`3o100000080?l0`@@00000
1`3o08L3000000@0o`1H100000040?l0D0<000001P3o034400000080o`0_
0`0000000`3oool000000?ooo`030?ooo`8000006P3oool007d0oooo00<0
00000?ooo`3oool00P0000020?l0a@@000000`3o0<h2000000030?l0fP00
00000000008000000P3o0>L00`000000o`3f0?l0mP020?l0mP8000000P3j
0?l;00000080`P3o0P0000020:h0o`8000000`2I0?l200000080Q@3o0P00
00000`1a0?l000000000000305l0o`040000001>0?l0CP3o04h0o`800000
0P0n0?l00`000000<@3o0340o`04000000802`3o0P0000030080o`030000
00000Ol0007o0080007o00@000000001o`000Ol0007o0P00000010020?l0
0000000000007ol2000000<001Go00<000000007o`001ol00P001ol20000
000400T0o`0000000000000Eo`8000001@030?l00`0000007`3o01l0o`02
01l0o`04000000060?l00000000000D0:@3o0P0000000`1=0?l0000003l0
o`0403l0o`030000001Y0?l0J@3o00@0J@3o0P0000080940o`<000001P34
0?l200000080k03o00<000000?l0o`3o0?l0103o0?l200000080o`3L00<0
00000?l0`@3o0<40103o0<4300000080o`2W0P0000030?l0Q`@000000`3o
07L4000000D0o`1@0`0000020?l0BP8000000P3o0343000000<0o`0_1000
00020?l0;P800000803oool007d0oooo00<000000?ooo`000000103o0<D2
00000080o`3@200000020?l0i`800000103o0?H010000000nP3o0?X0o`3j
0?l200000080jP3o0P0000020=T0o`8000000P380?l7000000<0V@3o00<0
000008D0o`250?l00P0000000`1a0?l000000000000305l0o`8000000P1>
0?l2000000<0?P3o00@000000340o`0a0?l0<@3o0P00000202L0o`<00000
0P020?l2000000<0007o0P0000030001o`03000000020?l00P3o00<00P3o
0P000002000Eo`80000010001ol00`0000002@3o00T0o`0300T0o`030000
00030?l00`3o00@00`3o00<0000001l0o`0O0?l0100O0?l00`000000:@3o
02T0o`0302T0o`800000101=0?l20000000303l0o`000000000000D0J@3o
0P0000000`2@0?l000000940o`050940o`8000000P2j0?l200000080a03o
0`0000050>`0o`030000003o0?l0o`3o00<000001@3o0=`00`000000o`31
0?l0`@03000000H0o`2W100000050?l0M`8000000P3o06/200000080o`1@
0`0000050?l0BP@000000`3o02l3000000<0o`0^1@00000P0?ooo`00O@3o
ool2000000@0o`3500<000000?l0d03o0=000P3o0=02000000030?l0f`00
0000000000H000000`3o0?H200000080nP3o0P0000030>X0o`050000003I
0?l0f@3o0=T0o`0000000`380?l200000080]P3o0P0000020:@0o`X00000
0`1O0?l00`000000CP3o04h0o`02000000<0?P3o0P0000030340o`040000
000W0?l09`3o02L0o`8000000P0Q0?l3000000<0007o00<000000001o`00
0Ol00P000Ol00`0000000P3o0080o`020080o`8000000P0;0?l2000000D0
00Oo00<0000000T0o`090?l00P090?l20000000301h0o`00000000000080
0`3o0P00000501l0o`80000000@0?03o000000000000:@3o0P00000804d0
o`030000001Y0?l0J@3o00<0J@3o0P0000040900o`030000002A0?l0T@3o
00<000001P2j0?l2000000P0k03o0`0000080?l0g0<000001`3o0:L20000
0080o`2C0P0000020?l0M`<000001@3o06/3000000@0o`1:100000040?l0
A@<000000`3o02h3000000<0oooo0P00000P0?ooo`00O03oool2000000<0
o`350P0000040?l0d0030000003o0=/0000000<000000P3o0>P200000080
o`3e1`0000030>X0o`8000000P3I0?l2000000<0b03o00D000000;H0o`2f
0?l0]P3o000000040:@0o`80000000<0TP3o0000000000000P210?l00`00
0000L@3o0740o`07000000<0?P3o00<000000340o`0a0?l00P0a0?l01@00
00009`3o02L0o`0W0?l0000000<08@3o0P00000201d0o`@000000P000Ol2
000000<00P3o0P00000300/0o`80000000@05P3o00000000000000Oo0P00
000400T0o`030000000N0?l07P3o00<07P3o0P00000501l0o`8000001@0l
0?l00`000000C@3o04d0o`0604d0o`80000000@0L@3o000000000000J@3o
0P0000070900o`8000001`2j0?l2000000030=l0o`000000k03o00D0k03o
0P0000020?l0l@8000000`3o0=`400000080o`310P0000030?l0Y`<00000
1@3o09<3000000H0o`1[0P0000030?l0HP@000001P3o04D2000000<0o`11
0`0000040?ooo`8000008P3oool007`0oooo00<000000?ooo`0000000`00
00030?l0d0H000000`3o0>P00`000000o`3e0?l0m@020?l0m@80000000<0
o03o0000000000000P3]0?l800000080b03o0P0000020;H0o`8000000`2T
0?l200000080TP3o00D000000840o`210?l0P@3o000000030740o`800000
0P1R0?l00`000000E@3o05D0o`0400000080<@3o0P00000302L0o`050000
000Q0?l08@3o0240o`000000100M0?l2000000807@3o0`0000020080o`80
0000100;0?l00`0000005P3o01H0o`0301H0o`03000000090?l02@3o00<0
2@3o00<0000001h0o`0N0?l00`0N0?l20000000403H0o`000000000001l0
o`8000001@0l0?l20000000305/0o`000000C@3o00@0C@3o0P0000050740
o`030000002@0?l0T03o00D0T03o0P0000000`2e0?l000000;X0o`040;X0
o`800000103O0?l00`000000k03o0>`0o`03000000D0o`3a100000080?l0
`@<000001P3o09<200000080o`240P0000020?l0J`<000000`3o06820000
0080o`1J0P0000030?l0A@<000000`3o0442000000D0oooo0P00000T0?oo
o`00O03oool00`000000oooo0?ooo`030?ooo`L000000`3o0>P2000000<0
o`3e0P0000020?`0o`030000003]0?l0k@3o0080k@3o0P0000020=h0o`80
00000P3>0?l700000080Y03o0P0000020980o`8000000P210?l200000080
L@3o0P0000030680o`040000001E0?l0E@3o05D0o`8000000P1:0?l30000
00809`3o0P0000020240o`800000100M0?l0100000007@3o01d0o`0M0?l2
000000808@3o0P00000500/0o`030000000F0?l05P3o00805P3o0P000000
100U0?l00000000000090?l2000000@07P3o0P00000503H0o`030000000l
0?l0?03o00<0?03o0P00000405/0o`030000001=0?l0C@3o008000001@1a
0?l20000000309<0o`000000T03o00<0T03o0P0000040;D0o`030000002j
0?l0^P3o008000001P3O0?l3000000H0o`3a0P0000020?l0eP030000003o
0<40o`3100@0o`310`0000020?l0Z`8000000P3o09<3000000D0o`240`00
00030?l0HP<000001P3o05X3000000<0o`110`0000040?ooo`<000009P3o
ool007`0oooo00<000000?ooo`3oool01@3oool2000000<0oooo20000002
0?`0o`800000103]0?l00`000000gP3o0=h0o`02000000<0cP3o0P000002
0;h0o`8000000P2^0?l700000080P@3o00<000000740o`1a0?l00P000003
0680o`8000000P1E0?l2000000<0BP3o0P0000020480o`H000001@0M0?l0
1@0000007@3o01d0o`0M0?l0000000<08@3o0P000000100W0?l000000000
000;0?l2000000<05P3o0P00000502D0o`8000000`0N0?l2000000D0=P3o
0P000000101?0?l000000000000l0?l2000000L0F`3o0P0000050740o`80
0000102C0?l010000000T03o0000000000060;D0o`<000001P3O0?l20000
0080oP3o0P0000020?l0l@<000001@3o0=H00`000000o`310?l0`@030000
00H0o`2[0`0000040?l0Q0@000000`3o07P3000000H0o`1J0`0000030?l0
E0<000001@3oool2000002T0oooo001l0?ooo`030000003oool0oooo00<0
oooo0P00000=0?ooo`<000000`3]0?l2000000030=h0o`000000000000@0
cP3o00<000000;h0o`2n0?l00P0000030:h0o`8000000P2N0?l200000080
T03o1P0000030680o`030000001E0?l0E@3o008000000`1:0?l2000000<0
@P3o0P00000203`0o`80000000@0>@3o0000000000007@3o0P00000301d0
o`050000000Q0?l08@3o0240o`0000001@0W0?l2000000805P3o0P000005
02D0o`8000000P0g0?l3000000D0=P3o0P00000504l0o`030000001K0?l0
F`3o00D0F`3o0P0000000`1j0?l00000000000020740o`8000001P2C0?l2
000000H0]@3o0P0000020=H0o`8000000`3O0?l2000000D0oP3o0`000008
0?l0eP<000001`3o0:/2000000<0o`2J100000050?l0N08000000P3o06h2
00000080o`1J0`0000030?l0E0<000001P3oool2000002/0oooo001l0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool70000
00<0cP3o0P0000000`2n0?l00000000000040:h0o`030000002N0?l0WP3o
008000000`2@0?l2000000030880o`00000000000080M@3o1`00000204X0
o`80000010120?l01@000000?03o03`0o`0l0?l0000000D0>@3o0P000002
01d0o`8000000`0Q0?l00`0000009`3o02L0o`0202L0o`8000000P0a0?l2
000000H09@3o00<0000003L0o`0g0?l00P0g0?l20000000404/0o`000000
000003H0o`8000001@1?0?l20000000306T0o`000000F`3o00<0F`3o0P00
000507X0o`8000001P2C0?l200000080]03o0P0000020;D0o`8000001P3F
0?l3000000D0oP3o0P0000020?l0iP8000000`3o0=H400000080o`2o0P00
00030?l0Z`<000000`3o09X200000080o`2;0P0000020?l0N0<000001@3o
06h3000000<0o`1D0`0000060?ooo`<00000;@3oool007`0oooo00<00000
0?ooo`3oool00P00000J0?ooo`L000000`2^0?l20000000309h0o`000000
000000@0T03o00@000000880o`220?l00000101e0?l200000080J@3o00<0
00000600o`1P0?l00`0000030480o`8000000`0l0?l00`000000>@3o03T0
o`0203T0o`8000000P0i0?l3000000808@3o0P00000402L0o`030000000a
0?l0<@3o0080<@3o00@0000003h0o`00000000000P0U0?l2000000@0=`3o
00<0000004/0o`1;0?l00`1;0?l00`000000C`3o04l0o`0304l0o`800000
101Y0?l010000000F`3o00000000000507X0o`80000000<0V03o00000000
00000`2C0?l2000000H0]03o0P0000060=H0o`8000000P3c0?l200000080
oP3o0P0000060?l0iP<00000203o0;l3000000<0o`2J0`0000050?l0R`<0
00001P3o06h2000000<0o`1U0`0000070?ooo`800000<03oool007`0oooo
0`00000S0?ooo`L000000`2@0?l2000000030880o`000000000000<0M@3o
0P00000306T0o`030000001P0?l0H03o008000000P1I0?l400000080?03o
0P00000303T0o`8000000`0i0?l200000080?03o0`00000302L0o`800000
100a0?l00`000000?P3o03h0o`0203h0o`8000001@0g0?l00`000000B`3o
04/0o`0204/0o`80000000@0H@3o000000000000C`3o0P00000706T0o`03
0000001j0?l0NP3o00<0NP3o0P00000509P0o`<000001P2d0?l200000003
0=40o`00000000000080eP3o0`0000060?<0o`8000001P3o0>H200000080
o`3?0P0000030?l0_`@000000`3o0:`3000000H0o`2;0P0000020?l0O`80
00000P3o06h3000000<0o`1U0P0000080?ooo`800000<P3oool007`0oooo
0P00000[0?ooo`L000000P1e0?l2000000<0J@3o0P0000020600o`030000
001I0?l0F@3o0080F@3o0P00000205@0o`<000000P0i0?l2000000@0>@3o
00@0000003`0o`0l0?l0?03o0P0000020480o`<00000100a0?l2000000@0
?P3o0P000000101>0?l000000000000g0?l2000000@0B`3o00<000000640
o`1Q0?l00`1Q0?l00`000000J@3o06T0o`0506T0o`80000000@0Q03o0000
00000000NP3o0P00000609P0o`80000000<0]@3o0000002d0?l00`2d0?l2
000000D0d@3o0P0000070?<0o`80000000<0o`3b0000000000000P3o0>H3
000000D0o`3?100000050?l0[08000000P3o09`200000080o`2;0`000005
0?l0O`<000000`3o06D3000000L0oooo0`00000d0?ooo`00OP3oool30000
02l0oooo0`00000306T0o`030000001P0?l0H03o008000000`1I0?l20000
00<0E03o0P0000020540o`<000000`0i0?l2000000<0?03o00<000000480
o`120?l00P120?l20000000504X0o`00000000000340o`000000100n0?l2
000000D0CP3o00<0000004/0o`1;0?l00`1;0?l00`000000H@3o0640o`02
0640o`80000000<0N03o0000001Y0?l00`1Y0?l2000000D0Q03o00<00000
09P0o`2H0?l0102H0?l2000000@0]@3o00@000000;@0o`00000000001@3A
0?l2000000030>d0o`000000l`3o00@0l`3o0P0000050?l0lP8000001P3o
0<l200000080o`2l0P0000020?l0[0<000001@3o09`3000000H0o`1o0P00
00030?l0M@<00000203oool2000003L0oooo00210?ooo`@00000;P3oool7
00000080F@3o0P00000405@0o`040000001A0?l0D@3o0540o`8000000P1A
0?l400000080?03o0P0000040480o`030000001:0?l0BP3o00<0BP3o0P00
000203h0o`8000001@1>0?l20000000405l0o`000000000004/0o`800000
0`1Q0?l2000000@0N03o00@0000006T0o`00000000001@240?l200000003
09h0o`00000000000080V03o0P0000060;D0o`8000001@3A0?l2000000@0
k@3o00<000000?<0o`3c0?l00P0000050?l0lP80000000<0o`3K00000000
00000P3o0<l3000000D0o`2l0`0000060?l0W08000000P3o08l200000080
o`1o0`0000030?l0M@8000002@3oool2000003T0oooo00250?ooo`<00000
<P3oool3000000<0E03o0P0000030540o`030000001A0?l0D@3o0080D@3o
0P00000205@0o`8000001@120?l00`000000BP3o04X0o`0204X0o`800000
0P1E0?l2000000D0CP3o0P00000505l0o`8000000P1Q0?l2000000H0N03o
0P00000508@0o`8000001@2N0?l2000000H0]@3o0P0000020=00o`800000
00<0d@3o0000000000001P3]0?l3000000D0o`3b0P0000040?l0f`<00000
1P3o0;`200000080o`2[0P0000020?l0W0<000001@3o08l3000000<0o`1e
0`0000080?ooo`<00000>`3oool008P0oooo0`00000b0?ooo`@000000P1A
0?l2000000<0D@3o0P00000305@0o`80000000@0F@3o000000000000@P3o
0P00000304X0o`8000000`1E0?l2000000040680o`000000000004h0o`80
00001@1O0?l200000080L@3o0P00000607P0o`8000000P2?0?l200000003
08@0o`000000000000D0WP3o0P0000000`2h0?l00000000000020;D0o`<0
00001@3@0?l2000000H0k@3o0P0000020?l0nP8000000P3o0?82000000@0
o`3K0P0000020?l0b08000000P3o0;`3000000D0o`2[0`0000060?l0S`80
00000`3o08@3000000T0oooo0P00000n0?ooo`00R`3oool400000380oooo
0`0000020540o`800000101D0?l00`000000F@3o05T0o`0305T0o`800000
0P1:0?l2000000<0E@3o0P0000050680o`030000001O0?l0G`3o00<0G`3o
0P0000030740o`80000000<0Q@3o0000000000000P1h0?l2000000D0S`3o
0P00000509h0o`800000102h0?l3000000H0d03o0P0000020>P0o`800000
0P3]0?l2000000D0o`3j0`0000030?l0f`<000001@3o0<P3000000H0o`2[
0P0000020?l0W@8000000P3o08l3000000<0o`240P0000090?ooo`<00000
@03oool008l0oooo0`00000b0?ooo`8000001@1D0?l00`000000F@3o05T0
o`0205T0o`8000000P1P0?l300000080E@3o0P0000050680o`80000000@0
L@3o000000000000G`3o0P0000030740o`8000001@250?l2000000D0S`3o
0P0000020:H0o`80000000<0WP3o000000000000102h0?l200000080d03o
0P0000020=00o`<000001@3X0?l3000000D0o`3j0P0000030?l0i@<00000
1P3o0<P200000080o`2g0P0000020?l0Z`<000001@3o09d3000000<0o`24
0`0000090?ooo`800000@`3oool00980oooo0`00000a0?ooo`80000000<0
E03o0000000000000`1I0?l2000000<0H03o0P00000206T0o`8000001@1R
0?l2000000D0L@3o0P0000020740o`8000001@250?l20000000309T0o`00
000000000080S`3o0P0000050:H0o`<000000`2h0?l2000000D0d03o0`00
00060>P0o`8000000P3o0?l200000080o`3j0P0000030?l0i@8000000P3o
0=8200000080o`380`0000050?l0]`<00000103o09d4000000<0o`2A0`00
000:0?ooo`800000A@3oool009D0oooo0`00000`0?ooo`8000000P1I0?l2
000000@0H03o00@0000006T0o`1Y0?l0J@3o0P000000101e0?l000000000
001R0?l2000000D0L@3o0P0000020840o`8000001@250?l2000000D0V@3o
0P0000050:H0o`8000000`2l0?l3000000D0d03o0P0000020>L0o`800000
0`3X0?l2000000D0o`3o0`0000030?l0i@8000001@3o0=83000000H0o`2g
0P0000030?l0Z@@000001@3o0942000000X0oooo0`0000170?ooo`00V03o
ool4000002h0oooo0`0000030600o`8000000`1Y0?l00`000000M@3o07D0
o`0307D0o`030000001a0?l0L@3o00@0L@3o00@000000840o`210?l0P@3o
0P000000102B0?l00000000000250?l2000000D0V@3o0P0000000`2^0?l0
0000000000020:H0o`800000102l0?l2000000030=80o`00000000000080
d03o0P0000060>L0o`<000001@3o0?l2000000<0o`3/0`0000050?l0dP80
00000P3o0<4200000080o`2g0`0000030?l0Z@8000000P3o09`200000080
o`2A0`00000:0?ooo`800000BP3oool009`0oooo0`00000^0?ooo`@00000
0P1Y0?l2000000@0M@3o0P0000000`220?l00000000000020740o`800000
0`210?l00`000000TP3o0980o`030980o`030000002I0?l0V@3o00<0V@3o
0P0000050:h0o`800000102l0?l2000000D0dP3o0P0000060>L0o`800000
0P3k0?l200000080o`3o0P0000040?l0k080000000<0o`3J000000000000
0P3o0=82000000D0o`310`0000030?l0Z@<000001@3o09`3000000/0oooo
0P00001<0?ooo`00W`3oool3000002l0oooo0P00000507D0o`0300000022
0?l0PP3o00<0PP3o0`0000020840o`800000102B0?l2000000040:@0o`00
0000000009T0o`8000001@2^0?l2000000040<80o`00000000000;`0o`80
00001@3B0?l2000000030>H0o`00000000000080i`3o0`0000050?/0o`<0
0000103o0>`2000000@0o`3J0`0000050?l0`@8000000`3o0;<3000000H0
o`2L0P00000;0?ooo`<00000CP3oool00:80oooo0`00000^0?ooo`800000
00<0M@3o00000000000010220?l2000000<0T03o0P0000050980o`030000
002T0?l0Y03o00<0Y03o00<000000:h0o`2^0?l0102^0?l00`000000`P3o
0<80o`030<80o`030000003B0?l0dP3o00<0dP3o0P0000040>H0o`<00000
1P3k0?l200000080o`3a0P0000000`3o0>`00000000000040?l0fP800000
0P3o0<T200000080o`310P0000030?l0/`8000000P3o0:H200000080o`2L
0`00000;0?ooo`800000D@3oool00:D0oooo1000000/0?ooo`8000000`22
0?l2000000@0T03o0P000000102N0?l000000000002B0?l2000000@0Y03o
0P0000000`2f0?l00000000000020:h0o`80000010320?l2000000040=D0
o`00000000000=80o`800000103V0?l200000080nP3o0P0000020?/0o`<0
00001@3o0?43000000<0o`3J0P0000050?l0b@<000000`3o0;<2000000D0
o`2V0`00000<0?ooo`800000D`3oool00:T0oooo0`00000[0?ooo`<00000
102@0?l2000000@0WP3o0`0000030:@0o`8000001@2f0?l3000000<0`P3o
0P0000050=D0o`8000000`3V0?l2000000D0nP3o0`0000060?l0l@800000
0`3o0=l3000000D0o`390P0000030?l0^`<000001@3o0:H2000000`0oooo
0`00001E0?ooo`00[03oool3000002X0oooo0P0000000`2@0?l000000000
000409h0o`8000000`2^0?l3000000D0]P3o0P0000030<P0o`<000001@3E
0?l200000080j03o0`0000050?X0o`8000000P3o0?@200000080o`3a0`00
00030?l0g`8000000P3o0=0200000080o`390P0000030?l0^`8000000P3o
0:h200000080o`2V0P00000<0?ooo`800000F03oool00:l0oooo1000000X
0?ooo`8000000`2N0?l2000000@0[P3o0P0000000`2n0?l0000000000002
0;H0o`80000010380?l2000000030=T0o`00000000000080e@3o0P000003
0>P0o`80000000<0n@3o0000000000000P3j0?l2000000D0o`3d0`000003
0?l0g`<000001@3o0=03000000<0o`2k0P0000050?l0[P<00000303oool2
000005X0oooo002c0?ooo`<000009`3oool3000000@0[P3o0P0000040;h0
o`<0000010380?l2000000@0f@3o0`0000040>P0o`030000003i0?l0n@3o
00<0n@3o0P0000050?l0m08000000`3o0><3000000H0o`3@0P0000030?l0
`P<000001@3o0:h2000000`0oooo0`00001L0?ooo`00]P3oool3000002H0
oooo0P0000000`2^0?l00000000000040;h0o`8000000P3>0?l200000003
0<P0o`000000000000@0f@3o0P0000020>X0o`80000000<0j03o00000000
0000103i0?l2000000030?l0m@00000000000080o`3d0P0000030?l0h`80
00000P3o0=@200000080o`3@0`0000030?l0`P8000000P3o0;D00`000000
o`2^0?l0[P03000000`0oooo0P00001O0?ooo`00^@3oool3000002D0oooo
0P0000030;h0o`8000001@3>0?l3000000<0f@3o0P0000050>X0o`<00000
0`3i0?l2000000D0o`3e0P0000030?l0h`8000001@3o0=@3000000<0o`32
0`0000040?l0]@<000003@3oool200000640oooo002l0?ooo`@000008`3o
ool3000000D0cP3o0P0000030=h0o`<000001@3Z0?l2000000<0nP3o0`00
00050?l0m@8000000P3o0>H3000000D0o`3D0P0000030?l0a`<000001@3o
0;D2000000d0oooo0`00001S0?ooo`00`03oool300000280oooo0P000002
0<h0o`800000103N0?l2000000030>d0o`00000000000080jP3o0P000003
0?X0o`8000000P3o0?H200000080o`3e0P0000030?l0iP80000000<0o`3H
0000000000000P3o0=@2000000<0o`370P0000020?l0^P8000000P3o0;D2
000000d0oooo0P00001V0?ooo`00``3oool300000240oooo0P0000040=h0
o`800000103]0?l3000000<0nP3o0P0000050?l0mP<000000`3o0>H20000
00D0o`3H0P0000030?l0a`8000001@3o0;X3000000d0oooo0P00001X0?oo
o`00aP3oool3000001l0oooo0P0000000`3N0?l00000000000040>d0o`80
00000`3l0?l3000000D0o`3f0P0000030?l0i`<000001@3o0=P200000080
o`3;0`0000050?l0^P8000003@3oool3000006X0oooo00390?ooo`@00000
7@3oool2000000<0k@3o0P0000030?`0o`8000000P3o0?D200000080o`3f
0P0000030?l0i`8000000P3o0=X200000080o`3H0P0000020?l0b`800000
0P3o0;l200000080o`2j0P00000=0?ooo`800000K@3oool00<d0oooo0`00
000L0?ooo`<000000`3l0?l2000000D0o`3e0`0000030?l0i`8000001@3o
0=X300000080o`3;0P0000050?l0_`<000003@3oool2000006l0oooo003@
0?ooo`<00000703oool3000000D0o`3e0P0000030?l0j0<000001@3o0=X2
00000080o`3>0`0000050?l0_`8000003@3oool300000740oooo003C0?oo
o`@000006P3oool200000080o`3e0P0000030?l0j08000000P3o0=/20000
0080o`3J0P0000030?l0cP80000000<0o`320000000000000P3o0;l20000
00d0oooo0P00001d0?ooo`00e`3oool3000001T0oooo0P0000030?l0j080
00001@3o0=/3000000<0o`3>0P0000040?l0`P<00000303oool3000007H0
oooo003J0?ooo`<00000603oool3000000D0o`3K0P0000030?l0d0<00000
0`3o0<83000000d0oooo0P00001i0?ooo`00g@3oool3000001L0oooo0P00
00020?l0f`8000000`3o0=02000000<0o`350`00000>0?ooo`800000N`3o
ool00>00oooo1000000E0?ooo`8000000`3o0=02000000<0o`350P00000>
0?ooo`<00000O@3oool00>@0oooo0`00000D0?ooo`<000000`3o0<D20000
00h0oooo0P0000200?ooo`00i`3oool3000001@0oooo0`00000>0?ooo`80
0000PP3oool00>X0oooo0`00000B0?ooo`030000003oool0oooo00X0oooo
0`0000240?ooo`00k@3oool4000000h0oooo00<000000?ooo`3oool0203o
ool2000008L0oooo003a0?ooo`<000002`3oool00`000000oooo0?ooo`06
0?ooo`800000R@3oool00?@0oooo0`0000080?ooo`030000003oool0oooo
00<0oooo0`00002;0?ooo`00m`3oool4000000@0oooo00@000000?ooo`3o
ool0oooo0P00002>0?ooo`00n`3oool3000000030?ooo`000000oooo0080
0000T03oool00?h0oooo0`00002B0?ooo`00o`3ooonD0?ooo`00o`3ooonD
0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3o
oonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 208},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function U[t] and use the Poisson integral to construct  ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[
    \(\(\(\(U[t_]\  = \ t\^2;\)\ \[IndentingNewLine]
    \(G[t_] = 
        y\/\[Pi]\ \(\[Integral]\(U[t]\/\(\((x - t)\)\^2 + 
                    y\^2\)\) \[DifferentialD]t\);\)\[IndentingNewLine]
    \(H[t_] = 
        y\/\[Pi]\ \(\[Integral]\(1\/\(\((x - t)\)\^2 + 
                    y\^2\)\) \[DifferentialD]t\);\)\[IndentingNewLine]
    \(\[Phi][x_, y_]\  = \ 
        H[\(-1\)] - H[\(-\[Infinity]\)] + G[1] - G[\(-1\)] + H[\[Infinity]] - 
          H[1];\)\[IndentingNewLine]
    \(\[Phi][x_, y_]\  = \ 
        Expand[Simplify[\[Phi][x, y], y > 0]];\)\[IndentingNewLine]
    \(Print["\<  U[t]  =  \>", 
        U[t], \*"\"\<  for  -1 \[LessEqual] \!\(t\^2\) \[LessEqual] \
1\>\""];\)\ \ \ \n
    \(Print["\<  U[t]  =  1   for  |t| \[GreaterEqual] 1\>"];\)\ \ \ \
\[IndentingNewLine]
    \(Print["\< \>"];\)\ \n
    \(Print[\*"\"\<\[Phi][x,y]  =  \!\(y\/\[Pi]\) \!\(\[Integral]\_\(-\
\[Infinity]\)\%\[Infinity]\)\!\(U[t]\/\(\((x - t)\)\^2 + y\^2\)\)\
\[DifferentialD]t\>\""];\)\ \ \n
    \(Print["\< \>"];\)\ \n
    \(Print["\<\[Phi][x,y]  =  \>", \[Phi][x, y]];\)\)\(\ \)\)\)], "Input",
  FormatType->TraditionalForm],

Cell["We can verify some of the boundary values by taking limits.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print["\<     \[Phi][x,y] = \>", \[Phi][x, y]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) \[Phi][-2,y] = \>\"", 
        Limit[\[Phi][\(-2\), y], \ y \[Rule] 0]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) \[Phi][\!\(\(-1\)\/2\),y] = \
\>\"", Limit[\[Phi][\(-1\)\/2, y], \ 
          y \[Rule] 0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) \[Phi][0,y] = \>\"", 
        Limit[\[Phi][0, y], \ y \[Rule] 0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) \[Phi][\!\(1\/2\),y] = \
\>\"", Limit[\[Phi][1\/2, y], \ y \[Rule] 0]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) \[Phi][2,y] = \>\"", 
        Limit[\[Phi][2, y], \ y \[Rule] 0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(cont = Table[k, {k, 0, 1, 1\/10}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Phi][x, y], {x, \(-2\), 2}, {y, 0.000001, 2}, 
        Contours \[Rule] cont, PlotPoints \[Rule] 35, 
        AspectRatio \[Rule] 1\/2, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[Phi][x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Then use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[\[Phi][x, y], {x, \(-2\), 2}, {y, 0.00001, 1.5}, 
        PlotPoints \[Rule] {41, 16}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\[Phi]\>"}, 
        ColorFunction \[Rule] Hue, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 1.5, 0.5], 
            Range[\(-1\), 3, 0.5]}, ViewPoint \[Rule] {\(-2.5\), \(-3\), 2}, 
        AxesEdge \[Rule] {{\(-1\), \(-1\)}, {\(-1\), \(-1\)}, {1, \
\(-1\)}}];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Therefore, the function  ",
  Cell[BoxData[
      \(\[Phi][x, y]\)]],
  "  is harmonic in the upper half-plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  ",  and takes on the desired boundary values."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the function ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  " that is harmonic in the upper half-plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  ", which takes on the boundary values  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(\[Phi] \((x, 0)\) = x\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "    ", "-", "1"}], "<", "x", "<", 
            "1"}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}], "\[IndentingNewLine]", 
      RowBox[{\(\[Phi] \((x, 0)\) = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          StyleBox["for",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", "|", "x", "|", 
          RowBox[{">", 
            RowBox[{"1", 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000d2000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD
0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00g`3o
ool200000;80oooo003M0?ooo`<0000000<0oooo000000000000603oool5
000009<0oooo003L0?ooo`040000003oool0oooo000000<0oooo0P00000H
0?ooo`030000003oool0oooo09<0oooo003K0?ooo`050000003oool0oooo
0?ooo`0000001@3oool2000001H0oooo00<000000?ooo`3oool0T`3oool0
0=T0oooo0P0000040?ooo`030000003oool0oooo00D0oooo0P00000<0?oo
o`@00000103oool00`000000oooo0?ooo`2C0?ooo`00f03oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo0P00000B0?ooo`03
0000003oool0oooo09<0oooo003F0?ooo`8000001`3oool00`000000oooo
0?ooo`090?ooo`8000003`3oool2000009D0oooo003E0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool02`3oool300000:<0oooo003D
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03P3oool2
000003@0oooo0P0000000`3oool000000000001X0?ooo`00dP3oool20000
00/0oooo00<000000?ooo`3oool0403oool2000003<0oooo00<000000?oo
o`000000J@3oool00=40oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0B0?ooo`800000<P3oool00`000000oooo0?ooo`1X0?ooo`00
c`3oool2000000h0oooo00<000000?ooo`3oool0503oool2000002h0oooo
0P0000000`3oool000000000001X0?ooo`00cP3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo01H0oooo0P00002I0?ooo`00c03oool2
00000140oooo00<000000?ooo`3oool0603oool2000009L0oooo003;0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0603oool01000
0000oooo00000000002E0?ooo`00bP3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo01`0oooo0`00002B0?ooo`00Y`3oool2000000@0
oooo0P0000030?ooo`@000000`3oool2000000d0oooo0P00000E0?ooo`03
0000003oool0oooo01l0oooo0P00002@0?ooo`00YP3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0240oooo0P00002>0?ooo`00YP3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool20000
01P0oooo00<000000?ooo`3oool08`3oool2000008`0oooo002V0?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool00P3oool20000
00T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0U0?oo
o`800000RP3oool00:H0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00L0oooo0P0000280?ooo`00Y`3oool2000000X0oooo0P0000040?oo
o`<000001@3oool2000001`0oooo00<000000?ooo`3oool0703oool30000
00X0oooo0P0000260?ooo`00`03oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01`0oooo00@000000?o7003oa`0000002`3oool30000
08<0oooo002n0?ooo`80000000<0oooo000000000000703oool00`000000
oooo0?ooo`0K0?ooo`8000000P3oa`000`000000oooo0?ooo`0<0?ooo`80
0000P@3oool00;d0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0J0?ooo`800000103oa`000`000000oooo0?ooo`0=0?ooo`800000
5@3oool2000006P0oooo002l0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool06@3oool00`000000dOl0000000050?o700030000003o
ool0oooo00h0oooo0P00000B0?ooo`040000003oool0oooo000006L0oooo
002j0?ooo`8000008`3oool00`000000oooo0?ooo`0I0?ooo`8000001`3o
a`000`000000oooo0?ooo`0?0?ooo`800000403oool010000000oooo0?oo
o`00001W0?ooo`00^@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo01P0oooo00<000000=7o000000001P3oa`000`000000oo/00000
000B0?ooo`8000003P3oool010000000oooo0?ooo`00001W0?ooo`00]`3o
ool2000002H0oooo00<000000?ooo`3oool05`3oool00`000000dOl00000
00060?o700050000003on`00oo/00?ok000000004`3oool2000000`0oooo
00@000000?ooo`3oool00000I`3oool008X0oooo0P00000Z0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool05`3oool00`000000dOl0
000000050?o700030000003on`00oo/000<0oo/000<000000?ooo`3oool0
4P3oool3000000X0oooo0P00001X0?ooo`00R`3oool00`000000oooo0?oo
o`0V0?ooo`800000:@3oool00`000000oooo0?ooo`0F0?ooo`030000003A
o`00000000D0olL000<000000?ok003on`001@3on`000`000000oooo0?oo
o`0D0?ooo`800000LP3oool008`0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo00@00000
0=7o003Ao`000000103oa`000`000000oo/00?ok00070?ok00030000003o
ool0oooo01D0oooo0P00001`0?ooo`00R`3oool00`000000oooo0000000T
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool05@3oool0
0`000000dOl000000003000000030?o700000000oo/000P0oo/000<00000
0<Go00000000603oool2000006h0oooo002:0?ooo`040000003oool0oooo
00000280oooo0P00000]0?ooo`030000003oool0oooo01@0oooo00@00000
0=7o0000000000000`3Io`000`000000oo/00?ok00070?ok000500000035
o`00aOl00<Go000000006@3oool2000006`0oooo00290?ooo`<0000000<0
oooo000000000000803oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo01<0oooo0`0000001`00od4000000=Wo003Io`0000000<Ko0000
00001`3on`000`000000aOl00<Go00020<Go00030000003oool0oooo01T0
oooo0P00001Z0?ooo`00[@3oool200000300oooo00<000000?ooo`3oool0
4P3oool2000000<00?m100<000000=Wo000000000`36o`000`000000oo/0
0?ok00030?ok000300000035o`00aOl000@0aOl000<000000?ooo`3oool0
6P3oool2000006P0oooo002@0?ooo`800000103oool2000000@0oooo0P00
000>0?ooo`030000003oool0oooo0300oooo0P00000C0?ooo`0700000000
od400?m1003o@@000000fOl0000000050<Ko00050000003on`00oo/00?ok
000000002035o`000`000000oooo0?ooo`0J0?ooo`<00000IP3oool008l0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000<
0?ooo`030000003oool0oooo02l0oooo0`0000001000ooX0000000000000
000?0?ooo`0300000000od400?m100800?m100<000000=Wo000000001P36
o`000`000000oo/00000000:0<Go00030000003oool0oooo01X0oooo00<0
00000?ooo`0000000P00001S0?ooo`00S`3oool010000000oooo0?ooo`00
000;0?ooo`030000003oool0oooo00P0oooo0P00000`0?ooo`8000000P00
ooX00`0000000?oj003onP02003onP<000002`3oool00`0000000?m1003o
@@02003o@@030000003Io`00000000P0a_l000<000000<Go0035o`001`35
o`0200000003087o00000000oooo01l0oooo0P00001Q0?ooo`00S`3oool0
10000000oooo0?ooo`0000090?ooo`8000002P3oool00`000000oooo0?oo
o`0^0?ooo`8000001000ooX0100000000?oj003onP00ooX2000000800?og
0P0000080?ooo`8000001000od42000000P0a_l000<0000009Wo00000000
1`35o`000`000000POl0087o0002087o00030000003oool0oooo01l0oooo
0P00001O0?ooo`00S`3oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo00L0oooo0P00000`0?ooo`8000001@00ooX0100000000?oj
000000000006003om`8000001@3oool2000000D00?m100<000000<Ko0036
o`001P36o`0010000000VOl009Wo002Io`02000000@0aOl000<00000087o
0021o`001021o`000`000000oooo0?ooo`0P0?ooo`800000G@3oool00900
oooo0P00000:0?ooo`<000001P3oool00`000000oooo0?ooo`0^0?ooo`80
00000P00onl3000000800?oj0P000007003om`80000000<00?ob00000000
00000P3oool00`0000000?lf00000004003o@@030000002?o`00000000H0
a_l000<0000009Wo002Io`00102Io`0010000000aOl0000000000008087o
00030000003oool0oooo0240oooo0P00001K0?ooo`00Y03oool00`000000
oooo0?ooo`0]0?ooo`8000001`00onl3000000H00?og0P000005003olP80
000000<00?lf00000000od401000od400`000000Sol008oo0002000000<0
a_l000<0000009Wo002Io`001P2Io`000`000000POl0087o0009087o0003
0000003oool0oooo0280oooo0P00001I0?ooo`00XP3oool2000000030?oo
o`000000oooo02/0oooo0P000007003ok`8000000P00onL3000000800?og
0P000008003olP<000001@00od400`000000Sol008oo000208oo00030000
0036o`00000000P0VOl000<00000067o000000002021o`020000000303co
00000000oooo02@0oooo0P00001G0?ooo`00X@3oool00`000000oooo0?oo
o`0/0?ooo`8000000P00onD2000000<00?o_0P000004003oi`0300000000
onL00?oW00@000001@00oo83000000<00?oS0`0000000`00od40000008oo
000508oo00030000002Io`00VOl000H0VOl000D00000067o001Qo`00HOl0
00000006087o00030000000lo`00??l00080??l000<000000?ooo`3oool0
903oool3000005@0oooo002O0?ooo`800000;P3oool00`0000000?oU003o
i@04003oi@<000001P00onL0100000000?oW000000000003003of@H00000
1P00on<4000000D0Sol000<0000006oo000000001P2Io`000`000000HOl0
067o0003067o000300000021o`00POl00080POl000<0000003co000lo`00
0`0lo`000`000000oooo0?ooo`0W0?ooo`800000503oool5000003T0oooo
002N0?ooo`030000003oool0oooo02`0oooo0P000006003oi@8000000P00
omT3000000<00?oW0P000005003of@8000001000ok@6000000P0Sol000@0
000006oo001_o`00Kol00P00000309Wo00030000001Qo`00HOl000D0HOl0
00@00000087o0000000000001`0lo`000`000000oooo0?ooo`0X0?ooo`80
0000503oool00`000000oooo0?ooo`0i0?ooo`00W@3oool00`000000oooo
0?ooo`0/0?ooo`8000001P00onD00`0000000?oI003of@05003of@@00000
1000omT2000000<00?nd10000000101Fo`00000000000000000708oo0080
00001P1_o`000`000000VOl000000009067o00030000000lo`00??l000P0
??l000<000000?ooo`3oool0:@3oool200000180oooo00<000000?ooo`3o
ool0>@3oool009/0oooo0P00000]0?ooo`8000000P00om`2000000800?oU
0P000006003of@8000000`00ol@;000000D0E_l000@0000005ko00000000
0000102?o`000`000000Kol006oo000706oo00030000001Qo`00HOl000L0
HOl000<0000002Co000000002P0lo`000`000000oooo0?ooo`0Z0?ooo`80
0000403oool00`000000oooo0?ooo`0i0?ooo`00VP3oool00`000000oooo
0?ooo`0[0?ooo`8000001P00om`4000000@00?oI0P000005003oa0<00000
0`00oiH20000000301oo00000000E_l000@0E_l000<0000005ko001No`00
0P1No`020000000308oo00000000Kol000L0Kol00P0000000`11o`000000
067o0006067o00050000000To`009?l002Co000000001`0lo`0200000003
003o20000000oooo02`0oooo0P00000>0?ooo`030000003oool0oooo03T0
oooo002H0?ooo`800000;03oool2000000L00?oL0P000003003oc@D00000
1@00ol@2000000<00?nF0P00000201oo00030000001Fo`00E_l000<0E_l0
00<0000005ko001No`001@1No`000`000000Kol006oo000606oo00030000
0011o`00@Ol00080@Ol000<00000067o001Qo`000`1Qo`000`0000009?l0
02Co000202Co00030000000lo`00??l000@0??l000<00000003o2000o`P0
0P00o`P00`000000oooo0?ooo`0/0?ooo`8000002`3oool2000003/0oooo
002G0?ooo`030000003oool0oooo02/0oooo0P000007003og00300000000
old00?o=00<00?o=0P000003003o]0/000000P0Oo`000`000000E_l005Ko
000305Ko00030000001No`00G_l000D0G_l000@0000004So000000000000
1@1_o`000`000000@Ol0047o0004047o00050000001Qo`00HOl0067o0000
00001P0To`000`000000??l003co000203co000300000000o`P00?l800@0
0?l800<000000?ooo`3oool0;@3oool3000004D0oooo002E0?ooo`800000
;03oool2000000800?oD0`000002003og08000001@00old00`0000000?nd
003o]004003o]08000000`00ohH30000000301oo00000000000000<00000
0`1Fo`000`000000G_l005ko000505ko000300000018o`00B?l00080B?l0
0P0000000`1_o`00000000000008047o00030000001Qo`00000000P09?l0
00@0000003co0000000000002000o`P00`000000oooo0?ooo`0_0?ooo`80
0000@`3oool009@0oooo00<000000?ooo`3oool0:`3oool00`0000000?oD
003oe005003oe0@000000`00old2000000D00?nd0P000003003oQPH00000
00<00?l00000000Zo`000P0Zo`04000000D0G_l00P00000704So00030000
0011o`00@Ol000T0@Ol000<0000002Co000To`00200To`000`0000000?l8
003o2009003o20030000003oool0oooo0300oooo0P0000110?ooo`00T`3o
ool00`000000oooo0?ooo`0Z0?ooo`8000001`00om@2000000<00?o41@00
0003003o]080000000<00?n60000000000000`0000000`00od800000003o
0002003o00030000000Zo`00:_l000<0:_l000<0000003Go000eo`000P00
000205ko000300000018o`00B?l000H0B?l000<0000002?o000000002011
o`020000000300co000000009?l000H09?l00P0000000`00oaX00000003o
2007003o2080000000<00?m?0000003oool0<P3oool2000003l0oooo002A
0?ooo`800000;03oool3000000D00?oD0P000005003oa08000000`00ojT8
000000<00?m20P0000000`00o`0000000000000502[o00030000000eo`00
=Ol000<0=Ol00P00000804So00050000000So`008ol002?o000000001P11
o`000`0000003?l000co000200co00800000100To`000`0000000?lJ003o
6P02003o6P0300000000o`P00?l800@00?l800<00000003oC`00odl00P00
odl00`000000oooo0?ooo`0b0?ooo`800000?@3oool00900oooo00<00000
0?ooo`3oool0:P3oool2000000<00?o>1P000004003oa08000001@00ojT2
000000<00?mo00@00000003o@P00od800?m20P0000000`00o`0000000000
000502[o008000001P0eo`000`0000009_l00000000604So00030000000S
o`008ol000<08ol000<00000047o0011o`000P11o`000`0000003?l000co
000500co00040000000To`000000000000H00?lJ00<00000003o2000o`P0
0P00o`P00`0000000?m?003oC`03003oC`030000003oool0oooo03@0oooo
0P00000k0?ooo`00SP3oool2000002/0oooo0P000006003ocP8000000`00
okd5000000@00?nY0P000003003oO`8000000`00od800`0000000?l00000
0004000000<0:_l000<0000003Go000eo`001@0eo`00100000009_l002Ko
000Vo`02000000<0B?l000<0000002?o000So`001@0So`0010000000@Ol0
00000000000900co000300000000oaX00?lJ00L00?lJ00@00000003o2000
000000001`00odl00`000000oooo0?ooo`0d0?ooo`<00000>@3oool008d0
oooo00<000000?ooo`3oool0:@3oool2000000L00?o>00<00000003o_@00
okd00`00okd2000000<00?nS400000000`00oaX000000000000200Oo00<0
00001`0eo`000`0000009_l002Ko000402Ko000300000018o`00000000T0
8ol000<0000000co000<o`001`0<o`0200000003003o;00000000?lJ00P0
0?lJ00<00000003oC`00odl02000odl00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo00800000=`3oool008`0oooo00<000000?ooo`3oool0
:03oool2000000800?o90`000002003ocP8000001@00okd00`0000000?nS
003oX`03003oX`8000001000ogd2000000<00?m<0P000003003o6P030000
0007o`00000000<01ol000@00000017o000000000000100eo`000`000000
9_l002Ko000602Ko00030000000So`008ol000H08ol00P0000000`00o`T0
000000co000600co000300000000ob`00?l/00800?l/00<00000003o6P00
oaX01000oaX200000003003oF`0000000?m?00T00?m?00<000000?ooo`3o
ool0=`3oool3000003@0oooo002:0?ooo`800000:P3oool00`0000000?o9
003ob@05003ob@@000000`00okd2000000D00?nS00<00000003oO@00ogd0
0P00ogd2000000@00?m<00<00000003o6P00oaX00P00oaX0100000001ol0
00Oo0000000200Oo00030000000Ao`004Ol000804Ol00P0000000`0eo`00
000002Ko000702Ko000400000008o`000000000000D08ol000<00000003o
2@00o`T00P00o`T2000000@03?l000<00000003o;000ob`01000ob`00`00
00000?lJ003o6P02003o6P0300000000oe/00?mK00800?mK00<00000003o
C`00odl01@00odl200000003003oU@000000oooo03X0oooo0P00000b0?oo
o`00R@3oool00`000000oooo0?ooo`0X0?ooo`8000001`00olT2000000<0
0?nh1@000003003oX`8000000`00ogd2000000@00?m<0P000004003o6P07
00000007o`001ol000Oo000000001ol000000007017o00030000000Vo`00
9_l000H09_l000<0000000So0008o`000P08o`020000000302?o00000000
000000L00?l900@0000000co0000000000002000ob`0100000000?lJ0000
00000006003oF`0300000000odl00?m?00800?m?0P000004003oU@030000
003oool0oooo03X0oooo0P00000C0?ooo`D00000603oool008L0oooo0P00
000Z0?ooo`8000001`00olT00`0000000?nh003o^003003o^08000000`00
oj0@000000<00?lJ00<0000000Oo0007o`000P07o`02000000L04Ol000@0
000000Oo000000000000100Vo`02000000L02?l000<00000003o2@00o`T0
2000o`T00`0000000?l/003o;009003o;00300000000oe/00?mK00L00?mK
00@00000003oC`00000000001`00oiD00`000000oooo0?ooo`0k0?ooo`80
00004`3oool00`000000oooo0?ooo`0H0?ooo`00QP3oool00`000000oooo
0?ooo`0X0?ooo`8000000P00olH3000000800?o90P000005003o^0030000
0000oj000?nP00<00?nP0P000003003oO`8000001@00oeL0100000000?l`
003o<000oc05000000<01ol000<00000017o000Ao`001@0Ao`000`000000
1ol000Oo000200Oo0080000000<09_l000000008o`001`08o`000`000000
0?lO00000008003o2@0300000000oc`0000000P00?l/0P0000000`00ofL0
0000003oF`08003oF`0300000000oiD00?nE00P00?nE00<000000?ooo`3o
ool0?03oool200000140oooo00<000000?ooo`3oool0603oool008D0oooo
00<000000?ooo`3oool0:03oool00`0000000?o6003oaP05003oaP@00000
0`00okP2000000D00?nP00<00000003oO`00ogl00P00ogl00`0000000?mG
003oE`04003oE`0300000000oc000?l`00800?l`0P000003003o5@@00000
1@0Ao`02000000L01ol000<0000000So0008o`001P08o`001@0000000?lO
003o7`00oal0000000H00?l900@00000003o?000oc`00?ll0P000004003o
;08000001000ofL00`0000000?mK003oF`04003oF`80000000<00?nL0000
0000oiD02@00oiD00`000000oooo0?ooo`0m0?ooo`8000001`3oool40000
00@0oooo00<000000?ooo`3oool0603oool008<0oooo0P00000Y0?ooo`80
00001`00olH2000000<00?ne1@000003003oX08000000`00ogl2000000D0
0?mG0P000004003o<00300000000oaD00?lE00@00?lE00<00000003o3000
00000P000002017o000300000007o`001ol000H01ol000@00000003o4@00
000000001008o`02000000D00?lO00@00000003o2@00o`T00?l90P000006
003o?00400000000ob`00000000000L00?mW00<00000003oF`00oe/00P00
oe/00`0000000?nL003oW002003oW00300000000oiD00?nE00D00?nE0P00
00000`00om`000000?ooo`0o0?ooo`8000003@3oool00`000000oooo0?oo
o`0H0?ooo`00PP3oool00`000000oooo0?ooo`0X0?ooo`<000001@00olH2
000000D00?ne0P000003003oWPX000001000oeL00`0000000?l`003o<002
003o<08000001P00oaD0100000000?l<003o30000002003o308000002007
o`000`0000000?lA003o4@02003o4@80000000<02?l000000000oal01`00
oal00`0000000?l900000009003o?00300000000ofL00?mW00P00?mW00@0
0000003oF`00000000001P00oi`00`0000000?nE003oU@02003oU@800000
1000om`00`000000oooo0?ooo`0o0?ooo`8000002P3oool2000001X0oooo
00200?ooo`800000:@3oool2000000<00?o31P000004003o]@8000001@00
oih2000000@00?n200@00000003oH@00of400?mQ2P000005003o5@800000
0`00o``01@0000000?l<003o300000000?lC008000001007o`02000000L0
0?lA00<00000003o7`00oal02000oal00`0000000?ll003o?007003o?003
00000000og80000000X00?mW00<00000003oW000oi`01`00oi`010000000
0?nE000000000007003og0030000003oool0oooo03d0oooo0`00000V0?oo
o`00O`3oool00`000000oooo0?ooo`0W0?ooo`8000001P00ol<2000000<0
0?nc1@000004003oWP8000001000oh82000000D00?mQ0P000004003o@`03
00000000obd00?l]008000000P00oaD00`0000000?l<003o3003003o3003
00000000o``0000000@00?lC0P0000000`07o`000000003o4@07003o4@03
00000000oc<0000000L00?lO0P0000000`00odd00000003o?006003o?005
00000000og800?mb003oLP0000001`00ofL200000003003oX`0000000?nL
00P00?nL00<00000003og000om`02000om`00`000000oooo0?ooo`0j0?oo
o`8000000P3oool00`000000oooo0?ooo`0T0?ooo`00O@3oool2000002T0
oooo0P000006003o``0300000000ok<00?nc00<00?nc0P000003003oW`D0
00001000oh800`0000000?mQ003oH@04003oH@0300000000od<00?m300<0
0?m300<00000003o;@00obd00`00obd3000000D00?l<0P000007003o4`03
00000000oa400?lA00H00?lA00@00000003o<`00oc<00?lc0P000004003o
7`0300000000odd00?m=00800?m=0P000003003o?08000001@00og800`00
00000?mW003oI`02003oI`8000001000oj<00`0000000?nL003oW004003o
W080000000<00?oN00000000om`02@00om`00`000000oooo0?ooo`0g0?oo
o`8000000P3oool3000002H0oooo001l0?ooo`030000003oool0oooo02L0
oooo0P000002003o`P8000000P00ol<2000000D00?nc00<00000003oW`00
oil01000oil0100000000?n6003oQP00ohH6000000<00?mQ0P000004003o
@`8000001@00obd2000000800?lU0P000002003o308000001P00oa<20000
0003003o:0000000000000@00?lA0P000006003o<`0400000000oal00000
000000L00?m=00<00000003o?00000002000og80100000000?mW00000000
0007003oX`0300000000oi`00?nL00800?nL00<00000003ogP00omh00P00
omh00`0000000?oL003og005003og080000000<00=co0000003oool0=@3o
ool2000000H0oooo00<000000?ooo`3oool0903oool007/0oooo00<00000
0?ooo`3oool09`3oool00`0000000?o2003o`P04003o`P@000000`00ok<2
000000D00?nO0P000005003oQP8000000`00of/5000000<00?m300<00000
003o;@00obd01000obd00`0000000?lU003o9@04003o9@@000001@00oa<0
0`0000000?lX003o:003003o:080000000<00?lA00000000oc<02000oc<0
0`0000000?m=003oC@08003oC@0300000000og800?mb00P00?mb00<00000
003oX`00oj<02000oj<0100000000?nL000000000006003ogP0300000000
om`00?oL00800?oL0P000004003Lo`030000003oool0oooo0340oooo0P00
00080?ooo`030000003oool0oooo02@0oooo001i0?ooo`800000:03oool2
000000H00?o20P000003003o/`D000001000oil00`0000000?n6003oQP04
003oQP0300000000of/00?m[00<00?m[0P000003003oD`D000000`00obd2
000000H00?lU0P000002003o:`8000000P00oa<2000000P00?lX00<00000
003o<`00oc<01P00oc<200000003003oG00000000?m=00H00?m=0P000000
0`00ogd00000003oLP06003oLP80000000<00?nZ00000000oj<02@00oj<0
0`0000000?oN003ogP07003ogP0400000000om`00000000000H00=co00<0
00000?ooo`3oool0;`3oool2000000X0oooo00<000000?ooo`3oool0903o
ool007P0oooo00<000000?ooo`3oool09`3oool3000000@00?o20P000006
003o/`0400000000oj400?nQ003oX@H000000`00ohH2000000D00?m[00<0
0000003oD`00oe<00`00oe<2000000<00?m210000006003o9@0300000000
ob/00?l[00800?l[10000008003o:080000000<00?m60000000000001@00
oc<00`0000000?mL003oG002003oG08000001000odd00`0000000?mm003o
O@02003oO@8000001000og800`0000000?nZ003oZP02003oZP0300000000
oj<00?nS00D00?nS0P0000000`00on400000003ogP08003ogP0300000000
g?l00=co00L00=co00<000000?ooo`3oool0;03oool2000000d0oooo00<0
00000?ooo`3oool08`3oool007H0oooo0P00000X0?ooo`8000000`00ol44
000000H00?nc0P000005003oX@8000000`00oh/5000000<00?m[0P000005
003oD`0300000000od800?m200@00?m200<00000003o>`00oc/00P000002
003o9@8000000`00ob/2000000800?l[10000005003o:00300000000odH0
0?m600<00?m60P0000000`00oc<0000000000007003oG00400000000odd0
0000000000L00?mm00@00000003oLP00000000001P00ojX00`0000000?nS
003oX`02003oX`8000001000on400`0000000?oN003ogP04003ogP800000
00<00=ko00000000g?l02000g?l00`000000oooo0?ooo`0Y0?ooo`800000
3`3oool00`000000oooo0?ooo`0S0?ooo`00M@3oool00`000000oooo0?oo
o`0W0?ooo`0300000000ol400?o100@00?o100<00000003o/`00ok<00`00
0002003o/`0300000000oj400?nQ00@00?nQ00<00000003oR`00oh/00`00
oh/2000000<00?me1@000003003oD`8000001P00od800`0000000?lk003o
>`03003o>`8000000`00ob/2000000<00?l[00<00000003o?@00ocd01000
00000`00obP0000000000008003oAP0300000000oe`00?mL00P00?mL00<0
0000003oO@00ogd02000ogd00`0000000?nZ003oZP07003oZP0400000000
oj<00000000000H00?oQ00<00000003ogP00omh00P00omh2000000@00=ko
00<00000003Lo`00g?l01P00g?l2000002P0oooo0P00000A0?ooo`030000
003oool0oooo02<0oooo001d0?ooo`030000003oool0oooo02H0oooo0P00
0005003o`@8000001P00ok<4000000<00?nQ0P000005003oR`0300000000
ogD00?me00<00?me0P000003003oH@@000001@00od82000000H00?lk00<0
0000003o@@0000000P000003003o:`8000001P00ocd2000000P00?m60P00
00000`00ofX00000003oG006003oG080000000<00?n800000000ogd01P00
ogd200000003003o/@0000000?nZ00P00?nZ00<00000003oh@00on401`00
on40100000000?oN000000000007003No`0300000000g?l00=co00<00=co
0P000002002Eo`030000003oool0oooo02<0oooo0P00000C0?ooo`030000
003oool0oooo02<0oooo001b0?ooo`800000:03oool3000000@00?o100<0
0000003o/`00ok<01@00ok<2000000<00?nS1@000003003oR`8000001@00
ogD00`0000000?mQ003oH@03003oH@8000000P00oe<2000000800?m200<0
0000003o>`00oc/01@00oc/00`0000000?m1003o@@0400000003003o:`00
00000?lm00L00?lm00<00000003oE`0000000P000004003oAP0300000000
ofX00?mZ00800?mZ00<00000003oG000oe`00P00oe`2000000@00?n800<0
0000003oO@00ogd00P00ogd2000000@00?na0P000005003oZP80000000<0
0?oS00000000on402000on400`0000000=ko003No`08003No`0300000000
g?l00=co008000001@00UOl00`000000oooo0?ooo`0P0?ooo`8000005@3o
ool00`000000oooo0?ooo`0S0?ooo`00L@3oool2000002L0oooo0P000003
003o`@H000001000ok<2000000D00?nS0P000003003oT@D000000`00ogD2
000000D00?mQ00<00000003oD`00oe<01000oe<3000000D00?lk0P000000
0`00od40000000000004003o@@0300000000ocd00?lm00H00?lm00H00000
003oE`00oeL00?mG00000000odH200000003003oAP0000000?mZ00D00?mZ
00@00000003oG000000000001`00ohP0100000000?mm000000000008003o
/@0300000000ojX00?nZ008000001000on<2000000D00?oQ0P0000000`00
hOl00000003No`08003No`<000002000UOl00`000000oooo0?ooo`0M0?oo
o`8000005`3oool00`000000oooo0?ooo`0S0?ooo`00L@3oool00`000000
oooo0000000200000280oooo0P000006003o`@8000000`00ok@4000000H0
0?nS00<00000003oT@00oi400`00oi42000000<00?mn1@000003003oH@80
00001P00oe<2000000800?m>0P000002003o>`0400000000od400?m10000
00@00?m10P0000000`00oe00000000000004003o?@8000001@00oeL00`00
00000?m600000003000000H00?mZ00<00000003oR000ohP02000ohP00`00
00000?na003o/@09003o/@8000002000on<00`0000000?oQ003oh@020000
00@00>7o0P000005003No`8000000P00W?l00`00000009Go002Eo`07002E
o`030000003oool0oooo01X0oooo0P00000I0?ooo`030000003oool0oooo
02<0oooo001a0?ooo`030000003oool0oooo0080oooo0P00000O0?ooo`80
00001P00ol400`0000000?nd003o]004003o]00300000000ojH00?nV0080
00000P00oj<2000000D00?nA00<00000003oOP00ogh01000ogh010000000
0?m^003oKP00ofh4000000H00?mC00<00000003oCP00odh01000odh50000
00@00?m100<00000003oD000oe000`00oe0200000003003o?@0000000?mG
00L00?mG00<00000003oJP00ofX00P00ofX2000000800?mZ0P0000000`00
oi800000003oR006003oR080000000<00?ng00000000ok401`00ok420000
0003003oi@0000000?oS00P00?oS0P000008003Qo`0300000000g_l00=ko
008000001@00W?l00`00000009Go002Eo`06002Eo`8000006@3oool20000
01/0oooo00<000000?ooo`3oool08`3oool00740oooo00<000000?ooo`3o
ool0103oool3000001/0oooo00<00000003o`@00ol400P000002003o`@80
00001@00ok@2000000D00?nV10000003003oT@8000001@00ogh2000000D0
0?m^00<00000003oH`00of<00P000002003oD`8000001P00odh600000080
0?m10P000008003oD00300000000oeL00?mG00D00?mG0P0000000`00ogL0
000000000004003oJP<000000`00oi82000000@00?n800<00000003o]`00
okL00P00okL2000000@00?na0P000004003oi@0300000000on<00?oS00@0
0?oS0P0000000`00hol00000003Qo`08003Qo`8000002000W?l00`000000
09Go002Eo`03002Eo`8000000P00Col00`000000oooo0?ooo`0D0?ooo`80
00007@3oool00`000000oooo0?ooo`0S0?ooo`00L@3oool00`000000oooo
0?ooo`070?ooo`<000005P3oool2000000D00?o110000004003o]0030000
0000ojH00?nV00@00?nV0P000003003oUPD000001000ogh00`0000000?m^
003oKP03003oKP8000001@00of<3000000H00?m>00<00000003oD`000000
1000oe<2000000P00?m@0P0000000`00ofH00000003oE`04003oE`030000
0000ogL00?mg00<00?mg0P0000000`00ofX0000000000002003oTP800000
0`00oi80100000000?n8000000000007003o]`0400000000ok4000000000
00H00?oU00<00000003oh`00on<00P00on<2000000@00>?o00<00000003Q
o`00hOl01000hOl200000003002So`00000009co00P009co00<00000002E
o`00UOl00P000005001?o`030000003oool0oooo0140oooo0P00000O0?oo
o`030000003oool0oooo02<0oooo001a0?ooo`030000003oool0oooo00X0
oooo0`00000B0?ooo`0300000000ol400?o100@00?o10P000003003o]PH0
00000`00ojH2000000H00?nF00@00000003oQP00ohH00?n61P000003003o
KP0300000000of<00?mS00D00?mS00<00000003oG`00oel00P000002003o
CP@000001000oe<200000003003oH0000000000000D00?m@00<00000003o
IP00ofH00P00ofH200000003003oE`000000000000P00?mg00<00000003o
TP00oi801000oi82000000800?nB00<00000003o]`00okL02000okL00`00
00000?oU003oi@07003oi@0400000000on<00000000000L00>?o00<00000
003Qo`00hOl00P00hOl00`0000000:?o002So`02002So`0300000000W?l0
09co00H009co0`000007001?o`030000003oool0oooo00l0oooo0P00000Q
0?ooo`030000003oool0oooo02<0oooo001a0?ooo`030000003oool0oooo
00d0oooo0`00000>0?ooo`<000000`00ol42000000H00?nf0P000003003o
Z@@000001@00oiH2000000D00?n60P000003003oN@@000001@00of<20000
00D00?mO10000005003oD`0300000000of000?mP00<00?mP0P0000000`00
oe00000000000007003oIP0300000000ogL00?mg00H00?mg0P0000000`00
oi/00000003oTP06003oTP@000001`00okL200000003003oi`0000000?oU
00P00?oU00<00000003So`00hol02000hol0100000000>7o000000000006
002So`0300000000W?l009co00<009co0P000002001Ko`0300000000Col0
04oo00H004oo00<000000?ooo`3oool0303oool2000002<0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0;0?ooo`00L03oool00`00
0000oooo0?ooo`0A0?ooo`8000002P3oool2000000<00?o210000006003o
]P0300000000ojT00?nY00<00?nY0P000002003oV`8000000P00oiH00`00
00000?n6003oQP04003oQP0300000000ogT00?mi00<00?mi0P000002003o
L@8000000P00of<00`0000000?mO003oG`04003oG`<0000000<00?mT0000
000000000P00oe<2000000P00?mP00<00000003oIP00ofH01P00ofH01000
00000?n3000000000005003oM`0300000000oi/00?nK00800?nK0P000004
003oTP0400000000okd00?nm003o_@<000001000okL00`0000000?oW003o
i`02003oi`8000001@00onD200000003003Uo`0000000>?o00P00>?o0P00
0009002So`0300000000W?l009co008000001@00Fol00`00000004oo001?
o`06001?o`030000003oool0oooo00T0oooo0P00000U0?ooo`030000003o
ool0oooo01D0oooo0`00000;0?ooo`00L03oool00`000000oooo0?ooo`0C
0?ooo`<000001@3oool2000000H00?o200<00000003o^000okP00P000002
003o]P8000001@00ojT00`0000000?nK003oV`04003oV`@000000`00ohH2
000000D00?mi00<00000003oL@00og401000og42000000H00?mO0`000004
003oI08000002000of0200000003003oM@000000000000@00?mV0P000004
003oP`80000000<00?mg0000000000001`00oi/0100000000?nB00000000
0006003o_@D000001`00onL00`0000000?oU003oi@02000000@00>Go0P00
0005003So`8000000P00Z_l00`0000000:?o002So`06002So`<000002000
Fol00`00000004oo001?o`03001?o`80000000<000So0000003oool0203o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01<0oooo00D0
00000?ooo`000000oooo0000000:0?ooo`00L03oool00`000000oooo0?oo
o`0F0?ooo`D000001P00ol82000000D00?nh10000003003oZ@8000001P00
oi/2000000<00?n>1@000003003oN@8000001P00og4200000003003oKP00
0000000000800?mO0`000005003oI080000000<00?m_0000000000001@00
of000`0000000?me003oM@03003oM@80000000<00?mV00000000oh<01`00
oh<00`0000000?nK003oV`08003oV`0300000000okd00?nm00P00?nm0`00
0008003oi`8000002000iOl00`0000000>?o003So`02000000D00:[o00<0
0000002So`00Xol00`00Xol20000008006Oo00<00000001Ko`00Fol01`00
Fol00`00000004oo001?o`02000000@000So00<000000?ooo`3oool0103o
ool2000002T0oooo00<000000?ooo`3oool04`3oool01@000000oooo0000
003oool0000000X0oooo001`0?ooo`030000003oool0oooo01P0oooo00<0
0000003o``00ol<00`000002003o`P0300000000okP00?nh00@00?nh0P00
0003003o[0D000001000oi/2000000D00?n>0P000003003oQ0@000001P00
og400`0000000?m^003oKP03003oKP<000001P00of@00`0000000?m_003o
K`03003oK`80000000<00?mP0000000000002000ogD00`0000000?n3003o
P`05003oP`80000000<00?nT0000000000001P00oi/200000003003o``00
0000000000H00?nm0P0000000`00onT00000003oi`03000000<00?oW0P00
00000`00iol00000003Uo`08003Uo`8000002000Z_l00`0000000:?o002S
o`02000000D006Oo00<00000001Ko`00Fol01P00Fol3000000L000So00@0
00000?ooo`3oool0oooo0P00000[0?ooo`030000003oool0oooo01<0oooo
00D000000?ooo`000000oooo0000000:0?ooo`00L03oool00`000000oooo
0?ooo`0F0?ooo`8000001P00ol<4000000<00?nh0P000005003o[0800000
0`00oj44000000H00?n>00<00000003oQ000oh@01000oh@00`0000000?mm
003oO@02000000800?ma0P000006003oKP80000000<00?mb000000000000
0P00of@2000000P00?m_0P000007003oM@80000000<00?n?00000000oh<0
1000oh<00`0000000?nT003oY003003oY08000000P00oi/2000000D00?o3
0P000002003o_@8000001000onT2000000800?oW0`000004003Wo`800000
1@00iOl200000003002ao`0000000:[o00P00:[o0P000008001Wo`030000
0000Fol005_o00<005_o0P000002000Jo`03000000002?l000So00H000So
0`00000]0?ooo`030000003oool0oooo01@0oooo0`00000;0?ooo`00L03o
ool00`000000oooo0?ooo`0E0?ooo`0300000000ol<00?o300D00?o30P00
0003003o^PD000000`00oj`2000000H00?nQ00<00000003oUP00oiH00P00
0002003oSP8000001@00oh@2000000D00?mm0`000005003oKP8000001@00
og82000000P00?m_0P000002003oPP8000000`00ogD2000000@00?n?0P00
00000`00oh<0000000000008003oY08000002@00ol<2000000P00?oY00<0
0000003oi`00000010000004003Wo`0300000000iOl00>Go008000001000
/Ol2000000D00:[o0P0000000`00L_l00000001Wo`08001Wo`0300000000
Fol005_o008000001@006_l00`00000000So0008o`050008o`800000;P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00T0oooo001`
0?ooo`030000003oool0oooo01@0oooo0`000004003o``8000001P00okX0
100000000?n`003o/000ok04000000D00?nQ0P000005003oUP@000001000
oh@00`0000000?mm003oO@04003oO@8000000P00og/2000000800?m^00<0
0000003oLP00og801@00og80100000000?mm000000000005003oK`030000
0000oh800?n200@00?n20`000008003oS`0300000000oj@00?nT00H00?nT
0P0000000`00olP00000003o``06003o``80000000<00?o[00000000onT0
2000onT00`0000000>Oo003Wo`03003Wo`8000000`00iol2000000P00;7o
00<00000002Zo`00Z_l00P000004001bo`0300000000Iol006Oo00H006Oo
0`000007000Jo`03000000002?l000So00<000So0P00000203`0o`030000
003oool0oooo01/0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0R0?ooo`00L03oool00`000000oooo0?ooo`0B0?ooo`8000000`00
ol@4000000H00?nj0P000005003o/00300000000ojH00?nV008000000P00
oj400`0000000?nF003oUP04003oUP8000000`00ohd4000000H00?mm00<0
0000003oN`00og/01000og/3000000D00?mb0P000004003oO@80000000<0
0?m_0000000000001P00oh8200000003003oV@000000000000D00?n?0P00
00000`00oj`0000000000005003oY00300000000olP00?o800800?o80P00
0004003o``0300000000on/00?o[00800?o[0P000005003oj@80000000<0
0>Wo00000000iol01@00iol300000003002go`0000000;7o00L00;7o0`00
0007001bo`0300000000Iol006Oo00<006Oo0P000002000/o`0300000000
6_l001[o00H001[o00<000000008o`002?l00P00000503`0o`030000003o
ool0oooo01T0oooo1000000=0?ooo`030000003oool0oooo00<0oooo0P00
000M0?ooo`00L03oool00`000000oooo0?ooo`0@0?ooo`8000001@00ol@2
000000800?nl0`000002003o^P0300000000ok000?n`00<00?n`0P000005
003oYP@000000`00oiH2000000H00?n=0P0000000`00ohL0000000000002
003oO@8000001@00og/3000000800?mo0P000002003oLP0300000000ogd0
0?mm00H00?mm0P000006003oPP0300000000oiT00?nI00<00?nI0P000000
0`00ohl0000000000005003o[080000000<00?nT0000000000001`00olP0
100000000?o3000000000007003oj`0300000000onT00?oY008000001000
jOl00`0000000>Oo003Wo`02003Wo`8000000P00]ol3000000D00;7o0P00
0002001mo`0300000000L_l007;o00H007;o00<00000001Wo`00Iol00P00
0005000/o`03000000006_l001[o00D001[o0`00000703`0o`030000003o
ool0oooo01P0oooo0P000003003So`8000002`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000001`0oooo001`0?ooo`030000003o
ool0oooo00l0oooo0`000003003oa08000001`00ok`4000000<00?n`00<0
0000003oYP00ojH01000ojH2000000<00?nM10000006003oS@0300000000
ohL00?n700<00?n70`000005003oN`8000001P00ogl3000000H00?mm0P00
0002003oS@8000000P00oh82000000P00?nI00<00000003o[000oj`01`00
oj`00`0000000?o8003ob008003ob00300000000on/00?o[00P00?o[0P00
0007003Yo`0400000000iol00000000000H00;Oo0`0000000`00/Ol00000
00000005001mo`0300000000L_l007;o00H007;o0P000007000/o`030000
00006_l001[o00<001[o0P00000202@0o`030000000l0?l0?03o00H0?03o
00<000000?ooo`3oool05P3oool00`000000047o00000002003So`800000
00<00?;o0000000000002@3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000001`0oooo001`0?ooo`030000003oool0oooo00d0oooo
0P000003003oaP@000001`00ok`2000000<00?nc1@000003003oYP800000
1P00oid00`0000000?nF003oUP02000000800?n=0P000006003oQ`030000
0000ohL00?n70080000000@00?mk00000000000000001P00ogl200000080
0?n90P000002003oO@8000001P00ohd2000000P00?nI0P0000000`00ok<0
0000003o[005003o[080000000<00?o=0000000000001P00olP200000003
003ok@000000000000H00?o[0P0000000`00jol00000003Yo`07003Yo`03
00000000]ol00;Oo00P00;Oo0`000007001mo`0300000000L_l007;o00<0
07;o0P0000000`00??l00000000/o`07000/o`03000000006_l001[o0080
00001@0T0?l00`000000?03o03`0o`0603`0o`030000003oool0oooo01@0
oooo00H000000011o`00@Ol00000003So`000005003bo`8000001`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000001`0oooo001`
0?ooo`030000003oool0oooo00/0oooo0P000006003oaP0300000000okh0
0?nn008000000`00ok`2000000D00?nc0P000003003oZ`@000001@00oid2
000000D00?nF0`000005003oQ`8000001000ohL4000000H00?mo00<00000
003oR@00ohT01000ohT2000000L00?n=0P0000000`00oj80000000000005
003oV@0300000000ok<00?nc00800?nc00<00000003o[000oj`00P00oj`0
0`0000000?o=003oc@03003oc@8000000P00olP2000000D00?o]0P000002
003oj`8000001000jol00`0000000>Wo003Yo`03003Yo`80000000<00;go
0000000000001P00]ol2000000030028o`00000007go00<000001@00OOl0
0`00000007;o001bo`02000000@003co0P000006000/o`<00000200T0?l0
0`000000?03o03`0o`0503`0o`800000503oool010000000047o0011o`00
@Ol2000000D00?;o0P0000000`00mol00000000000050?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000703oool00700oooo00<0
00000?ooo`3oool02P3oool2000000D00?o60P000005003o_P@000001000
ok<2000000H00?n[00<00000003oX`00oj<00P000002003oW@0300000000
oiH00?nF00@00?nF0P000002003oT@8000000P00ohL00`0000000?n7003o
Q`03003oQ`<000000P00oh/2000000800?mo0P000006003oR@80000000<0
0?nH00000000ohd01000ohd00`0000000?nR003oXP03003oXP80000000<0
0?nI0000000000001P00ok<0100000000?n/000000000008003oc@800000
2@00ond2000000L00>_o00<00000003Yo`00jOl00P000005002mo`800000
0P00]ol2000000@008So0P000002001mo`8000000`00OOl3000000P003co
00<00000000/o`00;?l00`00000200`0o`030000000T0?l0903o00L0903o
00<0000003`0o`0l0?l0100000020840o`030000003oool0oooo0100oooo
00@000000011o`00@Ol0047o0P000004003bo`8000001@00mol400000003
0?ooo`000000oooo00@0oooo0P00000M0?ooo`00K`3oool00`000000oooo
0?ooo`0:0?ooo`0300000000olL00?o7008000000P00olH00`0000000?nn
003o_P04003o_P8000000`00okL5000000D00?n[0P000005003oX`@00000
0`00oiH2000000H00?nA10000002003oQ`<000001P00oh/3000000H00?n9
00<00000003oV000oiP00P00oiP200000003003oS@000000000000P00?nR
00<00000003o/`00ok<01`00ok<00`0000000?o=003oc@06003oc@800000
00<00?o^00000000ond01P00ond200000003003]o`0000000>_o00L00>_o
0P000009002mo`8000002000R?l00`00000007go001mo`040000008004go
00<00000000lo`00??l01P00??l3000000H0303o0P00000702@0o`<00000
1`210?l00`000000oooo0?ooo`0>0?ooo`0300000000@Ol0047o0080047o
00@00000003bo`00l_l00?;o0P000006003go`8000000`00n_l3000002<0
oooo001_0?ooo`030000003oool0oooo00P0oooo0P000005003oa`@00000
0`00okh2000000H00?ng0P000002003o[`8000000P00oj/00`0000000?nS
003oX`04003oX`8000000`00oid4000000H00?nA0P000003003oT@@00000
1P00oh/2000000800?nC0P000002003oR@8000001`00oiP00`0000000?nR
003oXP06003oXP80000000<00?nj0000000000001@00ok<200000003003o
d@000000000000D00?o=00<00000003okP00onh00P00onh2000000@00?o]
00<00000003]o`00kOl00P00kOl00`0000000>_o003[o`03003[o`800000
00<00<?o0000000000001P00_Ol200000003002Bo`00000008So00P008So
0P000004001=o`80000000<004go00000000??l01000??l20000008000Wo
00<0000000`0o`0<0?l01P0<0?l00`000000903o02@0o`0400000080H@3o
00<000000840o`210?l01P210?l00`000000oooo0?ooo`0;0?ooo`800000
1@00@Ol6000000@00?Oo0P000005003jo`800000903oool006l0oooo00<0
00000?ooo`3oool01`3oool00`0000000?o7003oa`04003oa`8000000`00
ol44000000H00?ng00<00000003o[`00ojl01000ojl4000000<00?nS0P00
0006003oW@0300000000oiX00?nJ008000000P00oi42000000@00?nA00<0
0000003oT@0000000P00oiD2000000800?n;0P000006003oT`<000001P00
oiP200000003003oZ`000000000000D00?nR00<00000003o^P00okX00`00
okX200000003003o/`000000000000D00?oA0P0000000`00old000000000
0007003okP0400000000ond00000000000H00>go00<00000003[o`00jol0
0P0000050033o`8000000P00_Ol2000000@009;o0P0000050028o`800000
00<005co00000000COl01@00COl30000008003co0P0000050009o`030000
000<0?l0303o00D0303o0`0000070640o`03000000210?l0P@3o00H0P@3o
00<000000?ooo`3oool02@3oool00`00000003Ko000000040011o`040000
0000fOl00000000000<00>Oo10000005003jo`8000000P3oool00`000000
oooo0?ooo`0Q0?ooo`00K`3oool00`000000oooo0?ooo`060?ooo`<00000
0`00olL2000000H00?o100<00000003o^P00okX00P000002003o]`800000
1P00ojl2000000<00?nY10000005003oW@8000001@00oiX3000000<00?nA
10000005003oU@8000002000oi<00`0000000?nQ003oX@02000000800?nH
0P000005003oZ`80000000<00?nR0000000000002000okX00`0000000?oA
003od@07003od@0300000000onh00?o^00P00?o^00<00000003]o`00kOl0
1`00kOl2000000T00<?o0P000008002Bo`0300000000R?l008So00800000
1000G?l2000000H004go0`0000080009o`030000000<0?l0303o00@00000
0P110?l00`000000H@3o0640o`060640o`03000000210?l0P@3o00D0P@3o
0P0000090?ooo`0300000000=_l0000000D0047o0P000005003Wo`800000
00<00>oo0000000000000P00n_l2000000@0oooo00<000000?ooo`3oool0
8@3oool006l0oooo00<000000?ooo`3oool0103oool2000000<00?o91000
0005003o`@8000001@00okX4000000@00?n_0P000005003oZ@8000000P00
oj@2000000800?nM00<00000003oVP00oiX01000oiX2000000800?nJ0`00
00000`00oi400000003oU@05003oU@80000000<00?nM0000000000001000
oi<2000000D00?nQ0P000009003oZ`8000001`00okX200000003003oe@00
00000?oA00D00?oA0P0000000`00oo00000000000006003okP80000000<0
0>ko00000000kOl01@00kOl2000000030038o`000000000000H00<?o0P00
00000`00Vol00000002Bo`08002Bo`8000002000G?l00`00000004go001=
o`030000008001oo0`0000060009o`<000001`110?l2000000L0H@3o00<0
00000840o`210?l0100000020<D0o`030000003oool0oooo00@0oooo0P00
0002000fo`0300000000@Ol0047o00<0047o00<00000003Wo`00iol00P00
iol2000000D00>oo0P0000060?ooo`030000003oool0oooo0240oooo001_
0?ooo`030000003oool0oooo0080oooo0P000005003ob@8000000P00ol<2
000000800?o100<00000003o^P00okX01000okX2000000<00?nd10000006
003oZ@0300000000oj@00?nT00@00?nT0P000006003oVP0300000000oiX0
0?nJ00800?nJ00@00000003oVP00000000001P00oiD00`0000000?nM003o
W@03003oW@80000000<00?nC00000000oj401@00oj4200000003003o/P00
0000000000D00?n[0P000002003o`@8000000`00okX2000000@00?oE0P00
0002003od@8000001@00oo02000000800?o^0P000004003^o`8000000P00
kOl2000000D00<So0P0000020033o`8000001000Vol2000000D009;o0P00
00000`00J_l00000001Lo`07001Lo`<000001`007ol7000000808`3o00<0
00000440o`110?l01`110?l00`000000H@3o0640o`020640o`D000001`35
0?l00`000000oooo0?ooo`020?ooo`0500000000=_l003Ko000fo`000000
1P00@Ol00`0000000>Oo003Wo`02000000H00>oo0P0000070?ooo`030000
003oool0oooo0240oooo001_0?ooo`040000003oool0oooo0?ooo`<00000
0`00olT2000000H00?o310000003003o^P8000001P00ok@00`0000000?n^
003o[P02000000800?nY0P000006003oY080000000<00?nR000000000000
0P00oiX2000000<00?nJ0P0000001000oiX0000000000000oih200000080
0?nE0P000008003oW@0300000000oj400?nQ00@00?nQ00<00000003o/P00
ok800`00ok8200000003003oZ`000000000000H00?o10`000008003oe@80
00002@00oo02000000P00>ko0P0000090038o`8000002000Vol00`000000
09;o002Bo`02000000@006[o00<00000001Lo`00G?l00`00G?l200000080
03?o00<00000000Oo`007ol01P007ol5000000@08`3o0P0000070440o`D0
0000102I0?l00`000000a@3o0<D0o`050<D0o`030000003oool0oooo0080
00001000=_l00`000000047o0011o`030011o`@000001P00kol2000000T0
oooo00<000000?ooo`3oool08@3oool006l0oooo00@000000?ooo`000000
00000`00ol/4000000H00?o30P000003003o_@@000001@00ok@2000000D0
0?n^10000004003oY08000001@00oj8400000004003oVP0000000000003o
VP8000001@00oih3000000L00?nM0P0000000`00ojT0000000000002003o
X@8000002000ok800`0000000?o1003o`@05003o`@80000000<00?oI0000
000000001@00omD200000003003ol@000000000000H00?o`0P0000000`00
l?l00000003^o`05003^o`80000000<00<go0000000000001P00b?l20000
0003002To`00000009_o00L009_o0`000007001Zo`0300000000G?l005co
008000001@00<ol00`00000001oo000Oo`03000Oo`8000000P080?l00`00
00008`3o02<0o`03000000<08`3o00<000000440o`110?l01000000206l0
o`030000002I0?l0V@3o00D0V@3o00<000000<D0o`350?l01@350?l30000
00@003Ko00@000000011o`00@Ol0047o1P0000000`00iOl0000000000002
003_o`8000002`3oool00`000000oooo0?ooo`0Q0?ooo`00K`3oool20000
00H00?o;00<00000003oaP00olH00P000002003o``8000001@00okd20000
00800?nh0P000002003o]00300000000ojh00?n^00@00?n^0P000003003o
Z`@000001P00oj82000000<00?nR10000006003oWP8000000P00ojH20000
00<00?nM0P000005003oZ@<000001`00ok8200000003003oaP0000000?o1
00@00?o100<00000003of@00omT00`00omT200000003003oe@0000000000
00D00?oa0P000002003ol08000001000l?l2000000800>ko0P000005003=
o`8000000P00b?l2000000@00:Co00<00000002Ko`00Vol00`00Vol20000
008007Oo00<00000001Zo`00J_l01@00J_l3000000P003?o00<00000000O
o`007ol00P00000500P0o`030000000S0?l08`3o00808`3o0P000000100S
0?l0000000000000000706l0o`030000002I0?l0V@3o00D0V@3o00<00000
0<D0o`350?l00P350?l5000000<003Ko1@0000030=40o`0300000000iOl0
0>Go00<00>Go0P00000=0?ooo`030000003oool0oooo0240oooo001^0?oo
o`8000001@00ol/2000000D00?o610000003003o_@8000001P00okP40000
00<00?n^0P000006003oZ`0300000000ojT00?nY008000000P00oj820000
00<00?nR0P0000001000oj800000003oYP00ojH2000000800?nN0P000006
003oYP<000001P00ojT2000000800?ni0P000003003o/P8000001000olH2
00000003003o`@000000000000P00?oI00<00000003ol@00oo401`00oo42
000000P00?3o0P000009003=o`8000001`00Y?l00`00000009_o002Ko`02
000000D007Oo0P000002001Zo`<000000P00A_l2000000L003?o0`000008
00P0o`030000000S0?l08`3o00L00000201_0?l00`000000V@3o09T0o`02
09T0o`L00000103o0?/4000000030880o`000000d@3o00@0d@3o00<00000
003Uo`00iOl00P00iOl2000000l0oooo00<000000?ooo`3oool08@3oool0
06l0oooo0`000002003ob`0300000000olH00?o600D00?o600@00000003o
`@00ol400?o110000006003o^08000000`00ok<4000000D00?n[0P000005
003oZ@<000000P00oj8200000003003oXP000000000000D00?nV0P000008
003oYP0300000000ok400?na008000000P00ojT2000000H00?ni0`000008
003oaP8000001`00omT200000003003olP0000000?oa00D00?oa0P000000
0`00lOl0000000000005003`o`80000000<00=7o0000000000001P00cOl2
00000003002/o`0000000:Co00H00:Co0`000009001go`8000001`00A_l2
0000008003?o0`000002000Ao`8000001`080?l3000000H0B03o0`000006
06l0o`D0000010360?l00`000000o`3k0?l0n`050?l0n`04000000220?l0
PP3o000000H0d@3o00<00000003Uo`00iOl00P00000A0?ooo`030000003o
ool0oooo0240oooo001_0?ooo`030000003oool0oooo00@000001000olH2
000000D00?o100<00000003o_000ok`00P000002003o^08000001@00ok<2
000000800?n`0P000002003oZ`0300000000ojT00?nY00@00?nY0P000002
003oZP8000000P00oj800`0000000?nV003oYP05003oYP0400000000ojd0
0000000000@00?nV0P000005003o/@8000002000okT0100000000?o;0000
00000005003oaP8000000P00om`2000000<00?oI0P000004003olP800000
0P00oo42000000D00?7o0P0000000`00l?l0000000000005003Ao`800000
0P00cOl2000000@00:co0P000002002To`<000000P00Pol2000000H007Oo
0P0000000`00Eol00000000000070016o`<000001`004Ol200000080203o
0`00000202H0o`8000001`180?l30000000406l0o`000000000000000080
S`3o0P0000060<H0o`8000001P3o0?/00`000000PP3o000000060=40o`<0
00004`3oool00`000000oooo0?ooo`0Q0?ooo`00KP3oool00`000000oooo
0?ooo`050?ooo`D000001@00ol400`0000000?nl003o_003003o_0@00000
0`00ok<2000000H00?n`10000003003oZ@8000000`00ojX200000004003o
ZP0000000000000000D00?nV0P000004003o[@80000000<00?nV00000000
ok401P00ok40100000000?no000000000004003o^@8000001000ol/20000
0003003oaP000000000000H00?oL0`000008003olP8000002@00lOl00`00
00000=7o003Ao`07003Ao`8000002000[?l2000000L008?o0P000002001g
o`8000001@00Eol20000008004Ko0`000002000Xo`8000001`004Ol30000
00L09P3o0P00000404P0o`H000001P2?0?l2000000H0aP3o00<000000?l0
n`3o0?/0103o0?/00`000000d@3o0=40o`050=40o`030000003oool0oooo
01<0oooo00<000000?ooo`3oool08@3oool006h0oooo00<000000?ooo`3o
ool02P3oool2000000800?o100<00000003o_000ok`01000ok`010000000
0?nh003o^000okP4000000H00?n`0P000003003o[`@000000P00ojX20000
00800?nZ0P000002003o[P8000000P00ojH00`0000000?n]003o[@06003o
[@8000001@00ok42000000@00?no0P0000000`00okT00000003ob`07003o
b`0300000000om`00?oL00D00?oL0P0000000`00oo@0000000000005003o
lP80000000<00?;o0000000000001P00lOl200000003003Eo`0000000=7o
00D00=7o0P0000000`00/ol0000000000005002/o`80000000<008oo0000
000000001`00Pol3000000T005Oo0P000007000Xo`8000000P004Ol30000
00801`3o00<0000002H0o`0V0?l01P0V0?l5000000@0GP3o1@00000208l0
oa8000001@3A0?l00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0240oooo001^0?ooo`030000003oool0oooo00`0oooo10000003003o_080
00001@00okP00`0000000?nf003o]P02000000800?n`0P000006003o[`03
00000000ok000?n`008000000P00ojX2000000H00?n^0`000006003o[@80
00000P00okP2000000800?na00<00000003o_`00okl01P00okl00`000000
0?o;003ob`05003ob`80000000<00?oO00000000om`01000om`00`000000
0?od003om003003om080000000<00?ob0000000000001@00l_l200000080
0?7o0P000004003Eo`8000000P00dOl2000000D00;?o0P0000000`00[?l0
000000000005002?o`8000000P00Pol30000008006Ko0P000006001Go`80
000000<003go00000000:?l01`00:?l3000000H01`3o0P00000202H0o`@0
00000P0e0?l2000000D0GP3o1`00000508l0o`@000000P3I0?l2000000D0
o`3700<000000=40o`3A0?l00P3A0?l00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0240oooo001^0?ooo`030000003oool0oooo0100oooo
10000005003o^00300000000okH00?nf00<00?nf0`000005003o[`800000
0P00ok0200000004003o/00000000000000000H00?n^0P000002003o]080
00000P00ojd2000000H00?nh0P000007003o_`80000000<00?o@00000000
00000`00ol/2000000@00?oO0P0000000`00om`0000000000008003om003
00000000l_l00?;o00L00?;o0P000008003Eo`8000002@00/ol00`000000
08oo002?o`07002?o`8000001`00I_l20000008005Oo0P000004000mo`80
00000P00:?l40000008001?o0P00000500L0o`@00000200e0?l5000000D0
EP3o2@0000020034o`H00000103o0<L01@000000d@3o0=40o`3A0?l00000
01L0oooo00<000000?ooo`3oool0803oool006h0oooo00<000000?ooo`3o
ool0503oool2000000800?nh00<00000003o]P00okH00`00okH200000080
0?ne0P000002003o[`0300000000ok000?n`008000000P00ok0200000080
0?nd0P000002003o[P8000001P00ok@2000000L00?nh0P0000000`00olD0
000000000003003o_`8000001@00om03000000P00?oO0P000007003om080
000000<00?Co00000000l_l01@00l_l200000003003Io`0000000=Go00D0
0=Go0P0000000`00^_l0000000000006002co`80000000<009Wo00000000
Sol01@00Sol200000003001eo`000000000000L006Ko0`000007000mo`<0
000020004ol5000000@04@3o0P00000303D0o`<000000`0Z0?l?000000<0
0<Co0P000002003Do`@000000`3o0<L010000000d@3o0=40o`00000G0?oo
o`030000003oool0oooo0200oooo001^0?ooo`030000003oool0oooo01H0
oooo0`000003003o]P8000001P00okD5000000800?n`0P000006003o]0<0
00001P00ok@200000003003o_P000000000000<00?nh0P000005003oa@<0
00001P00om0200000003003ohP000000000000D00?oO0P000002003om@80
00000`00oo@2000000@00?Co0P000002003bo`8000001000fOl200000080
0=Go0P000005002jo`8000000P00/ol2000000@009Wo0P000002002?o`80
00001@00MOl20000008006Ko0`000002001@o`8000000`00?Ol3000000<0
02_o0P000003000Co`<000000P003?l2000000D04@3o3`000003001mo`80
00000P00Xol200000003002mo`000000000000<000001000e?l200000003
0?ooo`000000000000@00000603oool00`000000oooo0?ooo`0P0?ooo`00
KP3oool00`000000oooo0?ooo`0I0?ooo`@000001P00okD200000003003o
]`000000000000@000001P00ok@2000000800?nk0P000002003o]0800000
1@00okh3000000H00?o50P000002003oe08000000P00om02000000D00?oR
0P0000000`00oml0000000000006003om@<000002000m?l2000000P00=Wo
0P000008002jo`<000001`00VOl3000000P007Go0`000007001@o`<00000
2000:ol3000000L000co1@00000300L0o`<0000000<001[o000000000000
10000003001mo`8000000P00Xol2000000@00;go200000070?ooo`800000
603oool00`000000oooo0?ooo`0P0?ooo`00KP3oool00`000000oooo0?oo
o`0M0?ooo`8000000P00okD200000003003o]`000000000000<00?ng00<0
0000003o^P00okX00P000002003o]08000001P00ok/2000000H00?nn0P00
0002003obP8000000P00olD2000000H00?oD0P000009003ohP8000001P00
ooD200000003003eo`000000000000D00?Co0P0000000`00g?l000000000
0005003Io`8000000P00`Ol2000000<00;[o0`000002002Ro`8000000`00
VOl3000000<008;o0P000003001eo`<000000P00H?l00`000000053o001@
o`04001@o`8000000P00@Ol2000000<002_o0`000002000Uo`8000000`00
3?l3000000@001Go5@000004002mo`8000001000c_l300000280oooo00<0
00000?ooo`3oool0803oool006h0oooo00<000000?ooo`3oool07`3oool3
00000003003o]`0000000?ng00800?ng0P000005003o^P<000001P00ok/2
00000003003o``000000000000800?nn0P000006003obP<000001P00om@2
00000003003oi@000000000000D00?oR0P000002003omP8000000P00ooD2
000000D00?Go0P0000000`00m?l0000000000005003Lo`80000000<00=Wo
0000000000001P00`Ol3000000L00:;o0`0000080022o`<000001P00H?l2
00000080053o0P0000060011o`<000001`009Ol4000000@001Go0`000000
1000<?l00000000000000003001Go`8000000P00Ool2000000800:3o0P00
0003002ho`@000001000c_l2000000<0oooo0P00000P0?ooo`030000003o
ool0oooo0200oooo001^0?ooo`030000003oool0oooo0240oooo0`000002
003o]`0300000000okX00?nj00@00?nj0P000002003o`08000000P00ok/2
000000D00?o30`000006003obP8000000P00omP2000000800?oD0P000005
003oi@80000000<00?oR0000000000001P00ooH2000000T00?Go00<00000
003Lo`00g?l01P00g?l2000000L00<7o0P0000000`00Zol00000002Ro`05
002Ro`80000000<008go0000000000001P00P_l200000003001_o`000000
063o00H0063o0`0000060011o`8000000P00>ol2000000<002Go0`000004
000]o`P000001000Eol20000008007oo0P000002002Po`8000001@00^?l2
000000800<Wo100000070?ooo`<000007@3oool00`000000oooo0?ooo`0P
0?ooo`00KP3oool00`000000oooo0?ooo`0O0?ooo`8000000`3oool40000
00<00?nj0P000006003o`08000001P00ol<2000000800?o>0P000002003o
bP8000001P00omP2000000T00?oU00<00000003omP00ooH01@00ooH20000
0003003fo`0000000?Go00D00?Go0P0000000`00gol0000000000003003L
o`<000000P00a_l2000000<00<7o0P000004002[o`8000000P00X_l20000
00D008go0P0000020022o`8000001000Kol200000080063o0`000002001C
o`8000000`00@Ol2000000H003_o0`000004000]o`@000000`00@ol20000
0080067o3@000004002ho`8000001000bOl2000000`0oooo0P00000K0?oo
o`030000003oool0oooo0200oooo001^0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool4000000H00?o00P0000000`00olP0
000000000002003o``8000001P00olh3000000H00?oH0P0000000`00onL0
0000003oi@05003oi@80000000<00?og0000000000000`00ooH2000000@0
0?Ko0P000002003eo`8000001@00gol3000000L00<Ko0`000008002[o`80
00002000SOl3000000L006oo0`000007001Co`@000001000>ol3000000<0
04;o1@0000040013o`8000000P00HOl3000000<008;o0P000002002No`80
00000`00]Ol4000000@00<Wo0P00000@0?ooo`<00000603oool00`000000
oooo0?ooo`0P0?ooo`00KP3oool00`000000oooo0?ooo`0L0?ooo`800000
3P3oool2000000800?o00P000005003ob0<000001P00olh2000000800?oK
0P000002003of08000001000onL2000000800?oU0P000005003om`<00000
1`00m_l3000000H00=oo0P0000000`00bol00000000000050036o`800000
00<00;;o0000000000001@00Zol20000008009So0P000003002=o`<00000
0P00OOl2000000<006oo0`000002001To`8000000`00Dol3000000@004ko
100000040012o`<000001000Dol8000000@008;o0P000002002No`800000
1000]Ol2000000<00<Ko1000000E0?ooo`8000005P3oool00`000000oooo
0?ooo`0P0?ooo`00K@3oool00`000000oooo0?ooo`0K0?ooo`8000004P3o
ool2000000H00?o80P000002003odP8000000P00olh2000000H00?oK0P00
0008003oi`8000001P00ooL2000000800?Oo0P000003003fo`8000000`00
h_l2000000800=oo0P000005003;o`80000000<00<Ko0000000000001@00
/_l200000003002[o`000000000000H009So0`000007001mo`<000001`00
I?l4000000@004ko0`000003001Co`D000001000Dol3000000<006_o0P00
00020026o`P000001000]Ol2000000@00<Ko0P00000J0?ooo`800000503o
ool00`000000oooo0?ooo`0P0?ooo`00K@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo01@0oooo0P000002003ob08000001P00om83
000000H00?oK0P0000000`00onT00000003oi`04003oi`8000000P00ooL2
000000800?og0P000006003go`<000001`00h_l2000000P00<_o0P000008
002bo`8000001`00V?l2000000030029o`00000007go00D007go0P000002
001bo`8000000`00I?l2000000@005oo10000006001Co`8000000`00HOl4
000000@006_o0P0000040026o`8000000P00Wol2000000800;?o10000004
0036o`8000007P3oool300000140oooo00<000000?ooo`3oool00P3oool5
000001T0oooo001]0?ooo`030000003oool0oooo01P0oooo0P00000I0?oo
o`<000001P00om82000000800?oN0P000002003of`8000001000onT20000
0003003oi`000000000000H00?og0`000006003go`80000000<00>Go0000
0000h_l01@00h_l200000003003@o`000000000000<00<_o0`000002002i
o`8000000`00/_l3000000800:7o0P000003002Ho`8000001000ROl20000
008007go0P000006001bo`<000001P00Gol200000003001So`0000000000
00<005?o0P000005001Qo`8000000P00MOl4000000@008Ko0P000002002O
o`8000001000/ol2000000800<?o1000000S0?ooo`8000003`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01T0oooo001]0?ooo`03
0000003oool0oooo01H0oooo0P00000N0?ooo`8000000P00om82000000H0
0?oN0P000008003oj@8000001P00ooL2000000800?Oo0P000002003go`80
00001000iOl2000000800>;o0P000005003@o`<000001`00^Ol3000000L0
0:7o0`0000070029o`@000001000L_l30000008006ko0P000003001Oo`80
00001@00Hol4000000@0067o0P000002001eo`<000000`00Rol8000000@0
0;?o0P0000040033o`8000009`3oool3000000d0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0I0?ooo`00K@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0200oooo0`000006003ogP800000
00<00?o[00000000onT01000onT2000000800?oh0P000002003om`800000
1P00mol2000000P00>Go0P000006003@o`80000000<00;oo000000000000
1@00^Ol2000000800:Wo0P000003002Qo`8000000`00Tol2000000<008Wo
0P000004001oo`@000001`00K_l3000000@006?o0`000004001^o`P00000
1000Rol3000000<00:7o0P000002002co`@000001000`ol2000002`0oooo
0P00000;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
6@3oool006d0oooo00<000000?ooo`3oool04`3oool2000002H0oooo0P00
0002003ogP8000001000on/200000003003oj@000000000000H00?oh0P00
0007003go`80000000<00>Oo00000000iOl01000iOl2000000800=Co0P00
0002003@o`8000001@00_ol200000003002io`000000000000H00:Wo0`00
0007002Co`<000001P00Ool200000003001ko`000000000000<006ko0`00
0003001ao`D000001000K_l3000000<007ko0P000002002Ao`@000001000
XOl2000000@00;?o0P0000020032o`@00000<03oool3000000P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0I0?ooo`00K@3oool0
0`000000oooo0?ooo`0A0?ooo`800000:P3oool2000000L00?o[0`000006
003on080000000<00?So0000000000000`00mol2000000@00>Oo0P000000
0`00iOl0000000000006003Do`8000002000_ol2000000L00:Wo0P000000
0`00WOl0000000000003002Co`<000000P00Rol2000000<007oo0P000005
001ko`<000001000LOl3000000@007Wo10000004001no`8000001000TOl2
000000800:?o10000004002co`8000001000`_l2000003D0oooo0P000006
0?ooo`030000003oool0oooo0080oooo0P00000K0?ooo`00K@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo02`0oooo0P000003003o
j`8000000`00ooT2000000800?oh0P000005003ho`<000001`00iol30000
00H00=Co0P0000000`00aOl0000000000003002oo`<000000P00/Ol20000
00<00:Wo0P000005002Mo`<000001`00Rol3000000@007_o0`000003001m
o`@000001`00NOl20000008008Ko10000004002Ao`8000001000Xol20000
00800;?o100000040032o`800000>@3oool3000000<0oooo00<000000?oo
o`3oool07`3oool006d0oooo00<000000?ooo`3oool03P3oool200000340
oooo0`000007003on@8000001P00n?l2000000800>Wo0P000003003Wo`80
00000`00f?l2000000800=Co0P0000050035o`<000001`00/Ol3000000H0
09go0P0000000`00UOl0000000000003002;o`<000000`00Qol4000000H0
07go0P0000020024o`8000000`00NOl2000000@008Ko0P000002002Fo`@0
00001000Xol2000000@00;?o0P0000020031o`@00000?P3oool400000240
oooo001]0?ooo`030000003oool0oooo00`0oooo0P00000f0?ooo`800000
0`00ooT2000000800?Wo0P000002003ho`8000001P00jOl3000000L00=So
0P0000060035o`8000000P00^?l2000000<00;7o0P000003002Vo`800000
0P00WOl2000000D009Go0`0000060027o`8000000P00Qol20000008007go
0P0000060024o`<000001000Q_l2000000@009Ko0P000002002Vo`@00000
1000/ol2000000@00<7o0P0000120?ooo`8000008@3oool006d0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0h0?ooo`<000001P00
nOl3000000H00>Wo0P0000000`00fol0000000000003003Ho`<000000P00
b_l2000000800<Go0P000006002ho`<000001`00Y_l2000000H009Go0P00
0002002Ao`8000000P00Qol2000000H008Oo0`0000040024o`<000000`00
S_l4000000@009Ko0P000004002Vo`8000000P00]?l4000000@00<7o0P00
00120?ooo`8000008`3oool006d0oooo00<000000?ooo`3oool02@3oool2
000003d0oooo0P000003003io`8000000`00jol2000000800>Wo0P000005
003Ko`<000001`00b_l2000000L00;So0P0000000`00[Ol0000000000003
002Vo`<000000P00W_l20000008009Go0P000006002Ao`<000001000Qol3
000000<008go10000004002>o`<000000`00Vol4000000@00:Ko0P000004
002do`8000000P00`Ol400000480oooo0P00000U0?ooo`00K@3oool00`00
0000oooo0?ooo`070?ooo`800000@@3oool3000000L00>_o0P000006003K
o`8000000P00c_l2000000<00<[o0P000002002no`8000000`00^?l20000
00D00:go0`000007002No`<000001000TOl3000000<0097o10000004002=
o`<000000`00U_l5000000@009_o0P000003002Yo`D000000`00]?l20000
00@00<7o0P0000110?ooo`<000009`3oool006`0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`140?ooo`8000000`00jol200000080
0=ko0P000002003Ko`8000001P00c_l3000000H00;ko0`000006002]o`80
000000<00:Ko0000000000000`00W_l3000000<009[o10000006002Ao`80
00000P00U_l4000000H009Ko0P000003002Qo`@000001000ZOl2000000@0
0;Ko100000030031o`800000@@3oool2000002X0oooo001/0?ooo`030000
003oool0oooo00D0oooo0P0000190?ooo`<000001P00g_l3000000H00<ko
0P0000000`00`ol0000000000003002no`8000000`00]?l2000000800:go
0P000005002Vo`<000001P00V_l20000008009[o0P000002002Ao`800000
1000U_l20000008009go0P000002002Fo`8000001@00XOl2000000800:co
10000004002fo`<000000`00`Ol300000440oooo0P00000/0?ooo`00K03o
ool00`000000oooo0?ooo`030?ooo`800000C@3oool2000000<00=ko0P00
0003003Bo`8000000P00c_l2000000D00<?o0`000007002do`<000001000
Y_l2000000<00:;o0P000002002Jo`8000001P00V_l3000000<009Ko0P00
0006002Mo`<000001000XOl2000000@00:co0P000002002ho`@000001000
`Ol300000440oooo0P00000^0?ooo`00K03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo04l0oooo0`000007003Bo`8000001P00`ol2
000000800;_o0P000003002do`8000000`00[_l4000000L00:;o0`000004
002Jo`<000000`00WOl4000000@009go0`000003002Vo`@000001000[?l2
000000@00;So0P0000020032o`@00000@@3oool300000300oooo001/0?oo
o`030000003oool0oooo00800000E03oool2000000<00=;o0`0000020038
o`8000000P00`ol2000000H00;_o0`000005002^o`80000000<00:[o0000
000000000`00X_l3000000<00:;o10000004002Mo`<000000`00Xol40000
00@00:Ko0`000003002`o`@000001000^?l2000000@00<;o0P0000110?oo
o`800000<`3oool006`0oooo0`00001H0?ooo`<000001`00b?l3000000@0
0;_o0`000002002do`8000000P00[_l2000000D00:[o10000004002Ro`80
00000`00Y?l4000000H00:?o0P000002002[o`@000001000/?l3000000<0
0;[o100000040032o`800000@@3oool2000003D0oooo001/0?ooo`800000
G03oool2000000<00<So0P0000030030o`@000001`00]?l3000000@00:[o
0P000004002Yo`@000001@00Y?l2000000800:Wo0P000002002So`800000
1000Zol2000000800;?o1@000004002jo`8000000`00`ol400000400oooo
0`00000g0?ooo`00KP3oool3000005/0oooo0`0000050030o`8000000P00
^_l2000000<00;Co0P000003002`o`@000001P00ZOl200000003002[o`00
0000000000800:Co0P000006002Yo`<000000`00Zol2000000@00;?o0P00
0003002lo`@000001@00`ol200000400oooo0P00000j0?ooo`00L@3oool4
000005T0oooo0P0000020030o`8000001P00^_l3000000D00;3o0P000000
0`00[ol0000000000003002Yo`8000001@00Zol3000000@00:Wo0`000003
002_o`@000000`00/ol2000000D00;co0P0000000`00a?l0000000000002
0033o`800000@03oool2000003`0oooo001e0?ooo`<00000F03oool40000
00@00;[o0P000002002go`8000000P00/?l2000000D00:oo10000004002[
o`8000000`00[_l4000000@00:oo0`000003002go`@000001000_?l20000
00D00<Co0P00000o0?ooo`<00000?P3oool007P0oooo0`00001I0?ooo`@0
00001P00]ol3000000@00:oo0P000004002`o`@000001000[_l2000000<0
0;Co1@000004002go`8000000`00__l4000000@00<Co0`00000o0?ooo`80
0000@@3oool007/0oooo0`00001I0?ooo`8000000`00]ol2000000<00;Go
10000004002`o`<000000`00/ol4000000D00;Co0P000003002jo`@00000
1000__l2000000<00<Ko100000100?ooo`800000@`3oool007h0oooo1000
001G0?ooo`<000001000]Ol2000000<00;Ko10000006002co`80000000<0
0;So0000000000000P00]?l2000000D00;[o0P0000020031o`@000001@00
a_l200000400oooo0P0000150?ooo`00PP3oool3000005L0oooo10000005
002fo`8000000P00^?l2000000800;?o0P000005002ho`<000001000^_l2
000000@00<7o0P0000000`00aol00000000000020036o`800000?`3oool3
000004L0oooo00250?ooo`<00000E`3oool2000000800;Ko0P000006002h
o`<000001000^?l2000000<00;go100000040031o`8000001@00aol20000
03l0oooo0P00001:0?ooo`00R03oool3000005H0oooo0`000004002ho`<0
00000`00_?l4000000@00;go0P0000030033o`@000001000aol3000003l0
oooo0P00001<0?ooo`00R`3oool3000005H0oooo1@000004002lo`800000
0`00`Ol4000000@00<?o0P0000030039o`@00000?`3oool3000004h0oooo
002>0?ooo`@00000E`3oool4000000@00<7o0P0000030036o`@000001000
bOl200000400oooo0P00001A0?ooo`00TP3oool3000005P0oooo10000005
0036o`8000000P00bol400000400oooo0P00001C0?ooo`00U@3oool30000
05P0oooo0P0000020036o`8000001000bol2000003l0oooo0`00001E0?oo
o`00V03oool3000005L0oooo0`000003003;o`800000?`3oool2000005P0
oooo002K0?ooo`@00000EP3oool3000003l0oooo0P00001J0?ooo`00W`3o
ool3000005D0oooo00<000000?ooo`3oool0>`3oool2000005`0oooo002R
0?ooo`<00000DP3oool00`000000oooo0?ooo`0h0?ooo`<00000GP3oool0
0:D0oooo0`00001?0?ooo`030000003oool0oooo03H0oooo0P00001Q0?oo
o`00Z03oool4000004/0oooo00<000000?ooo`3oool0=03oool2000006<0
oooo002/0?ooo`<00000B03oool00`000000oooo0?ooo`0a0?ooo`<00000
I@3oool00:l0oooo0`0000150?ooo`030000003oool0oooo02l0oooo0P00
001X0?ooo`00/P3oool300000480oooo00<000000?ooo`3oool0;@3oool2
000006X0oooo002e0?ooo`<00000?`3oool00`000000oooo0?ooo`0Z0?oo
o`<00000K03oool00;P0oooo1000000k0?ooo`030000003oool0oooo02P0
oooo0P00001_0?ooo`00_03oool3000003P0oooo00<000000?ooo`3oool0
9P3oool200000740oooo002o0?ooo`<00000=@3oool00`000000oooo0?oo
o`0S0?ooo`<00000L`3oool00<80oooo0`00000b0?ooo`030000003oool0
oooo0240oooo0P00001f0?ooo`00a@3oool4000002h0oooo00<000000?oo
o`3oool07`3oool2000007P0oooo00390?ooo`<00000:`3oool00`000000
oooo0?ooo`0M0?ooo`800000NP3oool00<`0oooo0`00000X0?ooo`030000
003oool0oooo01X0oooo0`00001l0?ooo`00c`3oool3000002D0oooo00<0
00000?ooo`3oool0603oool2000007l0oooo003B0?ooo`@000008@3oool0
0`000000oooo0?ooo`0F0?ooo`800000P@3oool00=H0oooo0`00000N0?oo
o`030000003oool0oooo01<0oooo0`0000230?ooo`00f@3oool3000001/0
oooo00<000000?ooo`3oool04@3oool2000008H0oooo003L0?ooo`<00000
603oool00`000000oooo0?ooo`0?0?ooo`800000R03oool00=l0oooo0`00
000E0?ooo`030000003oool0oooo00`0oooo0`00002:0?ooo`00hP3oool4
00000140oooo00<000000?ooo`3oool02P3oool2000008d0oooo003V0?oo
o`<000003P3oool00`000000oooo0?ooo`080?ooo`800000S`3oool00>T0
oooo0`00000;0?ooo`030000003oool0oooo00H0oooo0P00002A0?ooo`00
k03oool3000000P0oooo00<000000?ooo`3oool00`3oool3000009<0oooo
003_0?ooo`@00000103oool010000000oooo0?ooo`3oool2000009H0oooo
003c0?ooo`<0000000<0oooo0000003oool00P00002H0?ooo`00mP3oool3
000009X0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo
003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0
oooo003o0?oooi@0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 208},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  Using Equation ",
  StyleBox["(11-12)",
    FontColor->RGBColor[0, 0, 1]],
  ", we obtain\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Phi] \((x, 
            y)\)\ \  = \ \ y\/\[Pi]\ \(\[Integral]\_\(-1\)\%1\( 
                  t\/\(\((x - t)\)\^2 + 
                    y\^2\)\) \[DifferentialD]t\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(y\/\[Pi]\ \(\
\[Integral]\_\(-1\)\%1\(\(\((x - t)\) \((\(-1\))\)\)\/\(\((x - t)\)\^2 + 
                      y\^2\)\) \[DifferentialD]t\)\ \  + \ \ x\/\[Pi]\ \(\
\[Integral]\_\(-1\)\%1\( 
                    y\/\(\((x - t)\)\^2 + 
                      y\^2\)\) \[DifferentialD]t\)\)\)\)}]],
  "  \n\nUsing techniques from calculus we have the integration formulas\n\n\t\
\t\t",
  Cell[BoxData[
      \(\[Integral]\(\(\((x - t)\) \((\(-1\))\)\)\/\(\((x - t)\)\^2 + 
                  y\^2\)\) \[DifferentialD]t\ \  = \ \ 1\/2\ ln \((\((x - \
t)\)\^2 + y\^2)\)\)]],
  ",   and   ",
  Cell[BoxData[
      \(\[Integral]\(y\/\(\((x - t)\)\^2 + 
                  y\^2\)\) \[DifferentialD]t\ \  = \ \ Arctan \((y\/\(x - \
t\))\)\)]],
  ".  \n\nWe obtain the solution as follows \n\n\t\t\t",
  Cell[BoxData[
      \(\[Phi] \((x, 
            y)\)\ \  = \ \ \(\(y\/\[Pi]\) \((1\/2\ ln \((\((x - t)\)\^2 + 
                      y\^2)\))\)\( | \+\(t = \(\(-1\)\(\ \)\)\)\%\(t - 
                  1\)\)\ \ \(+\ \ \(x\/\[Pi]\)\) \((Arctan \((y\/\(x - \
t\))\))\)\( | \+\(t = \(\(-1\)\(\ \)\)\)\%\(t - 
                  1\)\)\[IndentingNewLine]\[IndentingNewLine]\ \ \ \ \ \ \ \ \
\ \ \ \ \ \  = \ \ \(y\/\(2\ \[Pi]\)\) 
              ln \((\(\((x - 1)\)\^2\  + \ y\^2\)\/\(\((x + 1)\)\^2\  + \ \
y\^2\))\)\ \  + \ \ \(x\/\[Pi]\) 
              Arctan \((y\/\(x\  - \ 1\))\)\ \  - \ \ \(x\/\[Pi]\) 
              Arctan \((y\/\(x\  + \ 1\))\)\)\)]],
  "  \n\nThe function ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  " is continuous in the upper half-plane, and on the boundary ",
  Cell[BoxData[
      \(\[Phi] \((x, 0)\)\)]],
  ", except at the discontinuities ",
  Cell[BoxData[
      \(x = \(\[PlusMinus]1\)\)]],
  " on the real axis.  The graph in Figure 11.14 shows this phenomenon."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.14",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/poissonintegralplane/\
PoissonIntegralFigures/mat1114.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The graph of ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  " with the boundary values ",
  Cell[BoxData[
      RowBox[{\(\[Phi] \((x, 0)\)\), "=", 
        RowBox[{"{", GridBox[{
              {
                RowBox[{"x", 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}], 
                RowBox[{
                  RowBox[{
                    RowBox[{
                      StyleBox["for",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], "    ", "-", "1"}], "<", 
                    "x", "<", "1"}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[";",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]},
              {
                RowBox[{"0", 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}], 
                RowBox[{
                  StyleBox["for",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "   ", "|", "x", "|", 
                  RowBox[{">", 
                    RowBox[{"1", 
                      StyleBox[
                        RowBox[{
                          StyleBox[" ",
                            FontFamily->"Times New Roman",
                            FontSize->12,
                            FontWeight->"Bold",
                            FontSlant->"Plain",
                            FontColor->GrayLevel[0],
                            FontVariations->{"Underline"->False,
                            "StrikeThrough"->False}], 
                          StyleBox[" ",
                            FontFamily->"Times New Roman",
                            FontSize->12,
                            FontWeight->"Plain",
                            FontSlant->"Plain",
                            FontColor->GrayLevel[0],
                            FontVariations->{"Underline"->False,
                            "StrikeThrough"->False}]}]], 
                      StyleBox[".",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], "   "}]}]}]}
              }], 
          StyleBox["}",
            FontColor->GrayLevel[1]]}]}]]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function U[t] and use the Poisson integral to construct  ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(z = \(y = \(x = 0\)\); \ Remove[x, y, z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[\[Phi]];\)\ \), "\n", 
    \(\(U[t_]\  = \ t;\)\ \), "\[IndentingNewLine]", 
    \(\(g[t_] = 
        y\/\[Pi]\ \(\[Integral]\(U[t]\/\(\((x - t)\)\^2 + 
                    y\^2\)\) \[DifferentialD]t\);\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ Expand[g[1] - g[\(-1\)]];\)\ \), "\n", 
    \(\(v[x_, y_]\  = 
        ReplaceAll[\[Phi][x, y], 
          ArcTan[z_] \[Rule] \(-ArcTan[1\/z]\)];\)\ \), "\n", 
    \(\(Print["\<  U[t]  =  \>", U[t]];\)\ \ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\[Phi][x,y]  =  \!\(y\/\[Pi]\) \
\!\(\[Integral]\_\(-1\)\%1\)\!\(U[t]\/\(\((x - t)\)\^2 + y\^2\)\)\
\[DifferentialD]t\>\""];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y]  =  \>", \[Phi][x, y]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y]  =  \>", v[x, y]];\)\ \), "\n", 
    \(\)}], "Input"],

Cell[TextData[{
  "Using the identities  ",
  Cell[BoxData[
      \(arctan \((\(-t\))\) = \(\(-arctan\) \((t)\)\ \ and\ \ ln \((a\/b)\) = 
          ln \((a)\) - ln \((b)\)\)\)]],
  ",  the above result can be written as  ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\) = \(x\/\[Pi]\) 
            arctan \((y\/\(x\  - \ 1\))\) - \(x\/\[Pi]\) 
            arctan \((y\/\(x\  + \ 1\))\) + \(y\/\(2\ \[Pi]\)\) 
            ln \((\(\((x - 1)\)\^2\  + \ y\^2\)\/\(\((x + 1)\)\^2\  + \ \
y\^2\))\)\)]],
  ".  However for computing values of ArcTan we use the two variable form of \
the function and the following version of  ",
  Cell[BoxData[
      \(\[Phi][x, y]\)]],
  ".  We can verify some of the boundary values by taking limits."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(\[Phi][x_, 
          y_] = \(x\/\[Pi]\) ArcTan[x - 1, y] - \(x\/\[Pi]\) 
            ArcTan[x + 1, y] + \(y\/\(2\ \[Pi]\)\) 
            Log[\(\((x - 1)\)\^2 + y\^2\)\/\(\((x + 1)\)\^2 + y\^2\)];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, y]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) \[Phi][\!\(\(-3\)\/2\),y] = \
\>\"", Limit[\[Phi][\(-3\)\/2, y], \ 
          y \[Rule] 0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) \[Phi][\!\(\(-3\)\/4\),y] = \
\>\"", Limit[\[Phi][\(-3\)\/4, y], \ y \[Rule] 0]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) \[Phi][\!\(\(-1\)\/2\),y] = \
\>\"", Limit[\[Phi][\(-1\)\/2, y], \ 
          y \[Rule] 0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(lim\+\(y \[Rule] 0\)\) \[Phi][0,y] = \>\"", 
        Limit[\[Phi][0, y], \ y \[Rule] 0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(lim\+\(y \[Rule] 0\)\) \[Phi][\!\(1\/2\),y] = \
\>\"", Limit[\[Phi][1\/2, y], \ y \[Rule] 0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  \!\(lim\+\(y \[Rule] 0\)\) \[Phi][\!\(3\/4\),y] = \
\>\"", Limit[\[Phi][3\/4, y], \ y \[Rule] 0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<  \!\(lim\+\(y \[Rule] 0\)\) \[Phi][\!\(3\/2\),y] = \
\>\"", Limit[\[Phi][3\/2, y], \ y \[Rule] 0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Phi][x, y], {x, \(-2\), 2}, {y, 0.000001, 2}, 
        Contours \[Rule] 10, PlotPoints \[Rule] 35, AspectRatio \[Rule] 1\/2, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Then use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[\[Phi][x, y], {x, \(-1.5\), 1.5}, {y, 10\^\(-8\), 1.0}, 
        PlotPoints \[Rule] {31, 21}, 
        PlotRange \[Rule] {{\(-1.5\), 1.5}, {0, 1.0}, {\(-1.05\), 1.05}}, 
        AxesLabel \[Rule] {"\<x\>", "\<   y\>", "\<\[Phi]\>"}, 
        BoxRatios \[Rule] {1, 1, 0.8}, ColorFunction \[Rule] Hue, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0.25, 0.5, 0.25], 
            Range[\(-1\), 3, 1]}, ViewPoint \[Rule] {\(-2.5\), \(-3\), 2}, 
        AxesEdge \[Rule] {{\(-1\), \(-1\)}, {\(-1\), \(-1\)}, {1, \
\(-1\)}}];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y]  =  \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Therefore, the function  ",
  Cell[BoxData[
      \(\(\(\ \)\(\[Phi] \((x, y)\) = \(x\/\[Pi]\) 
            arctan \((y\/\(x\  - \ 1\))\) - \(x\/\[Pi]\) 
            arctan \((y\/\(x\  + \ 1\))\) + \(y\/\(2\ \[Pi]\)\) 
            ln \((\(\((x - 1)\)\^2\  + \ y\^2\)\/\(\((x + 1)\)\^2\  + \ \
y\^2\))\)\)\)\)]],
  "  is harmonic in the upper half-plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  ",  and takes on the desired boundary values."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.13.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Poisson's Integral formula to find the harmonic function ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  " that is harmonic in the upper half-plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  ", that takes on the boundary values  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(\[Phi] \((x, 0)\) = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[
          RowBox[{
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  "}]], 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "       ", "x"}], 
            "\[LessEqual]", \(-1\)}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}], "\[IndentingNewLine]", 
      RowBox[{\(\[Phi] \((x, 0)\) = \ x\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "    ", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "   ", "-", "1"}], "\[LessEqual]", 
            "x", "\[LessEqual]", "1"}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}], "\[IndentingNewLine]", 
      RowBox[{\(\[Phi] \((x, 0)\) = \ 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "    ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "       ", "1"}], "\[LessEqual]", 
          RowBox[{"x", 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000d2000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD
0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3o
oonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD
0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3o
oonD0?ooo`00i`3oool400000:P0oooo003@0?ooo`8000005@3oool00`00
0000oooo0?ooo`2Y0?ooo`00cP3oool3000000030?l800000000000001@0
oooo00<000000?ooo`3oool0Z03oool00<d0oooo0P0000000`3o20000000
0?l800020?l8008000002`3oool4000000@0oooo00<000000?ooo`3oool0
Y`3oool00</0oooo0P0000030?l800030000003o2000o`P00080000000<0
o`T00000000000003`3oool010000000oooo0?ooo`00002X0?ooo`00bP3o
ool2000000@0o`P000<000000?l8000000001@3o2@03000000d0oooo0P00
002Y0?ooo`00b@3oool2000000030?lJ0000000000000080o`P00P000006
0?l900030000003o2P00000000800000;P3oool2000000030?ooo`000000
000008<0oooo00370?ooo`<00000103o6P03000000D0o`T00P0000040?l:
00<00000;@3oool00`000000oooo000000240?ooo`00aP3oool2000000H0
oaX000<000000?lL000000000P0000020?l900030000003o2P00o`X000@0
o`X01@00000/0?ooo`030000003oool0oooo08<0oooo00340?ooo`<00000
1@3o6P0200000080oa`000<000000?lL003o70000P0000060?l:00030000
003o2`00o`/00080o`/00`00000X0?ooo`80000000<0oooo000000000000
P`3oool00<<0oooo0`0000000`3o:`000000000000020?lJ00030000003o
7000oa`00080oa`000D000000?lL0000000000000?lN000200000080o`X0
0P0000050?l;0080000000<0o``00000000000005`3oool500000980oooo
00310?ooo`<000001@3o:`02000000D0oa`00P0000050?lN008000001P3o
2`000`000000o``00?l<00030?l<008000005`3oool00`000000oooo0?oo
o`2B0?ooo`00`03oool3000000H0ob/000@000000?l_0000000000000P3o
7002000000H0oah000@000000?lR0000000000000P3o2`02000000H0o``0
1000000E0?ooo`030000003oool0oooo0980oooo002T0?ooo`800000103o
ool2000000@0oooo0P00000=0?ooo`8000001`3o:`000`000000obl00?l_
00020?l_0080000000<0oah00000003o7P00103o7P000`000000ob800?lR
00020?lR00<000001@3o3002000000@0o`h00`00000:0?ooo`@00000103o
ool00`000000oooo0?ooo`2B0?ooo`00X`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000X0oooo0`0000000`3o?@000000
000000040?l[00030000003o;`00obl000<0obl000@000000?lc00000000
0000103o7P000`000000ob800?lR00030?lR00030000003o9@00obD00080
00000P3o30000`000000o`h00?l>00040?l>00030000003o400000000080
0000403oool00`000000oooo0?ooo`2B0?ooo`00X`3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`00
0000103o?@02000000030?l[00000000obl000@0obl000@000000?lc003o
<`00oc<00`0000000`3o7P0000000?lR00040?lR00030000003o9@00obD0
00<0obD00P0000050?l>00800000103o4003000000d0oooo0P00002D0?oo
o`00X`3oool010000000oooo0?ooo`0000090?ooo`800000203oool20000
00030?ooo`000000ocd000H0ocd000<000000?l_003o;`000`3o;`000`00
0000oc<00?lc00020?lc00040000003o<`00oc<0000000D0ob8000<00000
0?lU003o9@00103o9@0010000000ob/00000000000020?l>00030000003o
4000oa0000D0oa001000002Q0?ooo`00X`3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000
1`3o?@0010000000od800000000000020?l_00030000003o<`00oc<000<0
oc<000@000000?lc00000000ocP00P0000020?lR00030000003o9@00obD0
00@0obD000<000000?l[003o:`000P3o:`02000000L0oa0000@000000?lC
003o4`00oa<00`00002O0?ooo`00Y03oool2000000X0oooo0`0000040?oo
o`8000000P3oool2000000D0ocd00P0000040?m200<000001@3o<`020000
00@0ocP00P0000050?lU008000001@3o:`000`000000oc40000000040?l@
008000001@3o4`0010000000oaT000000000002M0?ooo`00]P3oool30000
00040?ooo`000000odh00?m>008000000P3o?@000`000000od800?m20004
0?m200030000003oA`00odL0008000000P3o<`02000000D0ocP000@00000
0?ln0000000000000P3o9@000`000000ob/00?l[00040?l[00040000003o
<@00oc400?la0080000000<0oa000000003o4`001@3o4`000`000000oaT0
0?lI00020?lI008000005P3oool2000008<0oooo002d0?ooo`8000000P3o
ool2000000D0odh00P0000050?m2008000001@3oA`02000000030?lh0000
0000ocP00080ocP00P0000040?ln00<000001@3o:`000`000000oc400?la
00040?la00030000003o4`00oa<000<0oa<00P0000050?lI00040000003o
9P000000000001<0oooo00@000000?ooo`3oool00000PP3oool00;<0oooo
00D000000?ooo`3oool0oooo000000070?m>00040000003oE00000000000
0080od8000<000000?m7003oA`00103oA`02000000030?m?000000000000
0080ocP000<000000?ln003o?P00103o?P000`000000odL00?m700020000
0080ob/000<000000?la003o<@00103o<@0010000000ocX0000000000002
0?lC00030000003o6@00oaT000@0oaT000<000000?lV003o9P000P3o9P02
00000140oooo00@000000?ooo`3oool00000PP3oool00;80oooo00@00000
0?ooo`3oool0oooo0P0000050?m>00800000103oE002000000H0odL000<0
00000?m?003oC`000P3oC`03000000D0och00P0000050?m7008000001@3o
<@02000000@0ocX00P0000050?lI008000001@3o9P04000000l0oooo00@0
00000?ooo`3oool00000PP3oool008P0oooo0P00000V0?ooo`8000000`3o
ool00`000000oel00?mO000200000080odh000<000000?mD003oE000103o
E00010000000oe`00000000000020?m7008000001@3oC`02000000030?mG
0000000000000080och000<000000?m7003oA`001@3oA`0010000000oe40
0000000000020?la00030000003o>P00ocX000@0ocX000@000000?m:0000
000000000P3o6@000`000000obH00?lV00050?lV00040000003oLP000000
0?ooo`8000003@3oool010000000oooo0?ooo`0000220?ooo`00R@3oool0
0`000000oooo0?ooo`0S0?ooo`040000003oool0oooo0?ooo`8000001@3o
G`02000000D0oe@00P0000040?mL00<000001@3oC`02000000@0oeL00P00
00070?m700030000003oD@00oe400080oe400P0000060?lj00030000003o
BP00odX00080odX00P0000070?lV00050000003oLP00og800?mb00000000
0P3oool2000000`0oooo0P0000230?ooo`00RP3oool00`000000oooo0?oo
o`0P0?ooo`8000000`3oool00`000000oel00?mO00050?mO00040000003o
IP00000000000080oe@000<000000?mL003oG000103oG0000`000000of@0
0?mT000200000080odl000<000000?mG00000000103oE`000`000000of80
000000040?m7008000001@3oD@000`000000of00000000040?lj00030000
003oBP00odX000<0odX000<000000?m[000000001@3o9P000`000000og80
0?mb00020?mb00030000003oool0oooo0080oooo0`00002>0?ooo`00R@3o
ool00`000000oooo0000000P0?ooo`030000003oool0oooo0080oooo0P00
00050?mO00800000103oIP02000000D0oe`00P0000050?mT008000000P3o
E`001@000000oeL00?mG003oE`00000000<0of800P0000000`3oA`000000
0?mA00050?mA00040000003oH000of000?mP0080000000<0ocX00000003o
BP00103oBP0010000000of/00?m[003oJ`0200000080obH000<000000?mb
003oLP00103oLP000`000000oooo0?ooo`040?ooo`800000S03oool008P0
oooo00@000000?ooo`3oool000007P3oool2000000@0oooo00<000000?m`
003oL0000P0000020?mO00030000003oIP00ofH000@0ofH000@000000?m_
0000000000000P3oG0000`000000of@00?mT00050?mT00050000003oK`00
00000?mG000000000P3oE`000`000000of800?mR00040?mR00030000003o
D@00oe4000<0oe400P0000060?mP00030000003oBP00odX000<0odX000<0
00000?m[003oJ`00103oJ`000`000000obH0000000060?mb00030000003o
ool0oooo00H0oooo0P00002:0?ooo`00Q`3oool3000000030?ooo`000000
000001`0oooo00<000000?ooo`3oool00P3oool2000000D0og000P000005
0?mV00800000103oK`03000000D0of@00P0000030?m_0080000000<0oeL0
0000003oHP001@3oHP0010000000og000000000000020?mA00030000003o
H000of0000D0of0000<000000?mh00000000103oBP000`000000of/00?m[
00050?m[00030000003oLP00og8000H0og8000<000000?ooo`3oool01`3o
ool2000001@0oooo1@00001_0?ooo`00Z03oool00`000000oooo0?ooo`02
0?ooo`030000003oL000og0000D0og0000@000000?mh0000000000000P3o
IP000`000000ofl00?m_00040?m_00030000003oNP00ogX0008000000P3o
I0000`000000ofl00?m_00040?m_008000001@3oHP02000000@0og000P00
00070?mP00040000003oN000ogP00?mh0080000000<0odX00000003oJ`00
1P3oJ`000`000000ok<0000000060?mb008000002`3oool2000001@0oooo
00<000000?ooo`3oool0K`3oool009L0oooo1@00000:0?ooo`800000103o
ool2000000D0og000P0000040?mh008000001@3oK`02000000D0ogX00P00
00070?m_00040000003oO@00000000000080of8000<000000?m`003oL000
103oL00010000000oh@00000000000040?mP00030000003oN000ogP000@0
ogP000<000000?m[003oJ`001@3oJ`001@000000ok<00?nc003o/`000000
00@0og8000@000000?ok003on`000000303oool300000140oooo00<00000
0?ooo`3oool0K`3oool009T0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`030000003oP000oh00008000000P3oL0000`00
0000ogP00?mh00040?mh00040000003oP`00000000000080ofl000<00000
0?mj003oNP001@3oNP000`000000ohL0000000040?m_00<000000`3oO@02
000000D0og000P0000040?n40080000000<0of000000003oN0001@3oN000
0`000000oj00000000040?m[00800000103o/`001@000000og800?mb003o
LP00000000<0oo/000<000000?ooo`3oool0303oool200000100oooo00<0
00000?ooo`3oool0K`3oool009T0oooo00<000000?ooo`3oool01`3oool2
000000D0oooo00<000000?n0003oP0000`3oP002000000D0ogP00P000004
0?n3008000001`3oNP0010000000ohL00?n7003oQ`02000000050?m_0000
0000ogd00?mm000000000`3oO@0010000000ohh00000000000020?m`0003
0000003oQ000oh@000H0oh@000<000000?mh003oN000103oN00010000000
oj000?nP003oX002000000030?m[00000000ok<000H0ok<000<000000?mb
000000001@3on`000`000000oooo0?ooo`0=0?ooo`<000003@3oool00`00
0000oooo0?ooo`1_0?ooo`00V@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo00<000000?n0003oP000103oP00010000000
ohX00000000000020?mh00030000003oP`00oh<000@0oh<000@000000?n?
000000000000103oNP000`000000ohL00?n700040?n700060000003oO@00
ogd00?mm00000000ogd00P0000040?n>008000001`3oQ002000000030?nQ
00000000ogP000<0ogP000<000000?nP003oX000103oX0000`000000ok<0
0?nc00070?nc00030000003on`00oo/000@0oo/000<000000?ooo`3oool0
403oool2000000X0oooo0P00001a0?ooo`00V@3oool00`000000oooo0?oo
o`040?ooo`8000001P3oool00`000000oh000?n000030?n000800000103o
RP02000000D0oh<00P0000040?n?0080000000<0ogX00000003oQ`001@3o
Q`001@000000oiL0000000000000ogd0008000001P3oSP000`000000ojH0
000000050?n400030000003oX@00oj400080oj400P0000000`3oN0000000
0?nP00050?nP00030000003oi`00000000L0ok<000<000000=[o00000000
1P3on`000`000000oooo0?ooo`0A0?ooo`800000N`3oool009P0oooo0P00
00040?ooo`8000001P3oool2000000030?n@0000000000000080oh0000<0
00000?n:003oRP00103oRP0010000000oiD00000000000020?n300030000
003oS`00ohl000H0ohl000<000000?n7003oQ`000`3oQ`02000000@0oiL0
0P0000060?n>00040000003oYP00ojH00?nV0080000000<0oh@000000000
00001`3oX@000`000000oj000?nP00040?nP00050000003oi`00onL00?oW
000000001@3o/`0010000000f_l00=[o000000060?ok00030000003oool0
oooo01<0oooo0P00001i0?ooo`00W@3oool4000000<0oooo0P0000050?n@
008000001@3oRP02000000@0oiD00P0000080?n?00040000003oW@000000
00000080ohL000<000000?nG003oU`00103oU`03000000@0ohh000<00000
0?nV003oYP00103oYP000`000000oj400?nQ00060?nQ00030000003ocP00
000000@0oj0000<000000?oW003oi`000P3oi`0010000000ok<00?nc003o
/`02000000@0f_l000<000000?ok003on`00103on`000`000000oooo0?oo
o`0D0?ooo`800000M`3oool009`0oooo00<000000?ooo`3oool0103oool0
0`000000oi000?n@00050?n@00040000003oV`00000000000080ohX000<0
00000?nE003oU@00103oU@0010000000oj<00000000000040?n?00800000
103oW@02000000D0oiL00P0000000`3oZ`0000000?n[0002000000030?n>
00000000ojH000D0ojH000@000000?o7000000000000103oX@02000000<0
olh00P0000000`3oX00000000?oW00050?oW00030000003o/`00000000H0
f_l000<000000?ok003on`000`3on`000`000000L_l00000000G0?ooo`80
00004`3oool4000005h0oooo002K0?ooo`030000003oool0oooo00@0oooo
00<000000?nP00000000103oT002000000@0oi/00P0000050?nE00800000
103oX`02000000030?n?00000000oid000D0oid000@000000?n_00000000
00000P3oU`001@000000oj/00?n[003oZ`00000000<0oj/000<000000?nV
003oYP00103oYP000`000000olL00?o700020?o70080000000<0oj400000
003ocP001P3ocP000`000000onL00?oW00060?oW00030000003Jo`00f_l0
00H0f_l000<000000?ok003on`000P00000207;o00030000003oool0oooo
01L0oooo0P00000A0?ooo`030000003oool0oooo05l0oooo002I0?ooo`80
00001@3oool2000000<0oj000P0000000`3oT00000000?nK00050?nK0004
0000003oZ000000000000080oiD000<000000?nS003oX`001P3oX`000`00
0000oid00?nM00030?nM00800000103o[`02000000@0oj/000H000000?n[
003oZ`0000000?o5000000040?nV00030000003oa`00olL000D0olL000<0
00000?o>003ocP001@3ocP000`000000kOl0000000060?oW00030000002c
o`00000000L0f_l000<000000?ok000000001@1bo`000`000000oooo0?oo
o`0H0?ooo`<000003`3oool00`000000oooo0?ooo`1N0?ooo`00V03oool0
0`000000oooo0?ooo`040?ooo`030000003oX000oj0000D0oj0000<00000
0?nK003oV`000`3oV`02000000@0ojP00`0000060?nS0080000000<0ok<0
0000000000000P3oW@000`000000ojl00?n_00040?n_00030000003oaP00
000000<0oj/00`0000030?o50080000000<0ojH00000003oa`001P3oa`00
0`000000ooH0000000050?o>00050000003]o`00kOl00>go00000000103o
i`0010000000/ol00;?o000000080=[o00030000001bo`00L_l000D0L_l0
00<000000?ooo`3oool06@3oool3000000h0oooo00<000000?ooo`3oool0
G@3oool009H0oooo0P0000060?ooo`030000003oX000oj0000@0oj000P00
00000`3o[0000000000000020?nK00030000003oZ000ojP000@0ojP000<0
00000?nf003o]P000P0000020?nS008000001@3o/`02000000D0ojl00P00
00030?o60080000000<0oj/00000003oa@001P3oa@000`000000olL00?o7
00050?o700050000003omP00ooH00?of000000000`3ocP000`000000kOl0
0>go00020>go00050000003oi`00onL00?oW00000000102co`000`000000
f_l00=[o00030=[o0080000000<0Eol00000001bo`001P1bo`000`000000
oooo0?ooo`0K0?ooo`8000002P3oool010000000oooo0?ooo`00001N0?oo
o`00U@3oool00`000000oooo0?ooo`050?ooo`040000003o[`0000000000
0080oj000P0000050?n/00<000001@3oZ0000`000000okH00?nf00030?nf
008000001`3o/`0010000000olL00000000000020?n_00030000003oaP00
olH000D0olH00P0000060?o500030000003oj@00000000@0olL00P000005
0?of00030000003ocP00000000H0kOl000<000000?oW000000001P2co`00
1@000000f_l00=[o003Jo`00000000<0Eol000<0000007;o001bo`001@1b
o`000`000000oooo0?ooo`0M0?ooo`8000002@3oool2000005l0oooo002C
0?ooo`8000001`3oool00`000000ojl00?n_00020?n_00<000001P3o[000
0`000000okT00?ni000200000080ojP000<000000?nf003o]P00103o]P00
0`000000olP0000000040?nc00800000103oa`02000000L0olH000<00000
0?oR00000000103oa@02000000<0onT00P0000000`3oa`0000000?of0007
0?of00030000003]o`00kOl000H0kOl000<000000;?o002co`001@2co`00
10000000f_l000000000000505Oo00030000001bo`00L_l000D0L_l000<0
00000?ooo`3oool07P3oool2000006P0oooo002B0?ooo`030000003oool0
oooo00H0oooo00<000000?n_003o[`000`3o[`000`000000ok`00?nl0002
00000080oj`00P0000050?ni008000001@3o]P02000000<0olP00P000000
0`3o/`0000000?o700050?o700030000003og`00000000@0olH00P000002
0?oR00<0000000<0olD00000003oj@001P3oj@000`000000ooH00?of0006
0?of000300000037o`00000000H0kOl000<00000097o000000001`2co`00
0`000000Eol005Oo000505Oo00030000001bo`00L_l000<0L_l00P000000
0`00ob4000000?ooo`0P0?ooo`800000IP3oool007D0oooo1@0000020?oo
o`800000103oool2000000d0oooo00<000000?ooo`3oool01P3oool00`00
0000ojl00?n_00030?n_00030000003o_000ok`000<0ok`00P0000070?ni
00040000003ob@00000000000080okH000<000000?o8003ob0001@3ob000
0`000000olL00?o700030?o7008000000`3og`02000000030?o600000000
on8000<0on8000@000000?oR003ohP0000001`3oj@000`000000i_l00000
00060?of000500000037o`00aol00<Oo00000000103]o`0010000000TOl0
097o000000060;?o00030000000no`00000000L0Eol000D0000007;o001b
o`00L_l000000003003o8@030000003oool0oooo0240oooo0P00001T0?oo
o`00M`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0000
00X0oooo0P0000070?ooo`80000000<0okh00000000000000P3o[`000`00
0000ok`00?nl00040?nl00030000003ob`00000000@0okT00P0000040?o9
008000001`3ob00010000000omd00000000000020?o700030000003og`00
oml000D0oml000<000000?oR003ohP000`3ohP001@000000on800000003h
o`00000000@0onT00P0000030>Ko00040000003omP00ooH00?of00800000
1037o`001@000000kOl00>go003]o`00000000@0TOl000<000000;?o002c
o`000P2co`0010000000?_l003ko0000000705Oo00040000001bo`000000
000000D00?lQ00<000000?ooo`3oool08P3oool200000680oooo001g0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`050?ooo`8000001@3o_P02000000D0ok`00P0000030?o;
0080000000<0okT00000003ob@001@3ob@000`000000om`0000000040?o8
00800000103og@02000000L0oml000<000000?om00000000103ohP020000
00<0n?l00P0000000`3oj@0000000>Ko00050>Ko00030000003omP000000
00L0aol000<000000>go000000001P2Ao`0010000000/ol00;?o00000004
03ko00030000001Go`00Eol000D0Eol000<00000003o8@00ob401@00ob40
0`000000oooo0?ooo`0T0?ooo`80000000<0oooo0000003oool0G@3oool0
07L0oooo00<000000?ooo`3oool0203oool2000000P0oooo0P0000070?oo
o`030000003o_P00okh000D0okh000@000000?o<0000000000000P3o_000
0`000000ol/00?o;00050?o;00030000003ob@00olT000<0olT00P000003
0?oL0080000000<0olP00000003og@001@3og@000`000000ooL000000004
0?oO008000000`3oo@02000000030?oR00000000000000H0n?l000<00000
0>Ko003Vo`001P3Vo`000`000000aol00<Oo00070<Oo00030000002Ao`00
TOl000D0TOl000<000000;?o000000001P0no`000`000000Eol005Oo0003
05Oo000300000000oc00000000L00?lQ00<000000?ooo`3oool09@3oool3
000005d0oooo001g0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oc@000000
00@0okh00P0000040?o<008000001P3ob`02000000030?oK000000000000
0080olT000<000000?oL003og0001@3og0000`000000omd00?oM00030?oM
008000000`3om`02000000030?oO00000000ood000H0ood000<000000?So
000000001@3ho`000`000000aol0000000060>Ko00030000002Vo`000000
00L0aol000<0000007?o000000001`2Ao`000`000000?_l003ko000603ko
00030000001Go`00Eol0008000000P00oc000`0000000?lQ003o8@05003o
8@030000003oool0oooo02H0oooo00@000000?ooo`00000000005`3oool5
000003l0oooo001f0?ooo`8000002P3oool3000000@0oooo0P0000080?oo
o`040000003oc@00old00?o=0080000000<0okh00000003oc0001@3oc000
10000000om/00000000000020?o;008000001@3of`02000000H0om`00P00
00000`3olP000000000000020?oM00030000003om`00ooL000D0ooL000<0
00000?om003oo@001@3oo@0010000000fol00000000000030?So00800000
0`37o`0010000000i_l00>Ko003Vo`02000000<0Y_l00P0000030<Oo0080
00000`1co`000`000000TOl0097o0003097o00030000000Vo`00000000L0
?_l000<0000005Oo000000001@00oc000`0000000?lQ003o8@05003o8@03
0000003oool0oooo02T0oooo0P00000G0?ooo`030000003oool0oooo03l0
oooo00280?ooo`<000001`3oool00`000000old00?o=00040?o=00800000
1@3oc0000`000000om/00?oK00020?oK008000001`3of`0010000000onl0
0000000000020?oL008000001@3olP02000000L0ooL000<000000>Wo0000
0000103oo@02000000<0fol00P0000000`3ho`0000000<Oo00050<Oo0003
0000003Vo`00000000L0Y_l000<000000<Oo000000001@1co`0010000000
TOl0097o002Ao`02000000809_l000<0000003ko000no`001P0no`000`00
00000?l`003o<004003o<00300000000ob400?lQ00<00?lQ0`00000]0?oo
o`8000005@3oool00`000000oooo0?ooo`0o0?ooo`00QP3oool2000000T0
oooo00<000000?o=003oc@00103oc@000`000000om/00?oK000200000080
ol`000<000000?oK003of`000`3of`0010000000ond00000000000040?oK
00030000003ok`00onl00080onl00P0000070?ob00030000003bo`000000
00@0ooL00P0000030>Wo0080000000<0ood00000003Ko`00103Ko`000`00
0000fol0000000080<Oo00030000002Vo`00Y_l000L0Y_l000<0000007?o
001co`001@1co`000`000000TOl00000000502Ko00030000000no`00?_l0
00<0?_l00P0000000`00och00000003o<005003o<00500000000ob400?lQ
003o8@0000000`00okD00`000000oooo0?ooo`0/0?ooo`8000002`3oool4
000000@0oooo00<000000?ooo`3oool0?`3oool008D0oooo00<000000?oo
o`3oool01`3oool2000000030?oK0000000000000080old00P0000050?oK
008000001@3of`000`000000ond00?o]00020?o]0080000000<0om/00000
003ok`00103ok`0010000000nOl00000000000040?ob00040000003bo`00
l_l00?;o0080000000<0ooL00000003Yo`001P3Yo`000`000000fol00=_o
00040=_o0080000000<0Zol000000037o`001@37o`000`000000R_l00000
00060:Ko0080000000<0F?l00000001co`001P1co`000`0000009_l002Ko
000502Ko00050000000no`00?_l003ko000000000`00och00`0000000?l`
003o<004003o<00400000000ob400000000000@00?ne00<000000?ooo`3o
ool0;P3oool200000140oooo00<000000?ooo`3oool0?`3oool008@0oooo
00<000000?ooo`3oool01P3oool2000000D0om/00P0000060?oK00800000
00<0on/00000000000000P3of`000`000000ond00?o]00050?o]00030000
003ok`00onl000<0onl000<000000?Wo003io`000P3io`02000000030?ob
00000000l_l000D0l_l000<000000>Wo003Yo`001@3Yo`000`000000`_l0
000000040=_o008000000`2[o`0010000000aol00<Oo0037o`02000000<0
R_l000<000000:Ko002Vo`000P2Vo`000`000000F?l005So000205So0003
0000001co`00Lol000<0Lol000<00000013o000000001P0Vo`0010000000
?_l0000000000005003o?P0300000000oc000?l`00@00?l`00<00000003o
]@00okD01@00okD00`000000oooo0?ooo`0_0?ooo`8000003P3oool20000
0440oooo00220?ooo`800000203oool00`000000om/00?oK00040?oK0080
000000<0onX00000000000000P3of`02000000D0on/00P0000060?o]0080
000000<0oOl00000000000000P3ok`000`000000nOl00?Wo00050?Wo0003
0000003bo`00l_l000@0l_l000<000000=;o00000000103Yo`02000000<0
`_l00P000000103Ko`0000000:_o000000040:_o000300000037o`000000
00H0R_l000@000000:Ko0000000000001@1Ho`0010000000Lol007?o001c
o`02000000<04?l000<0000002Ko000Vo`00100Vo`000`0000000?ln003o
?P06003o?P0400000000oc000?l`003o<080000000<00?nj00000000okD0
1@00okD00`000000oooo0?ooo`0a0?ooo`800000C`3oool00840oooo00<0
00000?ooo`3oool01`3oool010000000onT00000000000020?oK00800000
1@3ojP02000000H0on/00P0000000`3ooP000000000000020?o]00800000
1@3mo`02000000L0nOl000<000000=go00000000103bo`0010000000d_l0
0=;o003Bo`02000000030>Wo00000000`_l000H0`_l000@000000:_o002[
o`0000001@2[o`000`000000R_l008[o000608[o00030000001Ho`00F?l0
00H0F?l000<0000007?o000000001@0@o`000`0000009_l002Ko000202Ko
0080000000<00?m<00000000och01P00och0100000000?l`000000000003
003o^P0300000000okD00?ne00D00?ne00<000000?ooo`3oool0<P3oool2
000004d0oooo001o0?ooo`8000002@3oool00`000000onT00?oY00020?oY
008000001`3ojP0010000000oo/00000000000020?o[008000001@3ooP02
000000L0oOl000<000000>Ko00000000103io`02000000<0gOl00P000000
0`3bo`0000000=;o00050=;o000300000032o`00`_l000D0`_l000D00000
09;o00000000Zol0000000040:_o00030000001`o`00000000H0R_l000<0
000003oo00000000201Ho`000`0000004?l0013o0005013o00040000000V
o`000000000000<00?m<00<00000003o?P00och01P00och00`0000000?nj
003o^P04003o^P0300000000okD00?ne00@00?ne00<000000?ooo`3oool0
<@3oool3000004d0oooo001n0?ooo`030000003oool0oooo00P0oooo00<0
00000?oY003oj@000`3oj@0010000000ooP00000000000040?oZ00030000
003on`00oo/00080oo/00P0000070?on00030000003/o`00000000@0oOl0
0P0000030>Ko0080000000<0nOl00000003Mo`001P3Mo`000`000000d_l0
0=;o00040=;o00030000002[o`00000000@0`_l00P00000309;o00800000
0P2[o`02000000<0L?l000@0000008[o002:o`00R_l00P00000303oo0003
0000001Ho`00F?l000<0F?l00P0000000`00o`800000013o0006013o0003
00000000od`00?m<00@00?m<00<00000003o?P00och00`00och200000003
003o_`0000000?nj00@00?nj00<00000003o]@00okD01@00okD00`000000
oooo0?ooo`0^0?ooo`8000000P3oool00`000000oooo0?ooo`1;0?ooo`00
O03oool2000000X0oooo00<000000?oY003oj@000`3oj@000`000000ooP0
0?oh00020?oh0080000000<0onX00000003on`00103on`000`000000lOl0
000000040?on008000000`3/o`02000000030?go00000000i_l000H0i_l0
00<000000=go003Mo`00103Mo`02000000030;co00000000d_l000<0d_l0
00@000000:_o002[o`00Zol00P0000000`32o`00000009;o000509;o0003
0000002[o`00000000H0L?l000<0000008[o000000001@0oo`000`000000
F?l005So000205So000300000000o`800?l200800?l200<00000013o000@
o`000`0@o`000`0000000?mI00000006003oC00500000000och00?ln003o
?P0000000`00okl00`0000000?nj003o^P04003o^P0300000000okD00?ne
00800?ne0P0000000`00]Ol000000?ooo`0/0?ooo`800000103oool00`00
0000oooo0?ooo`1;0?ooo`00K@3oool4000000X0oooo00<000000?ooo`3o
ool02@3oool010000000ooH00000000000020?oY00030000003on000ooP0
00D0ooP000<000000?ok003on`000`3on`0010000000lOl00?7o003ao`02
000000030?on00000000k?l000H0k?l000<000000>Ko003Vo`00103Vo`02
000000030<Wo0000000000000080gOl00P0000040;co0080000000<0d_l0
0000002[o`001@2[o`000`000000T_l009;o000509;o00800000201`o`00
0`000000?ol003oo000503oo00040000001Ho`000000000000D00?l200@0
0000013o000@o`004?l00P000002003oF@0300000000od`00?m<00@00?m<
00@00000003o?P00000000001@00okl00`0000000?nj003o^P03003o^P03
00000000okD00?ne008000000`00]Ol00`000000oooo0?ooo`0Y0?ooo`80
00001P3oool00`000000oooo0?ooo`1;0?ooo`00K@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00P0oooo0P0000040?of00800000
1P3on002000000030?Ko0000000000000080oo/000<000000?7o003ao`00
103ao`02000000H0k?l000@000000=?o0000000000000P3Vo`02000000D0
bOl00P0000080;co00030000002[o`00Zol000@0Zol000@0000007co0000
000000001@2Bo`03000000H0L?l000<0000002[o000000001`0oo`000`00
00000?l2003o0P06003o0P030000000@o`00000000D00?mI00<00000003o
C000od`01000od`00`0000000?no003o_`05003o_`0300000000okX00?nj
00@00?nj0P000006002eo`030000003oool0oooo02H0oooo0P0000080?oo
o`030000003oool0oooo04/0oooo001^0?ooo`030000003oool0oooo00L0
oooo0P00000:0?ooo`030000003omP00ooH000@0ooH000@000000?Wo0000
000000000P3on002000000D0m_l00P0000060?7o00030000003Ko`00fol0
008000000P3/o`02000000@0dol00P0000070<Wo00030000002Xo`000000
00D0_?l00P0000000`2Eo`0000000:_o00030:_o00030000001lo`00O?l0
0080O?l00P0000000`2Bo`0000000000000205Wo008000000`1`o`020000
00<0:_l000<0000003oo000oo`000P0oo`0200000003003o500000000?l2
00L00?l200<00000003oF@00oeT01@00oeT0100000000?m<003oC000od`2
00000003003o``0000000?no00H00?no00@00000003o^P00okX00?nj0P00
00000`00^_l00000002eo`05002eo`030000003oool0oooo02@0oooo0P00
000;0?ooo`030000003oool0oooo04X0oooo001_0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0203oool2000000030?co00000000
00000080ooH00P0000040?Wo00<000001P3fo`0010000000h_l000000000
00020?7o008000001@3Ko`02000000H0dol000<000000;Oo000000001039
o`02000000<0Z?l00P0000000`2lo`0000000000000409Go0080000000<0
Zol00000001lo`001@1lo`02000000H0FOl00`00000602[o00040000000o
o`000000000000@00?lD00<00000003o0P00o`800`00o`8200000003003o
I@0000000?mI00D00?mI00@00000003oC000000000000`00ol<00`000000
0?no003o_`05003o_`0400000000okX00000000000<00;[o00<00000002e
o`00]Ol01@00]Ol00`000000oooo0?ooo`0Q0?ooo`8000003@3oool00`00
0000oooo0?ooo`080?ooo`800000103oool2000000@0oooo0P00000d0?oo
o`00K@3oool010000000oooo0?ooo`0000040?ooo`8000002@3oool20000
00D0o?l00P0000060?Wo00030000003Wo`00iol0008000000P3fo`020000
00@0h_l00P0000070=_o000300000033o`00000000@0dol000@000000;Oo
002go`00]ol00P0000000`39o`0000000:So00060:So00030000002Eo`00
UOl000H0UOl000<0000007co001lo`00101lo`020000000304Go00000000
FOl000D0FOl000@0000002[o0000000000001@0Zo`000`0000000?lD003o
5005003o500300000000o`800?l2008000001000ofD00`0000000?mI003o
F@04003oF@0300000000ol<00?o300@00?o300<00000003o_`00okl01@00
okl00`0000000;[o002jo`04002jo`0300000000]Ol00;Go00@00;Go00<0
00000?ooo`3oool07`3oool2000000l0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000003<0
oooo001^0?ooo`800000103oool2000000T0oooo0P0000060?co00040000
003/o`00000000000080nOl00P0000050>Oo008000001P3Ro`000`000000
c?l0000000040=_o008000000`33o`02000000030=?o00000000]ol000D0
]ol000<000000:So002Xo`001@2Xo`000`000000P_l00000000509Go0080
000000<0Iol00000001lo`000P1lo`03000000<0AOl000<0000005Wo001I
o`000P1Io`000`0000005ol00000000202[o00<0000000@0:_l000000000
ob@000001`00oa@2000000H00?mU00<00000003oF@00oeT00P00oeT20000
0003003oa`0000000?o300D00?o300<00000003o_`00okl00P00okl20000
0003002oo`0000000;[o00@00;[o00<00000002eo`00]Ol01@00]Ol00`00
0000oooo0?ooo`0L0?ooo`8000004@3oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0<@3oool0
07@0oooo00<000000?ooo`0000000P0000050?ooo`030000003_o`00kol0
008000000P3lo`02000000@0k?l00P0000070>Oo00030000003Co`000000
00@0h_l000@000000<co003<o`00c?l00P0000000`3Ko`0000000<?o0006
0<?o00030000002go`00]ol000@0]ol000<0000009Ko00000000102Xo`02
000000<0P_l00P0000000`2Eo`0000000000000406Oo00@000001P15o`00
10000000FOl000000000000301Oo00040000000Zo`00:_l002[o00<00000
0P00ob@00`0000000?lD003o5003003o500300000000ofl0000000L00?mU
00@00000003oF@00000000000`00olL00`0000000?o3003o``04003o``03
00000000okl00?no008000000`00_ol00`0000000;[o002jo`04002jo`03
00000000]Ol00;Go00800;Go0`00000L0?ooo`8000004`3oool010000000
oooo0?ooo`3oool400000080oooo00@000000?ooo`3oool000002@3oool2
000003@0oooo001d0?ooo`030000003oool0oooo0080oooo0P0000020?oo
o`030000003_o`00kol000<0kol00P0000060>co00030000003Jo`000000
00@0iol00P0000030=?o0080000000<0h_l00000003<o`001@3<o`000`00
0000`ol00<?o00040<?o0080000000<0Y_l00000000000000P2go`020000
00<0U_l00P0000000`2Xo`00000008;o000608;o00030000001Wo`00Iol0
00@0Iol000<0000006Oo000000002015o`000`0000005ol001Oo000401Oo
00030000000Zo`00000000<00?lT0`000003003o508000000P00ofl00`00
00000?mU003oI@06003oI@0300000000olL00?o700@00?o700<00000003o
``00ol<01000ol<2000000H00;oo00<00000002jo`00^_l00`00^_l00`00
00000;Go002eo`02000000<0027o00<000000?ooo`3oool05`3oool20000
01D0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo03<0oooo001d0?ooo`030000003oool0oooo
00@0oooo0P0000060>oo00030000003Oo`00000000@0k?l000@000000=[o
003Jo`00f_l00P0000000`3Wo`0000000=?o00060=?o00030000003<o`00
c?l000@0c?l000@000000;;o0000000000000P33o`02000000D0Y_l00P00
000709Ko000300000022o`00P_l000D0P_l000<0000005Go000000000`1W
o`040000000303;o00000000AOl000D0AOl000<0000000Ko000000001P0G
o`000`0000000?lT003o9005003o90<000001@00ofl00`0000000?mU003o
I@03003oI@80000000<00?o<00000000olL01@00olL0100000000?o3003o
``00ol<2000000030033o`0000000;oo00D00;oo00<00000002jo`00^_l0
1000^_l2000000D0027o00<000000?ooo`3oool05@3oool2000001L0oooo
00<000000?ooo`3oool0203oool2000000X0oooo0`00000c0?ooo`00M03o
ool00`000000oooo0?ooo`040?ooo`8000001@3_o`0010000000gol00=oo
003Oo`02000000030>co00000000f_l000D0f_l000<000000=?o003Co`00
103Co`02000000030;go0000000000000080c?l00P0000040;;o00800000
1`2Vo`000`000000QOl00000000509Ko00030000001`o`00000000@0P_l0
0P00000305Go00D00000100bo`0010000000AOl004Go0015o`0200000080
1_l000<0000001Oo000Go`000P0Go`0200000003003o<P0000000?lT00H0
0?lT10000004003oK`0500000000ofD00?mU003oI@0000000`00ol`00`00
00000?o7003oa`04003oa`0400000000ol<00000000000<00<?o00<00000
002oo`00_ol01@00_ol0100000000;[o002jo`00^_l200000003000`o`00
0000027o00D0027o00<000000?ooo`3oool04P3oool2000001P0oooo0P00
000W0?ooo`8000003P3oool2000000@0oooo0P00000=0?ooo`00M03oool0
0`000000oooo0?ooo`030?ooo`030000003So`00hol0008000000P3_o`00
0`000000gol00=oo00040=oo00030000003Jo`00f_l000@0f_l000@00000
0<Go0000000000000P3Co`02000000D0_Ol00P0000060;;o00030000002F
o`00000000@0Y_l00P00000308Go0080000000<0U_l00000000000000`1`
o`020000000308;o00000000EOl000@0EOl000<0000005Go000000001`0b
o`000`000000AOl00000000500Ko00040000000Go`000000000000@00?lb
00<00000003o9000ob@00P00ob@200000004003oN@0000000?m_003oK`80
00000P00ofl0100000000?mU000000000005003oc00300000000olL00?o7
00@00?o700<000000033o`00`ol01000`ol00`0000000;oo002oo`04002o
o`0400000000^_l00000000000<0033o00<00000000Qo`008Ol010008Ol0
0`000000oooo0?ooo`0@0?ooo`8000006`3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02`3oool007@0oooo00@000000?ooo`3oool0oooo0P000005
0>?o008000001P3Oo`0010000000c?l00000000000020=[o008000001035
o`02000000H0_Ol00P0000000`2So`000000000000020;;o008000000`2F
o`02000000030:Ko00000000QOl000H0QOl000<00000073o001`o`001@1`
o`000`000000EOl005Go000205Go0080000000@0EOl00000000Ro`000000
1`0bo`000`0000001_l000Ko000500Ko000300000000oc800?lb00D00?lb
00@00000003o9000000000001000ogT0100000000?m_003oK`00ofl40000
00P00?o<00@00000003oa`00olL00?o70P0000000`00aol000000033o`05
0033o`0300000000_ol00;oo00<00;oo0P000006000`o`03000000008Ol0
027o00@0027o00<000000?ooo`3oool03@3oool2000001d0oooo00<00000
0?ooo`3oool07P3oool3000000@0oooo00<000000?ooo`3oool00P000000
0`3oool00000000000030?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`00L`3oool01@00
0000oooo0?ooo`3oool0000000H0hol00P0000000`3Bo`00000000000002
0=oo00800000103<o`02000000H0aOl000@000000:ko0000000000000P2m
o`02000000D0Xol00P00000709Ko000300000025o`00QOl000@0QOl00P00
00000`1Oo`000000073o0004073o000400000014o`00000005Go00800000
00<0EOl00000000000000`0Ro`000`000000<_l003;o000203;o00800000
00<00?l900000006o`001006o`000`0000000?lo00000007003o<P030000
0000ogT00?mi00@00?mi00<00000003oK`00ofl00P00ofl4000000L00?o<
00@00000003oa`00000000000`00aol00`0000000<?o0033o`040033o`03
00000000_ol00;oo00<000000P00?_l00`000000033o000`o`04000`o`03
000000008Ol0027o00<0027o00<000000?ooo`3oool02`3oool2000001l0
oooo00<000000?ooo`3oool07@3oool01@000000oooo0000003oool00000
00<0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000030?ooo`030000003o
ool0oooo00/0oooo001c0?ooo`050000003oool0oooo0000003Ho`000P00
00020>?o008000001@3Bo`02000000H0c?l000@000000;So000000000000
0P35o`02000000@0[_l00P0000070:?o000300000026o`00000000D0U_l0
00@0000007Go0000000000000P25o`02000000@0Gol00P0000000`1`o`00
00000000000204Co00<0000000<0EOl00000000Ro`001@0Ro`0010000000
<_l0000000000004003o2@80000000<01_l00000000000000`00ocl00`00
00000?lb003o<P02003o<P80000000<00?n200000000ogT01@00ogT01000
00000?m_000000000004003oc`<000001@00ol`00`0000000<Oo0037o`04
0037o`0300000000`ol00<?o00@00<?o0P000005000no`0300000000<?l0
033o00D0033o00<00000000Qo`008Ol00P008Ol2000000X0oooo0P00000R
0?ooo`030000003oool0oooo01`0oooo00D000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00/0oooo
001c0?ooo`<00000103Ho`03000000H0d_l000@000000<3o000000000000
0P3<o`02000000@0^?l00P0000060:ko00030000002Eo`00000000@0Xol0
0P00000308Ko0080000000<0U_l0000000000000101eo`02000000P0Gol0
00D0000004Co0014o`00A?l00000000304Co00030000000Ro`008_l000H0
8_l000<00000003o2@00o`T01P00o`T00`0000000?lo003o?`04003o?`04
00000000oc800000000000@00?n200<00000003oN@00ogT01000ogT00`00
00000?o?003oc`04003oc`0300000000ol`00?o<0080000000D00?o<0000
000000000<co000000060037o`0400000000`ol00<?o0033o`80000000<0
04co00000000?_l01@00?_l00`000000033o000`o`04000`o`0300000000
8Ol0027o008000000P1b0?l00`000000oooo0?ooo`050?ooo`800000903o
ool00`000000oooo0?ooo`0L0?ooo`050000003oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`02000000030?ooo`000000000000L0oooo
0`0000000`3oool00000000000020?ooo`030000003oool0oooo00/0oooo
001c0?ooo`030000003Ho`00f?l000@0f?l000<000000<Ko0036o`000P00
00020=;o008000001030o`02000000H0^?l000@000000:7o000000000000
0P2^o`02000000<0UOl00P0000000`2So`00000008Ko000608Ko00030000
001eo`00MOl000@0MOl000<00000053o000000001@1Oo`020000000403Co
000000000000000000<0A?l000<0000001;o000000001@0Ro`0200000003
003o5`0000000?l900D00?l900<00000003oB`0000001P00ocl00`000000
0?n2003oPP04003oPP0300000000ogT00?mi00800?mi0P0000000`00om80
0000003oc`05003oc`0300000000ol`00?o<00@000000P00c?l00`000000
0<Oo0037o`030037o`0400000000`ol00000000000<004co00<00000000n
o`00?_l01@00?_l00`000000033o000`o`03000`o`<00000101b0?l00`00
0000oooo0?ooo`030?ooo`8000009P3oool00`000000oooo0?ooo`0M0?oo
o`<00000103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00/0oooo001c0?ooo`<000000P3Ho`02000000D0a_l00P0000060<3o0004
0000002[o`00000000000080^?l00P0000040:7o008000001`2Eo`000`00
0000Q_l008Ko000408Ko0080000000<0I_l00000001eo`000`1eo`001000
0000D?l0053o001@o`020000000305oo0000000000000080=?l010000000
0`14o`0000000000000301;o0080000000<08_l00000000000001000oaL0
100000000?l9003o2@00o`T2000000<00?m;00<00000003o?`00ocl00P00
ocl00`0000000?n:00000006003oPP0400000000ogT00000000000@00?oB
00<00000003oc`00oll01000oll2000000@00<co0`0000050037o`800000
1P00C?l00`00000003ko000no`04000no`0300000000<?l0033o00<00000
0P1G0?l00`000000LP3o0780o`030780o`030000003oool0oooo00800000
:03oool00`000000oooo0?ooo`020?ooo`8000006`3oool00`000000oooo
0?ooo`020?ooo`800000503oool2000000d0oooo001c0?ooo`030000003o
ool0oooo00<000001P36o`0010000000/ol00000000000020<3o00800000
102[o`02000000H0XOl000<0000008Oo000000001@2Eo`0010000000N?l0
00000000000208Ko00800000101Vo`020000000307Go00000000D?l000D0
D?l000D0000003Co000do`00=?l00000000403Co00030000000Bo`004_l0
00D04_l000<00000003o5`00oaL01@00oaL00`0000000?l900000006003o
B`0400000000ocl00000000000<00?n:00<00000003oPP00oh801000oh80
0`0000000?oB003odP04003odP0300000000oll00?o?00800?o?0P000000
0`00col00000003<o`05003<o`<0000000<00<Oo0000000000000P00FOl0
0`00000004co001<o`04001<o`0300000000?_l003ko00<003ko0`000005
05L0o`030000001b0?l0LP3o00@0LP3o0P00000Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`120?ooo`00L`3oool0
0`000000oooo0?ooo`030?ooo`8000000P36o`02000000@0/ol00P000006
0:_o00040000002Do`00000000000080XOl00P00000308Oo0080000000<0
UOl0000000000000101ho`02000000P0I_l000<00000053o001@o`00101@
o`000`0000009_l000000002000000<0=?l00P0000000`05o`00000001;o
000401;o000300000000ob<0000000L00?lG00<00000003oB`00od/01P00
od/00`0000000?n:003oRP03003oRP0300000000oh800?n200800?n20P00
00000`00omD00000003odP05003odP0400000000oll00000000000@00<oo
00<00000003<o`00c?l01@00c?l3000000<005Wo00<00000001<o`00C?l0
1000C?l00`00000003ko000no`0300000080?P3o00<0000005L0o`1G0?l0
101G0?l00`000000LP3o0780o`040780o`030000003oool0oooo02P0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0480
oooo001c0?ooo`030000003oool0oooo00D0oooo0P0000060;?o00040000
002No`00000000000080Zol00P00000409Co008000001`27o`000`000000
N?l007So000407So00030000001Ho`00000000D0I_l00P0000000`11o`00
000000000002053o0080000000<09_l00000000000000P0000000`0do`00
00000000000400Go0080000000<04_l00000000000000`00ob<00`000000
0?lG003o5`02003o5`80000000<00?mE00000000od/01000od/200000003
003oT@0000000?n:00@00?n:00@00000003oPP00000000001000omD00`00
00000?oB003odP03003odP8000001P00col00`0000000<co003<o`03003<
o`80000000<006Go00000000FOl00`0000000`00FOl00000001<o`05001<
o`8000001@0n0?l00`000000E`3o05L0o`0405L0o`030000001b0?l0LP3o
00@0LP3o00<000000?ooo`3oool0:03oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0@P3oool007<0oooo00<000000?oo
o`3oool01`3oool200000080/ol00P00000409ko008000001P2Do`000`00
0000N_l00000000508Oo00040000001[o`00000000000080N?l00P000003
05So0080000000<0I_l00000000000001@11o`02000000809_l000<00000
02Ko000Vo`000P0Vo`000`0000001Ol000Go000600Go000300000000ob<0
0?lS00@00?lS00@00000003o5`00000000001000oeD200000003003oB`00
0000000000<00?nA00<00000003oRP00ohX01000ohX00`0000000?oE003o
e@05003oe@0300000000om800?oB008000000P00d_l00`0000000<oo003?
o`04003?o`0300000000c?l00<co008000000`00IOl00`00000005Wo001I
o`02001Io`<000000`00C?l20000000302H0o`000000?P3o00D0?P3o00<0
000005L0o`1G0?l0101G0?l00`000000LP3o0780o`030780o`800000:@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
@P3oool007<0oooo00<000000?ooo`3oool02@3oool2000000H0W_l000@0
000008Oo0000000000000P2Do`02000000<0N_l00P0000000`27o`000000
0000000406_o008000001`1Ho`000`000000@Ol0047o0004047o00800000
00<06Ol0000000000000100Vo`000`0000000?l70000000500Go00800000
00<00?l_00000000ob<01@00ob<00`0000000?mE003oE@06003oE@030000
0000oi400?nA00@00?nA00@00000003oRP00ohX00?n:0P0000000`00omP0
0000003oe@06003oe@8000001@00d_l00`0000000<oo003?o`03003?o`<0
00001P00IOl00`00000005Wo001Io`03001Io`@000000`0V0?l00`000000
?P3o03h0o`0403h0o`030000001G0?l0E`3o00@0E`3o00<000000780o`1b
0?l00`0000000`3o0?/000000?ooo`0X0?ooo`030000003oool0oooo0080
oooo0P0000150?ooo`00L`3oool00`000000oooo0?ooo`0;0?ooo`800000
0P2No`02000000@0Qol00P00000707[o00030000001[o`00Jol000@0Jol0
00<0000004_o000000001@1Ho`0010000000=?l0000000000002047o0080
000000@06Ol00000000000006Ol00P0000000`0Vo`00000000000003003o
1`80000000<01Ol00000000000001000obl00`0000000?lS003o8`02003o
8`0300000000oel0000000D00?mE0P0000000`00oiP00000003oT@04003o
T@0400000000ohX00000000000@00?oH00<00000003oe@00omD00P00omD2
00000003003Eo`0000000=;o00D00=;o00<00000003?o`00col00P000002
001_o`0300000000IOl006Go00D006Go00<00000001Io`00FOl00P00FOl2
0000000302H0o`000000000000<09P3o00<0000003h0o`0n0?l0100n0?l0
0`000000E`3o05L0o`0305L0o`<000001@3o0?/00`000000oooo0?ooo`0V
0?ooo`800000BP3oool007<0oooo00<000000?ooo`3oool03@3oool20000
00H0Qol000<0000006ko000000001@1jo`0010000000G_l0000000000002
06_o008000000`1;o`020000000305So00000000000000@0=?l00P000002
01Wo00030000000Io`006Ol000<06Ol000<00000003o1`00o`L01@00o`L0
0`0000000?l_003o;`05003o;`0400000000ob<00000000000<00?mO0P00
00000`00oeD0000000000004003oV00300000000oi400?nA00<00?nA00<0
0000003of000omP01@00omP0100000000?oE000000000004003Eo`030000
0000d_l00=;o00@00=;o0P000005001_o`0300000000IOl006Go00@006Go
00<00000001Io`00FOl00P0000020100o`030000000V0?l09P3o00<00000
00<09P3o0000000n0?l0100n0?l00`000000E`3o05L0o`0300000080fP3o
00<000000?l0n`3o0?/00`3o0?/00`000000oooo0?ooo`0U0?ooo`800000
B`3oool007<0oooo00<000000?ooo`3oool03`3oool200000080Qol00P00
000306ko0080000000<0N_l0000000000000101No`02000000L0Bol000<0
000003Co000do`00100do`00100000003Ol000000000000401Wo00800000
00<00?lC00000000o`L01000o`L00`0000000?li00000007003o;`030000
0000oel00?mO00D00?mO00<00000003oV000oiP01@00oiP00`0000000?nA
003oT@0200000003003ofP0000000?oH00H00?oH00<00000003Eo`00eOl0
1000eOl00`0000000=;o003Bo`02003Bo`80000000<007Wo00000000Kol0
1000Kol00`00000006Go001Uo`04001Uo`<000001@0@0?l00`0000009P3o
02H0o`0202H0o`800000100n0?l4000000D0fP3o00<000000?l0n`3o0?/0
103o0?/00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04P0oooo
001b0?ooo`030000003oool0oooo0180oooo0P00000706ko00030000001N
o`00G_l000@0G_l000<0000003oo000000001@1;o`0010000000:?l00000
0000000203Co00@0000000@03Ol00000000000006Ol00P000004003o4`80
000000<00?l70000000000000`00ocT00`0000000?l_003o;`02003o;`80
000000<00?mW00000000oel00`00oel200000003003oW@0000000?nH00H0
0?nH0P000004003ofP0300000000omP00?oH00800?oH0P0000000`00f?l0
0000003Eo`05003Eo`0400000000d_l00000000000@007Wo00<00000001_
o`00Kol00`00Kol00`00000006Go001Uo`030000008000;o00<000000100
o`0@0?l00`0@0?l00`0000009P3o02H0o`0302H0o`D000000`2c0?l00`00
0000fP3o0=X0o`040=X0o`030000003o0?/0o`3k00<0o`3k00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000
oooo0?ooo`0D0?ooo`030000001^o`00K_l000<0K_l000@0000005;o0000
000000000P1No`02000000<0?ol00P0000000`1;o`0000000000000402So
0080000000<03Ol00000000=o`00100=o`000`0000000?lC003o4`06003o
4`0300000000ocT00?li00@00?li00@00000003o;`00000000001000ofL0
100000000?mO000000000004003oW@0300000000oiP00?nH00800?nH0P00
00000`00omd00000003ofP04003ofP0400000000omP00000000000@00=So
00<00000003Eo`00eOl00`00eOl2000000H007Wo00<00000001_o`00Kol0
0`00Kol3000000H000;o00<000000100o`0@0?l00`0@0?l00`0000009P3o
02H0o`0200000080T@3o100000020;<0o`030000003J0?l0fP3o00@0fP3o
00<000000?l0n`3o0?/0103o0?/00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo04P0oooo001b0?ooo`030000003oool0oooo01D0oooo0P00
00000`1^o`0000000000000405;o008000001`0oo`000`000000:?l002So
000402So00<000001@0=o`000`0000000?lM00000005003o4`80000000<0
0?m300000000ocT01@00ocT00`0000000?mW003oI`05003oI`0300000000
oid00?nM00D00?nM00@00000003oV000000000001000omd00`0000000?oJ
003ofP03003ofP0300000000f?l00=So00D00=So00<00000003Eo`00eOl0
0P0000020022o`0300000000NOl007Wo00@007Wo00<00000001_o`00Kol0
0P000002000Do`03000000000_l000;o00@000;o00<000000100o`0@0?l0
0`0@0?l3000000@0T@3o00@000000;<0o`2c0?l0/`3o0P0000000`2c0?l0
00000=X0o`050=X0o`030000003o0?/0o`3k00<0o`3k00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo
0?ooo`0G0?ooo`030000001Bo`00D_l000@0D_l000<0000003?o00000000
1@0oo`00100000007?l000000000000202So00<000000P02o`0200000003
00go00000000000000<00?lM0P0000000`00oa<0000000000004003o@`03
00000000ocT00?li00800?li00<00000003oK`0000001@00ofL00`000000
0?nS00000007003oW@0300000000omd00?oM00D00?oM00<00000003ofP00
omX00P0000000`00f_l00000003Ho`06003Ho`8000001@00P_l00`000000
07Wo001io`03001io`<000001@005?l00`00000000;o0002o`040002o`03
0000000@0?l0403o008000000P1c0?l00`000000T@3o0940o`030940o`03
0000002c0?l0/`3o0080/`3o0`0000050=X0o`030000003o0?/0o`3k0080
o`3k0`00000V0?ooo`030000003oool0oooo04P0oooo001b0?ooo`030000
003oool0oooo01P0oooo0P00000205;o008000000`0co`020000000303oo
00000000000000@07?l00`00000600;o000300000000oad00?lM00D00?lM
00<00000003o@`00od<01@00od<0100000000?li000000000003003oK`80
000000<00?mW0000000000000`00oj<00`0000000?nM003oW@02003oW@80
000000<00?oO00000000omd01P00omd2000000@00=[o00<00000003Ho`00
f?l00P00f?l200000003002:o`00000008;o00D008;o00<00000001io`00
NOl00P000002000To`03000000005?l001Co00<001Co00<000000002o`00
0_l010000_l3000000D0L`3o00<000000940o`2A0?l00`2A0?l00`000000
/`3o0;<0o`030;<0o`<000000P3J0?l6000000<0o`1b00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`180?ooo`00LP3oool00`000000oooo
0?ooo`0J0?ooo`8000001`0co`000`0000007?l001co000401co00<00000
1@02o`000`0000000?lW00000005003o7@0300000000od`0000000H00?m3
0P000007003oK`0300000000oj<00?nS00@00?nS00@00000003oW@000000
00001000oml00`0000000?oM003og@02003og@80000000<00=go00000000
f_l01000f_l0100000000=So000000000004002:o`0300000000P_l008;o
00@008;o0P000005000To`03000000005?l001Co00<001Co00<000000002
o`000_l00`00000205P0o`030000001c0?l0L`3o00<0L`3o00<000000940
o`2A0?l00`2A0?l00`000000/`3o0;<0o`020;<0o`L000000P3o0;<00`00
0000o`1b0?l0LP030?l0LP030000003oool0oooo02<0oooo00<000000?oo
o`3oool00P3oool2000000@0oooo0P0000040?ooo`800000>03oool00780
oooo00<000000?ooo`3oool0703oool00`000000<ol003?o000303?o0004
0000000Bo`000000000000807?l00P000003003o2080000000<00_l00000
000000000`00obL200000003003o7@000000000000<00?m<0P000002003o
@`8000000P00ogH00`0000000?m_003oK`02003oK`80000000<00?nX0000
0000oj<01@00oj<00`0000000?oO003og`05003og`0400000000omd00000
000000<00=go00<00000003Jo`00f_l00`00f_l2000000H008[o00<00000
0022o`00P_l00P00P_l200000003000bo`00000002Co00@002Co00<00000
000Do`005?l00`005?l3000000D0F03o00<0000007<0o`1c0?l0101c0?l0
10000000T@3o0940o`2A0?l6000000<0o`3W00@000000?l0/`3o0;<0o`2c
0P0000000`3o0;<000000?l0LP040?l0LP030000003oool0oooo0280oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0
oooo00@000000?ooo`3oool00000=`3oool00780oooo00<000000?ooo`3o
ool07@3oool20000000303?o00000000000000@04_l00P000007003o2003
00000000obL00?lW00D00?lW00<00000003oC000od`01@00od`2000000D0
0?mf00@00000003oK`00000000001000ojP00`0000000?nS003oX`02003o
X`0300000000on40000000H00?oO0P000006003Mo`0300000000f_l00=[o
008000000P00TOl00`00000008[o002:o`04002:o`0400000000P_l00000
000000@003;o00<00000000To`009?l00`009?l00`00000001Co000Do`02
00000080?`3o00<0000005P0o`1H0?l0101H0?l00`000000L`3o07<0o`03
07<0o`@000000`3]0?l00`000000o`3W0?l0i`040?l0i`030000003o0;<0
o`2c0080o`2c0`0000040?l0LP030000003oool0oooo0280oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0=@3oool00780oooo00<000000?ooo`3oool07`3oool0
0`0000004_l001;o000301;o0080000000<00?lB00000000o`P01000o`P0
0`0000000?l`00000005003o9`0300000000oe@0000000D00?m<00<00000
003oO@0000001P00ogH00`0000000?nX003oZ005003oZ00400000000oj<0
0000000000<00?oQ0P000002003og`8000000P00gol00`0000000=go003M
o`04003Mo`8000001@00TOl00`00000008[o002:o`03002:o`8000001P00
<_l00`00000002Co000To`03000To`<000001@0o0?l00`000000F03o05P0
o`0305P0o`030000001c0?l0L`3o00<000000P370?l00`000000k@3o0>d0
o`030>d0o`030000003o0>L0o`3W00<0o`3W00<000000?l0/`3o0;<0103o
0;<3000000<0o`1b00<000000?ooo`3oool08@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool01`3oool2000003P0oooo
001b0?ooo`030000003oool0oooo0200oooo0P000000100Bo`0000000000
00000003003o4P80000000<00?l80000000000000`00oc0200000003003o
9`000000000000<00?mD0P0000000`00od`0000000000003003oO@030000
0000ogH00?mf00800?mf00<00000003o[00000001P00ojP2000000L00?oQ
0P000005003Oo`0300000000gOl00=go00800=go00<00000002Ho`000000
1P00TOl00`00000008[o002:o`020000008003oo00<00000000bo`00<_l0
1000<_l00`00000002Co000To`0200000080:P3o00<0000003l0o`0o0?l0
100o0?l010000000F03o05P0o`1H0?l4000000H0a`3o00<000000>d0o`3]
0?l00`3]0?l00`000000o`3W0?l0i`030?l0i`030000003o0;<0o`2c0080
o`2c2000000T0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0g0?ooo`00LP3oool00`000000
oooo0?ooo`0Q0?ooo`<000001`00oa800`0000000?l`003o<005003o<003
00000000oe@00?mD00D00?mD00<00000003oO@00ogd01000ogd010000000
0?mf000000000003003o[08000000P00ojP2000000800?oR00<00000003o
h@00on400`00on400`0000000>7o00000006003Oo`0400000000gOl00000
000000<009So00<00000002Ao`00TOl00`00TOl3000000D003oo00<00000
000bo`00<_l00`00<_l3000000D0:P3o00<0000003l0o`0o0?l00`0o0?l4
000000<0YP3o00<000000<L0o`370?l010370?l00`000000k@3o0>d0o`03
0>d0o`/000000`3o06/00`000000o`0V00000003000002<0oooo00@00000
0?ooo`3oool0oooo0P00000:0?ooo`<00000=`3oool00780oooo00<00000
0?ooo`3oool0803oool01@000000oooo0?ooo`3oool0000000@00?lB0P00
00000`00ocT00000003o<003003o<080000000<00?mK00000000oe@00`00
oe@200000003003oP`0000000?mm00D00?mm00<00000003o[000oj`01@00
oj`2000000D00?oR0P0000000`00on40000000000003003Qo`0300000000
gol00=oo00<00=oo0P000006002Ho`0300000000TOl0097o008000000P00
Bol00`00000003oo000oo`04000oo`0300000000<_l003;o008000000P0G
0?l00`000000:P3o02X0o`0402X0o`030000000o0?l0?`3o008000000P2:
0?l00`000000YP3o0:H0o`030:H0o`03000000370?l0a`3o00@0a`3o00<0
00000>d0o`3]0?l00P0000020?l0cP030000003o0:00o`2P00<0o`2P00<0
00000?l0J`3o06/0103o06/2000000<0o`0V0`00000P0?ooo`030000003o
ool0oooo04L0oooo001b0?ooo`030000003oool0oooo01h0oooo0P000005
0?ooo`0400000000oa800000000000@00?li00@00000003o<00000000000
1000oe/0100000000?mD000000000004003oP`8000000P00ogd200000003
003o/00000000?n/00@00?n/00<00000003oi00000001P00on82000000H0
0>7o00<00000003Oo`00gol00P000002002Mo`0300000000V?l009So00<0
09So0`000005001;o`0300000000?ol003oo00<003oo0`00000501L0o`03
0000000Z0?l0:P3o00<0:P3o0`00000508X0o`030000002V0?l0YP3o00<0
YP3o00<000000<L0o`370?l00P370?l4000000D0o`3>00<000000?l0X03o
0:000`3o0:02000000@0o`1[2P00000L0?ooo`<00000B@3oool00780oooo
00<000000?ooo`3oool0703oool2000000P0oooo00<00000003o>@00ocT0
1@00ocT00`0000000?mK003oF`05003oF`0300000000oh<00?n300H00?n3
0P000004003o/080000000<00?n/0000000000000`00on@2000000800?oR
0P000002003Ro`0300000000hOl00>7o00<00>7o0`000005002Mo`030000
0000V?l009So008000000P00EOl00`00000004_o001;o`04001;o`030000
0000?ol003oo008000000P060?l00`0000005`3o01L0o`0401L0o`030000
000Z0?l0:P3o008000000P1`0?l00`000000RP3o08X0o`0408X0o`040000
002V0?l0YP3o0:H0o`H000000`3o0?H00`000000o`3>0?l0cP040?l0cP03
0000003o0:00o`2P0080o`2P1P0000030?l0BP8000001@3o01T3000001/0
oooo00<000000?ooo`3oool0A`3oool00740oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`090?ooo`8000000`00ocT200000003003o
HP000000000000<00?mK0P0000000`00ohP00000003oP`04003oP`800000
00<00?nd00000000ok001000ok02000000L00?oT0P000005003Ro`030000
0000hOl00>7o008000000P00Xol00`00000009go002Mo`04002Mo`800000
1@00EOl00`00000004_o001;o`03001;o`<000001@060?l00`0000005`3o
01L0o`0301L0o`<000001@1`0?l00`000000RP3o08X0o`0308X0o`@00000
0`3V0?l00`000000o`3f0?l0mP040?l0mP8000000`3o0<h6000000<0o`1h
0P0000050?l0BPH000000`3o01<2000001T0oooo00<000000?ooo`3oool0
A`3oool00740oooo00<000000?ooo`3oool06P3oool2000000h0oooo0`00
0005003oHP<000001000ohP200000003003oP`000000000000@00?nd00<0
0000003o/000ok000P000002003oi@0300000000on@00?oT00<00?oT00<0
0000003To`0000001P00h_l2000000D00:?o00<00000002Mo`00WOl00P00
WOl00`00000005oo00000006001Eo`0300000000Bol004_o008000000P00
2Ol00`0000001P3o00H0o`0400H0o`030000000G0?l05`3o008000000P1I
0?l00`000000L03o0700o`040700o`030000002:0?l0RP3o008000000P37
0?l00`000000iP3o0>H0o`030>H0o`800000103o0?H5000000<0o`2Q00<0
00000?l0N03o07P01@3o07P5000000<0o`0j0P0000040?l04`D000005P3o
ool00`000000oooo0?ooo`170?ooo`00L@3oool00`000000oooo0?ooo`0H
0?ooo`8000004P3oool00`0000000?mR003oHP03003oHP0300000000ohh0
000000H00?n800<00000003o]000ok@01@00ok@2000000D00?oU0P000000
0`00on@0000000000003003To`0300000000h_l00>;o00800>;o00<00000
002Xo`0000001P00Xol01000000009go000000000003001Oo`0300000000
EOl005Go00<005Go0`0000050009o`03000000060?l01P3o00<01P3o0`00
000505T0o`8000000`1`0?l4000000D0a`3o00<000000>H0o`3V0?l00`3V
0?l5000000<0o`3700<000000?l0X@3o0:400`3o0:4200000080o`1h0`00
00020?l0H0030000003o03X0o`0j00@0o`0j1@0000040?l040<00000503o
ool00`000000oooo0?ooo`170?ooo`00L@3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo01<0oooo0P0000000`00of80000000000003
003oSP8000000P00ohP200000003003o]`0000000?nd00@00?nd00<00000
003oiP0000001P00onD2000000H00>Co00@00000003Ro`00000000000`00
Z?l00`0000000:?o002So`03002So`8000001P00Gol00`00000005Go001E
o`020000008001Oo00<000000009o`002Ol010002Ol00`0000001P3o00H0
o`0200000080A@3o00<0000005T0o`1I0?l0101I0?l4000000<0Z`3o00<0
00000<L0o`370?l010370?l00`000000iP3o0>H0o`0200000080o`3Y00<0
00000?l0a`3o0<L0103o0<L2000000<0o`2Q100000060?l0H08000000P3o
03X200000080o`0a0P0000030?l040<000000P3o00h300000140oooo00<0
00000?ooo`3oool0A`3oool00740oooo00<000000?ooo`3oool05@3oool2
000001P0oooo00<00000003oSP00ohh01@00ohh2000000@00?ng0P000000
0`00ok@0000000000003003oiP8000000P00onD2000000800>Go00<00000
003To`00i?l00`00i?l2000000H00:So00<00000002So`00Xol00P000002
001Wo`0300000000Gol005oo00@005oo0P000005000Go`8000000`002Ol4
000000D0A@3o0P00000205T0o`8000000P2B0?l00`000000Z`3o0:/0o`03
0:/0o`8000000`370?l4000000D0o`3Y0P0000040?l0a`D000000`3o08@2
000000D0o`1P100000050?l0<@@000001P3o00h4000000l0oooo00<00000
0?ooo`3oool0A`3oool00740oooo00<000000?ooo`3oool04`3oool20000
01/0oooo00<00000003oSP00ohh00`00ohh00`0000000?nj00000006003o
]`0300000000onH00?oV00D00?oV0P000005003Uo`0300000000i?l00>Co
008000000P00[?l00`0000000:So002Xo`04002Xo`8000001@00Iol20000
008005oo0P0000000`008ol00000000Go`05000Go`@000000`0b0?l00`00
0000A@3o04D0o`0404D0o`<00000102B0?l00`000000Z`3o0:/0o`040:/0
o`@000000`3h0?l00`000000o`3Y0?l0j@040?l0j@D000000`3o0:H20000
00@0o`241P0000040?l0D@D00000103o02/6000000@0o`0<0`00000<0?oo
o`040000003oool0oooo0?ooo`D00000@@3oool00740oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0L0?ooo`80000000<00?n>0000
000000000`00okX2000000800?ng0P0000000`00onL00000003oiP04003o
iP0300000000i_l0000000H00>Go0P000005002/o`8000000P00Z?l20000
0003001_o`00000006Oo00D006Oo0`000004000So`8000000P005ol20000
00808P3o00<000000380o`0b0?l00`0b0?l200000080A@3o0P00000207`0
o`030000002B0?l0TP3o00<0TP3o00<000000:/0o`2[0?l00`0000020=/0
o`030000003h0?l0n03o00<0n03o0P0000020?l0j@8000000P3o0<D00`00
0000o`2V0?l0YP040?l0YPD000000`3o0702000000<0o`1A0P0000020?l0
A`8000000`3o02/300000080o`0U0P0000030?l0308000000P3o00/30000
00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?oo
o`00L@3oool00`000000oooo0?ooo`0@0?ooo`8000008@3oool00`000000
0?nj003o^P05003o^P8000001000onL200000003003oiP000000000000<0
0>Ko0P000002003Uo`80000000<00;3o00000000[?l01@00[?l3000000@0
06oo0P000002001Wo`8000000P00;ol00`00000002?o000So`03000So`<0
00001@0R0?l00`000000<P3o0380o`030380o`<000001@1l0?l010000000
TP3o0980o`2B0?l4000000H0f`3o00<000000?P0o`3h0?l00P3h0?l40000
00D0o`350P0000020?l0YP8000000P3o08h2000000D0o`1`100000060?l0
A`<000001`3o02D3000000H0o`0;100000080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0@@3oool00740oooo00<000000?ooo`3o
ool03P3oool2000002@0oooo00<00000003o^P00okX00`00okX00`000000
0?oX00000006003oi`0300000000i_l00>Ko00D00>Ko0P000004002`o`80
00000P00[?l20000008007Ko00<00000001_o`00Kol00`00Kol3000000D0
02oo00<00000000So`008ol00P0000020180o`030000000R0?l08P3o00@0
8P3o00<000000380o`0b0?l00P00000206L0o`030000001l0?l0O03o00<0
O03o100000030<80o`030000003K0?l0f`3o00@0f`3o1@0000030?l0hP80
0000103o0<D4000000H0o`2>1@0000030?l0HP8000000P3o04L300000080
o`0n0P0000030?l09@<000000P3o028200000080o`0;0`0000030?l02P<0
00001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440
oooo001a0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
9@3oool200000003003o^P000000000000<00?oX0P000002003oi`800000
00<00>Oo00000000i_l01000i_l00`0000000;Co00000006002`o`800000
1@00M_l00`00000006oo001_o`020000008003Wo00<00000000_o`00;ol0
1000;ol2000000D04P3o00<000000280o`0R0?l00`0R0?l3000000D0I`3o
00<0000007`0o`1l0?l00P0000020:/0o`03000000320?l0`P3o00<0`P3o
0P0000020=/0o`8000000P3o0?d00`000000o`3R0?l0hP040?l0hPD00000
0`3o0:/2000000<0o`2>0P0000020?l0O@800000103o0684000000H0o`0n
100000050?l08P@00000103o00X300000080o`090`0000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00740oooo00<0
00000?ooo`3oool02`3oool2000002X0oooo00<00000003oj000onP01000
onP3000000@00>Oo0P0000000`00i_l0000000000003002do`8000000P00
/?l200000003001mo`00000007Ko00D007Ko0P000005000io`8000000P00
;ol20000000300D0o`0000004P3o00D04P3o00<000000280o`0R0?l00P00
000205D0o`030000001W0?l0I`3o00<0I`3o0`0000050:/0o`8000000`32
0?l4000000D0o`3m0P0000020?l0hP8000000P3o0<H2000000D0o`2[1000
00060?l0O@@00000103o05L6000000@0o`0h1@0000040?l07P@000001P3o
00T4000000030?ooo`000000oooo0080oooo0P0000130?ooo`00L@3oool0
0`000000oooo0?ooo`090?ooo`800000;@3oool2000000800?oX0P000002
003Xo`0300000000iol00>Oo00<00>Oo0P000007002do`8000001000OOl2
0000008007Ko0P0000000`00@ol00000000io`05000io`<0000010050?l2
000000<04P3o1000000505D0o`030000001W0?l0I`3o008000000P2E0?l0
0`000000Z`3o0:/0o`040:/0o`@000000`3Y0?l2000000@0o`3m10000006
0?l0aPD000000`3o09L200000080o`1m0`0000020?l0K`8000000P3o05L3
00000080o`1?0P0000030?l0>08000000P3o03<2000000<0o`0N0`000002
0?l0708000000P3o00T3000000<0o`080`0000180?ooo`00L@3oool00`00
0000oooo0?ooo`070?ooo`800000<@3oool2000000D00>So00<00000003W
o`00iol00P000002002go`0300000000]?l00;Co00800;Co0P0000000`00
Pol00000001mo`04001mo`<000001000@ol20000008003Wo0P0000020007
o`03000000050?l01@3o00<01@3o1000000304@0o`030000001E0?l0E@3o
00@0E@3o0P00000509D0o`8000000P2[0?l200000080dP3o00<000000>T0
o`3Y0?l0103Y0?l4000000<0o`3O0P0000030?l0aP8000000P3o0:l00`00
0000o`2G0?l0U`040?l0U`<000001P3o06l3000000L0o`1?0`0000060?l0
<`<000001@3o01`4000000@0o`08100000190?ooo`00L03oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0380oooo00<00000003Xo`00
j?l01000j?l2000000D00;Oo00@00000002do`00000000001000Pol00`00
000007go001mo`020000008004co00<000000013o`00@ol01000@ol20000
00D000Oo00<0000000D0o`050?l00P00000203@0o`03000000140?l0A03o
00<0A03o0P00000205D0o`80000000<0PP3o0000002E0?l01@2E0?l30000
00D0dP3o0P0000020>T0o`8000000P3o0?L00`000000o`3O0?l0g`040?l0
g`<000001@3o0:l200000080o`2G0P0000020?l0Q`8000000`3o06l20000
0080o`1T0P0000030?l0C`<000000P3o04L200000080o`0c0`0000030?l0
;`D00000103o01X5000004`0oooo001`0?ooo`030000003oool0oooo00D0
oooo0P00000f0?ooo`8000000P00j?l200000003002jo`0000000;Oo00D0
0;Oo00<000000023o`00Pol01@00Pol2000000D004co0P0000020013o`80
000000<001?o000000001ol01@001ol2000000D0=03o0P00000304@0o`@0
000010220?l200000080U@3o0P0000020;`0o`030000003B0?l0dP3o00@0
dP3o0`0000050?l0m`8000000P3o0=l200000080o`370P0000040?l0[`@0
00001@3o08L4000000H0o`1T0`0000050?l0A`@00000103o02l300000080
o`0[0P0000020?l06PD00000CP3oool00700oooo00<000000?ooo`3oool0
0`3oool2000003X0oooo0P000004002jo`8000000P00]ol2000000030028
o`000000000000<008?o0P0000000`00E?l00000001<o`05001<o`<00000
10004ol20000008000Oo0P0000000`0V0?l0000003@0o`0503@0o`@00000
0`1`0?l2000000<0PP3o100000050;`0o`8000000P3B0?l200000080lP3o
0P0000040?l0m`@000001P3o0<L4000000@0o`2M1@0000030?l0NP800000
0`3o06@2000000<0o`1L1@0000040?l0@P@000001P3o02/500000540oooo
001`0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>`3o
ool00`0000000;[o002jo`04002jo`8000001@00R?l3000000@005Co0P00
0002001<o`8000000P007Ol00`00000001?o000Co`03000Co`<00000100V
0?l200000080=03o0P00000205l0o`030000001`0?l0L03o00<0L03o1000
00030:P0o`800000102l0?l4000000D0lP3o1@0000030?l0g@8000000P3o
0<L300000080o`2c0P0000020?l0W@<000000P3o08l2000000@0o`1j1000
00030?l0G0<000000P3o05@200000080o`120`0000020?l0?@8000000P3o
02/3000000030?ooo`000000000005<0oooo001`0?ooo`030000003oool0
oooo00800000?`3oool2000000800;[o0P0000000`00S_l0000000000003
0028o`80000000<005_o00000000E?l01@00E?l2000000D001go00<00000
000Co`004ol00P00000201T0o`030000000V0?l09P3o00<09P3o0`000005
05l0o`030000001`0?l0L03o008000000P2F0?l00`000000Z03o0:P0o`04
0:P0o`@000000`3M0?l200000080lP3o0P0000020?l0lP800000103o0=d4
000000H0o`2c0`0000060?l0S`D00000103o06l3000000H0o`1D0`000006
0?l0?@<0000000@0oooo0000000000000000E@3oool00700oooo0`000013
0?ooo`8000001@00S_l3000000@005_o0P000002001Do`80000000<002Oo
000000007Ol01@007Ol2000000D06@3o00<0000002H0o`0V0?l00P000002
0500o`030000001O0?l0G`3o00@0G`3o0P00000509H0o`8000000P2X0?l2
00000080b@3o00<000000=d0o`3M0?l00`3M0?l3000000H0o`3b10000003
0?l0b08000000`3o0;<200000080o`2S0P0000030?l0S`8000000P3o08<2
000000<0o`1_0P0000020?l0IP8000000`3o05@200000080o`1>0P000003
0?l0?@8000000P3oool2000005P0oooo001`0?ooo`800000A@3oool20000
008008ko0P000002001Ro`0300000000Fol005_o00<005_o0`000004000W
o`8000000P007Ol20000000300d0o`0000006@3o00D06@3o0P0000050500
o`8000000P1O0?l20000000308D0o`000000UP3o00D0UP3o0`0000050<T0
o`030000003M0?l0g@3o008000000P3i0?l2000000<0o`3b0P0000020?l0
g0800000103o0<P4000000H0o`2S0`0000060?l0P`<000001P3o06H30000
00D0o`1>100000020?ooo`800000FP3oool00780oooo0`0000140?ooo`80
00001@00H_l00`00000005_o001Ko`0200000080033o00<00000000Wo`00
9ol00`009ol3000000@03@3o0P00000201T0o`80000000<0@@3o0000001@
0?l01@1@0?l3000000@0Q@3o0P00000209H0o`8000000P2g0?l2000000@0
b@3o0`0000060?T0o`<000001P3o0=`4000000<0o`2f0P0000030?l0X`80
00000P3o09D200000080o`230`0000020?l0N08000000P3o06H3000000<0
o`1O1@0000030?ooo`<00000G03oool007D0oooo100000110?ooo`030000
0000H_l006;o00@006;o0P000005000`o`03000000009ol002Oo00800000
0P020?l00`0000003@3o00d0o`0300d0o`<0000010110?l200000080D03o
0P00000207D0o`8000000`250?l4000000H0]`3o100000020>H0o`800000
0`3i0?l200000080o`3_0P0000030?l0g08000000P3o0<T2000000@0o`2f
100000040?l0U@@000001@3o07P4000000@0o`1O0P0000060?ooo`800000
G`3oool007T0oooo0`00000o0?ooo`8000000P00H_l200000003000io`00
0000033o00D0033o0P0000050080o`030000000=0?l03@3o008000000P0d
0?l2000000@0@@3o0`00000607D0o`<000000`2V0?l2000000<0]`3o0P00
00020=<0o`8000000`3V0?l4000000H0o`3_0`0000050?l0b@D00000103o
0:P4000000@0o`2:1@0000040?l0L0@000001P3oool200000640oooo001l
0?ooo`<00000?P3oool2000000@003Wo0P000002000`o`80000000<000So
00000000000010020?l3000000H0=03o1000000206H0o`8000000`1e0?l2
0000000309H0o`000000YP3o00D0YP3o0`0000050=<0o`@000000`3m0?l2
000000<0o`3_0P0000020?l0f`8000000P3o0<T200000080o`2i0P000003
0?l0Z08000000P3o09/2000000<0o`2:0P0000020?l0P08000000P3o0703
000000L0oooo0P00001S0?ooo`00O`3oool3000003`0oooo00<00000000i
o`00>Ol01000>Ol2000000D000So1000000202P0o`8000000`0d0?l20000
0080F03o00<0000006H0o`1V0?l00`1V0?l3000000@0UP3o0P0000020:H0
o`8000000P330?l200000080d`3o0P0000020>`0o`800000103m0?l40000
00D0o`3K0`0000060?l0^@<000001P3o09/3000000D0o`200`0000070?oo
o`<00000I@3oool00880oooo0`00000j0?ooo`8000000P00>Ol200000003
000Bo`000000000000<000So0P0000000`0L0?l0000002P0o`0402P0o`<0
00001@1H0?l00`000000IP3o06H0o`0200000080QP3o0P00000309H0o`@0
00001P330?l2000000H0k03o100000030?l0k@8000000P3o0=/200000080
o`3;0P0000030?l0^@8000000P3o0:`200000080o`2K0`0000020?l0T080
00000P3o0802000000P0oooo0P00001X0?ooo`00Q@3oool4000003P0oooo
0P000005000Bo`<00000100L0?l200000080:03o0P0000000`1;0?l00000
0000000405P0o`<000001P260?l3000000<0/P3o0P0000030<<0o`800000
00<0f`3o0000000000000`3/0?l200000080o`3n0P0000030?l0k@@00000
1@3o0</4000000@0o`2/100000050?l0T0@00000203oool2000006X0oooo
00290?ooo`<00000=P3oool20000008001;o0P0000020180o`030000000L
0?l0703o00<0703o0`00000504/0o`@000000P1h0?l2000000<0QP3o0P00
00000`2S0?l00000000000040;80o`@000001@3K0?l3000000H0o`3n0`00
00040?l0f`D00000103o0;`4000000@0o`2P1@0000090?ooo`<00000K03o
ool008`0oooo0`00000e0?ooo`8000001@0B0?l00`000000703o01`0o`02
00000080?`3o0P00000204/0o`8000000P1[0?l00`000000N03o07P0o`03
07P0o`<000001@2S0?l4000000<0c03o0P0000020=/0o`8000000P3a0?l2
000000<0o`3n0P0000000`3o0>/00000000000030?l0f`8000000P3o0<`2
00000080o`2l0P0000020?l0[`8000000`3o0:02000000/0oooo0P00001_
0?ooo`00S`3oool3000003<0oooo0P0000040180o`<000001P0o0?l20000
00D0J`3o00<0000007P0o`1h0?l00P00000209D0o`8000000P2S0?l20000
0080_@3o0P0000040<`0o`<000001P3a0?l3000000D0o`3[0`0000050?l0
c0<000001P3o0:l3000000/0oooo0P00001a0?ooo`00TP3oool400000340
oooo1000000203<0o`8000000`0o0?l20000000305h0o`000000000000@0
J`3o0`00000609D0o`8000001P2m0?l400000080hP3o0P0000030?40o`80
00000P3o0?/200000080o`3[0P0000020?l0f`8000000P3o0<`200000080
o`2n0P0000030?l0[`8000002`3oool3000007<0oooo002F0?ooo`<00000
<03oool00`000000<`3o03<0o`0303<0o`<000001@1N0?l400000080Q`3o
0P00000309D0o`80000000<0[P3o0000000000000`2m0?l200000080d`3o
0P0000030>80o`@00000103o0?/4000000H0o`3K0P0000050?l0_P@00000
2`3oool2000007H0oooo002I0?ooo`<00000;P3oool200000080<`3o0P00
00000`1B0?l000000000000205h0o`8000000P1j0?l2000000<0Q`3o1000
00050:h0o`<000001@3C0?l4000000@0mP3o100000030?l0jP8000000`3o
0=/200000080o`3=1@00000=0?ooo`800000N03oool009`0oooo0`00000]
0?ooo`8000001@1B0?l2000000H0NP3o0`0000030:40o`8000000P2^0?l2
00000080a@3o0P0000020=<0o`8000000P3W0?l2000000<0mP3o0P000000
0`3o0?P00000000000040?l0jP@000000`3o0<d2000000h0oooo0`00001j
0?ooo`00W`3oool3000002/0oooo0P0000020580o`80000000<0KP3o0000
000000000`1j0?l20000000309@0o`000000000000@0X@3o0`0000060<D0
o`8000001P3W0?l3000000D0o`3h100000040?l0f`<000003P3oool20000
07d0oooo002R0?ooo`@00000:@3oool2000000D0KP3o0`00000509@0o`@0
00000P2h0?l2000000<0a@3o0P0000000`3J0?l00000000000030>L0o`80
00000P3i0?l200000080o`3h0P0000020?l0j@8000000P3o0=/2000000l0
oooo0P00001o0?ooo`00YP3oool3000002L0oooo0P00000306h0o`800000
00<0Q`3o0000000000000P2D0?l200000080Z`3o0P0000030;P0o`@00000
103J0?l4000000@0n@3o100000050?l0j@<000003P3oool300000840oooo
002Y0?ooo`<000009P3oool3000000D0Q`3o0P0000060:/0o`<00000103<
0?l4000000@0k03o100000040?l0mPD000003`3oool2000008@0oooo002/
0?ooo`<000009@3oool200000080Q`3o0P0000000`2N0?l0000000000003
0:/0o`80000000<0`03o0000000000000`3<0?l2000000030=l0o`000000
000000<0k03o0P0000000`3l0?l00000000000030?l0mP8000004@3oool2
000008H0oooo002_0?ooo`@000008`3oool2000000D0WP3o0`0000050<00
o`<000001@3O0?l3000000D0o03o0`00000@0?ooo`<00000R03oool00;<0
oooo0`00000R0?ooo`D000000P2c0?l200000080`03o0P0000020=80o`80
00000P3O0?l200000080k`3o0P0000020?`0o`8000004@3oool2000008/0
oooo002f0?ooo`<000008P3oool2000000<0/`3o0`0000050=80o`<00000
1@3_0?l300000140oooo0P00002=0?ooo`00^@3oool300000240oooo0`00
00030<H0o`D000000`3S0?l500000140oooo0`00002?0?ooo`00_03oool3
000001l0oooo0P0000030<H0o`80000000<0f03o0000000000000P3S0?l2
000001<0oooo0P00002B0?ooo`00_`3oool4000001d0oooo0`0000050=P0
o`8000004`3oool2000009@0oooo00330?ooo`<00000703oool200000080
f03o0P00000C0?ooo`800000UP3oool00<H0oooo0`00000K0?ooo`800000
4P3oool3000009P0oooo00390?ooo`<00000603oool00`000000oooo0?oo
o`0?0?ooo`800000V`3oool00<`0oooo1000000D0?ooo`030000003oool0
oooo00d0oooo0P00002M0?ooo`00d03oool300000140oooo00<000000?oo
o`3oool02P3oool3000009l0oooo003C0?ooo`<000003P3oool00`000000
oooo0?ooo`080?ooo`800000XP3oool00=H0oooo0`00000;0?ooo`030000
003oool0oooo00H0oooo0P00002T0?ooo`00f@3oool3000000P0oooo00<0
00000?ooo`3oool00`3oool300000:H0oooo003L0?ooo`@00000103oool0
10000000oooo0?ooo`3oool200000:T0oooo003P0?ooo`<0000000<0oooo
0000003oool00P00002[0?ooo`00h`3oool300000:d0oooo003o0?oooi@0
oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oo
oi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o
0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo
003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0
oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oo
oi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo0000
\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 208},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  Using techniques from Section 11.2, we find that the function  \
\n\n\t\t\t",
  Cell[BoxData[
      \(v \((x, y)\)\ \  = \ \ 1\ \  - \ \ \(1\/\[Pi]\) 
            Arctan \((y\/\(x + 1\))\)\  - \ \ \(1\/\[Pi]\) 
            Arctan \((y\/\(x - 1\))\)\)]],
  "  \n\nis harmonic in the upper half-plane and has the boundary values  ",
  Cell[BoxData[
      RowBox[{\(v \((x, 0)\) = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", "|", "x", "|", \(\(<\)\(1\)\)}], 
          
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}]]],
  "  ",
  Cell[BoxData[
      RowBox[{\(v \((x, 0)\) = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], " ", "x"}], "<", \(-1\)}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}]]],
  "  ",
  Cell[BoxData[
      RowBox[{\(v \((x, 0)\) = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", "1"}], "<", "x", ">", 
          RowBox[{"1", 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]]],
  "  This function can be added to the one in Example 11.12 to obtain the \
desired result:  \n\n\t\t",
  Cell[BoxData[{
      \(\[Phi] \((x, y)\)\ \  = \ \ 1\ \  - \ \ \(1\/\[Pi]\) 
            Arctan \((y\/\(x - 1\))\)\ \  - \ \ \ \(1\/\[Pi]\) 
            Arctan \((y\/\(x + 1\))\)\ \  + \ \ \ \(y\/\(2\ \[Pi]\)\) 
            ln \((\(\((x - 1)\)\^2\  + \ y\^2\)\/\(\((x + 1)\)\^2\  + \ \
y\^2\))\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(+\ \ \ \
\(x\/\[Pi]\)\) Arctan \((y\/\(x - 1\))\)\ \  - \ \ \ \(x\/\[Pi]\) 
          Arctan \((y\/\(x + 1\))\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(1\ \  + \ \ \(\
\(x - 1\)\/\[Pi]\) Arctan \((y\/\(x - 1\))\)\ \  - \ \ \(\(x + 1\)\/\[Pi]\) 
            Arctan \((y\/\(x + 1\))\)\ \  + \ \ \(y\/\(2\ \[Pi]\)\) 
            ln \((\(\((x - 1)\)\^2\  + \ y\^2\)\/\(\((x + 1)\)\^2\  + \ \
y\^2\))\)\)\)\)}]],
  "  \n\nFigure 11.15 shows the graph of ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.15",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/poissonintegralplane/\
PoissonIntegralFigures/mat1115.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The graph of ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.13.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "This is similar to Example 11.17, but the method of solution is different.\
\n\nUsing techniques from Section 11.2, the function  ",
  Cell[BoxData[
      \(v \((x, y)\) = 
        1 - \(1\/\[Pi]\) arctan \((y\/\(x\  + \ 1\))\) - \(1\/\[Pi]\) 
            arctan \((y\/\(x\  - \ 1\))\)\)]],
  "  is harmonic in the upper half plane and takes on the boundary values\n",
  Cell[BoxData[
      \(v \((x, 
            0)\) = \(-1\)\ \ \ for\ \ \ \ \ \ \ x < \(-1\), \
\[IndentingNewLine]v \((x, 0)\) = \ 
        0\ \ \ \ for\ \ \  - 1 < x < 1, \[IndentingNewLine]v \((x, 0)\) = \ 
        1\ \ \ \ for\ \ \ \ \ \ \ 1 < \(\(x\)\(.\)\)\)]],
  " \n\nThus, we should add it to the solution  ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  "  in Example ",
  "11.",
  "12 to obtain the desired result.  However, with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  we need to use  ",
  Cell[BoxData[
      \(ArcTan[x \[PlusMinus] 1, y]\ \ instead\ of\ \ ArcTan[
          y\/\(x\  \[PlusMinus] \ 1\)]\)]],
  ".\n\nEnter the function U[t] and use the Poisson integral to construct  ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(z = \(y = \(x = 0\)\); \ Remove[x, y, z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[\[Phi]];\)\ \), "\n", 
    \(\(U[t_]\  = \ t;\)\ \), "\[IndentingNewLine]", 
    \(\(g[t_] = 
        y\/\[Pi]\ \(\[Integral]\(U[t]\/\(\((x - t)\)\^2 + 
                    y\^2\)\) \[DifferentialD]t\);\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ Expand[g[1] - g[\(-1\)]];\)\ \), "\n", 
    \(\(v[x_, y_]\  = \ 
        ReplaceAll[\[Phi][x, y], 
          ArcTan[z_] \[Rule] \(-ArcTan[1\/z]\)];\)\ \), "\n", 
    \(\(V[x_, y_]\  = \ 
        1\  - \ \(1\/\[Pi]\) ArcTan[x + 1, y]\  - \(1\/\[Pi]\) 
            ArcTan[x - 1, y];\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ \[Phi][x, y]\  + \ V[x, y];\)\ \), "\n", 
    \(\(v[x_, y_]\  = \ v[x, y]\  + \ V[x, y];\)\ \), "\n", 
    \(\(Print["\<  U[t] = \>", U[t]];\)\ \ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<V[x,y] = \>", V[x, y]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\[Phi][x,y] = \!\(y\/\[Pi]\) \
\!\(\[Integral]\_\(-1\)\%1\)\!\(U[t]\/\(\((x - t)\)\^2 + y\^2\)\)\
\[DifferentialD]t + V[x,y]\>\""];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, y]];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(\[Phi][x_, y_] = 
        1 + x\/\[Pi]\ \((ArcTan[\(1 - x\)\/y] - 
                ArcTan[\(\(-1\) - x\)\/y])\) - \(1\/\[Pi]\) \((ArcTan[\(-1\) \
+ x, y] + ArcTan[1 + x, y])\) + \(y\/\(2  \[Pi]\)\) 
            Log[\(1 - 2\ x + x\^2 + y\^2\)\/\(1 + 2\ x + x\^2 + y\^2\)];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Phi][x, y], {x, \(-3\), 3}, {y, 0.000001, 3}, 
        Contours \[Rule] 10, PlotPoints \[Rule] 35, AspectRatio \[Rule] 1\/2, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Then use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[\[Phi][x, y], {x, \(-3\), 3}, {y, 10\^\(-6\), 2}, 
        PlotPoints \[Rule] {31, 21}, 
        PlotRange \[Rule] {{\(-3\), 3}, {0, 2}, {\(-1\), 1}}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<  \[Phi][x,y]\>"}, 
        ColorFunction \[Rule] Hue, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0.5, 2, 0.5], 
            Range[\(-1\), 1, 0.5]}, ViewPoint \[Rule] {\(-2.5\), \(-3\), 2}, 
        AxesEdge \[Rule] {{\(-1\), \(-1\)}, {\(-1\), \(-1\)}, {1, \
\(-1\)}}];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y]  =  \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Therefore, the function \n",
  Cell[BoxData[{
      \(\[Phi][x, y] = 
        1 + x\/\[Pi]\ \((ArcTan[\(1 - x\)\/y] - 
                ArcTan[\(\(-1\) - x\)\/y])\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(-\(1\/\[Pi]\)\) \
\((ArcTan[\(-1\) + x, y] + ArcTan[1 + x, y])\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(+\(y\/\(2  \[Pi]\)\)\) 
        Log[\(1\  - \ 2\ x\  + \ x\^2\  + \ y\^2\)\/\(1\  + \ 2\ x\  + \ x\^2\
\  + \ y\^2\)]\)}]],
  " \nis harmonic in the upper half-plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  ",  and takes on the desired boundary values. "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Poisson's Integral formula to find the harmonic function ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  " that is harmonic in the upper half-plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  ", that takes on the boundary values  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{\(\[Phi] \((x, 0)\) = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[
          RowBox[{
            StyleBox["  ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  "}]], 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "       ", "x"}], 
            "\[LessEqual]", \(-1\)}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}], "\[IndentingNewLine]", 
      RowBox[{\(\[Phi] \((x, 0)\) = \ x\^3\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[
          RowBox[{
            StyleBox["   ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " "}]], 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "   ", "-", "1"}], "\[LessEqual]", 
            "x", "\[LessEqual]", "1"}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}], "\[IndentingNewLine]", 
      RowBox[{\(\[Phi] \((x, 0)\) = \ 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "     ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "       ", "1"}], "\[LessEqual]", 
          RowBox[{"x", 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000d2000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD
0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3o
oonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD
0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3o
oonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00k@3oool400000:80oooo003G0?ooo`800000503oool0
0`000000oooo0?ooo`2S0?ooo`00e@3oool3000000030?l6000000000000
01<0oooo00<000000?ooo`3oool0XP3oool00=@0oooo0P0000000`3o1P00
00000?l600020?l6008000002P3oool4000000@0oooo00<000000?ooo`3o
ool0X@3oool00=<0oooo00D000000?l6003o1P00o`H0000000020?l60080
000000<0o`L00000000000003P3oool010000000oooo0?ooo`00002R0?oo
o`00d@3oool2000000@0o`H000<000000?l6000000001@3o1`02000000d0
oooo0P00000O0?ooo`80000000<0oooo000000000000O`3oool00=00oooo
0P0000000`3o50000000000000020?l6008000001P3o1`0010000000o`P0
00000000000]0?ooo`030000003oool000000800oooo003>0?ooo`<00000
103o5003000000D0o`L00P0000040?l800800000;03oool00`000000oooo
0?ooo`1o0?ooo`00c@3oool2000000H0oa@000<000000?lF000000000P00
00020?l700030000003o2000o`P000@0o`P000<000000?l8000000000P00
000W0?ooo`80000000<0oooo000000000000O`3oool00</0oooo0`000005
0?lD008000000P3o5P000`000000oaH00?lF0002000000D0o`P00P000004
0?l800<000005`3oool5000008d0oooo003:0?ooo`040000003oool00000
0?lR008000000P3o50000`000000oaH00?lF00020?lF00050000003o5P00
oaH00000003o60000P0000020?l800030000003o2000o`P000@0o`P000<0
00000?l:003o2P000`00000F0?ooo`030000003oool0oooo08d0oooo0039
0?ooo`<00000103o8P03000000@0oaH00`0000040?lH008000001@3o2002
000000@0o`X01000000D0?ooo`030000003oool0oooo08d0oooo00370?oo
o`<000001P3o8P000`000000obD00?lU000200000080oaH000<000000?lH
003o6000103o600010000000oa/00000000000020?l800030000003o2P00
o`X000<0o`X000@000000?l;00000000o`/00`00000:0?ooo`@00000103o
ool00`000000oooo0?ooo`2=0?ooo`00aP3oool00`000000oooo00000005
0?lR008000001@3o9@03000000@0oaP00P0000040?lK008000001@3o2P00
0`000000o`/00?l;00030?l;00@00000403oool00`000000oooo0?ooo`2=
0?ooo`00a03oool4000000030?l_0000000000000080ob8000<000000?lU
003o9@001@3o9@0010000000obP00000000000020?lH00030000003o6`00
oa/000@0oa/000@000000?lN0000000000000P3o2P000`000000o`/00?l;
00030?l;00040000003o3@00o`d00?l=00<000003@3oool2000008l0oooo
00330?ooo`<000001@3o;`03000000D0obD00P0000020?lX00040000003o
:0000000000000D0oa/00P0000040?lN008000001@3o2`000`000000o`d0
0?l=00030?l=00@00000W03oool00<40oooo100000060?l_00030000003o
<`00oc<0008000000P3o9@000`000000obP00?lX00020?lX00040000003o
:00000000?l]008000000P3o6`000`000000oah00?lN00040?lN00040000
003o8`00000000000080o`/000<000000?l=003o3@000`3o3@0010000000
oa400?lA003o4@03000009X0oooo00300?ooo`030000003oool000000080
oc`00P0000020?l_008000001@3o<`02000000D0obP00P0000040?l]0080
00001@3o7P02000000@0ob<00P0000050?l=00030000003o4@00oa4000<0
oa4000@000000?lH000000000000V03oool00:D0oooo0P0000040?ooo`80
0000103oool2000000`0oooo00<000000?ooo`0000001@3o?002000000H0
oc<00P0000000`3o>0000000000000020?lX008000001@3o;@0010000000
oc800000000000020?lN00030000003o8`00ob<000@0ob<000@000000?lY
0000000000000P3o3@000`000000oa400?lA00030?lA00030000003o6000
oaP00080oaP00P00000D0?ooo`800000P03oool00:@0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000090?ooo`80000000<0
oooo0000003o?0001@3o?00010000000od800000000000020?lc00800000
1@3o>002000000030?l]00000000obd00080obd00P0000040?lb00800000
1@3o8`02000000@0obT00P0000050?lA00030000003o6000oaP000<0oaP0
00@000000?l_0000000000004@3oool010000000oooo0?ooo`00001o0?oo
o`00Y03oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo
00H0oooo00@000000?ooo`3oool000001@3o?002000000@0od800P000006
0?lh0080000000<0och00000000000000P3o;@000`000000oc800?lb0004
0?lb00040000003o>P00000000000080ob<000<000000?lY003o:@00103o
:@0010000000oc<00000000000020?lA00030000003o6000oaP000<0oaP0
00<000000?l_003o;`000P3o;`02000000l0oooo00@000000?ooo`3oool0
0000O`3oool00:@0oooo00@000000?ooo`3oool000002@3oool2000000L0
oooo0P0000020?ooo`040000003oBP00000000000080oc`000<000000?m2
003o@P00103o@P0010000000odP00000000000020?lh00800000103o?P03
000000D0oc800P0000040?lj008000001@3o:@02000000@0oc<00P000005
0?lH00030000003o;`00obl000<0obl01000000=0?ooo`040000003oool0
oooo000007l0oooo002C0?ooo`8000003`3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P00
00040?m:008000001@3o@P02000000@0odP00P0000060?ln0080000000<0
odH00000000000000P3o<P000`000000ocX00?lj00040?lj00040000003o
A000000000000080obT000<000000?lc003o<`00103o<`0010000000odH0
0000000000020?lH00030000003o;`00obl000@0obl000@000000?oK0000
0000oooo0P00000;0?ooo`040000003oool0oooo000007l0oooo002D0?oo
o`030000003oool0oooo00h0oooo0P00000:0?ooo`<000000`3oool20000
0080oooo00<000000?m:003oBP00103oBP0010000000oe00000000000002
0?m200030000003oB000odP000@0odP000<000000?m@00000000103o?P02
000000@0odH00P0000050?lj00800000103oA002000000D0oc<00P000004
0?m6008000001P3o;`0010000000om/00?oK000000030?ooo`<000002@3o
ool200000800oooo002E0?ooo`030000003oool0oooo01h0oooo00D00000
0?ooo`000000oooo000000050?m:00800000103oD002000000D0odP00P00
00030?m@0080000000@0och00000003oAP000000103oAP0010000000oe00
0000000000020?lj00030000003oA000od@000@0od@000@000000?mD0000
000000000P3o<`000`000000odH00?m600040?m600030000003oN`000000
00@0obl000D000000?oK003of`00om/0000000060?ooo`800000R@3oool0
09@0oooo00<000000?ooo`0000007P3oool01P000000oooo0?ooo`3oool0
00000?mG008000000P3oBP000`000000oe000?m@00040?m@00040000003o
F000000000000080odP000<000000?m@003oD0001@3oD00010000000odH0
0?m6000000020?m600800000103oD002000000D0od@00P0000040?mD0080
00001P3oAP001@000000og/00?mk003oN`00000000<0obl000D000000?oK
003of`00om/0000000080?ooo`800000Q`3oool009<0oooo00@000000?oo
o`3oool00000703oool200000080oooo0P0000040?mG008000001@3oD002
000000@0oeP00P0000060?m@0080000000H0oeX000000000000000000?m6
000000060?m@00040000003oGP00000000000080od@000<000000?mD003o
E000103oE0000`000000og40000000040?m600030000003oN`00og/00080
og/000@000000?l_003o;`0000001@3of`000`000000oooo0?ooo`070?oo
o`800000503oool5000006`0oooo002B0?ooo`<0000000<0oooo00000000
00006P3oool01@000000oooo0?ooo`3oool0000000H0oeL000@000000?mN
0000000000000P3oD0000`000000oeP00?mH00040?mH00040000003oH@00
000000000080oe000P0000050?mJ008000001@3oD002000000@0oeh00P00
00060?mD00040000003oL@00og400?ma0080000000<0odH00000003oN`00
1@3oN`000`000000obl0000000050?oK00030000003oool0oooo00T0oooo
0P00000D0?ooo`030000003oool0oooo06`0oooo002`0?ooo`8000000`3o
ool00`000000oeL00?mG00030?mG00800000103oGP02000000D0oeP00P00
00040?mQ008000001P3oFP02000000030?mV0000000000000080oe0000<0
00000?mN003oGP00103oGP000`000000og@0000000040?mD00030000003o
L@00og4000@0og4000<000000?mk003oN`001P3oN`000`000000om/00?oK
00040?oK00030000003oool0oooo00/0oooo0P00000B0?ooo`030000003o
ool0oooo06`0oooo002_0?ooo`030000003oool0oooo0080oooo00@00000
0?mT0000000000000P3oE`000`000000oeh00?mN00040?mN00040000003o
I`00000000000080oeP000<000000?mQ003oH@00103oH@0010000000ofd0
0000000000020?mJ0080000000<0ofH00000003oIP000P3oIP02000000D0
oeh00P0000030?md0080000000<0oe@00000003oL@001@3oL@000`000000
ok00000000060?mk008000001P3of`000`000000oooo0?ooo`0=0?ooo`80
0000403oool00`000000oooo0?ooo`1/0?ooo`00[@3oool2000000<0oooo
0P0000040?mT00<000001@3oGP000`000000ofL00?mW00020?mW00800000
1@3oH@02000000@0ofd00P0000030?mV00060000003oIP00ofH00?mV0000
0000ogP00P0000020?mN00030000003oM000og@000D0og@000<000000?ma
003oL@00103oL@001@000000ok000?n`003o/000000000@0og/000@00000
0?7o003ao`0000001P3of`000`000000oooo0?ooo`0=0?ooo`<000003P3o
ool00`000000oooo0?ooo`1/0?ooo`00[03oool00`000000oooo0?ooo`02
0?ooo`030000003oI000of@000@0of@000<000000?m]003oK@000P000002
0?mN00030000003oI`00ofL000<0ofL000@000000?mb0000000000000P3o
H@000`000000ofd00?m]00040?m]00030000003oO00000000080ofH000@0
00000?mV000000000000103oN002000000L0og@000<000000?nH00000000
103oL@000`000000ok000?n`00020?n`00050000003oN`00og/00?mk0000
00000`3ao`000`000000om/00?oK00040?oK00030000003oool0oooo0100
oooo0`00000:0?ooo`800000KP3oool00:/0oooo00<000000?ooo`3oool0
0P3oool010000000og400000000000020?mT008000001@3oK@02000000D0
ofL000<000000?mb003oLP000P3oLP02000000D0ofd00P0000030?ml00@0
00001P3oN0000`000000oi80000000040?md008000000`3oV00200000003
0?ma00000000ok0000D0ok0000<000000?mk000000001@3ao`000`000000
om/00?oK00030?oK00030000003oool0oooo01<0oooo0P00001h0?ooo`00
Z@3oool2000000<0oooo0P0000040?ma008000001P3oK@02000000030?mg
0000000000000080ofL000<000000?mb003oLP000`3oLP0010000000ogl0
0000000000020?m]00030000003oO000og`000D0og`000<000000?mh003o
N0000`3oN002000000<0oi800P0000000`3oM00000000?nH00060?nH0003
0000003o/000ok0000H0ok0000<000000?7o003ao`00103ao`000`000000
om/00?oK00030?oK00030000003oool0oooo01D0oooo0P00001f0?ooo`00
Z03oool00`000000oooo0?ooo`020?ooo`030000003oL@00og4000@0og40
00@000000?mj0000000000000P3oK@02000000D0ogL00P0000050?mb0003
0000003oO`00ogl00080ogl00P0000070?ml00@000000P3oN0000`000000
oi800?nB00050?nB00030000003oV000oiP000D0oiP000<000000?oJ0000
00001P3o/002000000H0lOl000<000000?oK003of`00103of`000`000000
oooo0?ooo`0F0?ooo`800000M03oool00:H0oooo0P0000040?ooo`030000
003oL@00og4000<0og400P0000040?mj008000001P3oM`02000000030?n3
0000000000000080og8000<000000?mo003oO`000`3oO`000`000000oi40
000000040?ml0080000000@0oi000000003oT000oi000P0000070?nB0003
0000003o^P00000000@0oiP00P0000030?oJ00030000003o/000ok000080
ok0000@000000<oo003?o`0000001P3ao`000`000000om/00?oK00030?oK
00030000003oool0oooo01P0oooo0P00000B0?ooo`@00000G03oool00:D0
oooo00<000000?ooo`3oool00`3oool010000000ogh00000000000020?ma
00030000003oNP00ogX000@0ogX000@000000?n50000000000000P3oM`02
000000D0oh<00P0000050?mo00040000003oT@00oi400?nA0080000000<0
og`00000003oT0000P3oT0001P000000oi000?n@00000000ojd0000000@0
oi800P0000030?nj0080000000<0oiP00000003ofP00103ofP001@000000
ok000?n`003o/000000000<0col000<000000?7o003ao`00103ao`001000
0000om/00?oK003of`03000001`0oooo0P00000@0?ooo`030000003oool0
oooo05d0oooo002S0?ooo`800000103oool2000000@0ogh00P0000050?mj
00800000103oQ@02000000H0oh<00P0000000`3oTP000000000000020?mo
00030000003oT@00oi4000@0oi4000<000000?n@003oT0000P3oT0030000
00<0ojd00P0000000`3oTP0000000?nj00060?nj00030000003ofP00omX0
00D0omX000<000000?n`000000001@3?o`000`000000lOl00?7o00040?7o
00<000000`0Oo`000`000000oooo0?ooo`0K0?ooo`<000003P3oool00`00
0000oooo0?ooo`1L0?ooo`00T`3oool5000000X0oooo00<000000?ooo`3o
ool00`3oool00`000000ogh00?mn00040?mn00040000003oR00000000000
0080ogX000<000000?n5003oQ@00103oQ@0010000000oi<0000000000002
0?n3008000001@3oTP02000000H0oi4000@000000?nX0000000000000P3o
T0000`000000ojd00?n]00050?n]00030000003o^P00okX000D0okX000<0
00000?om000000001`3ofP000`000000col00<oo00040<oo00030000003a
o`00lOl000@0lOl000<0000001oo000Oo`000`0Oo`000`000000oooo0?oo
o`0M0?ooo`<000003@3oool00`000000oooo0?ooo`1K0?ooo`00U@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00@00000
0?n:0000000000000P3oOP02000000@0ohP00P0000050?n500800000103o
T`02000000L0oi8000@000000?nU0000000000000P3oT@02000000@0ojP0
0`0000060?n]00030000003of@00000000@0okX00P0000030?om00030000
003ofP00omX000<0omX00P0000070<oo00040000003ao`00lOl00?7o00<0
00001P0Oo`000`000000oooo0?ooo`0O0?ooo`8000002@3oool010000000
oooo0?ooo`00001L0?ooo`00U@3oool00`000000oooo0?ooo`070?ooo`80
0000103oool2000000@0ohX00P0000060?n800040000003oU00000000000
0080ohD000<000000?nC003oT`00103oT`000`000000oj<0000000040?nB
00800000103oY@02000000H0ojP000<000000?o700000000103o[@020000
00<0omT00P0000000`3o^P0000000?om00040?om00040000003ofP00omX0
0?oJ008000000P2do`000`000000col00<oo00040<oo00040000003ao`00
0000000000<0:ol000<0000001oo000Oo`000`0Oo`000`000000oooo0?oo
o`0Q0?ooo`800000203oool2000005d0oooo002E0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000ohX00?n:0004
0?n:00040000003oU@00000000000080ohP00P0000040?nD008000001@3o
T`02000000<0oj<00P0000000`3oTP0000000?nU00050?nU00030000003o
_P00000000<0ojP00P0000020?o700<0000000<0ojd00000003of@001P3o
f@000`000000ood00?om00050?om00030000003ofP00000000@0]?l000<0
00000<oo003?o`001@3?o`000`000000:ol002_o000302_o00030000000O
o`007ol000@07ol000<000000?ooo`3oool08P3oool2000006D0oooo002E
0?ooo`030000003oool0oooo00@0oooo0P0000050?ooo`040000003oUP00
000000000080ohX00P0000040?nE008000001P3oU00010000000oj<00000
000000020?nC00030000003oX`00oj<000D0oj<000<000000?nU003oY@00
0`3oY@02000000<0okh000<000000?nX00000000103oa`0010000000olL0
0?o7000000070?oI00030000003Uo`00000000L0ood000<000000;Co002d
o`00102do`000`000000col00<oo00020<oo00<000001P0[o`000`000000
7ol001oo000301oo00030000003oool0oooo02@0oooo0P00001S0?ooo`00
U03oool2000000D0oooo00<000000?ooo`3oool00`3oool2000000@0oiH0
0P0000060?nE00040000003oXP00000000000080oi@00P0000040?nS0080
00001P3oX`02000000030?nh0000000000000080ojD000<000000?nn003o
_P00103o_P000`000000olL00?o700030?o700050000003oa`0000000?od
00000000103of@02000000<0iOl000<000000?om003oo@000`3oo@020000
00H0]?l000<000000<oo003?o`000P00000302go00030000000[o`00:ol0
00<0:ol000<0000001oo000Oo`00100Oo`000`000000oooo0?ooo`0U0?oo
o`800000H@3oool009T0oooo0`0000040?ooo`030000003oUP00oiH000@0
oiH000@000000?nR0000000000000P3oU@02000000@0oj800P0000060?nS
00040000003o]000000000000080oj<00P0000050?nh008000001P3o_P00
0`000000oml0000000040?o7008000000`3om002000000030?oI00000000
iOl000@0iOl000@000000?om003oo@00ood00P00000209go00030000002d
o`00]?l000@0]?l00P00000502go00030000000[o`00:ol000@0:ol000<0
000001oo000Oo`000P0Oo`02000002T0oooo0P00001O0?ooo`00V03oool0
0`000000oooo0?ooo`040?ooo`030000003oUP00oiH000<0oiH00P000004
0?nR008000001P3oXP0010000000ok800000000000020?nS00800000103o
]002000000L0okP000<000000?oB00000000103o_P0010000000oml00?oO
003og`02000000030?o700000000000000H0oo@000<000000>Go003Uo`00
1@3Uo`000`000000ood00000000409go00030000002do`00]?l000<0]?l0
00<0000002_o000000001@0]o`000`000000:ol002_o000402_o00030000
000Oo`007ol0008000000P00oh@00`000000oooo0?ooo`0X0?ooo`<00000
G03oool009L0oooo00<000000?ooo`3oool0103oool010000000oj800000
000000020?nF00030000003oXP00oj8000@0oj8000<000000?n`00000000
103oXP000`000000ok800?nb00020?nb008000001P3o]0000`000000olX0
000000040?nh008000000`3odP02000000030?nn00000000oml000D0oml0
00<000000?od000000001@3om0000`000000bol0000000070>Go00030000
002Mo`00WOl000@0WOl000<000000;Co002do`000P00000202_o00030000
000]o`00;Ol000@0;Ol000<0000002_o000[o`00100[o`02000000@00?n4
00<000000?ooo`3oool0:P3oool3000005X0oooo002E0?ooo`8000001@3o
ool2000000@0oj800P0000050?nR008000000`3o/002000000030?nR0000
0000ok8000@0ok8000<000000?o500000000103o]00010000000olX00?o:
003obP02000000030?nh00000000om8000H0om8000<000000?oO003og`00
103og`0010000000l_l00000000000030?od008000000`3;o`000`000000
iOl00>Go00030>Go000300000029o`00000000D0WOl000<000000;Co0000
00001@0[o`000`000000;Ol002go000302go00030000000[o`00:ol00080
:ol00P0000000`00ofX00000003oQ004003oQ0030000003oool0oooo02`0
oooo0P00000E0?ooo`D00000?P3oool009@0oooo00<000000?ooo`3oool0
103oool00`000000oj800?nR00040?nR00040000003o[`00000000000080
oj8000<000000?n`003o/0001@3o/0000`000000ok800?nb00030?nb0004
0000003oa@00olD00?o50080000000<0ok@00000003obP001@3obP000`00
0000om800?oB00040?oB0080000000<0ooD00000000000000P3og`020000
00<0l_l00P0000000`3om00000000<_o00040<_o00040000003Uo`00iOl0
0>Go008000000P29o`000`000000WOl009go000409go00030000000[o`00
:ol000@0:ol000<0000002go000]o`00100]o`0010000000:ol000000000
0003003oJP0300000000oh@00?n400@00?n400<000000?ooo`3oool0;@3o
ool2000001D0oooo00<000000?ooo`3oool0?P3oool00980oooo0P000006
0?ooo`040000003o[P00000000000080oj800P0000040?n_008000001P3o
/002000000030?o10000000000000080ok8000<000000?o5003oa@00103o
a@000`000000olX00?o:00040?o:00040000003oiP00000000000080om80
0P0000050?oe008000001@3bo`000`000000l_l0000000070<_o00030000
003Uo`00000000D0ROl000@0000009go002Mo`00WOl00P0000000`0Uo`00
000002_o000502_o00030000000]o`00;Ol00080;Ol00`000006003oJP03
00000000oh@00?n400<00?n400<000000?ooo`3oool0;`3oool2000001<0
oooo00<000000?ooo`3oool0?P3oool00940oooo00<000000?ooo`3oool0
103oool2000000@0ojh00P0000060?n_00040000003o_P00000000000080
ok000P0000050?o1008000001P3oa@0010000000om`00000000000020?o:
00800000103oiP02000000L0ooD000<000000=co00000000103bo`020000
00030;Co00000000bol000H0bol000<0000008Wo0029o`001029o`001000
0000WOl000000000000302Go00030000000[o`00:ol000@0:ol000<00000
02go000]o`000P000002003oF00300000000ofX00?mZ00D00?mZ00<00000
003oQ000oh@00P00oh@200000380oooo0P0000090?ooo`@00000103oool0
0`000000oooo0?ooo`0n0?ooo`00S`3oool2000000H0oooo00<000000?n^
003o[P00103o[P0010000000ok/00000000000020?n_00800000103o_P02
000000H0ol400P0000000`3oe0000000000000020?o500800000103og002
000000H0onH000<000000?Go00000000103om@02000000<0g?l000D00000
0?;o003bo`00l_l0000000030;Co00030000003;o`00bol00080bol00P00
00000`1go`00000008Wo000508Wo00030000000Uo`009Ol000@09Ol000<0
000002_o000[o`00100[o`02000000D00?mH00<00000003oJP00ofX01000
ofX00`0000000?n4003oQ002000000800?oG00<000000?ooo`3oool0<@3o
ool2000000l0oooo00<000000?ooo`3oool0?P3oool008h0oooo00<00000
0?ooo`3oool01@3oool010000000okX00000000000020?n^00800000103o
^`02000000H0okh000@000000?o?0000000000000P3o`@02000000D0om@0
0P0000050?oL0080000000<0ooT00000003oiP000`3oiP0010000000mOl0
0?Go003eo`02000000030?oe00000000g?l000D0g?l000@000000?;o0000
00000000102do`0010000000bol000000000000407Oo000300000029o`00
ROl00080ROl000<0000001ko000000001P0Uo`0010000000:ol002_o000[
o`0200000003003oCP0000000?mH00@00?mH00<00000003oJP00ofX01000
ofX3000000D00?oG0P00000c0?ooo`800000303oool200000400oooo002=
0?ooo`030000003oool0oooo00@0oooo0P0000040?nj008000001P3o^`00
10000000ol/00000000000020?nn00800000103oc`02000000H0om@00P00
0000103ok@0000000000003og002000000@0ooT00P0000000`3oiP000000
0?Go00050?Go00030000003Lo`00g?l000H0g?l000<000000;Co00000000
1@2do`000`000000Mol007Oo000407Oo000500000029o`00ROl008Wo0000
00000P0No`000`0000009Ol002Go000402Go00040000000[o`0000000000
00@00?m>00<00000003oF000oeP00`00oeP00`0000000?mZ003oJP030000
00800?o100<00000003oe`00omL01@00omL00`000000oooo0?ooo`0b0?oo
o`800000C03oool008/0oooo0P0000060?ooo`030000003o^P00okX000@0
okX000@000000?o80000000000000P3o^`02000000@0ol/00P0000060?o?
00040000003oi000000000000080om@00P0000050?o]00030000003on@00
ooT000H0ooT000<000000?Go003eo`00103eo`000`000000aol000000005
0=co0080000000<0X?l0000000000000102do`000`000000I_l000000006
07Oo000300000029o`00000000@07_l000<0000002Go000Uo`00100Uo`00
0`0000000?m>003oCP04003oCP0300000000oeP00?mH00<00?mH0`000006
003o`@0300000000omL00?oG00800?oG0P0000000`00ooP000000000000a
0?ooo`<00000C03oool008X0oooo00<000000?ooo`3oool01@3oool01000
0000olD00000000000020?nj00800000103ob002000000H0ol/000@00000
0?oM0000000000000P3oc`02000000@0on@00P0000060?o]00030000003e
o`00000000D0ooT00P0000000`3Ro`000000000000020?Go008000000`37
o`02000000030=co00000000000000<0X?l00P0000020;Co008000000`1V
o`000`000000Mol007Oo000407Oo00030000000No`007_l000@07_l000@0
000002Go000Uo`009Ol00P0000000`00odP00000003oCP05003oCP030000
0000oeP00?mH008000000P00ok400`0000000?o1003o`@05003o`@040000
0000omL00000000000D00?oh0P00000]0?ooo`8000000P3oool00`000000
oooo0?ooo`1:0?ooo`00R03oool2000000H0oooo0P0000040?o500800000
1P3ob00010000000omP00000000000020?o;00800000103og@02000000H0
on@000<000000?om00000000103ok@0010000000mOl00?Go003eo`020000
00030?oi00000000000000D0h_l00P0000070<Oo00030000002Po`00X?l0
00@0X?l000<000000;Co000000001@1Vo`000`000000Mol007Oo000207Oo
0080000000<05ol00000000No`00100No`00100000009Ol0000000000004
003oB00300000000odh00?m>00@00?m>0P000005003o/@0300000000ol40
0?o100@00?o10P000006003on080000000<00?So000000000000:@3oool2
000000@0oooo00<000000?ooo`3oool0BP3oool006d0oooo1@0000020?oo
o`800000103oool2000000/0oooo00<000000?ooo`3oool01@3oool00`00
0000olD00?o500040?o500040000003od`00000000000080olP00P000004
0?oH008000001P3og@000`000000oo80000000040?oT00040000003oo@00
ood00?om0080000000<0ond00000003eo`001@3eo`000`000000h_l00>;o
00050>;o00030000002eo`00000000D0aol000<0000008ko000000001@2P
o`02000000L0I_l000@0000007Oo0000000000000`0Go`000`0000007_l0
01ko000401ko000300000000odP00?m800@00?m800<00000003oCP00odh0
0P00odh200000003003oYP0000000?na00D00?na00<00000003o`@00ol40
0`000002003ol08000000P00ooP2000000D00?So00<000000?ooo`3oool0
903oool2000000H0oooo00<000000?ooo`3oool0BP3oool006l0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0?ooo`0000080?ooo`800000
1`3oool010000000om000000000000020?o500800000103od`02000000H0
omP000@000000?o[0000000000000P3og@02000000<0oo800P0000000`3o
i00000000?om00050?om00030000003eo`00mOl000@0mOl000<000000=3o
00000000103Ro`0200000080]Ol000@000000<Oo0037o`00aol00P000003
08ko00030000002Po`00X?l00080X?l00`00000706Ko00030000000Go`00
5ol000@05ol000@0000001ko000No`007_l00P0000000`00odD00000003o
B005003oB00400000000odh00000000000@00?nV00<00000003o/@00ok40
1000ok42000000L00?o`0P000006003ho`0300000000eol0000002<0oooo
0P0000080?ooo`030000003oool0oooo04X0oooo001_0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`800000103od002000000H0om<000@000000?oT000000000000
0P3of002000000@0on/00P0000070?ob00030000003oo@00ood000@0ood0
00@000000>Co0000000000000P3eo`02000000<0d?l00P0000000`3Ro`00
00000;Go00040;Go000300000037o`00000000H0S_l000@000000:3o0000
000000000P1Go`02000000@0I_l00P0000000`0>o`00000001Oo000401Oo
00040000000No`000000000000@00?m500<00000003oB000odP01000odP0
0`0000000?nV003oYP04003oYP0300000000ok400?na00800?na0P000000
0`00onT00000003ol004003ol080000000<00?3o00000000n?l00`00n?l2
000000<00=Oo0P00000O0?ooo`8000002`3oool00`000000oooo0?ooo`08
0?ooo`800000103oool2000000@0oooo0P00000c0?ooo`00K`3oool00`00
0000oooo0?ooo`080?ooo`8000001`3oool00`000000oooo0?ooo`050?oo
o`030000003od000om0000@0om0000@000000?oO0000000000000P3od`02
000000@0on@00P0000060?o[00030000003no`00000000D0oo8000@00000
0??o0000000000000P3oo@02000000@0i?l00P0000070=3o00030000002e
o`00]Ol000D0]Ol000<0000008ko002>o`001@2>o`02000000H0Eol01000
000400ko00030000000Go`005ol000<05ol000<00000003oA@00odD01000
odD00`0000000?m8003oB002003oB080000000<00?nN00000000ojH01@00
ojH0100000000?na000000000004003oj@80000000<00?o`000000000000
1000l?l200000003003ho`0000000=Oo00H00=Oo00<000000?ooo`3oool0
6P3oool2000000d0oooo00<000000?ooo`3oool01`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo00000380oooo001_0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool2000000L0
oooo00@000000?oK0000000000000P3od002000000@0oml00P0000060?oT
00030000003on000000000@0on/000@000000?ko003no`00o_l00P000000
0`3olP000000000000040??o008000001P3To`000`000000_ol000000005
0=3o00030000002So`00000000D0]Ol000<0000007go000000001@2>o`02
0000000304Wo00000000Eol000D0Eol000@0000000ko000000000000100>
o`000`0000005ol001Oo000200000003003oAP0000000?m500D00?m500@0
0000003oB000000000001000oih00`0000000?nV003oYP03003oYP800000
2000onT00`0000000?3o003`o`06003`o`0300000000eol00=Oo00D00=Oo
00<000000024o`0000006@3oool2000000l0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0300
oooo001^0?ooo`8000002P3oool3000000<0oooo0P0000060?ooo`800000
103of`02000000H0oml000@000000?o`0000000000000P3oi002000000<0
ooP00P0000000`3oj`0000000?ko00050?ko00030000003co`00lol000@0
lol000@000000=Co0000000000000P3To`02000000<0_ol00P0000000`3@
o`000000000000030:?o0080000000<0]Ol00000000000000`1mo`020000
000308ko00000000000000@0BOl000<0000005Oo001Go`000P1Go`000`00
00001_l00000000200ko00<000000P0>o`02000000@00?m600<00000003o
A@00odD00`00odD2000000L00?nN00<00000003oYP00ojH00P000002003o
i@0300000000onT00?oY00<00?oY0P0000000`00jOl00000003`o`04003`
o`80000000<00<7o00000000eol00`00eol20000008008Co00<000000?oo
o`3oool05@3oool200000140oooo00@000000?ooo`3oool0oooo10000002
0?ooo`040000003oool0oooo000000T0oooo0P00000c0?ooo`00P03oool0
0`000000oooo0000000200000080oooo00<000000?oK003of`00103of`00
10000000on/00000000000020?oO00800000103ol002000000L0ooP000<0
00000?ko003no`00103no`0010000000i?l00000000000020??o00800000
103Do`02000000L0_ol000<000000:?o002So`001@2So`000`000000OOl0
07go000407go008000001`19o`0010000000Eol000000000000300Ko0003
0000000>o`003_l000803_l00P0000000`00odP00000003oAP04003oAP03
00000000odD00?m5008000000P00oiX00`0000000?nN003oWP05003oWP80
00001@00onD200000003003oj@000000000000@00>Wo0P0000000`00l?l0
0000000000040031o`80000000<00=Oo00000000Q?l01000Q?l00`000000
oooo0?ooo`0B0?ooo`8000004`3oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool0<P3oool00800
oooo00<000000?ooo`3oool00P3oool2000000030?oU0000000000000080
om/00P0000040?o[008000001P3ol0000`000000nol0000000050?oh0004
0000003ao`00000000000080o_l00P0000040>Co008000001P3Do`000`00
0000/?l0000000040;oo0080000000<0Tol00000002So`00102So`000`00
0000K_l00000000407go0080000000<0??l000000019o`001P19o`000`00
00001_l000Ko000400Ko00040000000>o`000000000000800?m80`000005
003oAP8000001@00oiX00`0000000?nN003oWP02003oWP80000000<00?oR
00000000onD01P00onD00`0000000>Wo003Yo`06003Yo`0300000000`Ol0
0<7o00H00<7o00<000000024o`00Q?l01@00Q?l00`000000oooo0?ooo`0?
0?ooo`8000005@3oool00`000000oooo0?ooo`080?ooo`8000002P3oool3
00000380oooo00200?ooo`040000003oool0oooo0?ooo`800000103oi@02
000000H0on/000@000000?ol0000000000000P3ol002000000<0nol00P00
00000`3on0000000000000040?7o008000001@3To`02000000030<Ko0000
0000e?l00080e?l00P0000030;3o00040000002oo`000000000000@0Tol0
0P0000000`2So`0000000000000306ko00D000000`0lo`000`000000BOl0
04Wo000204Wo0080000000<00?l200000006o`001@06o`000`0000000?m8
003oB004003oB0<0000000D00?m60000000000000?nG00000006003oVP04
00000000oih00000000000@00?oR00<00000003oi@00onD00P00onD20000
0003003Uo`0000000>Wo00@00>Wo0P0000000`00/Ol000000031o`050031
o`0300000000J_l0000000H008Co00<000000?ooo`3oool03@3oool20000
01L0oooo00<000000?ooo`3oool0903oool2000000h0oooo0P0000040?oo
o`8000003@3oool00800oooo00@000000?ooo`3oool000001P3oi@001000
0000ooD00000000000020?o[00800000103oo002000000L0nol000<00000
0?7o003ao`000`3ao`02000000040=Oo0000000000000>Co008000001036
o`000`000000e?l0000000060;3o00030000002Co`00Tol000H0Tol000<0
000006ko001^o`000`1^o`03000000H0??l000@0000004Wo000000000000
0`00o`800`0000001_l000Ko000200Ko0080000000<00?m;00000000odP0
1000odP00`0000000?m600000002000000<00?nG00<00000003oVP00oiX0
0`00oiX2000000L00?oR00@00000003oi@00000000001000iOl200000003
003Yo`000000000000@00;7o00@000000031o`00`Ol00<7o0P000002001Z
o`0300000000Q?l008Co00D008Co00<000000?ooo`3oool02P3oool20000
01P0oooo0P00000O0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02`3oool00800oooo00@000000?ooo`00
0000oo000P0000020?oU00800000103om@02000000H0oo`000<000000>oo
000000001@3ko`001@000000i?l0000000000000lOl0008000001@3Go`00
0`000000a_l00<Ko00050<Ko00030000002`o`00/?l000@0/?l000<00000
08Go000000001@2Co`020000000405oo00000000K_l006ko0080000000@0
K_l00000000`o`0000001P0lo`000`0000000?l2003o0P04003o0P040000
0006o`000000000000@00?m;00<00000003oB000odP00`00odP010000000
0?nG003oU`00oiL300000004003oU`0000000?nJ003oVP8000000P00oml0
0`0000000?oR003ohP04003ohP8000002000iOl00`0000000;7o002ao`05
002ao`0300000000`Ol0000000D006[o00<000000024o`00Q?l00`00Q?l2
000000X0oooo0P00000K0?ooo`030000003oool0oooo01d0oooo0`000004
0?ooo`030000003oool0oooo0080000000<0oooo0000000000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02`3oool00800oooo0P0000040?o`008000001P3om@001000
0000n?l00000000000020?ol008000000`3_o`02000000030?_o00000000
000000@0i?l000<000000=Oo003Go`00103Go`000`000000^?l000000005
0<Ko00040000002Qo`00000000000080/?l00P00000308Go0080000000<0
Tol00000000000000`1Oo`0010000000K_l00000001^o`0200000080<?l0
00<0000003co000lo`000P0lo`0200000003003o2P0000000?l200D00?l2
00<00000003oB`00od/01000od/00`0000000?m8003oB002003oB0030000
0000oiL0000000D00?nG10000005003og`8000000P00on82000000800>;o
00<00000003Uo`00iOl00`00iOl200000003002Vo`0000000;7o00H00;7o
00<00000001Zo`00J_l01@00J_l00`00000008Co0024o`02000000807`3o
00<000000?ooo`3oool01@3oool2000001d0oooo00<000000?ooo`3oool0
703oool01@000000oooo0000003oool0000000<0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo00/0oooo001o0?oo
o`030000003ol000oo0000@0oo0000@000000?oo0000000000000P3om@02
000000@0n?l00P0000070>oo00030000003To`00i?l000<0i?l000@00000
0<Wo0000000000000P3Go`02000000<0^?l00P0000000`36o`0000000000
00040:7o008000001`25o`000`000000Gol005oo000305oo0080000000<0
K_l00000000`o`00100`o`0010000000??l0000000000004003o2P030000
0000o`800?l200800?l200<00000003oC`0000001P00od/0100000000?m8
000000000003003oU`0300000000oiL00?nG00800?nG1@000006003og`80
00001@00h_l200000003003Uo`000000000000<00:Ko00<00000002ao`00
/Ol00`00/Ol200000003001Ho`00000006[o00D006[o00<000000024o`00
0000100O0?l00`000000oooo0?ooo`030?ooo`800000803oool00`000000
oooo0?ooo`0K0?ooo`050000003oool000000?ooo`0000000`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`0;0?ooo`00O`3oool30000
0080oo000P0000040?oo008000001P3ho`000`000000hol0000000050>oo
00050000003Ho`0000000000003To`000P0000040<Wo008000001`2ho`00
0`000000XOl00:7o00040:7o00030000001go`00000000D0QOl000<00000
05;o000000000P1Oo`0200000080Gol000<00000033o000`o`001@0`o`00
0`0000000?l:003o2P05003o2P0400000000o`800000000000<00?m?00<0
0000003oB`00od/00`00od/2000000H00?nG00@00000003oU`0000000000
1000omh3000000800?oO0P0000000`00gol00000003Ro`06003Ro`030000
0000Y_l00:Ko00@00:Ko00<00000002ao`00/Ol00P000003001Ho`030000
0000J_l006[o00D006[o00<0000001l0o`0O0?l0100O0?l00`000000oooo
0?ooo`0200000280oooo00<000000?ooo`3oool06`3oool01@000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool00P0000000`3oool0
0000000000070?ooo`<0000000<0oooo0000000000000P3oool00`000000
oooo0?ooo`0;0?ooo`00O`3oool00`000000oooo0?ooo`02000000H0ool0
00@000000>go0000000000000P3ho`02000000<0hol00P0000000`3_o`00
0000000000040=So000300000039o`00bOl000@0bOl000<000000:_o0000
00001@2ho`0010000000U?l00000000000020:7o008000000`1go`020000
000308Go00000000000000<0D_l00P00000205oo0080000000<09?l00000
000`o`00100`o`000`0000000?lC00000007003o2P0300000000odl00?m?
00@00?m?00<00000003oB`00od/00P000002003oU`0300000000oiL00?nG
00@00?nG00<00000003ogP00omh01@00omh00`0000000?oO000000020000
00800=oo00<00000003Ro`00h_l00`00h_l200000003002No`0000000:Ko
00D00:Ko0P000006001Ho`0300000000J_l006[o008006[o0`00000601l0
o`<00000903oool00`000000oooo0?ooo`0L0?ooo`<00000103oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo001o0?ooo`03
0000003oool0oooo0080oooo0P0000020?oo00800000103]o`02000000L0
hol000<000000=So003Ho`000`3Ho`0010000000_Ol00000000000020<Wo
008000000`2[o`02000000030;So00000000000000@0U?l00P00000707Oo
00030000001Bo`00D_l00080D_l00P0000000`1Bo`0000000000000402Co
0080000000<0<?l00000000000000`00oa<00`0000000?l:003o2P02003o
2P80000000<00?mC00000000odl01@00odl2000000@00?nG00<00000003o
U`00oiL00P00oiL200000003003ogP0000000?oN00H00?oN00@00000003O
o`00gol00=oo0P0000001000gol00000003Ro`00h_l2000000<009ko00<0
0000002Vo`00Y_l00P00Y_l200000003001>o`00000005So00D005So00<0
0000001Zo`00J_l00P00000302/0o`030000000O0?l07`3o00@07`3o00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`020?ooo`8000006P3o
ool00`000000oooo0?ooo`020?ooo`800000503oool2000000d0oooo001o
0?ooo`030000003oool0oooo00@0oooo0P0000060>go00040000003Ho`00
0000000000<0hol00P000000103<o`0000000000003Ho`02000000@0_Ol0
0P0000070:_o00030000002Do`00U?l000@0U?l000<0000006[o00000000
1@1go`0010000000A_l00000001Bo`0200000080D_l000<0000001[o0000
00001P0To`000`0000000?lC003o4`04003o4`0400000000o`X000000000
00<00?mC00<00000003oC`00odl00P00odl200000003003oV00000000?nG
00@00?nG00@00000003oU`00000000001000omh00`0000000?oN003ogP02
003ogP80000000<00=ko00000000gol00`00gol4000000H009ko00@00000
002Vo`00000000001000C_l00`00000005So001Ho`04001Ho`8000001@0[
0?l00`0000007`3o01l0o`0401l0o`030000003oool0oooo02<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0440oooo
001o0?ooo`030000003oool0oooo00H0oooo0P0000020>go00800000103H
o`03000000D0c?l000<000000;go002mo`00102mo`000`000000W_l00000
00050:_o000400000027o`00000000000080U?l00P00000306[o00800000
00<0Mol00000000000000`16o`020000000305;o00000000000000<06_l0
00<0000002Co000To`000P0To`000`0000000?lK00000006003o4`030000
0000oe<00?mC00@00?mC00@00000003oC`00000000001000oiP00`000000
0?nG003oU`03003oU`0300000000omh00?oN00D00?oN00@00000003ogP00
000000001000g_l00`0000000=oo003Oo`02003Oo`0400000000V_l00000
000000H009ko00<00000001>o`00C_l01000C_l00`00000005So001Ho`02
001Ho`<000001`0[0?l00`0000007`3o01l0o`0401l0o`030000003oool0
oooo0280oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0440oooo001o0?ooo`030000003oool0oooo00P0oooo0P000006
0=So000300000030o`00000000@0c?l000@000000;7o0000000000000P2m
o`02000000<0W_l00P0000000`2[o`0000000000000408Oo008000001`1Z
o`0010000000A_l004Ko0016o`0200000080A_l000<0000001[o000Jo`00
100Jo`00100000009?l0000000000003003o6`0300000000oa<00?lC0080
0?lC00<00000003oF00000001P00oe<00`0000000?nH003oV005003oV003
00000000oiL00?nG0080000000<00?oM00000000omh01@00omh2000000L0
0=ko00@00000003Oo`00000000000`00V_l400000005002No`0000000000
0018o`0000001P00C_l01000000005So00000000000302d0o`030000000[
0?l0:`3o00@0:`3o00<0000001l0o`0O0?l0100O0?l00`000000oooo0?oo
o`0R0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`110?ooo`00O`3oool00`000000oooo0?ooo`0:0?ooo`8000000P3H
o`02000000<0`?l00P0000000`3<o`0000000;7o00030;7o008000001`2N
o`000`000000Qol008Oo000408Oo00030000001No`00000000D0J_l000<0
000003_o000000000P00000204Ko0080000000<04?l00000000Jo`001@0J
o`000`0000000?lK003o6`04003o6`0400000000oa<00000000000<00?mH
00<00000003oD`00oe<00P00oe<00`0000000?nJ00000007003oV0800000
1000omd2000000800?oN0P000002003No`0300000000g_l00=ko00@00=ko
0P000006002Jo`0300000000W_l00000008000000`00B?l00`00000004ko
001>o`04001>o`030000000]0?l0;@3o00<0;@3o00<0000002/0o`0[0?l0
1@0[0?l0100000007`3o01l0o`0O0?l3000002@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0440oooo001o0?ooo`03
0000003oool0oooo00`0oooo0P0000070<3o00030000002ao`00/Ol000<0
/Ol000@0000009;o0000000000000`2No`020000000307[o000000000000
0080Qol00P00000305ko0080000000<0J_l00000000000000P0ko`020000
000304Ko00000000000000<04?l000<0000001[o000Jo`000P0Jo`020000
0003003o8P0000000?lK00@00?lK0P000006003oF00400000000oe<00000
000000<00?nJ00<00000003oV000oiP00P00oiP200000003003og@000000
0?oM00D00?oM0P000005003No`8000000P00g_l20000008009Oo00<00000
002Jo`00V_l01000V_l01000000004So0018o`00B?l4000000@004ko0P00
00000`0[0?l0000002d0o`0402d0o`030000000[0?l0:`3o00@0:`3o00@0
000001l0o`00000000000`3o0=/00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0080oooo0P0000140?ooo`00O`3oool00`000000oooo0?oo
o`0>0?ooo`8000000`30o`02000000040:Go0000000000000;7o00800000
102Bo`03000000D0N_l00P00000705ko00030000000ko`00>ol000800000
0P0ko`000`0000004?l0013o0004013o00040000000Jo`000000000000@0
0?lR00<00000003o6`00oa/00P000002003oG@0300000000oeP00?mH00<0
0?mH0P000006003oVP0400000000oiP00000000000<00?oM00<00000003o
g@00omd00P00omd200000003003Mo`0000000=ko00H00=ko0P000004002G
o`0300000000V_l009[o008009[o0P0000000`00AOl000000018o`040018
o`80000000<004ko0000000000000`0[0?l00`000000;@3o02d0o`0302d0
o`030000000[0?l0:`3o00D0:`3o00<000000?l0f`3o0=/00`3o0=/00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo04P0oooo001o0?ooo`03
0000003oool0oooo0100oooo0`0000050:Go00030000002Bo`00T_l000@0
T_l000<0000006oo000000001@1jo`000`000000D_l00000000505ko0004
0000000`o`000000000000<0>ol000<0000000Ko000000001P0@o`000`00
00000?lR003o8P05003o8P8000001@00oed00`0000000?mH003oF0020000
00800?nL00<00000003oVP00oiX01000oiX00`0000000?oM003og@04003o
g@0400000000omd00000000000@00=go00<00000003No`00g_l00P00g_l2
00000003002Go`00000009Oo00@009Oo00@00000002Jo`00000000001000
AOl00`00000004So0018o`040018o`<00000100[0?l00`000000;@3o02d0
o`0302d0o`030000000[0?l0:`3o0080:`3o0`0000050?l0f`030000003o
ool0oooo0200oooo0P00001:0?ooo`00O`3oool00`000000oooo0?ooo`0B
0?ooo`030000002Uo`00YOl00080YOl000@0000008Ko0000000000000P2B
o`02000000<0Kol00P0000000`1jo`0000000000000305;o0080000000P0
G_l0000000000000<?l00000000`o`00000003_o008000000`06o`020000
00804?l00P0000000`00obX00000003o8P04003o8P0300000000of800000
00H00?mM0P000005003oW08000000P00oiX200000003003ogP0000000?oM
00D00?oM00<00000003Mo`00gOl01@00gOl0100000000=ko000000000003
002Go`0300000000Uol009Oo00<009Oo0P0000060015o`0300000000B?l0
04So008004So0P0000000`0U0?l0000002/0o`0200000080:`3o00<00000
02d0o`0]0?l00`0]0?l00`000000:`3o02/0o`02000000<0l@3o00<00000
0?l0f`3o0=/00`3o0=/00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo04L0oooo001n0?ooo`030000003oool0oooo01@0oooo00@000000:Go
0000000000001026o`02000000L0Kol000<0000005;o001Bo`001@1Bo`00
10000000<?l0000000000003033o000300000006o`001_l000D01_l00P00
0004003o:P80000000<00?lR0000000000000`00of800`0000000?mM003o
G@02003oG@0300000000oih0000000L00?nL0P000004003ogP8000000P00
omd200000003003Mo`0000000=go00H00=go00<00000002Go`00Uol01000
Uol00`00000009Oo002Go`020000008004Ko00<000000015o`00AOl01000
AOl01000000004So00000000000302D0o`040000000[0?l0:`3o02/0o`80
000000<0:`3o0000000]0?l00`0]0?l3000000D0l@3o00<000000?l0f`3o
0=/00`3o0=/00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo04L0
oooo001n0?ooo`030000003oool0oooo01D0oooo00<0000008Ko0026o`00
1026o`000`000000I?l00000000506oo000300000018o`00000000@0D_l0
10000004033o000300000000o`80000000D01_l000<00000003o<@000000
1P00obX00`0000000?mR003oHP04003oHP0400000000oed00000000000<0
0?nN00<00000003oW000oi`00P00oi`200000003003ogP0000000?oN00D0
0?oN0P000004003Mo`0300000000gOl00=go00800=go0P0000000`00Uol0
0000002Go`05002Go`8000001@00A_l00`00000004Go0015o`030015o`80
00001P0U0?l00`000000:`3o02/0o`0202/0o`<0000000D0;@3o00000000
0000c`3o000000070?40o`030000003o0=/0o`3K0080o`3K00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`170?ooo`00OP3oool00`000000
oooo0?ooo`0F0?ooo`8000000P26o`02000000<0I?l00P0000000`1_o`00
00000000000304So00060000001Bo`0000000000000Vo`0000000P0Vo`00
10000000<?l0000000000003003o0P80000000<01_l00000000000000`00
oc400`0000000?lZ003o:P02003o:P0300000000ofH0000000H00?mR00<0
0000003oWP00oih01000oih0100000000?nL000000000003003ogP030000
0000omh00?oN00800?oN0P0000000`00g_l00000003Mo`04003Mo`040000
0000gOl00000000000@009Oo00<00000002Go`00Uol00P00Uol00`000000
04So000000060016o`0300000000AOl004Go008000000P0N0?l00`000000
9@3o02D0o`0402D0o`030000000[0?l0:`3o0080:`3o100000030<l0o`03
0000003a0?l0l@3o00@0l@3o00<000000?l0f`3o0=/00`3o0=/00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo04L0oooo001n0?ooo`030000
003oool0oooo01P0oooo0P00000706Co000300000018o`00B?l000@0B?l0
00@0000002Ko000000000000100Vo`000`0000000?l2003o0P05003o0P03
00000000oc400?la00@00?la00@00000003o:P00000000000`00ofH20000
00800?mR0P0000000`00oj400000003oWP05003oWP0300000000omh00?oN
00@00?oN00@00000003ogP00000000000`00g_l00`0000000=go003Mo`03
003Mo`8000001`00Uol01000000009Oo0000000000030018o`0300000000
A_l004Ko00@004Ko0P00000501h0o`030000000U0?l09@3o00<09@3o00<0
000002/0o`0[0?l00P0000020;@0o`030000003?0?l0000000<000001P3a
0?l00`000000o`3K0?l0f`030?l0f`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0A`3oool007h0oooo00<000000?ooo`3oool06P3oool2
000000<0I?l00P0000000`0mo`0000000000000204So00D000000`0Vo`02
00000003003o2P0000000?l200@00?l200<00000003o>00000001P00oc40
0`0000000?mV003oIP05003oIP8000001000oj42000000800?nN0P000000
0`00oml00000003ogP05003ogP0300000000g_l00=ko00@00=ko00<00000
003Mo`00gOl00P000002002Ho`0300000000Uol009Oo00@009Oo0P000005
0018o`0300000000A_l004Ko008004Ko0P0000000`0G0?l0000001h0o`04
01h0o`030000000U0?l09@3o00<09@3o0`0000040;@0o`030000003?0?l0
c`3o0080c`3o0P0000060?40o`030000003o0=/0o`3K0080o`3K00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`020?ooo`800000103oool2
000000@0oooo0P00000g0?ooo`00OP3oool00`000000oooo0?ooo`0L0?oo
o`<000001@0mo`04000000<07?l00`000004003o2P80000000<00?l20000
000000000`00ocP2000000800?la0P0000000`00of/00000003oIP03003o
IP80000000<00?nT00000000oj401@00oj42000000@00?oO0P000002003o
gP80000000<00=ko00000000g_l01@00g_l2000000D009So0P000002002G
o`8000000P00Bol00`00000004So0018o`030018o`0400000000A_l00000
000000@05`3o00<0000001h0o`0N0?l00`0N0?l00`0000009@3o02D0o`02
00000080W@3o00<000000;@0o`2d0?l00`2d0?l00`000000c`3o0<l0o`02
0<l0o`@000000`3a0?l00`000000o`3K0?l0f`030?l0f`030000003oool0
oooo01l0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00H0oooo00@000000?ooo`3oool00000=P3oool007h0oooo00<0
00000?ooo`3oool07P3oool00`000000?Ol003go000303go00<00000100L
o`000`0000000?lB00000006003o2P0300000000ocP00?lh00D00?lh0P00
0004003oJ`0400000000ofH00000000000<00?nT00<00000003oX@00oj40
0P00oj4200000003003oh00000000?oO00D00?oO0P000004003No`800000
0P00g_l200000003002Jo`00000009So00H009So0P000004001;o`030000
0000B?l004So00<004So0P00000601L0o`030000000N0?l07P3o00<07P3o
0`00000409d0o`030000002d0?l0]03o00<0]03o00<000000<l0o`3?0?l0
0`3?0?l00`000000l@3o0?40o`0200000080l@3o00<000000?l0f`3o0=/0
0P3o0=/00`000000oooo0?ooo`0O0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0
oooo001n0?ooo`030000003oool0oooo01l0oooo0P000000100mo`000000
00000000000201?o00040000000Lo`000000000000<00?lB0P000002003o
2P80000000<00?ln00000000ocP00`00ocP200000003003oL00000000?m[
00@00?m[00<00000003oY000oj@01000oj@0100000000?nQ000000000003
003oh00300000000oml00?oO00800?oO0P0000000`00gol00000003No`05
003No`8000001000V_l00`00000009So002Ho`02002Ho`80000000<004oo
00000000Bol01000Bol00`00000004So0018o`02000000803P3o00<00000
01L0o`0G0?l0100G0?l00`0000007P3o01h0o`0200000080R@3o00<00000
09d0o`2M0?l00`2M0?l00`000000]03o0;@0o`030;@0o`030000003?0?l0
c`3o0080c`3o00<000000?40o`3a0?l00P3a0?l4000000<0o`3K00<00000
0?ooo`3oool07`3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool01`3oool2000003L0oooo001n0?ooo`030000003oool0
oooo0240oooo0P00000501?o000300000000oa800?lB00D00?lB0P000004
003o?P0400000000ocP00000000000@00?m`00<00000003oJ`00of/00P00
00000`00ojH00000003oY005003oY00300000000on000?oP00@00?oP00@0
0000003og`00000000000`00gol00`0000000=ko003No`02003No`800000
00<009co00000000V_l01000V_l01000000009So000000000003001?o`03
00000000Bol004_o00<004_o0`00000500h0o`030000000G0?l05`3o00<0
5`3o0`00000408T0o`030000002M0?l0W@3o00@0W@3o00<000000;@0o`2d
0?l00P2d0?l010000000c`3o0<l0o`3?0?l6000000<0o`1k100000000`3o
0=/000000?ooo`0O0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo03H0oooo001n0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`000000100Co`000`00
00000?lJ00000005003o4P0300000000od@0000000D00?ln00<00000003o
L000og001@00og02000000@00?nV0P000002003oY080000000<00?oQ0000
0000on001@00on000`0000000=oo003Oo`04003Oo`0400000000g_l00000
000000@009co00<00000002Jo`00V_l00`00V_l00`00000004oo001?o`04
001?o`0300000000Bol004_o008000000P060?l00`0000003P3o00h0o`04
00h0o`030000000G0?l05`3o008000000P1g0?l00`000000R@3o08T0o`03
08T0o`030000002M0?l0W@3o00<0W@3o00@000000;@0o`2d0?l0]03o1@00
00030?l0/0030000003o07/0o`1k00@0o`1k1@00000Q0?ooo`040000003o
ool0oooo0?ooo`8000002P3oool3000003H0oooo001n0?ooo`030000003o
ool0oooo01h0oooo0P0000030?ooo`040000000Co`000000000000<00?lJ
0P0000000`00oa80000000000003003oA00300000000och00?ln00800000
00<00?md00000000og001000og000`0000000?nY00000006003oYP800000
1000on42000000800?oP0P0000000`00h?l00000003Oo`05003Oo`030000
0000W?l009co00D009co00<00000002Jo`00V_l00P0000000`00Dol00000
001?o`05001?o`8000001@060?l00`0000003P3o00h0o`0300h0o`<00000
101g0?l00`000000R@3o08T0o`0308T0o`030000002M0?l0W@3o0080W@3o
1@0000030?l0fP030000003o0;00o`2`00<0o`2`00<000000?l0N`3o07/0
103o07/00`000000o`0_0?l0;`03000001h0oooo0P0000180?ooo`00OP3o
ool00`000000oooo0?ooo`0L0?ooo`8000001P3oool00`0000000?lJ003o
6P05003o6P0300000000od@00?m400@00?m40P000004003oM080000000<0
0?m`0000000000000`00ojT00`0000000?nV003oYP02003oYP0300000000
on80000000H00?oQ0P000004003Po`8000000P00gol200000003002No`00
000009co00D009co0`000004001Co`0300000000Col004oo008004oo00<0
00000002o`0000001P060?l00`0000003P3o00h0o`0200000080IP3o00<0
000007L0o`1g0?l00`1g0?l00`000000R@3o08T0o`0208T0o`D000000`3o
0?d00`000000o`3J0?l0fP030?l0fP030000003o0;00o`2`00<0o`2`00<0
00000?l0N`3o07/00P3o07/9000001/0oooo00<000000?ooo`000000B03o
ool007h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`07
0?ooo`8000000`00oaX200000003003oBP0000000?m400<00?m400<00000
003oN@0000001P00og@00`0000000?nY003oZ@04003oZ@0400000000ojH0
0000000000<00?oR00<00000003oh@00on400P00on400`0000000>7o0000
0006003Po`8000001000W_l20000008009co0P000002001Ho`0300000000
Dol005?o00<005?o00@00000001?o`00000000000`000_l00`0000001P3o
00H0o`0300H0o`<00000101V0?l00`000000M`3o07L0o`0307L0o`030000
00290?l0R@3o008000000P3U0?l00`000000o`3m0?l0o@030?l0o@030000
003o0=X0o`3J00@0o`3J00@000000?l0/03o0;00o`2`1P0000030?l0AP03
0000003o01P0o`0H00<0o`0H0`00000J0?ooo`030000003oool0oooo04H0
oooo001m0?ooo`030000003oool0oooo01X0oooo0P00000<0?ooo`<00000
1000odX0100000000?m4000000000003003oN@8000000P00og@200000003
003o[00000000?nY00D00?nY00<00000003ohP00on801000on8010000000
0?oQ000000000003003Qo`8000000P00h?l200000003002Qo`00000009ko
00D009ko0P000004001Ho`0300000000Dol005?o00<005?o0P0000060002
o`03000000060?l01P3o008000000P1G0?l00`000000IP3o06H0o`0306H0
o`030000001g0?l0M`3o0080M`3o0`0000050>D0o`030000003o0?d0o`3m
00<0o`3m00<000000?l0fP3o0=X00P3o0=X5000000<0o`1a00<000000?l0
AP3o04H0103o04H00`000000o`0H0?l06003000000040?l04@0000000000
000001P0oooo00<000000?ooo`3oool0AP3oool007d0oooo00<000000?oo
o`3oool0603oool200000100oooo00<00000003oBP00odX00`00odX00`00
00000?mi003oN@05003oN@8000001000oj`2000000800?nY0P0000000`00
on<00000003ohP04003ohP8000001`00hOl2000000@00:7o00<00000002N
o`00W_l00P00W_l00`00000005go00000005001Ho`0300000000Dol005?o
008000000P002_l00`00000000;o0002o`030002o`<000001@1G0?l00`00
0000IP3o06H0o`0206H0o`030000001g0?l0M`3o008000000P3;0?l00`00
0000i@3o0>D0o`030>D0o`030000003o0?d0o`3m00<0o`3m1@0000030?l0
V0030000003o0740o`1a00<0o`1a0P0000030?l0AP@000001@3o01440000
01H0oooo00<000000?ooo`3oool0AP3oool007d0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0A0?ooo`0300000000odX00?m:0080
000000<00?mm00000000ogT01000ogT00`0000000?n^00000006003o[080
00001000on<00`0000000?oR003ohP02000000800>;o00<00000003Qo`00
hOl00P00hOl200000003002To`0000000:7o00@00:7o00@00000002No`00
000000000`00GOl00`00000005So001Ho`03001Ho`8000001@002_l00`00
000000;o0002o`0200000080B@3o00<0000005L0o`1G0?l0101G0?l01000
0000IP3o06H0o`1V0?l3000000D0b`3o00<000000>D0o`3U0?l00`3U0?l0
0`000000o`3m0?l0o@0200000080o`2j00<000000?l0V03o09P0103o09P0
0`000000o`1a0?l0L@020?l0L@D00000103o03<5000000@0o`0=0`00000C
0?ooo`030000003oool0oooo04H0oooo001m0?ooo`030000003oool0oooo
01D0oooo0P00000E0?ooo`8000001000ogd200000003003oN@0000000000
00<00?n^0P000002003o[080000000<00?oT00000000on<01000on<20000
00D00>;o00@00000003Qo`00000000000`00Y?l00`0000000:7o002Qo`03
002Qo`8000001P00GOl00`00000005So001Ho`0200000003000Co`000000
00[o00D000[o0P00000504T0o`030000001G0?l0E`3o00<0E`3o10000002
0;@0o`030000003;0?l0b`3o00@0b`3o00@000000>D0o`3U0?l0i@3o1000
00050?l0^P8000000`3o09P6000000<0o`1D0P0000020?l0<`<000000P3o
02T200000080o`0=0`0000020?l02`8000004@3oool00`000000oooo0?oo
o`160?ooo`00O@3oool00`000000oooo0?ooo`0C0?ooo`800000603oool0
0`0000000?mm003oO@04003oO@0300000000ojh00?n^00D00?n^0P000004
003oi00300000000on<00?oS0080000000<00>?o00000000h_l01@00h_l0
0`0000000:Co002To`04002To`0300000000XOl00:7o008000000P00H_l0
0`00000005go001Mo`03001Mo`<0000010004ol20000008000[o0P000000
0`0l0?l0000004T0o`0504T0o`030000001G0?l0E`3o008000000P2P0?l0
0`000000]03o0;@0o`020;@0o`030000003;0?l0b`3o00<0b`3o10000003
0?l0f@030000003o0;X0o`2j00@0o`2j100000030?l0M0800000103o05@4
000000H0o`0Y0`0000050?l02`@000003`3oool00`000000oooo0?ooo`16
0?ooo`00O@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01T0oooo0P000002003oO@80000000<00?na00000000ojh01000ojh00`00
00000?oT00000005003oi08000001000hol2000000800>;o0P0000000`00
Y_l00000002To`05002To`8000001@00H_l00`00000005go001Mo`020000
008001_o00<00000000Co`004ol00`004ol3000000@0?03o00<0000004T0
o`190?l00`190?l3000000@0X03o00<000000;@0o`2d0?l00`2d0?l00`00
0000b`3o0</0o`0200000080o`3d00<000000?l0f@3o0=T00`3o0=T20000
0080o`2j0P0000020?l0TP030000003o07@0o`1d00@0o`1d100000030?l0
A08000000`3o02T2000000<0o`0S1@0000040?l02P@000002`3oool01000
0000oooo0?ooo`3oool500000400oooo001m0?ooo`030000003oool0oooo
0100oooo0P00000N0?ooo`8000001000ok4200000003003o[P0000000000
00<00?oT00<00000003oi000on@00P0000000`00i?l00000003So`05003S
o`8000001000Y_l2000000800:Co0P0000000`00I_l00000001Ro`05001R
o`8000001@006ol00`00000001?o000Co`0200000080<03o00<0000003`0
o`0l0?l00`0l0?l00`000000B@3o04T0o`0200000080SP3o00<000000:00
o`2P0?l00`2P0?l010000000]03o0;@0o`2d0?l4000000D0o`3d0P000003
0?l0f@@000001@3o098200000080o`1d0P0000020?l0GP800000103o04@4
000000<0o`0S0`0000020?l07P8000000P3o00X300000080o`080`00000:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03oool0
07d0oooo00<000000?ooo`3oool03P3oool200000240oooo00<00000003o
/@00ok401000ok400`0000000?oT003oi004003oi08000001000i?l20000
00800>?o0P0000000`00ZOl00000002Vo`05002Vo`8000001000I_l20000
008006;o0P0000000`008_l00000000Ko`05000Ko`800000100`0?l00`00
0000?03o03`0o`0303`0o`<00000102>0?l00`000000X03o0:00o`030:00
o`@000000`3b0?l00`000000o`3d0?l0m0040?l0m0@000000`3o0:d20000
00@0o`2B100000050?l0GPD00000103o03X3000000H0o`0N0`0000040?l0
2080000000@0o`080000000000000000203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0400oooo001m0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool08P3oool2000000800?na0P0000000`00
onD00000003oi003003oi00300000000i?l0000000H00>Co0P000004002Y
o`8000000P00Y_l200000003001[o`00000006Ko00@006Ko0`000004000R
o`8000000P006ol20000000302@0o`000000<03o00@0<03o00<0000003`0
o`0l0?l00P00000207d0o`030000002>0?l0SP3o00<0SP3o00<000000:00
o`2P0?l00P0000020=`0o`030000003b0?l0lP3o00<0lP3o0P0000020?l0
m08000000P3o0<L00`000000o`2]0?l0[@030?l0[@D000000`3o07P20000
0080o`1N0P0000020?l0D08000000`3o03X200000080o`0b0P0000030?l0
7P8000000`3o01/4000000H0o`080`0000050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0@03oool007d0oooo00<000000?ooo`3o
ool02`3oool2000002L0oooo0P000004003oi@0400000000on@000000000
00<00>Co0P000002003To`80000000<00:co00000000ZOl01000ZOl30000
00@006_o00<00000001Vo`00I_l00P000002000Zo`03000000008_l002;o
00<002;o0`00000402@0o`030000000`0?l0<03o00<0<03o0P00000507d0
o`8000000`2>0?l3000000D0g03o0P0000030?80o`@000001@3o0<L00`00
0000o`2]0?l0[@0200000080o`2@0P0000040?l0N0@000001P3o05030000
00D0o`0b100000030?l06`<000000P3o01P200000080o`080`0000020?l0
1`<000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0400oooo001m0?ooo`030000003oool0oooo00T0oooo0P00000Z0?ooo`03
00000000onD00?oU00<00?oU00<00000003To`00i?l01@00i?l2000000@0
0:co00<00000002Yo`00ZOl00P000002001`o`0300000000Jol006_o00<0
06_o0P000005000Zo`03000000008_l002;o008000000P0J0?l00`000000
903o02@0o`0302@0o`030000000`0?l0<03o0080000000<0KP3o0000001m
0?l01@1m0?l400000080a`3o00<000000=`0o`3L0?l0103L0?l4000000<0
o`3O0P0000030?l0a`@000001P3o0904000000<0o`1V0P0000030?l0D080
00000`3o04H5000000@0o`0]0`0000060?l060<00000103o00L200000080
o`060P0000000`3oool000000?ooo`020?ooo`800000@P3oool007d0oooo
00<000000?ooo`3oool01`3oool2000002d0oooo00<00000003oi@00onD0
0P0000000`00iOl0000000000003003To`80000000<00:ko00000000[?l0
1000[?l2000000D0073o00<00000001[o`00Jol00P0000000`00<Ol00000
000Zo`05000Zo`800000100J0?l00`000000903o02@0o`0302@0o`<00000
101^0?l200000080O@3o0P0000020;D0o`03000000370?l0a`3o0080a`3o
0P0000020=`0o`8000000P3o0?D00`000000o`3O0?l0g`030?l0g`@00000
0`3o0:P2000000<0o`2@0P0000020?l0O0800000103o06H4000000<0o`16
0P0000020?l0?P8000000`3o02d200000080o`0X0P0000030?l060800000
0`3o01H4000000D0o`060`0000170?ooo`00O03oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02h0oooo0P000005003Uo`<000001000
[_l00`0000000:co002/o`0200000003001do`000000073o00D0073o0P00
0004000ao`8000000P00:_l2000000030100o`0000006P3o00@06P3o00<0
000002@0o`0T0?l00P00000205l0o`030000001^0?l0KP3o00<0KP3o0`00
00050;D0o`04000000370?l0a`3o0<L0o`@000001@3o0?D00`000000o`3O
0?l0g`0200000080o`2n00<000000?l0Z03o0:P0103o0:P3000000D0o`1l
1@0000040?l0FP<000001P3o03h3000000D0o`0X100000030?l05P<00000
0`3o01@6000004T0oooo001l0?ooo`030000003oool0oooo00D0oooo0P00
000b0?ooo`0300000000iOl00>Go00<00>Go00<00000002ao`0000001@00
[_l2000000@007Co0P000002001`o`80000000<003So00000000<Ol01@00
<Ol2000000@0403o0P00000301X0o`<000001@1O0?l00`000000KP3o06h0
o`0200000080X`3o00<000000;D0o`2e0?l00`2e0?l4000000<0m@3o0P00
00030?l0m@@000001@3o0;h200000080o`2X0P0000020?l0T@8000000P3o
07`200000080o`1]0P0000030?l0FP8000000P3o0502000000<0o`0n0P00
00030?l0>0D00000103o02D3000000<0o`0D0`0000020?ooo`800000B`3o
ool007`0oooo00<000000?ooo`3oool00`3oool2000003D0oooo0P000000
0`00iOl0000000000003002ao`0300000000[_l00:ko0080000000<007Wo
00000000M?l01@00M?l2000000@003So0P000002000ao`80000000<01P3o
0000000@0?l0100@0?l400000080DP3o00<0000005l0o`1O0?l0101O0?l2
000000D0X`3o00<000000;D0o`2e0?l00P0000020>80o`030000003e0?l0
m@3o00@0m@3o0`0000030?l0dP800000103o0;h4000000@0o`2A10000006
0?l0K@<000001P3o0503000000<0o`0h0P0000020?l0<`8000000`3o02D2
000000<0o`0R0`0000020?ooo`<00000C@3oool007`0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0g0?ooo`0300000000/Ol00;7o
00@00;7o0P000004001io`8000000P00M?l200000003000no`00000003So
00@003So0`00000400H0o`030000000@0?l0403o008000000P160?l00`00
0000DP3o0580o`020580o`8000000P1O0?l20000000309<0o`000000X`3o
00D0X`3o0P0000050>80o`8000000P3e0?l2000000030?l0iP000000o`3B
00D0o`3B100000040?l0Y@@000000`3o07l2000000<0o`1]0P0000020?l0
H@8000000P3o0503000000<0o`180`0000060?l0<`<000000`3o02820000
00<0oooo0P00001@0?ooo`00O03oool00`000000oooo0?ooo`02000003/0
oooo0P000002002ao`80000000<007go00000000NOl01@00NOl2000000@0
03ko00<00000000ho`00>?l00P0000020002o`03000000060?l01P3o00<0
1P3o0P00000504H0o`040000001B0?l0DP3o0580o`@00000102C0?l20000
0080X`3o0P0000000`3@0?l000000>80o`050>80o`<00000103o0>H20000
0080o`3B0P0000020?l0^08000000P3o0:D200000080o`2B0P0000040?l0
O`@00000103o0644000000@0o`180P0000020?l0@P8000000P3o03<30000
00<0o`0_0`0000020?ooo`<00000DP3oool007`0oooo0`00000o0?ooo`80
00001000OOl20000008007Wo0P0000000`00A?l00000000no`04000no`80
00001@000_l00`0000001P3o00H0o`020000000303/0o`000000AP3o00D0
AP3o0`00000308D0o`8000000`2C0?l4000000@0d03o0P0000020>80o`80
00000P3o0?T2000000<0o`3V100000050?l0^0<000001P3o0984000000@0
o`1b100000040?l0F0@000001@3o0483000000@0o`0_0P0000030?ooo`80
0000E@3oool007`0oooo0P0000110?ooo`0300000000OOl007go00@007go
0P0000040014o`0300000000?_l003ko0080000000<000[o000000000_l0
1@000_l2000000@0>`3o0P00000204H0o`80000000<0M`3o000000250?l0
1@250?l3000000<0_`3o0P0000030=00o`@000001@3o0?T4000000<0o`3:
0P0000020?l0^08000000P3o0:<2000000<0o`2B0P0000020?l0P`800000
0P3o078200000080o`1W0P0000030?l0F08000000P3o050200000080o`12
0P0000030?l0?0@000000`3oool2000005L0oooo001n0?ooo`<00000?`3o
ool20000008007go0P0000000`00B_l000000014o`040014o`8000001000
2_l20000008000;o0P0000000`0`0?l0000003/0o`0503/0o`800000101g
0?l200000080Q@3o0P0000000`2`0?l000000;l0o`050;l0o`<000000`3e
0?l200000080o`3i0P0000020?l0g0800000103o0<X3000000H0o`2S0`00
00050?l0P`<000001P3o06L3000000@0o`1@100000030?l0?0<000000`3o
ool3000005T0oooo00210?ooo`@00000?@3oool2000000@004[o00<00000
0014o`00A?l00P0000000`004_l00000000:o`05000:o`800000100`0?l2
00000080>`3o0P0000000`1Z0?l0000007L0o`0407L0o`<00000102`0?l2
00000080_`3o0P0000000`3T0?l000000?D0o`050?D0o`8000001P3o0=`4
00000080o`2d0P0000030?l0X`8000000P3o09<200000080o`230P000002
0?l0M`8000000`3o06L2000000<0o`1N100000040?l0BP<00000103oool2
000005`0oooo00250?ooo`<00000>`3oool00`00000004[o001:o`03001:
o`80000010004_l20000008000[o0P0000000`0V0?l000000300o`040300
o`<00000101Z0?l00`000000M`3o07L0o`0200000080X@3o00<000000;00
o`2`0?l00`2`0?l3000000@0i03o0P0000020?D0o`80000000<0o`3]0000
000000000`3o0=`200000080o`350P0000030?l0]0@00000103o09<40000
00D0o`1g100000030?l0GP8000000P3o05L200000080o`1:0P0000050?oo
o`800000GP3oool008P0oooo0`00000i0?ooo`0300000000B_l004[o0080
000000<001[o000000004_l01@004_l2000000@09P3o00<000000300o`0`
0?l00P00000205h0o`030000001Z0?l0JP3o00<0JP3o0P0000050:40o`03
0000002`0?l0/03o008000000P3D0?l2000000<0i03o100000050?l0k@<0
00001@3o0<D4000000@0o`2S100000040?l0Q@D00000103o06d3000000D0
o`1G0`0000040?ooo`<00000H03oool008/0oooo0`00000g0?ooo`800000
10006_l20000008001;o0P0000000`0L0?l000000000000302H0o`<00000
1@1N0?l00`000000JP3o06X0o`020000000309@0o`000000000000@0X@3o
0`0000060=@0o`<000000`3o0?d200000080o`3]0P0000020?l0e0800000
0P3o0<D200000080o`2b0P0000020?l0X`8000000P3o09@2000000<0o`25
0P0000020?l0NP8000000P3o06d200000080o`1T0P0000020?l0E`800000
1@3oool2000006<0oooo002>0?ooo`@00000=03oool2000000@001[o0`00
000501`0o`<000000P1B0?l2000000@0GP3o0`00000509@0o`@000000P36
0?l2000000<0e03o0P0000000`3c0?l00000000000040?l0o@<000001P3o
0=@2000000H0o`2b0P0000060?l0U0<000001@3o07X3000000@0o`1T1000
00050?ooo`800000I@3oool00980oooo0`00000c0?ooo`@000000P0C0?l2
00000080703o0P0000000`180?l000000580o`040580o`@000000P270?l2
000000<0U03o0P0000000`2h0?l000000<H0o`040<H0o`<000001@3c0?l4
00000080o`3T0P0000030?l0e080000000<0o`310000000000000`3o0;82
000000030?l0XP000000000000<0o`2D0P0000020?l0R08000000P3o07X2
000000<0o`1a100000060?ooo`<00000I`3oool009D0oooo0`00000b0?oo
o`030000000C0?l04`3o00<04`3o0P00000404P0o`8000000P1B0?l20000
000307X0o`000000Q`3o00@0Q`3o0`0000040;P0o`03000000360?l0aP3o
008000000P3T0?l200000080l`3o0P0000020?l0lP8000000`3o0>@40000
00@0o`31100000040?l0XP@00000103o08P4000000<0o`1a0P0000080?oo
o`800000JP3oool009P0oooo0`00000`0?ooo`030000000C0?l04`3o0080
000000<0?@3o000000180?l010180?l3000000@0NP3o00<0000008L0o`27
0?l00P0000020:/0o`8000000`2h0?l3000000H0i03o0P0000060?l0lP<0
0000103o0<l4000000@0o`2`100000040?l0U@@00000103o07h3000000L0
oooo0`00001/0?ooo`00V`3oool3000002h0oooo0P00000403d0o`030000
00180?l0B03o008000000P1_0?l2000000<0NP3o0`0000060:/0o`<00000
0P3G0?l2000000<0i03o0P0000000`3n0?l00000000000030?l0lP800000
00<0o`3M0000000000000P3o0<l200000080o`2n0P0000020?l0/0800000
0P3o0:8200000080o`2E0P0000020?l0RP8000000P3o07h2000000P0oooo
0P00001_0?ooo`00WP3oool4000002/0oooo0P00000303d0o`<000001P1_
0?l300000080WP3o0P0000030:/0o`80000000<0b@3o0000000000000`3G
0?l4000000@0oP3o100000050?l0g@8000001P3o0;h2000000H0o`2R0P00
00050?l0RP<00000203oool200000740oooo002R0?ooo`<00000:P3oool3
00000080I03o0P00000306l0o`80000000<0TP3o0000000000000`2N0?l4
000000D0b@3o0`0000040?40o`@000000`3o0>/200000080o`3M0P000000
0`3o0</00000000000030?l0_P80000000<0o`2_0000000000000`3o0:82
00000080o`2F1@0000080?ooo`<00000L`3oool00:D0oooo0`00000X0?oo
o`030000001T0?l0I03o00<0I03o0`0000050980o`<000000`2m0?l20000
0080b@3o0P0000000`3T0?l00000000000030?40o`80000000<0o`3h0000
000000000`3o0>/4000000@0o`3;100000040?l0[`@000000`3o09H20000
00X0oooo0P00001f0?ooo`00Z03oool3000002H0oooo0P00000206@0o`80
000000<0QP3o0000000000000P2B0?l2000000030;40o`000000000000@0
_@3o0`0000050>@0o`<000001@3o0?P3000000@0o`3H100000040?l0^`@0
0000103o0:83000000X0oooo0P00001h0?ooo`00Z`3oool4000002@0oooo
0P00000508H0o`8000001@2a0?l400000080f03o0P0000020>@0o`800000
0P3k0?l200000080o`3h0P0000000`3o0>@00000000000030?l0f0800000
00<0o`380000000000000`3o0;/2000000030?l0[P00000000000080o`2R
0P00000:0?ooo`<00000NP3oool00:l0oooo0`00000R0?ooo`8000000P26
0?l2000000030:D0o`000000000000<0/@3o0P0000000`3<0?l000000000
00030=P0o`<000001@3k0?l3000000D0o`3T0`0000050?l0b0<00000103o
0:h3000000X0oooo0P00001m0?ooo`00/P3oool300000240oooo0P000005
0:D0o`<000001@3<0?l3000000<0k`3o1@0000020?l0l08000000P3o0>@2
00000080o`3C0P0000020?l0b08000000`3o0;X4000000/0oooo0P00001o
0?ooo`00]@3oool3000001l0oooo0P0000030:D0o`80000000<0`03o0000
000000000P3<0?l2000000030><0o`00000000000080k`3o0P0000020?l0
o08000000`3o0?03000000D0o`3C0`0000030?l0^P800000303oool30000
0840oooo002h0?ooo`@000007@3oool3000000@0`03o0`0000050><0o`80
00001P3o0?`3000000<0o`3O1@0000030?l0a@<00000303oool2000008@0
oooo002l0?ooo`<000007@3oool400000080f03o0P0000020><0o`800000
00<0n03o0000000000000`3o0?`2000000030?l0j`00000000000080o`3O
0P0000020?l0d08000000P3o0<D2000000/0oooo0`0000260?ooo`00_`3o
ool3000001`0oooo0P0000030=P0o`<000001@3h0?l3000000@0o`3[0`00
00050?l0d0<000002`3oool2000008T0oooo00320?ooo`<000006`3oool3
000000<0k@3o1@0000030?l0m@@000000`3o0=/5000000`0oooo0P00002;
0?ooo`00a@3oool4000001P0oooo0P0000020>d0o`8000000P3o0?l20000
0080o`3e0P0000000`3o0>D00000000000020?l0f`8000003@3oool30000
08d0oooo00390?ooo`<000005`3oool2000000D0o`3o0`0000040?l0i@<0
00003@3oool200000900oooo003<0?ooo`<000005P3oool5000000<0o`3`
1000000>0?ooo`800000TP3oool00<l0oooo0`00000F0?ooo`8000000P3o
0?02000000h0oooo0`00002D0?ooo`00dP3oool3000001D0oooo0P00000>
0?ooo`800000U`3oool00=D0oooo1000000A0?ooo`030000003oool0oooo
00/0oooo0P00002I0?ooo`00f@3oool3000000h0oooo00<000000?ooo`3o
ool0203oool3000009/0oooo003L0?ooo`<000002`3oool00`000000oooo
0?ooo`060?ooo`800000WP3oool00=l0oooo0`0000080?ooo`030000003o
ool0oooo00<0oooo0`00002P0?ooo`00hP3oool4000000@0oooo00@00000
0?ooo`3oool0oooo0P00002S0?ooo`00iP3oool3000000030?ooo`000000
oooo00800000Y@3oool00>T0oooo0`00002W0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD
0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3o
oonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD
0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 208},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(z = \(y = \(x = 0\)\); \ Remove[x, y, z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[\[Phi]];\)\ \), "\n", 
    \(\(U[t_]\  = \ t\^3;\)\ \), "\[IndentingNewLine]", 
    \(\(g[t_] = 
        y\/\[Pi]\ \(\[Integral]\(U[t]\/\(\((x - t)\)\^2 + 
                    y\^2\)\) \[DifferentialD]t\);\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ Expand[g[1] - g[\(-1\)]];\)\ \), "\n", 
    \(\(v[x_, y_]\  = \ 
        ReplaceAll[\[Phi][x, y], 
          ArcTan[z_] \[Rule] \(-ArcTan[1\/z]\)];\)\ \), "\n", 
    \(\(V[x_, y_]\  = \ 
        1\  - \ \(1\/\[Pi]\) ArcTan[x + 1, y]\  - \(1\/\[Pi]\) 
            ArcTan[x - 1, y];\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ \[Phi][x, y]\  + \ V[x, y];\)\ \), "\n", 
    \(\(v[x_, y_]\  = \ v[x, y]\  + \ V[x, y];\)\ \), "\n", 
    \(\(Print["\<  U[t]  =  -1  for  t \[LessEqual] -1\>"];\)\ \ \ \ \), "\n\
", 
    \(\(Print["\<  U[t]  =  \>", 
        U[t], "\<  for  -1 \[LessEqual] t \[LessEqual] 1\>"];\)\ \ \ \), "\n\
", 
    \(\(Print["\<  U[t]  =  1   for   t \[GreaterEqual] 1\>"];\)\ \ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<V[x,y] = \>", V[x, y]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\[Phi][x,y] = \!\(y\/\[Pi]\) \
\!\(\[Integral]\_\(-1\)\%1\)\!\(U[t]\/\(\((x - t)\)\^2 + y\^2\)\)\
\[DifferentialD]t + V[x,y]\>\""];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, y]];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Phi][x, y], {x, \(-3\), 3}, {y, 0.000001, 3}, 
        Contours \[Rule] 10, PlotPoints \[Rule] 35, AspectRatio \[Rule] 1\/2, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Then use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[\[Phi][x, y], {x, \(-3\), 3}, {y, 10\^\(-6\), 1.5}, 
        PlotPoints \[Rule] {31, 21}, 
        PlotRange \[Rule] {{\(-3\), 3}, {0, 1.5}, {\(-1\), 1}}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<  \[Phi][x,y]\>"}, 
        ColorFunction \[Rule] Hue, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0.5, 1.5, 0.5], 
            Range[\(-1\), 1, 0.5]}, ViewPoint \[Rule] {\(-2.5\), \(-3\), 2}, 
        AxesEdge \[Rule] {{\(-1\), \(-1\)}, {\(-1\), \(-1\)}, {1, \
\(-1\)}}];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y]  =  \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Therefore, the function ",
  Cell[BoxData[
      \(\[Phi][x, y]\)]],
  " is harmonic in the upper half-plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  ",  and takes on the desired boundary values. "
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Dirichlet Problem",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/DirichletProblemBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Neumann Problem",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/NeumannProblemBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Poisson Integral",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/PoissonIntegralBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{976, 644},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[4945, 157, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 367654, 6746}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 149, 3, 33, "Text"],
Cell[2254, 67, 816, 25, 71, "Text"],
Cell[3073, 94, 1521, 47, 193, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4619, 145, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[4767, 151, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[4945, 157, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[5305, 169, 3117, 88, 85, "Text",
  Evaluatable->False],
Cell[8425, 259, 57461, 945, 222, 57347, 941, "GraphicsData", "Bitmap", "Text",
  
  Evaluatable->False],
Cell[65889, 1206, 1023, 24, 227, "Text"],

Cell[CellGroupData[{
Cell[66937, 1234, 113, 2, 33, "Text"],
Cell[67053, 1238, 244, 7, 71, "Text"],
Cell[67300, 1247, 1103, 24, 336, "Input"],
Cell[68406, 1273, 466, 12, 56, "Text",
  Evaluatable->False],
Cell[68875, 1287, 843, 13, 207, "Input"],
Cell[69721, 1302, 134, 5, 33, "Text"],
Cell[69858, 1309, 713, 13, 217, "Input"],
Cell[70574, 1324, 134, 5, 33, "Text"],
Cell[70711, 1331, 660, 13, 130, "Input"],
Cell[71374, 1346, 329, 10, 38, "Text"]
}, Closed]],
Cell[71718, 1359, 3143, 88, 85, "Text",
  Evaluatable->False],
Cell[74864, 1449, 62341, 1025, 222, 62227, 1021, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[137230, 2478, 115, 2, 33, "Text"],
Cell[137348, 2482, 155, 5, 33, "Text"],
Cell[137506, 2489, 1140, 24, 279, "Input"],
Cell[138649, 2515, 123, 2, 33, "Text",
  Evaluatable->False],
Cell[138775, 2519, 843, 13, 207, "Input"],
Cell[139621, 2534, 134, 5, 33, "Text"],
Cell[139758, 2541, 713, 13, 217, "Input"],
Cell[140474, 2556, 134, 5, 33, "Text"],
Cell[140611, 2563, 660, 13, 130, "Input"],
Cell[141274, 2578, 233, 8, 33, "Text"]
}, Closed]],
Cell[141522, 2589, 3074, 88, 85, "Text",
  Evaluatable->False],
Cell[144599, 2679, 59661, 981, 222, 59547, 977, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[204263, 3662, 2252, 51, 418, "Text"],
Cell[206518, 3715, 4955, 119, 43, "Text"],

Cell[CellGroupData[{
Cell[211498, 3838, 113, 2, 33, "Text"],
Cell[211614, 3842, 155, 5, 33, "Text"],
Cell[211772, 3849, 995, 20, 336, "Input"],
Cell[212770, 3871, 788, 19, 81, "Text",
  Evaluatable->False],
Cell[213561, 3892, 1420, 23, 328, "Input"],
Cell[214984, 3917, 134, 5, 33, "Text"],
Cell[215121, 3924, 466, 8, 124, "Input"],
Cell[215590, 3934, 134, 5, 33, "Text"],
Cell[215727, 3941, 780, 14, 152, "Input"],
Cell[216510, 3957, 475, 12, 59, "Text"]
}, Closed]],
Cell[217000, 3972, 4813, 135, 104, "Text",
  Evaluatable->False],
Cell[221816, 4109, 64029, 1053, 222, 63915, 1049, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[285848, 5164, 4799, 126, 290, "Text"],
Cell[290650, 5292, 393, 14, 33, "Text"],

Cell[CellGroupData[{
Cell[291068, 5310, 113, 2, 33, "Text"],
Cell[291184, 5314, 1225, 32, 248, "Text",
  Evaluatable->False],
Cell[292412, 5348, 1401, 28, 450, "Input"],
Cell[293816, 5378, 134, 5, 33, "Text"],
Cell[293953, 5385, 779, 14, 163, "Input"],
Cell[294735, 5401, 134, 5, 33, "Text"],
Cell[294872, 5408, 733, 14, 132, "Input"],
Cell[295608, 5424, 664, 15, 131, "Text"]
}, Closed]],
Cell[296287, 5442, 5158, 145, 104, "Text",
  Evaluatable->False],
Cell[301448, 5589, 60181, 989, 222, 60067, 985, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[361654, 6582, 115, 2, 33, "Text"],
Cell[361772, 6586, 1646, 34, 490, "Input"],
Cell[363421, 6622, 134, 5, 33, "Text"],
Cell[363558, 6629, 466, 8, 124, "Input"],
Cell[364027, 6639, 134, 5, 33, "Text"],
Cell[364164, 6646, 739, 14, 132, "Input"],
Cell[364906, 6662, 232, 8, 33, "Text"]
}, Closed]],
Cell[365153, 6673, 290, 7, 30, "Text"],
Cell[365446, 6682, 291, 7, 33, "Text"],
Cell[365740, 6691, 287, 7, 33, "Text"],
Cell[366030, 6700, 289, 7, 33, "Text"],
Cell[366322, 6709, 257, 5, 33, "Text"],
Cell[366582, 6716, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

