(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    380678,       7862]*)
(*NotebookOutlinePosition[    381780,       7901]*)
(*  CellTagsIndexPosition[    381703,       7895]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["11.4  Two-Dimensional Mathematical Models",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tWe now consider problems involving steady state heat flow, \
electrostatics, and ideal fluid flow that can be solved with conformal \
mapping techniques.  Conformal mapping transforms a region in which the \
problem is posed to one in which the solution is easy to obtain.  As our \
solutions involve only two independent variables, ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["y",
    FontFamily->"Courier New"],
  ", we first mention a basic assumption needed for the validity of the \
model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tThe physical problems we just mentioned are real-world applications and \
involve solutions in three-dimensional Cartesian space.  Such problems \
generally would involve the Laplacian in three variables and the divergence \
and curl of three-dimensional vector functions.  Since complex analysis \
involves only ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["y",
    FontFamily->"Courier New"],
  ", we consider the special case in which the solution does not vary with \
the coordinate along the axis perpendicular to the ",
  StyleBox["xy",
    FontFamily->"Courier New"],
  " plane.  For steady state heat flow and electrostatics, this assumption \
means that the temperature, ",
  StyleBox["T",
    FontFamily->"Courier New"],
  ", or the potential, ",
  StyleBox["V",
    FontFamily->"Courier New"],
  ", varies only with ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ", and ",
  StyleBox["y",
    FontFamily->"Courier New"],
  ".  Thus for the flow of ideal fluids, the fluid motion is the same in any \
plane that is parallel to the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane.  Curves drawn in the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane are to be interpreted as cross sections that correspond to infinite \
cylinders perpendicular to the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane.  An infinite cylinder is the limiting case of a \"long\" physical \
cylinder, so the mathematical model that we present is valid provided the \
three-dimensional problem involves a physical cylinder long enough that the \
effects at the ends can be reasonably neglected."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tIn Section 11.1 and Section 11.2 we learned how to obtain solutions  ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  for harmonic functions.  For applications it is important to consider \
the family of level curves  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
          RowBox[{
            StyleBox[\(K\_1\),
              FontSize->14], ":", "  ", 
            RowBox[{
              StyleBox[\(K\_1\),
                FontSize->14], "  ", 
              StyleBox["is",
                FontFamily->"Times New Roman"], 
              StyleBox[" ",
                FontFamily->"Times New Roman"], 
              StyleBox["a",
                FontFamily->"Times New Roman"], 
              StyleBox[" ",
                FontFamily->"Times New Roman"], 
              StyleBox["real",
                FontFamily->"Times New Roman"], 
              StyleBox[" ",
                FontFamily->"Times New Roman"], 
              StyleBox["constant",
                FontFamily->"Times New Roman"]}]}]}], "}"}]]],
  "  and the conjugate harmonic function  ",
  Cell[BoxData[
      RowBox[{"\[Psi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  and its family of level curves  ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Psi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
          RowBox[{
            StyleBox[\(K\_2\),
              FontSize->14], ":", "  ", 
            RowBox[{
              StyleBox[\(K\_2\),
                FontSize->14], "  ", 
              StyleBox["is",
                FontFamily->"Times New Roman"], 
              StyleBox[" ",
                FontFamily->"Times New Roman"], 
              StyleBox["a",
                FontFamily->"Times New Roman"], 
              StyleBox[" ",
                FontFamily->"Times New Roman"], 
              StyleBox["real",
                FontFamily->"Times New Roman"], 
              StyleBox[" ",
                FontFamily->"Times New Roman"], 
              StyleBox["constant",
                FontFamily->"Times New Roman"]}]}]}], "}"}]]],
  ".  It is convenient to introduce the terminology complex potential for the \
analytic function   ",
  Cell[BoxData[
      RowBox[{\(F \((z)\)\), " ", "=", " ", 
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "+", " ", 
          RowBox[{"\[ImaginaryI]", " ", "\[CurlyPhi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  ".  The following result regarding the orthogonality of the above mentioned \
families of level curves will be use in developing the ideas concerning the \
physical applications."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tIn Sections 11.1 and 11.2, we showed how to obtain solutions ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " for harmonic functions.  For applications, we need to consider the family \
of level curves  \n\n",
  StyleBox["(10-16)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
          RowBox[{
            StyleBox[\(K\_1\),
              FontSize->14], ":", "  ", 
            RowBox[{
              StyleBox[\(K\_1\),
                FontSize->14], "  ", 
              StyleBox["is",
                FontFamily->"Times New Roman"], 
              StyleBox[" ",
                FontFamily->"Times New Roman"], 
              StyleBox["a",
                FontFamily->"Times New Roman"], 
              StyleBox[" ",
                FontFamily->"Times New Roman"], 
              StyleBox["real",
                FontFamily->"Times New Roman"], 
              StyleBox[" ",
                FontFamily->"Times New Roman"], 
              StyleBox["constant",
                FontFamily->"Times New Roman"]}]}]}], "}"}]]],
  " \n\nand the conjugate harmonic function  ",
  Cell[BoxData[
      RowBox[{"\[Psi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  and its family of level curves  \n\n",
  StyleBox["(10-17)\t\t",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Psi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
          RowBox[{
            StyleBox[\(K\_2\),
              FontSize->14], ":", "  ", 
            RowBox[{
              StyleBox[\(K\_2\),
                FontSize->14], "  ", 
              StyleBox["is",
                FontFamily->"Times New Roman"], 
              StyleBox[" ",
                FontFamily->"Times New Roman"], 
              StyleBox["a",
                FontFamily->"Times New Roman"], 
              StyleBox[" ",
                FontFamily->"Times New Roman"], 
              StyleBox["real",
                FontFamily->"Times New Roman"], 
              StyleBox[" ",
                FontFamily->"Times New Roman"], 
              StyleBox["constant",
                FontFamily->"Times New Roman"]}]}]}], "}"}]]],
  " \n\nFor convenience, we introduce the term complex potential for the \
analytic function  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(F \((z)\)\), "  ", "=", "  ", 
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "+", "  ", 
          RowBox[{"\[ImaginaryI]", " ", "\[Psi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  ".\n\nWe use Theorem 11.4, regarding the orthogonality of the families of \
level curves ",
  StyleBox["(10-16)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(10-17)",
    FontColor->RGBColor[0, 0, 1]],
  ", to develop ideas concerning the physical applications that we will \
consider.\n"
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 11.4 (Orthogonal Families of Level Curves).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " be harmonic in a domain D.  Let ",
  Cell[BoxData[
      RowBox[{"\[Psi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " be the harmonic conjugate and let   ",
  Cell[BoxData[
      RowBox[{\(F \((z)\)\), " ", "=", " ", 
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "+", " ", 
          RowBox[{"\[ImaginaryI]", " ", "\[Psi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  "  be the complex potential.  Then the two families of level curves given \
in Equations  ",
  StyleBox["(10-16)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(10-17)",
    FontColor->RGBColor[0, 0, 1]],
  ", respectively, are orthogonal in the sense that if ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"a", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "b"}], ")"}]]],
  " is a point in common to the two curves  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Phi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        StyleBox[\(K\_1\),
          FontSize->14]}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        StyleBox[\(K\_2\),
          FontSize->14]}]]],
  ",  and  if   ",
  Cell[BoxData[
      \(\(\(F' \((a + \[ImaginaryI]\ b)\)\)\(\ \)\(\[NotEqual]\)\(\ \)\(0\)\(\
\ \)\)\)]],
  " ,  then these two curves intersect orthogonally."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 11.4 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration for Theorem 11.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  FontColor->RGBColor[0, 1, 1]],

Cell[TextData[{
  "Use the Cauchy Riemann equations  ",
  Cell[BoxData[
      \(\[PartialD]\_x\ u \((x, y)\) = \[PartialD]\_y\ v \((x, y)\)\)]],
  "  and ",
  Cell[BoxData[
      \(\[PartialD]\_y\ u \((x, y)\) = \(-\[PartialD]\_x\ v\) \((x, y)\)\)]],
  ",  which are implemented by using the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  substitutions:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(the\ Cauchy\ Riemann\ equations\)], "Input"],

Cell[BoxData[{
    \(\(Clear[x, y, u, v, CR];\)\ \), "\n", 
    \(\(CR\  = \ {\[PartialD]\_y\ v[x, y] \[Rule] \[PartialD]\_x\ 
              u[x, y], \[PartialD]\_y\ 
              u[x, y] \[Rule] \ \(-\[PartialD]\_x\ 
                v[x, y]\)};\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Using Mathematica's notation\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(u\_x\)(x,y) = \>\"", \[PartialD]\_x\ 
          u[x, y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(u\_y\)(x,y) = \>\"", \[PartialD]\_y\ 
          u[x, y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(v\_x\)(x,y) = \>\"", \[PartialD]\_x\ 
          v[x, y]];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(y\_y\)(x,y) = \>\"", \[PartialD]\_y\ 
          v[x, y]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The Cauchy Riemann equations are\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(\[PartialD]\_x\) u[x,y] =  \!\(\[PartialD]\_y\) \
v[x,y]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(\[PartialD]\_y\) u[x,y] = -\!\(\[PartialD]\_x\) \
v[x,y]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<We will use the replacements\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\ TableForm[CR]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The normal vectors to the curves  ",
  Cell[BoxData[
      \(u \((x, y)\) = \(K\_1\ \ and\ \ v \((x, y)\) = K\_2\)\)]],
  "  are "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(\(\(N\_1\)\& \[RightVector] \)\  = \ {\[PartialD]\_x\ 
            u[x, y], \[PartialD]\_y\ u[x, y]};\)\ \), "\n", 
    \(\(\(\(N\_2\)\& \[RightVector] \)\  = \ {\[PartialD]\_x\ 
            v[x, y], \[PartialD]\_y\ v[x, y]};\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\(\(N\_1\)\& \[RightVector] \)\)  =  \
{\!\(u\_x\)(x,y), \!\(u\_y\)(x,y)}  =  \>\"", \(\(N\_1\)\& \[RightVector] \)\ \
];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\(\(N\_2\)\& \[RightVector] \)\)  =  \
{\!\(v\_x\)(x,y), \!\(v\_y\)(x,y)}  =  \>\"", \(\(N\_2\)\& \[RightVector] \
\)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We will show that  ",
  Cell[BoxData[
      StyleBox[\(\(N\_1\)\& \[RightVector] \),
        FontSize->14]]],
  StyleBox[" ",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  " is orthogonal to  ",
  Cell[BoxData[
      StyleBox[\(\(N\_2\)\& \[RightVector] \),
        FontSize->14]]],
  "  by forming the dot product: "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(\(\(N\_1\)\& \[RightVector] \)\).\!\(\(\(N\_2\)\& \
\[RightVector] \)\) = \>\"", \(\(N\_1\)\& \[RightVector] \), "\<.\>", \
\(\(N\_2\)\& \[RightVector] \)];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\(\(N\_1\)\& \[RightVector] \)\).\!\(\(\(N\_2\)\& \
\[RightVector] \)\) = \>\"", \(\(N\_1\)\& \[RightVector] \) . \(\(N\_2\)\& \
\[RightVector] \)];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Using the Cauchy Riemann equations, this is simplified and we obtain: \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{\(Print[\*"\"\<\!\(\(N\_1\)\&\[RightVector]\).\!\(\(N\_2\)\&\
\[RightVector]\) = \>\"", \(N\_1\)\&\[RightVector] . \
\(N\_2\)\&\[RightVector]];\), "\[IndentingNewLine]", \(Print["\<Use the \
replacements\>"];\), "\[IndentingNewLine]", \(Print["\<       \>", 
        TableForm[CR]\ ];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"replace", " ", "=", " ", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{\(\[PartialD]\_y\ v[x, y]\), "\[Rule]", "\"\<\!\(
\*SuperscriptBox[\(u\), 
TagBox[\((1, 0)\),
Derivative],
MultilineFunction->None]\)[x,y]\>\""}], ",", 
              
              RowBox[{\(\[PartialD]\_y\ u[x, y]\), "\[Rule]", " ", 
                "\"\<(-\!\(
\*SuperscriptBox[\(v\), 
TagBox[\((1, 0)\),
Derivative],
MultilineFunction->None]\)[x,y])\>\""}]}], "}"}]}], ";"}], 
      " "}], "\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(\(N\_1\)\&\[RightVector]\).\!\(\(N\_2\)\&\
\[RightVector]\) = \>\"", 
          ReplaceAll[\(N\_1\)\&\[RightVector] . \(N\_2\)\&\[RightVector], 
            replace]];\), 
      " "}], "\[IndentingNewLine]", \(Print["\<Therefore\>"];\), "\
\[IndentingNewLine]", 
    RowBox[{\(Print[\*"\"\<\!\(\(N\_1\)\&\[RightVector]\).\!\(\(N\_2\)\&\
\[RightVector]\) = \>\"", 
          ReplaceAll[\(N\_1\)\&\[RightVector] . \(N\_2\)\&\[RightVector], 
            CR]];\), " "}]}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Therefore  ",
  Cell[BoxData[
      StyleBox[\(\(N\_1\)\& \[RightVector] \),
        FontSize->14]]],
  StyleBox[" ",
    FontVariations->{"CompatibilityType"->"Subscript"}],
  " is orthogonal to  ",
  Cell[BoxData[
      StyleBox[\(\(N\_2\)\& \[RightVector] \),
        FontSize->14]]],
  " ."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\tThe complex potential  ",
  Cell[BoxData[
      RowBox[{\(F \((z)\)\), " ", "=", " ", 
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "+", " ", 
          RowBox[{"\[ImaginaryI]", " ", "\[Psi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  "  has many physical interpretations.  Suppose, for example, that we have \
solved a problem in steady state temperatures. Then we can obtain the \
solution to a similar problem with the same boundary conditions in \
electrostatics by interpreting the isothermals as equipotential curves and \
the heat flow lines as flux lines. This implies that heat flow and \
electrostatics correspond directly."
}], "Text"],

Cell[TextData[{
  "\tOr suppose that we have solved a fluid flow problem.  Then we can obtain \
a solution to an analogous problem in heat flow by interpreting the \
equipotentials as isothermals and streamlines as heat flow lines.  Various \
interpretations of the families of level curves given in Equations  ",
  StyleBox["(10-16)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(10-17)",
    FontColor->RGBColor[0, 0, 1]],
  " and correspondences between families are summarized in Table 11.1. "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[BoxData[GridBox[{
          {GridBox[{
                {
                  RowBox[{
                    StyleBox["   ",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["Physical",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], 
                      StyleBox[" ",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Bold",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], 
                      StyleBox["Phenomenon",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], "   "}]}]},
                {" "}
                },
              RowLines->True], GridBox[{
                {
                  RowBox[{"      ", 
                    RowBox[{
                      RowBox[{"\[Phi]", 
                        RowBox[{"(", 
                          RowBox[{"x", 
                            StyleBox[",",
                              FontFamily->"Times New Roman",
                              FontSize->12,
                              FontSlant->"Plain",
                              FontColor->GrayLevel[0],
                              FontVariations->{"Underline"->False,
                              "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
                      StyleBox["constant",
                        FontSize->14], 
                      StyleBox["   ",
                        FontSize->14]}]}]},
                {" "}
                },
              RowLines->True], GridBox[{
                {
                  RowBox[{"     ", 
                    RowBox[{
                      RowBox[{"\[Psi]", 
                        RowBox[{"(", 
                          RowBox[{
                            StyleBox["x",
                              FontWeight->"Plain"], 
                            StyleBox[",",
                              FontFamily->"Times New Roman",
                              FontSize->12,
                              FontSlant->"Plain",
                              FontColor->GrayLevel[0],
                              FontVariations->{"Underline"->False,
                              "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
                      StyleBox["constant",
                        FontSize->14], 
                      StyleBox["   ",
                        FontSize->14]}]}]},
                {" "}
                },
              RowLines->True]},
          {
            RowBox[{
              StyleBox[\(Heat\ flow\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}], 
            RowBox[{
              StyleBox["Isothermals",
                FontFamily->"Times New Roman"], "\[IndentingNewLine]"}], 
            RowBox[{
              StyleBox[\(Heat\ flow\ lines\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}]},
          {
            RowBox[{
              StyleBox["Electrostatics",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}], 
            RowBox[{
              StyleBox[\(Equipotential\ curves\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}], 
            RowBox[{
              StyleBox[\(Flux\ lines\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}]},
          {
            RowBox[{
              StyleBox[\(Fluid\ flow\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}], 
            RowBox[{
              StyleBox["Equipotentials",
                FontFamily->"Times New Roman"], "\[IndentingNewLine]"}], 
            RowBox[{
              StyleBox["Streamlines",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}]},
          {
            RowBox[{
              StyleBox[\(Gravitational\ field\),
                FontFamily->"Times New Roman"], "\[IndentingNewLine]"}], 
            RowBox[{
              StyleBox[\(Gravitational\ potential\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}], 
            RowBox[{
              StyleBox[\(Lines\ of\ force\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}]},
          {
            RowBox[{
              StyleBox["Magnetism",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}], 
            RowBox[{
              StyleBox["Potential",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}], 
            RowBox[{
              StyleBox[\(Lines\ of\ force\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}]},
          {
            RowBox[{
              StyleBox["Diffusion",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}], 
            RowBox[{
              StyleBox["Concentration",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}], 
            RowBox[{
              StyleBox[\(Lines\ of\ flow\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}]},
          {
            RowBox[{
              StyleBox["Elasticity",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}], 
            RowBox[{
              StyleBox[\(Strain\ function\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}], 
            RowBox[{
              StyleBox[\(Stress\ lines\),
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[IndentingNewLine]"}]},
          {
            StyleBox[\(Current\ flow\),
              FontFamily->"Times New Roman"], 
            StyleBox["Potential",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[\(Lines\ of\ flow\),
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}
          },
        GridFrame->True,
        ColumnLines->True]]]
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t\tTable 11.1",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Interpretations for the level curves of ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\)]],
  " and ",
  Cell[BoxData[
      \(\[Psi] \((x, y)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["Preview of Applications",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe following is a sample of applications taken from Section 11-5  \
to Section11-11."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 11.16.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the temperature ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " at each point in the upper half-disk  ",
  Cell[BoxData[
      \(H : y > 0, \(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ",  if the temperature at points on the boundary satisfies \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"T", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], "=", "100"}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "   ", "x"}], 
              "+", \(\[ImaginaryI]\ y\)}], 
            "=", \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", 
          RowBox[{
            RowBox[{"0", "<", "\[Theta]", "<", 
              RowBox[{
                RowBox[{"\[Pi]", "   ", 
                  StyleBox["on",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["the",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["upper",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["semi",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}], 
                StyleBox["-",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["circle",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}], 
            StyleBox[";",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{"T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", "  ", "50"}],
         
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "-", "1"}], "<", "x", "<", 
          RowBox[{"1", "  ", 
            StyleBox["on",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["the",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[\(\(diameter\)\(.\)\),
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "    "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00R`3oool50000
03@0oooo0P0000040?ooo`800000103oool2000003<0oooo0P00000e0?oo
o`800000103oool2000000@0oooo0P00000e0?ooo`D000003`3oool008d0
oooo00<000000?ooo`3oool0<`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo00000340oooo00@000000?ooo`3oool00000<`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000003H0
oooo00<000000?ooo`3oool03`3oool008d0oooo00<000000?ooo`3oool0
<`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo02l0
oooo00@000000?ooo`3oool00000<`3oool010000000oooo0?ooo`00000;
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool03`3oool0
08D0oooo100000040?ooo`030000003oool0oooo02d0oooo100000020?oo
o`040000003oool0oooo000000T0oooo0P00000b0?ooo`040000003oool0
oooo000003<0oooo00@000000?ooo`3oool000002@3oool2000003L0oooo
00<000000?ooo`3oool03`3oool008d0oooo00<000000?ooo`3oool0<`3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0340oooo
00@000000?ooo`3oool00000<`3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool03`3oool008`0
oooo0P00000f0?ooo`8000002P3oool300000380oooo0P00000e0?ooo`80
00002P3oool3000003D0oooo0P00000A0?ooo`00o`3ooonD0?ooo`00o`3o
oonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
OP3oool200000?l0oooo503oool007d0oooo00@000000?ooo`3oool00000
103ooooo000000<00000303oool007d0oooo00@000000?ooo`3oool00000
103oool2000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`040000003oool0oooo0?ooo`800000303oool007d0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`80
00000P3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo0080
0000103oool00`000000oooo0?ooo`0:0?ooo`00O@3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0080oooo100000000`1Zo`00
00000000000200000>H0ohl0100000000`1Zo`00000000000002000000@0
oooo00<000000?ooo`3oool02P3oool007h0oooo0P0000050?ooo`030000
003oool0oooo0080oooo1P00000206[o00@00000h03oS`0400000080J_l0
1P0000040?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003o
ool0oooo0080oooo0P0000000`00G_l00000003oV`02000000D0J_l00`00
003J0?n?00<000001@1Zo`0200000003003oV`000000000000800000103o
ool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`02
0?ooo`80000000<005ko0000000000000P00oi/00`000000J_l006[o0005
06[o00<00000e03oS`03000000L0J_l000H00000003oV`00oi/00?nK0000
0000G_l2000000@0oooo00<000000?ooo`3oool02P3oool008D0oooo0P00
00030?ooo`040000002V0?l00000001No`8000000P00oi/2000000P0J_l0
1000003<0?n?00@00000201Zo`02000000800?nK0P0000001000G_l00000
0:H0o`0000030?ooo`800000303oool008D0oooo00<000000?ooo`3oool0
0P3oool00`000000YP3o00000002001No`0300000000oi/00?nK00800?nK
0P00000:06[o00@00000a03oS`04000000X0J_l00P000004003oV`060000
0000G_l005ko0000002V0?l00000103oool00`000000oooo0?ooo`0:0?oo
o`00Q@3oool00`000000oooo0?ooo`020?ooo`040000002V0?l0YP3o0000
008005ko00<00000003oV`00oi/00P00oi/2000000d0J_l01@00002j0?n?
00D000003@1Zo`02000000@00?nK00@00000001No`00G_l000000P2V0?l0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00250?oo
o`030000003oool0oooo0080oooo00@000000:H0o`2V0?l000000P00G_l2
000000D00?nK0P00000?06[o00@00000]03oS`0400000100J_l00P000004
003oV`8000000P00G_l010000000YP3o0:H0o`0000040?ooo`030000003o
ool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo00@00000
0:H0o`2V0?l000000`00G_l2000000H00?nK00<0000006[o001Zo`00401Z
o`0500000:X0ohl01@00000B06[o008000001P00oi/01@00000005ko001N
o`00G_l000000080YP3o00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`050000002V
0?l0YP3o0:H0o`0000000`00G_l2000000H00?nK0P00000D06[o00D00000
XP3oS`05000001@0J_l00P000006003oV`8000000`00G_l01@000000YP3o
0:H0o`2V0?l0000000@0oooo00<000000?ooo`3oool02P3oool008D0oooo
0P0000030?ooo`050000002V0?l0YP3o0:H0o`0000001000G_l2000000L0
0?nK0P00000G06[o00D00000V03oS`05000001L0J_l00P000007003oV`80
00001000G_l01@000000YP3o0:H0o`2V0?l0000000<0oooo0P00000<0?oo
o`00Q@3oool00`000000oooo0?ooo`020?ooo`030000002V0?l0YP3o0080
YP3o00<00000001No`00G_l00P00G_l00`0000000?nK003oV`07003oV`03
0000001Zo`00J_l001T0J_l01P00002<0?n?00H000006`1Zo`000`000000
0?nK003oV`07003oV`0300000000G_l005ko008005ko00<000000:H0o`2V
0?l00P2V0?l00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo00250?ooo`030000003oool0oooo0080oooo0P0000030:H0o`030000
0000G_l005ko00<005ko00<00000003oV`00oi/01`00oi/2000001l0J_l0
1@0000220?n?00D000007`1Zo`02000000T00?nK00<00000001No`00G_l0
0`00G_l00`000000YP3o0:H0o`020:H0o`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3o
ool00`3o000000000:H0o`030:H0o`0300000000G_l005ko00<005ko00<0
0000003oV`00oi/02000oi/00`000000J_l006[o000Q06[o00H00000MP3o
S`06000002<0J_l000<00000003oV`00oi/02000oi/00`00000005ko001N
o`04001No`050000002V0?l0YP3o0:H0o`0000001@3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`030?l00000
0000YP3o00<0YP3o00<00000001No`00G_l01000G_l00`0000000?nK003o
V`08003oV`<000009P1Zo`08000006H0ohl02000000V06[o00<000002P00
oi/2000000D005ko00<000000:H0o`2V0?l00P2V0?l00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0
oooo0080oooo00<0o`000000002V0?l00`2V0?l2000000H005ko00<00000
003oV`00oi/02P00oi/2000002`0J_l02@00001D0?n?00T00000;01Zo`02
000000`00?nK00<00000001No`00G_l01000G_l2000000@0YP3o00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?ooo`030?l000000000YP3o00@0YP3o00<00000001N
o`00G_l01@00G_l00`0000000?nK003oV`0:003oV`<00000<`1Zo`0;0000
03h0ohl02`00000c06[o00<000003000oi/00`00000005ko001No`05001N
o`030000002V0?l0YP3o00<0YP3o00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0:0?ooo`00Q@3oool2000000<0oooo00<0o`000000002V
0?l0102V0?l2000000L005ko00<00000003oV`00oi/02`00oi/3000003`0
J_l04@00000L0?n?01400000?01Zo`03000000d00?nK0P000006001No`80
00001@2V0?l00`000000oooo0?ooo`020?ooo`800000303oool008D0oooo
00<000000?ooo`3oool00P3oool00`3o000000000:H0o`050:H0o`030000
0000G_l005ko00H005ko00<00000003oV`00oi/03@00oi/2000004/0J_l0
7000001;06[o008000003`00oi/00`00000005ko001No`06001No`030000
002V0?l0YP3o00@0YP3o00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`80o`0000<0
00000:H0o`2V0?l00`2V0?l2000000P005ko00<00000003oV`00oi/03P00
oi/200000:h0J_l00`00000?003oV`0300000000G_l005ko00H005ko0P00
00060:H0o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3o
ool008D0oooo00<000000?ooo`3oool00P3oool20?l000030000002V0?l0
YP3o00@0YP3o00<00000001No`00G_l01`00G_l00`0000000?nK003oV`0?
003oV`800000ZP1Zo`02000001400?nK00<00000001No`00G_l01`00G_l0
0`000000YP3o0:H0o`040:H0o`030000003o0000oooo00@0oooo00<00000
0?ooo`3oool02P3oool00780oooo0P0000040?ooo`8000000`3oool40000
00@0oooo00<000000?ooo`3oool00P3oool20?l000030000002V0?l0YP3o
00D0YP3o00<00000001No`00G_l01`00G_l00`0000000?nK003oV`0@003o
V`<00000Y01Zo`03000001800?nK00<00000001No`00G_l01`00G_l00`00
0000YP3o0:H0o`050:H0o`030000003o0000oooo00@0oooo00<000000?oo
o`3oool02P3oool00740oooo00@000000?ooo`3oool00000203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P3o00000`00
0000YP3o0:H0o`050:H0o`0300000000G_l005ko00P005ko00<00000003o
V`00oi/04@00oi/300000:40J_l00P00000C003oV`0300000000G_l005ko
00P005ko00<000000:H0o`2V0?l01@2V0?l00`000000o`000?ooo`040?oo
o`030000003oool0oooo00X0oooo001a0?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0103oool2000000<0oooo0P3o00000`00
0000YP3o0:H0o`060:H0o`0300000000G_l005ko00P005ko0P00000C003o
V`@00000V`1Zo`03000001<00?nK0P00000:001No`030000002V0?l0YP3o
00H0YP3o00<000000?l0003oool00`3oool2000000`0oooo001a0?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`80o`0000<000000:H0o`2V0?l01P2V0?l00`00
000005ko001No`09001No`8000005@00oi/2000009P0J_l00P00000F003o
V`0300000000G_l005ko00T005ko00<000000:H0o`2V0?l01P2V0?l00`00
0000o`000?ooo`040?ooo`030000003oool0oooo00X0oooo001a0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`020?ooo`<0o`0000<000000:H0o`2V0?l01P2V0?l0
0`00000005ko001No`09001No`8000005P00oi/400000900J_l01000000F
003oV`8000002`00G_l00`000000YP3o0:H0o`060:H0o`030000003o0000
o`0000D0oooo00<000000?ooo`3oool02P3oool00780oooo0P00000:0?oo
o`8000001@3oool00`000000oooo0?ooo`020?ooo`<0o`0000<000000:H0
o`2V0?l01`2V0?l00`00000005ko001No`0:001No`0300000000oi/00?nK
01L00?nK0P00002<06[o008000006@00oi/00`00000005ko001No`0;001N
o`030000002V0?l0YP3o00H0YP3o00<000000?l0003o00001@3oool00`00
0000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`<0
o`0000<000000:H0o`2V0?l01`2V0?l00`00000005ko001No`0:001No`80
00006P00oi/3000008H0J_l00`00000J003oV`8000003000G_l00`000000
YP3o0:H0o`070:H0o`030000003o0000o`0000D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo00<000000?ooo`3oool00P3oool30?l000800000
2@2V0?l00`00000005ko001No`0;001No`8000006`00oi/300000800J_l0
0`00000K003oV`8000003@00G_l00`000000YP3o0:H0o`080:H0o`030000
003o0000o`0000D0oooo00<000000?ooo`3oool02P3oool008D0oooo0P00
00030?ooo`@0o`0000<000000:H0o`2V0?l01`2V0?l2000000h005ko00<0
0000003oV`00oi/06`00oi/3000007X0J_l00`00000M003oV`8000003@00
G_l2000000T0YP3o00@000000?l0003o0000o`00103oool2000000`0oooo
00250?ooo`030000003oool0oooo0080oooo103o00000`000000YP3o0:H0
o`080:H0o`0300000000G_l005ko00`005ko0P00000O003oV`@00000LP1Z
o`04000001l00?nK0P00000>001No`030000002V0?l0YP3o00P0YP3o00@0
00000?l0003o0000o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?ooo`@0o`0000<000000:H0o`2V0?l02@2V
0?l00`00000005ko001No`0=001No`0300000000oi/00?nK02000?nK0`00
001/06[o00<000008P00oi/00`00000005ko001No`0=001No`030000002V
0?l0YP3o00T0YP3o00@000000?l0003o0000o`001@3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`@0o`0000<0
00000:H0o`2V0?l02@2V0?l2000000l005ko0P00000S003oV`@00000I01Z
o`04000002<00?nK0P00000@001No`030000002V0?l0YP3o00T0YP3o00@0
00000?l0003o0000o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?ooo`D0o`0000<000000:H0o`2V0?l02@2V
0?l00`00000005ko001No`0>001No`8000009P00oi/4000005`0J_l01000
000V003oV`8000004000G_l00`000000YP3o0:H0o`090:H0o`030000003o
0000o`000080o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooo`D0o`0000<000000:H0o`2V0?l02P2V0?l0
0`00000005ko001No`0?001No`0300000000oi/00?nK02L00?nK1@00001B
06[o00D00000:@00oi/00`00000005ko001No`0?001No`030000002V0?l0
YP3o00X0YP3o00<000000?l0003o00000P3o00050?ooo`030000003oool0
oooo00X0oooo00250?ooo`8000000`3oool50?l000030000002V0?l0YP3o
00X0YP3o0P00000A001No`800000;000oi/5000004P0J_l01@00000/003o
V`8000004@00G_l2000000`0YP3o00<000000?l0003o00000P3o00040?oo
o`800000303oool008D0oooo00<000000?ooo`3oool00P3oool60?l00003
0000002V0?l0YP3o00X0YP3o0P00000B001No`800000;`00oi/6000003`0
J_l01P00000`003oV`0300000000G_l005ko014005ko00<000000:H0o`2V
0?l02`2V0?l00`000000o`000?l000020?l000D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo00<000000?ooo`3oool00P3oool60?l000030000
002V0?l0YP3o00/0YP3o00<00000001No`00G_l04@00G_l2000003@00?nK
2@00000Z06[o00T00000=000oi/2000001<005ko00<000000:H0o`2V0?l0
2`2V0?l00`000000o`000?l000030?l000D0oooo00<000000?ooo`3oool0
2P3oool008D0oooo00<000000?ooo`3oool00P3oool60?l000030000002V
0?l0YP3o00`0YP3o00<00000001No`00G_l04P00G_l2000003/00?nK3`00
000<06[o00l00000>`00oi/2000001@005ko0P00000=0:H0o`030000003o
0000o`0000<0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooo`L0o`0000<000000:H0o`2V0?l0302V0?l0
0`00000005ko001No`0B001No`<00000B000oi/<000004T00?nK0P00000E
001No`030000002V0?l0YP3o00/0YP3o00<000000?l0003o0000103o0005
0?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo
0080oooo1`3o00000`000000YP3o0:H0o`0<0:H0o`8000005@00G_l20000
09X00?nK0P00000F001No`030000002V0?l0YP3o00`0YP3o00<000000?l0
003o0000103o00050?ooo`030000003oool0oooo00X0oooo00250?ooo`03
0000003oool0oooo0080oooo1`3o00000`000000YP3o0:H0o`0=0:H0o`80
00005P00G_l2000009H00?nK0P00000G001No`030000002V0?l0YP3o00d0
YP3o00<000000?l0003o0000103o00050?ooo`030000003oool0oooo00X0
oooo00250?ooo`8000000`3oool80?l000030000002V0?l0YP3o00d0YP3o
00<00000001No`00G_l05@00G_l3000009<00?nK0P00000G001No`030000
002V0?l0YP3o00d0YP3o00<000000?l0003o00001@3o00040?ooo`800000
303oool008D0oooo00<000000?ooo`3oool00P3oool80?l000030000002V
0?l0YP3o00h0YP3o00<00000001No`00G_l05P00G_l2000009000?nK0P00
000H001No`8000003`2V0?l00`000000o`000?l000050?l000D0oooo00<0
00000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3oool8
0?l000030000002V0?l0YP3o00l0YP3o00<00000001No`00G_l05`00G_l2
000008`00?nK0P00000I001No`030000002V0?l0YP3o00l0YP3o00<00000
0?l0003o00001@3o00050?ooo`030000003oool0oooo00X0oooo00250?oo
o`030000003oool0oooo0080oooo2@3o00000`000000YP3o0:H0o`0>0:H0
o`8000006P00G_l2000008P00?nK0P00000J001No`800000402V0?l00`00
0000o`000?l000060?l000D0oooo00<000000?ooo`3oool02P3oool00780
oooo0P0000040?ooo`8000001@3oool3000000<0oooo00<000000?ooo`3o
ool00P3oool90?l000030000002V0?l0YP3o00l0YP3o0P00000K001No`80
0000Q000oi/2000001/005ko0P00000A0:H0o`030000003o0000o`0000H0
o`001@3oool00`000000oooo0?ooo`0:0?ooo`00L@3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool:0?l000030000002V0?l0YP3o00l0YP3o00<00000001No`00
G_l06`00G_l2000008000?nK0P00000M001No`030000002V0?l0YP3o00l0
YP3o0P0000080?l000D0oooo00<000000?ooo`3oool02P3oool00740oooo
00@000000?ooo`3oool00000203oool5000000<0oooo0P0000030?ooo`X0
o`0000<000000:H0o`2V0?l0402V0?l2000001d005ko0P00001l003oV`80
00007@00G_l200000180YP3o00<000000?l0003o00001`3o00040?ooo`80
0000303oool00740oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo2`3o00000`00
0000YP3o0:H0o`0@0:H0o`0300000000G_l005ko01d005ko0P00001h003o
V`8000007`00G_l00`000000YP3o0:H0o`0A0:H0o`030000003o0000o`00
00L0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00L@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool00P3oool;0?l000030000002V0?l0YP3o0140YP3o00<00000001N
o`00G_l07P00G_l3000007800?nK0`00000P001No`030000002V0?l0YP3o
0140YP3o00<000000?l0003o0000203o00050?ooo`030000003oool0oooo
00X0oooo001b0?ooo`8000002`3oool2000000@0oooo00<000000?ooo`3o
ool00P3oool;0?l0008000004`2V0?l20000024005ko0`00001/003oV`<0
00008@00G_l2000001<0YP3o0P00000:0?l000D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo00<000000?ooo`3oool00P3oool<0?l000030000
002V0?l0YP3o0180YP3o00<00000001No`00G_l08@00G_l3000006P00?nK
0`00000S001No`030000002V0?l0YP3o0180YP3o00<000000?l0003o0000
2@3o00050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003o
ool0oooo0080oooo303o0002000001@0YP3o0P00000T001No`<00000HP00
oi/3000002@005ko0P00000E0:H0o`030000003o0000o`0000T0o`001@3o
ool00`000000oooo0?ooo`0:0?ooo`00Q@3oool2000000<0oooo3@3o0000
0`000000YP3o0:H0o`0C0:H0o`8000009P00G_l3000005`00?nK0`00000V
001No`8000005@2V0?l00`000000o`000?l0000:0?l000@0oooo0P00000<
0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`d0o`0000<000000:H0
o`2V0?l0502V0?l2000002P005ko1000001D003oV`@00000:000G_l20000
01H0YP3o00<000000?l0003o00002P3o00050?ooo`030000003oool0oooo
00X0oooo00250?ooo`030000003oool0oooo0080oooo3P3o00000`000000
YP3o0:H0o`0D0:H0o`800000:`00G_l3000004h00?nK0`00000[001No`80
00005P2V0?l00`000000o`000?l0000;0?l000D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo00<000000?ooo`3oool00P3oool>0?l000800000
5P2V0?l2000002`005ko1@000016003oV`D00000;000G_l2000001H0YP3o
0P00000=0?l000D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<0
00000?ooo`3oool00P3oool?0?l000030000002V0?l0YP3o01D0YP3o0P00
000`001No`@00000?P00oi/40000030005ko0P00000G0:H0o`030000003o
0000o`0000`0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooo`l0o`0000<000000:H0o`2V0?l05`2V0?l0
0`00000005ko001No`0a001No`H00000<P00oi/6000003<005ko00<00000
0:H0o`2V0?l05`2V0?l00`000000o`000?l0000<0?l000D0oooo00<00000
0?ooo`3oool02P3oool008D0oooo0P0000030?oooa00o`0000<000000:H0
o`2V0?l05`2V0?l00`00000005ko001No`0e001No`L000009P00oi/70000
03L005ko00<000000:H0o`2V0?l05`2V0?l00`000000o`000?l0000=0?l0
00@0oooo0P00000<0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooa40
o`0000<000000:H0o`2V0?l05`2V0?l2000003`005ko2`00000@003oV`/0
0000?000G_l2000001T0YP3o0P00000?0?l000D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo00<000000?ooo`3oool00P3ooolA0?l000030000
002V0?l0YP3o01T0YP3o00<00000001No`00G_l0A000G_l@000004H005ko
0P00000J0:H0o`030000003o0000o`0000h0o`001@3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooa80o`0000<0
00000:H0o`2V0?l06@2V0?l00`00000005ko001No`2H001No`030000002V
0?l0YP3o01T0YP3o00<000000?l0003o00003`3o00050?ooo`030000003o
ool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo4P3o0000
0`000000YP3o0:H0o`0J0:H0o`0300000000G_l005ko09H005ko00<00000
0:H0o`2V0?l06P2V0?l00`000000o`000?l0000?0?l000D0oooo00<00000
0?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3ooolC0?l0
00030000002V0?l0YP3o01X0YP3o0`00002C001No`800000702V0?l00`00
0000o`000?l0000@0?l000D0oooo00<000000?ooo`3oool02P3oool008D0
oooo00<000000?ooo`3oool00P3ooolD0?l000030000002V0?l0YP3o01/0
YP3o0P00002@001No`8000007@2V0?l200000180o`001@3oool00`000000
oooo0?ooo`0:0?ooo`00Q@3oool2000000<0oooo503o00000`000000YP3o
0:H0o`0M0:H0o`0300000000G_l005ko08`005ko00<000000:H0o`2V0?l0
7@2V0?l00`000000o`000?l0000A0?l000@0oooo0P00000<0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?oooaD0o`0000<000000:H0o`2V0?l07@2V
0?l2000008X005ko0P00000O0:H0o`030000003o0000o`000180o`001@3o
ool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`02
0?oooaH0o`0000<000000:H0o`2V0?l07@2V0?l3000008H005ko0`00000O
0:H0o`800000503o00050?ooo`030000003oool0oooo00X0oooo00250?oo
o`030000003oool0oooo0080oooo5P3o00000`000000YP3o0:H0o`0O0:H0
o`800000Q000G_l200000240YP3o00<000000?l0003o00004`3o00050?oo
o`030000003oool0oooo00X0oooo001b0?ooo`800000103oool2000000<0
oooo0`0000050?ooo`030000003oool0oooo0080oooo5`3o00000`000000
YP3o0:H0o`0P0:H0o`800000P000G_l200000280YP3o00<000000?l0003o
0000503o00050?ooo`030000003oool0oooo00X0oooo001a0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`020?oooaP0o`0000<000000:H0o`2V0?l0802V0?l30000
07`005ko0`00000R0:H0o`030000003o0000o`0001D0o`001@3oool00`00
0000oooo0?ooo`0:0?ooo`00L@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000@0oooo0P0000030?oooaP0o`000P00000S
0:H0o`800000NP00G_l2000002<0YP3o0P00000G0?l000@0oooo0P00000<
0?ooo`00L@3oool010000000oooo0?ooo`0000080?ooo`<000001@3oool0
0`000000oooo0?ooo`020?oooaT0o`000P00000T0:H0o`<00000M@00G_l2
000002@0YP3o0P00000H0?l000D0oooo00<000000?ooo`3oool02P3oool0
0740oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo6P3o00000`000000YP3o0:H0o`0T
0:H0o`<00000L000G_l3000002H0YP3o00<000000?l0003o00005`3o0005
0?ooo`030000003oool0oooo00X0oooo001b0?ooo`8000002P3oool30000
00@0oooo00<000000?ooo`3oool00P3ooolK0?l000030000002V0?l0YP3o
02D0YP3o0P00001^001No`8000009`2V0?l2000001T0o`001@3oool00`00
0000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooa`0
o`0000<000000:H0o`2V0?l09P2V0?l3000006P005ko0`00000Y0:H0o`03
0000003o0000o`0001P0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00
Q@3oool00`000000oooo0?ooo`020?oooa`0o`000P00000Y0:H0o`800000
IP00G_l2000002T0YP3o0P00000K0?l000D0oooo00<000000?ooo`3oool0
2P3oool008D0oooo0P0000030?oooad0o`000P00000Z0:H0o`<00000H000
G_l3000002X0YP3o0P00000L0?l000@0oooo0P00000<0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?oooah0o`0000<000000:H0o`2V0?l0:`2V0?l2
000005`005ko0P00000]0:H0o`030000003o0000o`0001/0o`001@3oool0
0`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oo
oal0o`0000<000000:H0o`2V0?l0;02V0?l4000005@005ko1000000^0:H0
o`030000003o0000o`0001`0o`001@3oool00`000000oooo0?ooo`0:0?oo
o`00Q@3oool00`000000oooo0?ooo`020?ooob00o`0000<000000:H0o`2V
0?l0;`2V0?l20000050005ko0P00000a0:H0o`030000003o0000o`0001d0
o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo
0?ooo`020?ooob00o`000P00000b0:H0o`@00000B000G_l400000380YP3o
0P00000O0?l000D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<0
00000?ooo`3oool00P3ooolQ0?l000800000=@2V0?l30000048005ko0`00
000e0:H0o`800000803o00050?ooo`030000003oool0oooo00X0oooo0025
0?ooo`8000000`3ooolS0?l000030000002V0?l0YP3o03D0YP3o1000000j
001No`D00000=P2V0?l200000240o`00103oool2000000`0oooo00250?oo
o`030000003oool0oooo0080oooo8`3o0002000003X0YP3o1@00000`001N
o`D00000>P2V0?l200000280o`001@3oool00`000000oooo0?ooo`0:0?oo
o`00Q@3oool00`000000oooo0?ooo`020?ooobD0o`0000<000000:H0o`2V
0?l0?02V0?l500000003001No`00000005ko02<005ko1@00000n0:H0o`80
00008`3o00050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000
003oool0oooo0080oooo9@3o000200000480YP3o2P00000B001No`X00000
@P2V0?l2000002@0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?ooobH0o`000P00001;0:H0oa800000B`2V
0?l2000002D0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooobP0o`0000<000000:H0o`2V0?l0Y02V0?l2
000002H0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?ooobP0o`000P00002T0:H0o`8000009`3o00050?oo
o`030000003oool0oooo00X0oooo00250?ooo`8000000`3ooolZ0?l00003
0000002V0?l0YP3o0:00YP3o00<000000?l0003o00009`3o00040?ooo`80
0000303oool008D0oooo00<000000?ooo`3oool00P3oool[0?l000800000
W`2V0?l2000002T0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?ooob`0o`000P00002L0:H0o`800000:`3o
00050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0
oooo0080oooo;@3o0002000009X0YP3o0P00000/0?l000D0oooo00<00000
0?ooo`3oool02P3oool00780oooo0P0000040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool00P3oool^0?l000800000V02V0?l20000
02d0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00L@3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00P3oool`0?l000800000U02V0?l2000002l0o`001@3oool0
0`000000oooo0?ooo`0:0?ooo`00L@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000@0oooo0P0000030?oooc40o`000P00
002C0:H0o`030000003o0000o`0002h0o`00103oool2000000`0oooo001a
0?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`030000003o
ool0oooo0080oooo<P3o000200000900YP3o0P00000a0?l000D0oooo00<0
00000?ooo`3oool02P3oool00740oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo
=03o00000`000000YP3o0:H0o`2<0:H0o`030000003o0000o`000340o`00
1@3oool00`000000oooo0?ooo`0:0?ooo`00LP3oool2000000X0oooo0P00
00050?ooo`030000003oool0oooo0080oooo=@3o0002000008X0YP3o0P00
000d0?l000D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<00000
0?ooo`3oool00P3ooolf0?l000<00000Q`2V0?l2000003D0o`001@3oool0
0`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oo
ocP0o`000P0000240:H0o`800000=`3o00050?ooo`030000003oool0oooo
00X0oooo00250?ooo`8000000`3oooli0?l000800000PP2V0?l2000003P0
o`00103oool2000000`0oooo00250?ooo`030000003oool0oooo0080oooo
>`3o0002000007l0YP3o00<000000?l0003o0000>03o00050?ooo`030000
003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo?03o
0003000007X0YP3o0`00000k0?l000D0oooo00<000000?ooo`3oool02P3o
ool008D0oooo00<000000?ooo`3oool00P3ooolo0?l000800000MP2V0?l2
000003h0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?oood00o`000P00001d0:H0o`800000?`3o00050?oo
o`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080
oooo@P3o000200000700YP3o0P0000110?l000D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo0P0000030?oood@0o`000P00001/0:H0o`800000
@`3o00040?ooo`800000303oool008D0oooo00<000000?ooo`3oool00P3o
oom60?l000800000J02V0?l2000004D0o`001@3oool00`000000oooo0?oo
o`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooodP0o`000`00001R
0:H0o`<00000A`3o00050?ooo`030000003oool0oooo00X0oooo00250?oo
o`030000003oool0oooo0080ooooBP3o0003000005h0YP3o0`0000190?l0
00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3o
ool00P3ooom=0?l000800000FP2V0?l2000004`0o`001@3oool00`000000
oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooodl0o`00
0`00001D0:H0o`<00000CP3o00050?ooo`030000003oool0oooo00X0oooo
00250?ooo`030000003oool0oooo0080ooooD@3o000300000500YP3o0`00
001@0?l000D0oooo00<000000?ooo`3oool02P3oool008D0oooo0P000003
0?oooe@0o`00100000180:H0o`@00000D`3o00040?ooo`800000303oool0
08D0oooo00<000000?ooo`3oool00P3ooomH0?l000@00000@@2V0?l30000
05L0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000
oooo0?ooo`020?oooe/0o`001000000j0:H0o`@00000FP3o00050?ooo`03
0000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo
G`3o000400000380YP3o1000001N0?l000D0oooo00<000000?ooo`3oool0
2P3oool007d0oooo1@0000030?ooo`030000003oool0oooo0080ooooH`3o
0006000002H0YP3o1P00001R0?l000D0oooo00<000000?ooo`3oool02P3o
ool007l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooofT0o`002000000F0:H0o`P00000J03o00050?ooo`030000003oool0
oooo00X0oooo001o0?ooo`030000003oool0oooo00<0oooo0P0000030?oo
og40o`005P00001`0?l000@0oooo0P00000<0?ooo`00O`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00X0oooo001o0?ooo`030000003oool0oooo00<0oooo
o`000003000000`0oooo001n0?ooo`800000o`3ooolD0?ooo`00o`3ooonD
0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  As discussed in Example 11.9, the transformation  \n\n\t\t\t",
  Cell[BoxData[
      \(w\ \  = \ \ \(u + \[ImaginaryI]\ v\ \  = \ \ \(\(\[ImaginaryI] \((1 - \
z)\)\)\/\(1 + z\)\ \  = \ \ \(\[ImaginaryI] \((1 - x - \[ImaginaryI]\ \
y)\)\)\/\(1 + x + \[ImaginaryI]\ y\)\)\)\)]],
  " \n\nis a one-to-one conformal mapping of the half-disk ",
  StyleBox["H",
    FontFamily->"Courier New"],
  " onto the first quadrant ",
  Cell[BoxData[
      RowBox[{\(Q : \ u > 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(v > 0\)}]]],
  ", and can be written as \n\n",
  StyleBox["(11-24)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[{
      \(\(\(u + \[ImaginaryI]\ v\ \  = \ \ \(\[ImaginaryI] \((1 - x - \
\[ImaginaryI]\ y)\) \((1 + x - \[ImaginaryI]\ y)\)\)\/\(\((1 + x + \
\[ImaginaryI]\ y)\) \((1 + x - \[ImaginaryI]\ y)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(2\ y + \[ImaginaryI]\
\ \((1 - x\^2 - y\^2)\)\)\/\(1 + 2\ x + x\^2 + 
              y\^2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(2\ y\)\/\(\((x + \
1)\)\^2 + y\^2\)\ \  + \ \ \[ImaginaryI] \( 1 - x\^2 - y\^2\)\/\(\((x + \
1)\)\^2 + y\^2\)\)\)\)}]],
  "    "
}], "Text"],

Cell[TextData[{
  "The conformal map given by Equation ",
  StyleBox["(11-24)",
    FontColor->RGBColor[0, 0, 1]],
  " gives rise to a new problem of finding the temperature ",
  Cell[BoxData[
      RowBox[{\(T\^*\), 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  " that satisfies the boundary conditions  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{\(T\^*\), 
              RowBox[{"(", 
                RowBox[{"u", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "0"}], ")"}]}], "=", "100"}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "   ", "u"}], ">", "0"}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[";",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{\(T\^*\), 
            RowBox[{"(", 
              RowBox[{"0", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "v"}], ")"}]}], "=", "  ", "50"}],
         
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "   ", "v"}], ">", 
          RowBox[{"0", 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "\n\n If we use Example 11.2, the harmonic function ",
  Cell[BoxData[
      RowBox[{\(T\^*\), 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  " is given by  \n \n",
  StyleBox["(11-25)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(T\^*\), 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], "  ", "=", 
        "  ", \(100\  + \ \(\(50 - 100\)\/\(\[Pi]/2\)\) 
              Arg \((u + \[ImaginaryI]\ v)\)\ \  = \ \ 100\  - \ \(100\/\[Pi]\
\) Arctan \((v\/u)\)\)}]]],
  ".  \n\nSubstituting the expressions for u and v from Equation ",
  StyleBox["(11-24)",
    FontColor->RGBColor[0, 0, 1]],
  " into Equation ",
  StyleBox["(11-25)",
    FontColor->RGBColor[0, 0, 1]],
  " yields the desired solution:  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
        "  ", \(100\  - \ \(100\/\[Pi]\) 
            Arctan \((\(1 - x\^2 - y\^2\)\/\(2\ y\))\)\)}]]],
  ".\nThe isothermals  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        "constant"}]],
    AspectRatioFixed->True],
  "  are circles that pass through the points \[PlusMinus]1, as shown in \
Figure 11.19. "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.19",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/temperature/\
TemperaturesFigures/mat1119.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The temperature ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        "=", \(100 - \(100\/\[Pi]\) 
            Arctan \((\(1 - x\^2 - y\^2\)\/\(2\ y\))\)\)}]]],
  " in a half-disk."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.16.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Construct the solution via a known conformal mapping. This is similar to \
Example 11.9.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[T, U, V, x, y, w, W];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, cont];\)\ \), "\n", 
    \(\(f[
          z_]\  = \(\(\ \)\(\[ImaginaryI] \((1\  - \ z)\)\)\)\/\(1\  + \ z\);\
\)\ \), "\n", 
    \(\(W\  = \ ComplexExpand[f[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(U\  = \ 
        Together[
          ComplexExpand[Re[W], 
            TargetFunctions \[Rule] {Re, Im}]];\)\ \), "\n", 
    \(\(\(V\  = \ 
          Together[
            ComplexExpand[Im[W], 
              TargetFunctions \[Rule] {Re, Im}]];\)\ ;\)\ \), "\n", 
    \(\(T[x_, y_]\  = \ 100\  - \ 100\/\[Pi]\ ArcTan[V\/U];\)\ \), "\n", 
    \(\(Print["\<w = \>", f[z], "\< = \>", 
        U\  + \ \[ImaginaryI]\ V];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u = \>", U\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<v = \>", \ V];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<T[x,y] = 100 - \!\(100\/\[Pi]\) \
ArcTan[\!\(v\/u\)]\>\""];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
We can check out some of the boundary values by taking limits.\
\>", "Text"],

Cell[BoxData[{
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) T[\!\(\(-1\)\/2\),y] = \
\>\"", Limit[T[\(-1\)\/2, y], \ y \[Rule] 0]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) T[0,y] = \>\"", 
        Limit[T[0, y], \ y \[Rule] 0]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) T[\!\(1\/2\),y] = \>\"", 
        Limit[T[1\/2, y], \ y \[Rule] 0]];\)\ \), "\n", 
    \(\(Print[\*"\"\< T[\!\(\@2\/2\),\!\(\@2\/2\)] = \>\"", 
        T[\@2\/2, \@2\/2]];\)\ \), "\n", 
    \(\(Print["\<       T[0,1] = \>", T[0, 1]];\)\ \), "\n", 
    \(\(Print[\*"\"\<T[\!\(\(-\@2\)\/2\),\!\(\@2\/2\)] = \>\"", 
        T[\(-\@2\)\/2, \@2\/2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the temperature."
}], "Text"],

Cell[BoxData[{
    \(\(cont\  = \ Table[50 + 10  k, {k, 0, 5}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[T[x, y], {x, \(-1\), 1}, {y, 0.01, 1}, 
        Contours\  \[Rule] \ cont, \[IndentingNewLine]PlotPoints \[Rule] 35, 
        AspectRatio \[Rule] 1\/2, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\n", 
    \(\(Print["\<The contours are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[T[x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nHence the temperature function  ",
  Cell[BoxData[
      \(T[x, y] = 
        100 - \(100\ ArcTan[\(1 - \ x\^2 - \ y\^2\)\/\(2\ y\)]\)\/\[Pi]\)]],
  "  is harmonic in the upper half-disk  ",
  Cell[BoxData[
      \(H : y > 0, \(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ",  and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.21.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the electrical potential  ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  in the disk  ",
  Cell[BoxData[
      \(D : \(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  "  that satisfies the boundary values\n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "=", "80"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "   ", "x"}], 
              "+", \(\[ImaginaryI]\ y\)}], "=", 
            RowBox[{
              RowBox[{"z", "  ", 
                StyleBox["on",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "  ", \(C\_1\)}], 
              "=", \({z = \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\  : \ 
                    0 < \[Theta] < \[Pi]\/2}\)}]}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->14,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->14,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "=", "  ", "0"}], 
        
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "   ", "x"}], 
            "+", \(\[ImaginaryI]\ y\)}], "=", 
          RowBox[{
            RowBox[{"z", "  ", 
              StyleBox["on",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(C\_2\)}], "=", 
            
            RowBox[{\({z = \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\  : \ \
\[Pi]\/2 < \[Theta] < 2  \[Pi]}\), 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005N0000l2000`400?l0
0000o`00003oo`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00
o`3ooomO0?ooo`00o`3ooomO0?ooo`00h@3oool00`000000oooo0?ooo`1j
0?ooo`00h@3oool00`000000oooo0?ooo`1j0?ooo`00h@3oool00`000000
oooo0?ooo`1j0?ooo`00h@3oool00`000000oooo0?ooo`1j0?ooo`00h@3o
ool00`000000oooo0?ooo`1j0?ooo`00h@3oool00`000000oooo0?ooo`1j
0?ooo`00h@3oool00`000000oooo0?ooo`1j0?ooo`00h@3oool00`000000
oooo0?ooo`1j0?ooo`00h@3oool00`000000oooo0?ooo`1j0?ooo`00f@3o
ool5000000<0oooo00<000000?ooo`3oool0NP3oool00=/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`1j0?ooo`00f03ooolC0000
og<0oooo003?0?ooo`T0003o0`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo20000?m[0?ooo`00b`3oool40000o``0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`@0003o
I`3oool00<H0oooo1@000?l?0?ooo`8000001@3oool00`000000oooo0?oo
o`0C0?ooo`D0003oHP3oool00<80oooo10000?lK0?ooo`030000003oool0
oooo01P0oooo10000?mN0?ooo`00_P3oool40000oal0oooo00<000000?oo
o`3oool0703oool30000oe/0oooo002l0?ooo`80003o8`3oool00`000000
oooo0?ooo`0O0?ooo`<0003oF03oool00;T0oooo0`000?lU0?ooo`030000
003oool0oooo0280oooo0P000?mF0?ooo`00]`3oool20000obP0oooo00<0
00000?ooo`3oool0903oool20000oe@0oooo002e0?ooo`80003o:P3oool0
0`000000oooo0?ooo`0V0?ooo`80003oDP3oool00;<0oooo0P000?l/0?oo
o`030000003oool0oooo02P0oooo0P000?m@0?ooo`00/@3oool20000obh0
oooo00<000000?ooo`3oool0:P3oool20000odh0oooo002_0?ooo`80003o
<03oool00`000000oooo0?ooo`0/0?ooo`80003oC03oool00:h0oooo00<0
003o0?ooo`3oool0<03oool00`000000oooo0?ooo`0^0?ooo`80003oBP3o
ool00:`0oooo0P000?lc0?ooo`030000003oool0oooo0300oooo0P000?m8
0?ooo`00ZP3oool20000ocD0oooo00<000000?ooo`3oool0<P3oool00`00
0?l0oooo0?ooo`150?ooo`00Z03oool20000ocL0oooo00<000000?ooo`3o
ool0<`3oool20000odD0oooo002V0?ooo`80003o>@3oool00`000000oooo
0?ooo`0e0?ooo`030000o`3oool0oooo0480oooo002U0?ooo`030000o`3o
ool0oooo03T0oooo00<000000?ooo`3oool0=P3oool20000od80oooo002T
0?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0>03oool2
0000od00oooo002S0?ooo`030000o`3oool0oooo03/0oooo00<000000?oo
o`3oool0>P3oool00`000?l0oooo0?ooo`0m0?ooo`00XP3oool00`000?l0
oooo0?ooo`0l0?ooo`030000003oool0oooo03/0oooo00<0003o0?ooo`3o
ool0?03oool00:00oooo0P000?lo0?ooo`030000003oool0oooo03`0oooo
0P000?ll0?ooo`00W`3oool00`000?l0oooo0?ooo`0o0?ooo`030000003o
ool0oooo03h0oooo00<0003o0?ooo`3oool0>@3oool009h0oooo00<0003o
0?ooo`3oool0@03oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0
oooo03P0oooo002M0?ooo`030000o`3oool0oooo0440oooo00<000000?oo
o`3oool0@03oool20000ocP0oooo002L0?ooo`030000o`3oool0oooo0480
oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0e0?ooo`00
V`3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo04<0oooo
00<0003o0?ooo`3oool0=03oool009X0oooo00<0003o0?ooo`3oool0A03o
ool00`000000oooo0?ooo`140?ooo`030000o`3oool0oooo03<0oooo002H
0?ooo`80003oA`3oool00`000000oooo0?ooo`150?ooo`030000o`3oool0
oooo0380oooo002G0?ooo`030000o`3oool0oooo04L0oooo00<000000?oo
o`3oool0AP3oool00`000?l0oooo0?ooo`0a0?ooo`00UP3oool00`000?l0
oooo0?ooo`180?ooo`030000003oool0oooo04L0oooo00<0003o0?ooo`3o
ool0<03oool009D0oooo00<0003o0?ooo`3oool0B@3oool00`000000oooo
0?ooo`180?ooo`030000o`3oool0oooo02l0oooo002D0?ooo`030000o`3o
ool0oooo04X0oooo00<000000?ooo`3oool0B@3oool00`000?l0oooo0?oo
o`0^0?ooo`00T`3oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0
oooo04X0oooo00<0003o0?ooo`3oool0;@3oool00980oooo00<0003o0?oo
o`3oool0C03oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo
02`0oooo002A0?ooo`030000o`3oool0oooo04d0oooo00<000000?ooo`3o
ool0C03oool00`000?l0oooo0?ooo`0[0?ooo`00T03oool00`000?l0oooo
0?ooo`1>0?ooo`030000003oool0oooo04d0oooo00<0003o0?ooo`3oool0
:P3oool008l0oooo00<0003o0?ooo`3oool0C`3oool00`000000oooo0?oo
o`1>0?ooo`030000o`3oool0oooo02T0oooo002>0?ooo`030000o`3oool0
oooo0500oooo00<000000?ooo`3oool0C`3oool00`000?l0oooo0?ooo`0X
0?ooo`00S@3oool00`000?l0oooo0?ooo`1A0?ooo`030000003oool0oooo
0500oooo00<0003o0?ooo`3oool09`3oool008`0oooo00<0003o0?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo02L0
oooo002<0?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3oool0
D@3oool00`000?l0oooo0?ooo`0V0?ooo`00R`3oool00`000?l0oooo0?oo
o`1C0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool09@3o
ool008X0oooo00<0003o0?ooo`3oool0E03oool00`000000oooo0?ooo`1C
0?ooo`030000o`3oool0oooo02@0oooo002:0?ooo`030000o`3oool0oooo
05@0oooo00<000000?ooo`3oool0D`3oool00`000?l0oooo0?ooo`0T0?oo
o`00R@3oool00`000?l0oooo0?ooo`1E0?ooo`030000003oool0oooo05@0
oooo00<0003o0?ooo`3oool08`3oool008P0oooo00<0003o0?ooo`3oool0
EP3oool00`000000oooo0?ooo`1E0?ooo`030000o`3oool0oooo0280oooo
00280?ooo`030000o`3oool0oooo05H0oooo00<000000?ooo`3oool0EP3o
ool00`000?l0oooo0?ooo`0Q0?ooo`00Q`3oool00`000?l0oooo0?ooo`1G
0?ooo`030000003oool0oooo05H0oooo00<0003o0?ooo`3oool08@3oool0
08H0oooo00<0003o0?ooo`3oool0F03oool00`000000oooo0?ooo`1G0?oo
o`030000o`3oool0oooo0200oooo00260?ooo`030000o`3oool0oooo04D0
oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3o
ool0E`3oool00`000?l0oooo0?ooo`0P0?ooo`00Q@3oool00`000?l0oooo
0?ooo`150?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1H0?ooo`030000o`3oool0oooo
01l0oooo00250?ooo`030000o`3oool0oooo04D0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`020?ooo`800000F@3oool00`00
0?l0oooo0?ooo`0O0?ooo`00Q03oool00`000?l0oooo0?ooo`100?ooo`@0
00000P3oool010000000oooo0?ooo`0000090?ooo`8000001@3oool00`00
0000oooo0?ooo`1I0?ooo`030000o`3oool0oooo01h0oooo00230?ooo`03
0000o`3oool0oooo04L0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo05T0oooo00<0003o0?oo
o`3oool07P3oool008<0oooo00<0003o0?ooo`3oool0B03oool2000000X0
oooo0`0000040?ooo`030000003oool0oooo01H0oooo2`3o000i0?ooo`03
0000o`3oool0oooo01d0oooo00220?ooo`030000o`3oool0oooo05`0oooo
00<000000?ooo`3oool03P3oool80?l000/0oooo2@3o000`0?ooo`030000
o`3oool0oooo01d0oooo00220?ooo`030000o`3oool0oooo05`0oooo00<0
00000?ooo`3oool02`3oool30?l001`0oooo103o000]0?ooo`030000o`3o
ool0oooo01`0oooo00210?ooo`030000o`3oool0oooo05d0oooo00<00000
0?ooo`3oool01`3oool40?l002<0oooo0`3o000Z0?ooo`030000o`3oool0
oooo01`0oooo00210?ooo`030000o`3oool0oooo05d0oooo00<000000?oo
o`3oool00`3oool40?l002X0oooo103o000W0?ooo`030000o`3oool0oooo
01/0oooo00200?ooo`030000o`3oool0oooo05h0oooo00<000000?ooo`3o
ool00`3o000b0?ooo`<0o`00903oool00`000?l0oooo0?ooo`0K0?ooo`00
P03oool00`000?l0oooo0?ooo`1N0?ooo`030000003o0000o`0003P0oooo
0P3o000S0?ooo`030000o`3oool0oooo01X0oooo001o0?ooo`030000o`3o
ool0oooo05d0oooo0`3o000l0?ooo`<0o`00803oool00`000?l0oooo0?oo
o`0J0?ooo`00O`3oool00`000?l0oooo0?ooo`1K0?ooo`80o`000P3oool0
0`000000oooo0?ooo`0m0?ooo`80o`007`3oool00`000?l0oooo0?ooo`0I
0?ooo`00O`3oool00`000?l0oooo0?ooo`1I0?ooo`80o`00103oool00`00
0000oooo0?ooo`0o0?ooo`<0o`00703oool00`000?l0oooo0?ooo`0I0?oo
o`00OP3oool00`000?l0oooo0?ooo`1H0?ooo`80o`001P3oool00`000000
oooo0?ooo`120?ooo`80o`006`3oool00`000?l0oooo0?ooo`0H0?ooo`00
OP3oool00`000?l0oooo0?ooo`1F0?ooo`80o`00203oool00`000000oooo
0?ooo`140?ooo`80o`006@3oool00`000?l0oooo0?ooo`0H0?ooo`00OP3o
ool00`000?l0oooo0?ooo`1D0?ooo`80o`002P3oool00`000000oooo0?oo
o`160?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0603o
ool007d0oooo00<0003o0?ooo`3oool0E03oool00`3o0000oooo0?ooo`0:
0?ooo`030000003oool0oooo04L0oooo00<0o`000?ooo`3oool05P3oool0
0`000?l0oooo0?ooo`0G0?ooo`00O@3oool00`000?l0oooo0?ooo`1B0?oo
o`80o`003@3oool00`000000oooo0?ooo`180?ooo`80o`005P3oool00`00
0?l0oooo0?ooo`0G0?ooo`00O@3oool00`000?l0oooo0?ooo`1A0?ooo`03
0?l0003oool0oooo00d0oooo00<000000?ooo`3oool0BP3oool00`3o0000
oooo0?ooo`0C0?ooo`030000o`3oool0oooo01L0oooo001l0?ooo`030000
o`3oool0oooo0540oooo00<0o`000?ooo`3oool03P3oool00`000000oooo
0?ooo`1;0?ooo`80o`00503oool00`000?l0oooo0?ooo`0F0?ooo`00O03o
ool00`000?l0oooo0?ooo`1?0?ooo`80o`004@3oool00`000000oooo0?oo
o`1=0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool05P3o
ool007`0oooo00<0003o0?ooo`3oool0CP3oool00`3o0000oooo0?ooo`0A
0?ooo`030000003oool0oooo04h0oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0E0?ooo`00N`3oool00`000?l0oooo0?ooo`1>0?oo
o`030?l0003oool0oooo0180oooo00<000000?ooo`3oool0C`3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo01D0oooo001k0?ooo`03
0000o`3oool0oooo04d0oooo00<0o`000?ooo`3oool04`3oool00`000000
oooo0?ooo`1@0?ooo`80o`00403oool00`000?l0oooo0?ooo`0E0?ooo`00
N`3oool00`000?l0oooo0?ooo`1;0?ooo`80o`005P3oool00`000000oooo
0?ooo`1B0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
503oool007/0oooo00<0003o0?ooo`3oool0BP3oool00`3o0000oooo0?oo
o`0F0?ooo`030000003oool0oooo05<0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0D0?ooo`00NP3oool00`000?l0oooo0?ooo`1:
0?ooo`030?l0003oool0oooo01L0oooo00<000000?ooo`3oool0E03oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01@0oooo001j0?oo
o`030000o`3oool0oooo04T0oooo00<0o`000?ooo`3oool0603oool00`00
0000oooo0?ooo`1E0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool04`3oool007X0oooo00<0003o0?ooo`3oool0B03oool00`3o0000
oooo0?ooo`0I0?ooo`030000003oool0oooo05H0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0C0?ooo`00N@3oool00`000?l0oooo
0?ooo`180?ooo`030?l0003oool0oooo01X0oooo00<000000?ooo`3oool0
E`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo01<0oooo
001i0?ooo`030000o`3oool0oooo04L0oooo00<0o`000?ooo`3oool06`3o
ool00`000000oooo0?ooo`1H0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool04P3oool007T0oooo00<0003o0?ooo`3oool0AP3oool0
0`3o0000oooo0?ooo`0L0?ooo`030000003oool0oooo0340oooo0`000?lU
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool04P3oool0
07T0oooo00<0003o0?ooo`3oool0AP3oool00`3o0000oooo0?ooo`0L0?oo
o`030000003oool0oooo02D0oooo30000?l30?ooo`/0003o6`3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo0180oooo001h0?ooo`03
0000o`3oool0oooo04H0oooo00<0o`000?ooo`3oool07@3oool00`000000
oooo0?ooo`0R0?ooo`<0003o6P3oool40000oaL0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0B0?ooo`00N03oool00`000?l0oooo
0?ooo`150?ooo`030?l0003oool0oooo01h0oooo00<000000?ooo`3oool0
7P3oool40000ob40oooo10000?lD0?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool04P3oool007P0oooo00<0003o0?ooo`3oool0A03o
ool00`3o0000oooo0?ooo`0O0?ooo`030000003oool0oooo01X0oooo1000
0?lY0?ooo`<0003o4P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo0180oooo001h0?ooo`030000o`3oool0oooo04<0oooo00<0o`00
0?ooo`3oool0803oool00`000000oooo0?ooo`0H0?ooo`80003o<03oool3
0000oa00oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B
0?ooo`00N03oool00`000?l0oooo0?ooo`130?ooo`030?l0003oool0oooo
0200oooo00<000000?ooo`3oool05@3oool30000ocD0oooo0P000?l>0?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool007L0
oooo00<0003o0?ooo`3oool0@`3oool00`3o0000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo01<0oooo0P000?lj0?ooo`80003o3@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo001g0?ooo`030000
o`3oool0oooo0480oooo00<0o`000?ooo`3oool08P3oool00`000000oooo
0?ooo`0A0?ooo`80003o?P3oool30000o`/0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`0A0?ooo`00M`3oool00`000?l0oooo0?oo
o`120?ooo`030?l0003oool0oooo0280oooo00<000000?ooo`3oool03`3o
ool20000od<0oooo0P000?l:0?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool04@3oool007L0oooo00<0003o0?ooo`3oool0@@3oool0
0`3o0000oooo0?ooo`0S0?ooo`030000003oool0oooo00d0oooo0P000?m7
0?ooo`80003o203oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0140oooo001g0?ooo`030000o`3oool0oooo0440oooo00<0o`000?oo
o`3oool08`3oool00`000000oooo0?ooo`0;0?ooo`80003oB`3oool20000
o`L0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0A0?oo
o`00M`3oool00`000?l0000000000002000002/0oooo0P0000040?ooo`80
0000103oool2000000D0oooo00<0o`000?ooo`3oool0903oool00`000000
oooo0?ooo`090?ooo`80003o803oool2000000@0oooo0P0000040?ooo`80
00008@3oool00`000?l0oooo0?ooo`050?ooo`050?l0003oool0oooo0000
00000?l00`00000@0?ooo`00M`3oool00`000?l0oooo0000000/0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool0
0`3o0000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo00<0003o
0?ooo`3oool07`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo00000240oooo0P000?l50?ooo`060?l0003oool0oooo0?ooo`00
0?l000004P3oool007H0oooo00@0003o0?ooo`3oool00000;03oool01000
0000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`3o00009`3o
ool00`000000oooo0?ooo`060?ooo`80003o8P3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`020000oa80oooo001a0?ooo`@0000000D0
oooo0000o`3oool0oooo0000000V0?ooo`@000000P3oool010000000oooo
0?ooo`0000090?ooo`8000000`3oool00`3o0000oooo0?ooo`0V0?ooo`03
0000003oool0oooo00D0oooo00<0003o0?ooo`3oool08P3oool010000000
oooo0?ooo`0000090?ooo`8000009@3oool00`000?l0oooo0?ooo`020?oo
o`050?l0003oool0oooo0?ooo`000?l04P3oool007H0oooo00@0003o0?oo
o`3oool00000;03oool010000000oooo0?ooo`0000090?ooo`030000003o
ool0oooo0080oooo00<0o`000?ooo`3oool09P3oool00`000000oooo0?oo
o`030?ooo`80003o9@3oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo00P0oooo3@3o000@0?ooo`80003o0`3oool0103o0000oooo
0?ooo`000?lB0?ooo`00MP3oool010000?l0oooo00000000000]0?ooo`80
00002P3oool3000000030?ooo`3o0000oooo02P0oooo00<000000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0V0?ooo`8000002P3oool3000000P0
o`003@3oool70?l000/0oooo00L0003o0?ooo`3oool0o`000?ooo`000000
003o0180oooo001f0?ooo`030000o`3oool0oooo03h0oooo00<0o`000?oo
o`3oool09`3oool01@000000oooo0?ooo`3oool0003o03D0oooo0`3o000L
0?ooo`D0o`001P3oool20000o`80oooo00<0o`000?ooo`000?l04P3oool0
07H0oooo00<0003o0?ooo`3oool0?@3oool00`3o0000oooo0?ooo`0X0?oo
o`040000003oool0oooo0000oc00oooo1P3o000T0?ooo`@0o`00103oool2
0000o`030?l0003oool0oooo0180oooo001f0?ooo`030000o`3oool0oooo
03d0oooo00<0o`000?ooo`3oool0:03oool00`000000oooo0000o`0_0?oo
o`80o`00;@3oool40?l00080oooo00<0003o0?ooo`3oool04`3oool007H0
oooo00<0003o0?ooo`3oool0?03oool00`3o0000oooo0?ooo`0Y0?ooo`03
000000000?l0oooo02`0oooo0`3o000c0?ooo`80o`005P3oool006`0oooo
2P0000000`000?l000000000000l000000030?l000000000000002T00000
00<0003o000000000000:@0000030?l004L000001`3oool007H0oooo00<0
003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`060?ooo`030?l0003o
ool0oooo02T0oooo00<0003o0000003oool0:03oool20?l000T0oooo00<0
00000?ooo`3oool0903oool;0000o`<0oooo00<000000?ooo`3oool0403o
ool007H0oooo00<0003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`06
0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`0000009`3oool2
0?l000/0oooo00<000000?ooo`3oool07`3oool50000o`T0oooo0P3o0003
0?ooo`030000003oool0oooo0100oooo001f0?ooo`030000o`3oool0oooo
03X0oooo00<0o`000?ooo`3oool0:03oool010000?l0oooo0?ooo`00000V
0?ooo`030?l0003oool0oooo02P0oooo1@000?l<0?ooo`<0o`0000<0oooo
0000o`3oool0503oool007H0oooo00<0003o0?ooo`3oool0>P3oool00`3o
0000oooo0?ooo`0X0?ooo`040000o`3oool0oooo000002@0oooo0P3o000V
0?ooo`D0003o3`3oool20?l000<0oooo0P000?l00`3o0000oooo0?ooo`0B
0?ooo`00MP3oool00`000?l0oooo0?ooo`0i0?ooo`030?l0003oool0oooo
02P0oooo00D0003o0?ooo`3oool0oooo0000000R0?ooo`80o`009@3oool3
0000oa80oooo0P3o00040?ooo`80003o00@0oooo0?l0003oool0003o4P3o
ool007H0oooo00<0003o0?ooo`3oool0>@3oool00`3o0000oooo0?ooo`0W
0?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`3oool07P3oool2
0?l002D0oooo0P000?lD0?ooo`030?l0003oool0oooo00<0oooo0P000?l0
1@3oool0o`000?l0003oool0003o0180oooo001g0?ooo`030000o`3oool0
oooo03P0oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`03
0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool08P3oool3
0000oa@0oooo0P3o00050?ooo`80003o0P3oool0103o0000oooo0?ooo`00
0?lB0?ooo`00M`3oool00`000?l0oooo0?ooo`0g0?ooo`030?l0003oool0
oooo02H0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`0K
0?ooo`80o`008P3oool30000oaD0oooo0P3o00060?ooo`040000o`3oool0
oooo0?ooo`80o`000P3oool00`000?l0oooo0?ooo`0@0?ooo`00M`3oool0
0`000?l0oooo0?ooo`0g0?ooo`030?l0003oool0oooo02D0oooo00<0003o
0?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0
oooo0200oooo0P000?lF0?ooo`80o`00203oool01@000?l0oooo0?ooo`3o
ool0o`0000<0oooo00<0003o0?ooo`3oool0403oool007L0oooo00<0003o
0?ooo`3oool0=`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0
oooo00D0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0N
0?ooo`<0003o5P3oool20?l000T0oooo00<0003o0?ooo`3oool00P3oool0
103o0000oooo0?ooo`000?lC0?ooo`00M`3oool00`000?l0oooo0?ooo`0g
0?ooo`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool01P3oool0
0`000000oooo0?ooo`0G0?ooo`80o`007`3oool20000oaL0oooo0P3o0009
0?ooo`80003o103oool01@3o0000oooo0?ooo`3oool0003o01<0oooo001g
0?ooo`030000o`3oool0oooo03H0oooo00<0o`000?ooo`3oool0903oool0
0`000?l0oooo0?ooo`070?ooo`030000003oool0oooo01H0oooo00<0o`00
0?ooo`3oool07@3oool20000oaL0oooo0P3o000:0?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0A
0?ooo`00M`3oool00`000?l0oooo0?ooo`0f0?ooo`030?l0003oool0oooo
02<0oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`0E0?oo
o`030?l0003oool0oooo01`0oooo0P000?lH0?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo0140oooo001h0?ooo`030000o`3oool0oooo03D0
oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`080?ooo`03
0000003oool0oooo01<0oooo0P3o000N0?ooo`030000o`3oool0oooo01H0
oooo0P3o000;0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0A0?ooo`00N03oool00`000?l0oooo
0?ooo`0e0?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool0
2@3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo01`0oooo
0P000?lG0?ooo`80o`00303oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool04@3oool007P0oooo00<0
003o0?ooo`3oool0=@3oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3o
ool0oooo00T0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0L0?ooo`030000o`3oool0oooo01D0oooo0P3o000=0?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0A0?ooo`00N03oool00`000?l0oooo0?ooo`0d0?ooo`030?l0003oool0
oooo0280oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`0@
0?ooo`030?l0003oool0oooo01/0oooo0P000?lF0?ooo`80o`003P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool04@3oool007P0oooo00<0003o0?ooo`3oool0=03oool00`3o
0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00X0oooo00<000000?oo
o`3oool03`3oool00`3o0000oooo0?ooo`0J0?ooo`80003o5`3oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`0B0?ooo`00N03oool00`000?l0
oooo0?ooo`0d0?ooo`030?l0003oool0oooo0240oooo00<0003o0?ooo`3o
ool02`3oool00`000000oooo0?ooo`0=0?ooo`80o`00703oool00`000?l0
oooo0?ooo`0F0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0180
oooo001h0?ooo`030000o`3oool0oooo03@0oooo00<0o`000?ooo`3oool0
8@3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo
00<0o`000?ooo`3oool06P3oool20000oaL0oooo0P3o000?0?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0B0?ooo`00N@3oool00`000?l0oooo0?ooo`0c0?ooo`030?l0003o
ool0oooo0200oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?oo
o`0;0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool05P3o
ool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?ooo`00N@3oool0
0`000?l0oooo0?ooo`0c0?ooo`030?l0003oool0oooo0200oooo00<0003o
0?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0
oooo01X0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0C0?ooo`00N@3oool00`000?l0oooo0?ooo`0c0?oo
o`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool03@3oool00`00
0000oooo0?ooo`090?ooo`030?l0003oool0oooo01T0oooo0P000?lH0?oo
o`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo01<0oooo001i0?ooo`03
0000o`3oool0oooo0380oooo00<0o`000?ooo`3oool0803oool00`000?l0
oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3o
ool0603oool00`000?l0oooo0?ooo`0F0?ooo`80o`00403oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool04`3oool007T0oooo00<0003o0?ooo`3oool0<P3oool00`3o0000oooo
0?ooo`0O0?ooo`030000o`3oool0oooo00h0oooo00<000000?ooo`3oool0
203oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo01H0oooo
00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool04`3oool007T0oooo00<0
003o0?ooo`3oool0<P3oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3o
ool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0H0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool0503oool007X0oooo00<0003o0?ooo`3oool0<@3oool0
0`3o0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00l0oooo00<00000
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0G0?ooo`80003o5`3oool2
0?l00140oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo01@0oooo001j0?ooo`030000o`3oool0oooo
0340oooo00<0o`000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0?0?oo
o`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool05P3oool00`00
0?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo0100oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
01@0oooo001j0?ooo`030000o`3oool0oooo0340oooo00<0o`000?ooo`3o
ool07P3oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo00D0
oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo01@0oooo001j0?ooo`030000
o`3oool0oooo0340oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo
0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0
5P3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo01@0oooo001k0?ooo`030000o`3oool0oooo0300oooo00<0
o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0@0?ooo`030000003o
ool0oooo00@0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?oo
o`0E0?ooo`80o`004P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool05@3oool007/0oooo00<0003o
0?ooo`3oool0<03oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0
oooo0100oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0E
0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool05@3oool007/0oooo00<0003o0?ooo`3oool0<03oool00`3o
0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo0140oooo00<000000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo
01D0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool05P3oool007/0
oooo00<0003o0?ooo`3oool0<03oool00`3o0000oooo0?ooo`0L0?ooo`03
0000o`3oool0oooo0140oooo00<000000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0D0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool05P3oool007`0oooo00<0003o0?ooo`3oool0
;`3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo0140oooo
00D000000?ooo`3oool0oooo0?l0000F0?ooo`030000o`3oool0oooo01D0
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool05P3oool007`0oooo
00<0003o0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`0L0?ooo`030000
o`3oool0oooo0140oooo00D000000?ooo`3oool0oooo0?l0000F0?ooo`03
0000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool05`3oool007`0oooo00<0003o0?ooo`3oool0;`3oool00`3o0000oooo
0?ooo`0K0?ooo`030000o`3oool0oooo0180oooo00@000000?ooo`3oool0
o`005P3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0180
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo01L0oooo001m0?ooo`030000o`3oool0oooo02h0oooo
00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0B0?ooo`030000
003oool0o`0001H0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo
0?ooo`0B0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0H0?ooo`00O@3oool00`000?l0oooo0?oo
o`0^0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool04P3o
ool00`000000oooo0?l0000E0?ooo`030000o`3oool0oooo01@0oooo00<0
o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool0603oool007h0oooo00<0003o
0?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0
oooo0180oooo00<000000?l0003oool0503oool00`000?l0oooo0?ooo`0D
0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01P0oooo001n0?oo
o`030000o`3oool0oooo02h0oooo00<0o`000?ooo`3oool06P3oool00`00
0?l0oooo0?ooo`0B0?ooo`030000003o0000oooo01<0oooo00<0003o0?oo
o`3oool0503oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0I0?oo
o`00O`3oool00`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0oooo01T0
oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0B0?ooo`03
0000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool06@3oool007l0oooo00<0003o0?ooo`3oool0;@3oool00`3o0000oooo
0?ooo`0I0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0180oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo01X0oooo00200?ooo`030000o`3oool0oooo02`0oooo00<0
o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0B0?ooo`030?l00000
0000oooo0180oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?oo
o`0B0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0J0?ooo`00P03oool00`000?l0oooo0?ooo`0/
0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool04P3oool0
0`3o000000000?ooo`0A0?ooo`030000o`3oool0oooo01<0oooo00<0o`00
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool06P3oool00840oooo00<0003o0?oo
o`3oool0:`3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo
0180oooo00<0o`000000003oool04@3oool00`000?l0oooo0?ooo`0B0?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool03`3oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01/0oooo00210?ooo`03
0000o`3oool0oooo02`0oooo00<0o`000?ooo`3oool0603oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool000000140oooo00<0003o0?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0K0?ooo`00
PP3oool00`000?l0oooo0?ooo`0[0?ooo`030?l0003oool0oooo01P0oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0000000@0?ooo`030000
o`3oool0oooo0180oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
703oool00880oooo00<0003o0?ooo`3oool0:`3oool00`3o0000oooo0?oo
o`0H0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`000000403o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0180oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo01`0oooo00230?ooo`030000o`3oool0oooo02X0oooo00<0o`00
0?ooo`3oool0603oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
000000l0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0M0?ooo`00P`3oool00`000?l0oooo0?ooo`0[0?oo
o`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool0403oool0103o
0000oooo0?ooo`00000?0?ooo`030000o`3oool0oooo0100oooo00<0o`00
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool07@3oool008@0oooo00<0003o0?oo
o`3oool0:P3oool00`3o0000oooo0?ooo`0F0?ooo`040000o`3oool0oooo
0?ooo`800000103oool2000000@0oooo0P0000020?ooo`040?l0003oool0
oooo000000h0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0B0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0N0?ooo`00Q03oool00`000?l0oooo0?ooo`0Z
0?ooo`030?l0003oool0oooo01H0oooo00@0003o0?ooo`3oool000000P3o
ool00`000000oooo0?ooo`060?ooo`060000003oool0oooo0000003oool0
o`000P3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo0100
oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool07`3oool008D0oooo
00<0003o0?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0E0?ooo`040000
o`3oool0oooo00000080oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?l000020?ooo`800000303oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo0180oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0?0?ooo`030000o`3oool0oooo01l0oooo00260?ooo`030000
o`3oool0oooo02T0oooo00<0o`000?ooo`3oool05@3oool010000?l0oooo
0?ooo`0000020?ooo`030000003oool0oooo00L0oooo0P0000000`3oool0
o`000?ooo`020?ooo`030000003oool0oooo00X0oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0P0?ooo`00
QP3oool00`000?l0oooo0?ooo`0Y0?ooo`030?l0003oool0oooo01D0oooo
00@0003o0?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo0?l000<0oooo00<000000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
0240oooo00270?ooo`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3o
ool05@3oool010000?l0oooo0?ooo`3oool2000000X0oooo0`0000001@3o
0000oooo0?ooo`3oool0000000/0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool0403oool00`000?l0oooo0?ooo`0Q0?ooo`00Q`3oool00`00
0?l0oooo0?ooo`0Y0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?oo
o`3oool0403oool01@3o0000oooo0?ooo`3oool0000000/0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0R
0?ooo`00R03oool00`000?l0oooo0?ooo`0X0?ooo`030?l0003oool0oooo
01D0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`020?oo
o`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0R0?ooo`00R@3oool00`000?l0
oooo0?ooo`0W0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0S0?ooo`00R@3oool00`000?l0oooo0?ooo`0X0?ooo`030?l0
003oool0oooo01@0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0T0?ooo`00RP3o
ool00`000?l0oooo0?ooo`0W0?ooo`030?l0003oool0oooo01@0oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`020?ooo`030000003o
ool0oooo00L0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`0T0?ooo`00R`3oool00`000?l0oooo0?ooo`0W
0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0U
0?ooo`00S03oool00`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo
01<0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`030?oo
o`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0V0?ooo`00S03oool00`000?l0
oooo0?ooo`0W0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo00D0
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0W0?ooo`00S@3oool00`000?l0oooo0?ooo`0V0?ooo`030?l0
003oool0oooo0180oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0W0?ooo`00SP3o
ool00`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0?0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`0X0?ooo`00S`3oool00`000?l0oooo0?ooo`0U
0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0Y
0?ooo`00S`3oool00`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04`3oool00`000?l0oooo0?ooo`0Z0?ooo`00T03oool00`000?l0
oooo0?ooo`0U0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04`3oool00`000?l0
oooo0?ooo`0[0?ooo`00T@3oool00`000?l0oooo0?ooo`0U0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0[0?ooo`00TP3o
ool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0503o
ool00`000?l0oooo0?ooo`0/0?ooo`00T`3oool00`000?l0oooo0?ooo`0T
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0]
0?ooo`00U03oool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0<0?ooo`80003o4`3oool00`3o0000oooo0?ooo`0D0?oo
o`030000o`3oool0oooo02h0oooo002E0?ooo`030000o`3oool0oooo02<0
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000o`0<0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool04@3oool20?l0
01H0oooo00<0003o0?ooo`3oool0;`3oool009H0oooo00<0003o0?ooo`3o
ool08`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0003o
00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0<03oool009L0
oooo00<0003o0?ooo`3oool08P3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool01@000000
oooo0?ooo`3oool0003o00/0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?oo
o`3oool0<@3oool009P0oooo00<0003o0?ooo`3oool08P3oool00`3o0000
oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0103oool01@000000oooo0?ooo`3oool0003o00X0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
01D0oooo00<0003o0?ooo`3oool0<P3oool009T0oooo00<0003o0?ooo`3o
ool08P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0103oool010000000oooo0?ooo`000?l:0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0403oool20?l0
01H0oooo0P000?le0?ooo`00VP3oool00`000?l0oooo0?ooo`0Q0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`040?ooo`040000003oool0oooo0000o`X0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo
01D0oooo00<0003o0?ooo`3oool0=@3oool009/0oooo0P000?lR0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`040?ooo`040000003oool0oooo0000o`T0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo
01D0oooo00<0003o0?ooo`3oool0=P3oool009d0oooo00<0003o0?ooo`3o
ool0803oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0103oool010000000oooo0?ooo`000?l90?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool20?l0
01L0oooo00<0003o0?ooo`3oool0=`3oool009h0oooo00<0003o0?ooo`3o
ool07`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool00`3oool010000000oooo0?ooo`000?l80?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`3o
0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo03P0oooo002O0?ooo`03
0000o`3oool0oooo01l0oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`00
0?l02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0i0?ooo`00
X03oool20000ob00oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`000?l0
203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00l0oooo
00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0j0?ooo`00XP3o
ool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030000003o
ool0003o00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0>0?ooo`80o`005`3oool20000ocd0oooo002S0?ooo`80003o7`3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool00`3oool00`000000oooo0000o`070?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0F
0?ooo`030000o`3oool0oooo03d0oooo002U0?ooo`030000o`3oool0oooo
01d0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00<0oooo00<000000?ooo`000?l01P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool05@3oool20000od00oooo002V0?ooo`030000o`3oool0oooo01d0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo0080oooo00<000000000o`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00d0oooo0P3o000G0?ooo`03
0000o`3oool0oooo0400oooo002W0?ooo`80003o7P3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
0P3oool00`000000003o0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0303oool20?l001L0oooo0P000?m30?ooo`00Z@3o
ool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`0300000000
0?l0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`0;0?ooo`80o`00603oool00`000?l0oooo0?ooo`130?ooo`00ZP3oool2
0000oad0oooo0P3o000:0?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00P3oool00`000000003o0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool02P3oool20?l001P0oooo0P000?m6
0?ooo`00[03oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?oo
o`03000000000?l0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`090?ooo`80o`00603oool20000odP0oooo002]0?ooo`80
003o7@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0203oool20?l001P0
oooo0P000?m:0?ooo`00[`3oool20000oa`0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00L0
oooo0P3o000H0?ooo`80003oC03oool00;40oooo0P000?lK0?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo01H0oooo0P000?m>0?ooo`00
/`3oool30000oaT0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo0P3o000G0?ooo`80
003oD03oool00;H0oooo0`000?lG0?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0
oooo00D0o`000?ooo`3oool0oooo0000o`070?ooo`80o`005P3oool30000
oe80oooo002i0?ooo`80003o5P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0003o0P3oool01@3o
0000oooo0?ooo`3oool0003o00H0oooo0P3o000F0?ooo`80003oE@3oool0
0;/0oooo0P000?lE0?ooo`80o`001P3oool01@000?l0oooo0?ooo`3oool0
o`000080oooo00@0003o0?ooo`3oool0o`000P3oool00`000?l0oooo0?oo
o`030?ooo`80o`005@3oool30000oeL0oooo002m0?ooo`<0003o503oool2
0?l000D0oooo00@0003o0?ooo`3oool0o`000P3oool00`000?l0oooo0?l0
00020?ooo`030000o`3oool0oooo0080oooo0P3o000D0?ooo`<0003oFP3o
ool00<00oooo0P000?lD0?ooo`80o`00103oool02P000?l0oooo0?ooo`3o
0000oooo0000o`3oool0o`000?ooo`000?l30?ooo`80o`00503oool20000
oed0oooo00320?ooo`<0003o4`3oool20?l000<0oooo00P0003o0?ooo`3o
0000oooo0000o`3o0000oooo0000o`80oooo0P3o000D0?ooo`80003oG`3o
ool00<D0oooo1@000?l@0?ooo`80o`000P3oool01`000?l0oooo0?ooo`00
0000oooo0000o`3oool00P3o000B0?ooo`@0003oH@3oool00<X0oooo2000
0?l70?ooo`<000000P3o00030?ooo`040000003oool0oooo0?l000l0oooo
1@000?mU0?ooo`00dP3oool70000o`80oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`/0003oJP3oool00=T0oooo10000?l4
0?ooo`8000000P3oool40000ogD0oooo003K0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0NP3oool00=/0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1j0?ooo`00fP3oool2000000D0oooo
00<000000?ooo`3oool0NP3oool00>40oooo00<000000?ooo`3oool0NP3o
ool00>40oooo00<000000?ooo`3oool0NP3oool00>40oooo00<000000?oo
o`3oool0NP3oool00>40oooo00<000000?ooo`3oool0NP3oool00>40oooo
00<000000?ooo`3oool0NP3oool00>40oooo00<000000?ooo`3oool0NP3o
ool00>40oooo00<000000?ooo`3oool0NP3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{350, 240},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The mapping  ",
  Cell[BoxData[
      \(w\  = \ \(S \((z)\)\  = \ \(\((1 - \[ImaginaryI])\) \((z - \
\[ImaginaryI])\)\)\/\((z - 1)\)\)\)]],
  "  is a one-to-one conformal mapping of ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " onto the upper half-plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  "  with the property that ",
  Cell[BoxData[
      \(C\_1\)]],
  " is mapped onto the negative ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " axis and ",
  Cell[BoxData[
      \(C\_2\)]],
  " is mapped onto the positive ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " axis.  The potential ",
  Cell[BoxData[
      RowBox[{"\[CapitalPhi]", 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  " in the upper half-plane that satisfies the new boundary values \n\n\t\t\t\
",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalPhi]", 
            RowBox[{"(", 
              RowBox[{"u", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", "80"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", \(for\ \ \ u < 0\), ",", 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"\[CapitalPhi]", 
            RowBox[{"(", 
              RowBox[{"u", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", "  ", "0"}], 
        
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", \(for\ \ \ u > 0\), ","}]]],
  "  \n\n is given by  \n \n",
  StyleBox[" (11-29)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPhi]", 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], "  ", "=", 
        "  ", \(\(80\/\[Pi]\) Arg \((w)\)\ \  = \ \ \(80\/\[Pi]\) 
            Arctan \((v\/u)\)\)}]],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[TextData[{
  "A straightforward calculation shows that  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(w\ \  = \ \ \(u + \[ImaginaryI]\ v\ \  = \ \ \(S \((z)\)\ \  = \ \
\ \(\((1 - \[ImaginaryI])\) \((x + \[ImaginaryI]\ y - \
\[ImaginaryI])\)\)\/\((x + \[ImaginaryI]\ y - 1)\)\)\)\)\(\[IndentingNewLine]\
\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(\(=\)\(\ \ \)\(\(\((1 - \[ImaginaryI])\) \((x + \
\[ImaginaryI]\ \((y - 1)\))\)\)\/\((x - 
                1 + \[ImaginaryI]\ y)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(\(=\)\(\ \ \)\(\(\((1 - \[ImaginaryI])\) \((x + \
\[ImaginaryI]\ \((y - 1)\))\) \((x - 1 - \[ImaginaryI]\ y)\)\)\/\(\((x - 
                  1 + \[ImaginaryI]\ y)\) \((x - 
                  1 - \[ImaginaryI]\ y)\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(\(=\)\(\ \ \)\(\(1 - 2\ x + x\^2 - 2\ y + 
              y\^2 + \[ImaginaryI]\ \((1 - x\^2 - y\^2)\)\)\/\(1 - 2\ x + 
              x\^2 + y\^2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(\(=\)\(\ \ \)\(\(\((x - 1)\)\^2 + \((y - 1)\)\^2 - 
              1 + \[ImaginaryI]\ \((1 - x\^2 - y\^2)\)\)\/\(1 - 2\ x + x\^2 + 
              y\^2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \(\(=\)\(\ \ \)\(\(\((x - 1)\)\^2 + \((y - 1)\)\^2 - \
1\)\/\(\((x - 1)\)\^2 + y\^2\)\  + \[ImaginaryI]\ \(\(\ \)\(1 - x\^2 - y\^2\)\
\)\/\(\((x - 1)\)\^2 + y\^2\)\)\)\)}]],
  " "
}], "Text"],

Cell[TextData[{
  "\n\nWe substitute the real and imaginary parts,  ",
  Cell[BoxData[
      RowBox[{"u", "=", 
        RowBox[{
          RowBox[{"u", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], 
          "=", \(\(\((x - 1)\)\^2 + \((y - 1)\)\^2 - 1\)\/\(\((x - 1)\)\^2 + 
                y\^2\)\)}]}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{"v", "=", 
        RowBox[{
          RowBox[{"v", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], 
          "=", \(\(\(\ \)\(1 - x\^2 - y\^2\)\)\/\(\((x - 1)\)\^2 + 
                y\^2\)\)}]}]]],
  "  from this equation, into Equation ",
  StyleBox[" (11-29)",
    FontColor->RGBColor[0, 0, 1]],
  " to obtain the desired solution:   \n\n \t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Phi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
        "  ", \(\(80\/\[Pi]\) 
          
          Arctan \((\(1 - x\^2 - y\^2\)\/\(\((x - 1)\)\^2 + \((y - 1)\)\^2 - \
1\))\)\)}]],
    AspectRatioFixed->True],
  ".  \n\nThe level curve  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPhi]", 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], "=", "\[Alpha]"}]],
    AspectRatioFixed->True],
  "  in the upper half-plane is a ray emanating from the origin, and the \
preimage  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Phi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "\[Alpha]"}]],
    AspectRatioFixed->True],
  "  in the unit disk is an arc of a circle that passes through the points  \
",
  Cell[BoxData[
      RowBox[{"z", "=", 
        RowBox[{
          RowBox[{"1", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "z"}], "=", 
          "\[ImaginaryI]"}]}]]],
  ".  Several level curves are illustrated in Figure 11.38."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.38",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/electrostatics/\
ElectrostaticsFigures/mat1138.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The potentials  ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{"\[CapitalPhi]", 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Construct the solution with a conformal mapping.  This example is similar to \
Example 11.8.\
\>", "Text"],

Cell[BoxData[{
    \(\(u = \(U = \(v = \(V = \(w = \(W = \(x = \(X = \(y = \(Y = \(z = \(Z = 
                              0\)\)\)\)\)\)\)\)\)\)\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(Remove[u, U, v, V, w, W, x, X, y, Y, z, 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, \[Phi]];\)\ \), "\n", 
    \(\(f[
          z_]\  = \ \(\((1\  - \ \[ImaginaryI])\) \((z\  - \ \[ImaginaryI])\)\
\)\/\(z\  - \ 1\);\)\ \), "\n", 
    \(\(W\  = \ \ ComplexExpand[f[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(U\  = \ 
        Together[
          ComplexExpand[Re[W], 
            TargetFunctions \[Rule] {Re, Im}]];\)\ \), "\n", 
    \(\(\(V\  = \ 
          Together[
            ComplexExpand[Im[W], 
              TargetFunctions \[Rule] {Re, Im}]];\)\ ;\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ 80\/\[Pi]\ ArcTan[V\/U];\)\ \), "\n", 
    \(\(Print["\<w = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<w = u + \[ImaginaryI] v = \>", 
        U\  + \ \[ImaginaryI]\ V];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\[Phi][x,y] = \!\(80\/\[Pi]\) \
ArcTan[\!\(v\/u\)]\>\""];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the temperature.  For computational purposes we \
use the following formula   ",
  Cell[BoxData[
      \(80\/\[Pi]\ ArcTan[\(1\  - \ x\^2\  - \ y\^2\)\/\(1\  - \ 2\ x\  + \ x\
\^2\  - \ 2\ y\  + \ y\^2\)] = \(-80\)\/\[Pi]\ \((\(-\[Pi]\)\/2 + 
              ArcTan[1 - x\^2 - y\^2, 1 - 2\ x + x\^2 - 2\ y + y\^2])\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(\[Phi][x_, 
          y_] = \(-80\)\/\[Pi]\ \((\(-\[Pi]\)\/2 + 
              ArcTan[1 - x\^2 - y\^2, 
                1 - 2\ x + x\^2 - 2\ y + 
                  y\^2])\);\)\ \), "\[IndentingNewLine]", 
    \(\(cont\  = \ Table[10  k, {k, 0, 8}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Phi][x, y], {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Contours\  \[Rule] \ cont, PlotPoints \[Rule] 60, 
        AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, y]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[Phi][x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The following commands will graph the contours as parametric curves.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(u = \(v = \(w = \(X = \(Y = \(z = \(Z = 0\)\)\)\)\)\); \ 
    Remove[u, v, w, X, Y, z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[F];\)\ \), "\n", 
    \(\(F[
          z_]\  = \ \(\((1\  - \ \[ImaginaryI])\) \((z\  - \ \[ImaginaryI])\)\
\)\/\(z\  - \ 1\);\)\ \), "\n", 
    \(\(solset\  = \ Solve[w\  \[Equal] \ F[z], z];\)\ \), "\n", 
    \(\(Z[u_, v_]\  = \ 
        ReplaceAll[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), 
          w \[Rule] u\  + \ \[ImaginaryI]\ v];\)\ \), "\n", 
    \(\(X[u_, v_]\  = \ 
        Together[
          ComplexExpand[
            Re[Z[u, v]], \n\ \ \ \ \ \ \ \ \ \ \ TargetFunctions \[Rule] {Re, \
\ Im}]];\)\ \), "\n", 
    \(\(Y[u_, v_]\  = \ 
        Together[
          ComplexExpand[
            Im[Z[u, v]], \n\ \ \ \ \ \ \ \ \ \ \ TargetFunctions \[Rule] {Re, \
\ Im}]];\)\ \), "\n", 
    \(\(Print["\<w = \>", F[z]];\)\ \), "\n", 
    \(\(Print["\<z = \>", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(Print["\<Z = \>", Z[u, v]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<X = \>", X[u, v]];\)\ \), "\n", 
    \(\(Print["\<Y = \>", Y[u, v]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(n\  = \ 8;\)\ \), "\n", 
    \(\(Clear[k];\)\ \), "\[IndentingNewLine]", 
    \(\(x[r_]\  = \ 
        Simplify[
          X[r\ Cos[\(k\ \[Pi]\)\/n], r\ Sin[\(k\ \[Pi]\)\/n]]];\)\ \), "\n", 
    \(\(y[r_]\  = \ 
        Simplify[
          Y[r\ Cos[\(k\ \[Pi]\)\/n], r\ Sin[\(k\ \[Pi]\)\/n]]];\)\ \), "\n", 
    \(\(eqns\  = \ N[Table[{x[r], y[r]}, {k, 0, n, 2}]];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns], {r, 0.05, 40}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(eqns\  = \ N[Table[{x[r], y[r]}, {k, 1, n - 1, 2}]];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns], {r, 0.05, 40}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, 
        PlotRange \[Rule] {{\(-1.1\), 1.1}, {\(-1.1\), 1.1}}, 
        AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Hence the electrical potential  ",
  Cell[BoxData[
      \(\[Phi][x, y] = 
        80\/\[Pi]\ ArcTan[\(1 - x\^2 - y\^2\)\/\(1 - 2\ x + x\^2 - 2\ y + \
y\^2\)]\)]],
  "  is harmonic in the disk |z| < 1 and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.24.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the complex potential for an ideal fluid flowing from left to right \
across the complex plane and around the unit circle  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006F0000UB000`400?l0
0000o`00003oo`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00
o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00R`3oool40000
03X0oooo1@00000g0?ooo`800000>P3oool5000003T0oooo1000000C0?oo
o`00R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03H0
oooo00@000000?ooo`3oool00000>`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo01@0oooo002<0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool0=P3oool010000000oooo0?ooo`00000k0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool04`3oool008D0
oooo100000040?ooo`030000003oool0oooo03<0oooo100000040?ooo`03
0000003oool0oooo03H0oooo00@000000?ooo`3oool00000>`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo0180oooo002;0?ooo`04
0000003oool0oooo000003`0oooo00<000000?ooo`3oool0=P3oool01000
0000oooo0?ooo`00000k0?ooo`030000003oool0oooo03T0oooo00@00000
0?ooo`3oool000004`3oool008`0oooo0P00000l0?ooo`800000>@3oool2
000003/0oooo0P00000l0?ooo`800000503oool00?l0ooooU`3oool00?l0
ooooU`3oool00?l0ooooU`3oool00?l0ooooU`3oool00?l0ooooU`3oool0
0?l0ooooU`3oool007h0oooo0P0000050?ooool000000`00000?0?ooo`00
O@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool007d0oooo
00@000000?ooo`3oool00000103oool2000000<0oooo?P00001l0?oooch0
00000`3oool2000000l0oooo001m0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P3oooln003oQ`030000003o0000o`0007P0
o`0000<00000003oQ`00ohL0>`00ohL50?ooo`030000003oool0oooo00d0
oooo001m0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3oooln003oQ`030000003o0000o`0007P0o`0000<00000003oQ`00
ohL0>`00ohL50?ooo`030000003oool0oooo00d0oooo001n0?ooo`800000
1@3oool00`000000oooo0?ooo`020?oooch00?n700<000000?l0003o0000
N03o00000`0000000?n7003oQ`0k003oQ`D0oooo00<000000?ooo`3oool0
3@3oool008D0oooo00<000000?ooo`3oool00P3oooln003oQ`030000003o
0000o`0007P0o`0000<00000003oQ`00ohL0>`00ohL50?ooo`030000003o
ool0oooo00d0oooo00250?ooo`030000003oool0oooo0080oooo?P00ohL0
0`000000o`000?l0001h0?l0000300000000ohL00?n703/00?n71@3oool0
0`000000oooo0?ooo`0=0?ooo`00Q@3oool2000000<0oooo?P00ohL00`00
0000o`000?l0001h0?l0000300000000ohL00?n703/00?n7103oool20000
00l0oooo00250?ooo`030000003oool0oooo0080oooo?P00ohL00`000000
o`000?l0001h0?l0000300000000ohL00?n703/00?n71@3oool00`000000
oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooch00?n7
00<000000?l0003o0000N03o00000`0000000?n7003oQ`0k003oQ`D0oooo
00<000000?ooo`3oool03@3oool008D0oooo00<000000?ooo`3oool00P3o
ooln003oQ`030000003o0000o`0007P0o`0000<00000003oQ`00ohL0>`00
ohL50?ooo`030000003oool0oooo00d0oooo00250?ooo`030000003oool0
oooo0080oooo?P00ohL00`000000o`000?l0001h0?l0000300000000ohL0
0?n703/00?n71@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?ooocl00?n700<000000?l0003o0000M`3o00000`00
00000?n7003oQ`0k003oQ`D0oooo00<000000?ooo`3oool03@3oool008D0
oooo00<000000?ooo`3oool00P3ooolo003oQ`030000003o0000o`0007H0
o`0000<00000003oQ`00ohL0?000ohL50?ooo`030000003oool0oooo00d0
oooo00250?ooo`8000000`3ooolo003oQ`030000003o0000o`0007H0o`00
00<00000003oQ`00ohL0?000ohL40?ooo`8000003`3oool008D0oooo00<0
00000?ooo`3oool00P3ooolo003oQ`030000003o0000o`0007H0o`0000<0
0000003oQ`00ohL0?000ohL50?ooo`030000003oool0oooo00d0oooo0025
0?ooo`030000003oool0oooo0080oooo?`00ohL00`000000o`000?l0001f
0?l0000300000000ohL00?n703`00?n71@3oool00`000000oooo0?ooo`0=
0?ooo`00Q@3oool00`000000oooo0?ooo`020?oood000?n700<000000?l0
003o0000M03o00000`0000000?n7003oQ`0m003oQ`D0oooo00<000000?oo
o`3oool03@3oool008D0oooo00<000000?ooo`3oool00P3oool9000003L0
0?n700<000000?l0003o0000M03o00000`0000000?n7003oQ`0e003oQ`T0
0000103oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo
0?ooo`020?ooo`T00?ol2000000_003oQ`030000003o0000o`0007@0o`00
00<00000003oQ`00ohL0;@00ohL8000000P00?ol1@3oool00`000000oooo
0?ooo`0=0?ooo`00Q@3oool2000000<0oooo4000oo`6000002/00?n700<0
00000?l0003o0000LP3o0002000002X00?n71P00000?003oo0@0oooo0P00
000?0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooaH00?ol1@00000V
003oQ`030000003o0000o`000780o`0000<00000003oQ`00ohL09000ohL5
000001D00?ol1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?oooa/00?ol1000000R003oQ`030000003o0000o`00
0780o`0000<00000003oQ`00ohL08000ohL4000001X00?ol1@3oool00`00
0000oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooal0
0?ol0`00000P003oQ`030000003o0000o`000740o`0000<00000003oQ`00
ohL07@00ohL3000001h00?ol1@3oool00`000000oooo0?ooo`0=0?ooo`00
Q@3oool00`000000oooo0?ooo`020?ooob800?ol0`00000M003oQ`030000
003o0000o`000700o`0000<00000003oQ`00ohL06`00ohL3000002400?ol
1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo0?oo
o`020?ooob@00?ol0`00000K003oQ`800000L@3o00000`0000000?n7003o
Q`0I003oQ`<000008`00oo`50?ooo`030000003oool0oooo00d0oooo0025
0?ooo`8000000`3ooolW003oo08000006P00ohL00`000000o`000?l0001^
0?l0000300000000ohL00?n701P00?n70P00000V003oo0@0oooo0P00000?
0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooobT00?ol0P00000H003o
Q`030000003o0000o`0006h0o`0000<00000003oQ`00ohL05P00ohL20000
02P00?ol1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`000000
oooo0?ooo`020?ooob/00?ol00<00000003oQ`00ohL05P00ohL00`000000
o`000?l0001/0?l0000300000000ohL00?n701H00?n700<00000003oo000
oo`0:000oo`50?ooo`030000003oool0oooo00d0oooo00250?ooo`030000
003oool0oooo0080oooo;000oo`3000001D00?n700<000000?l0003o0000
K03o00000`0000000?n7003oQ`0C003oQ`<00000:`00oo`50?ooo`030000
003oool0oooo00d0oooo001b0?ooo`800000103oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo0080oooo;P00oo`2000001D00?n700<0
00000?l0003o0000JP3o00000`0000000?n7003oQ`0C003oQ`800000;@00
oo`50?ooo`030000003oool0oooo00d0oooo001a0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`020?oooc000?ol00<00000003oQ`00ohL04P00ohL2000006/0o`00
00<00000003oQ`00ohL04P00ohL00`0000000?ol003oo00]003oo0D0oooo
00<000000?ooo`3oool03@3oool00740oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`020?ooo`8000000`3ooola003oo0800000
4`00ohL00`000000o`000?l0001X0?l0000300000000ohL00?n701400?n7
0P00000`003oo0@0oooo0P00000?0?ooo`00L@3oool010000000oooo0?oo
o`0000090?ooo`8000001@3oool00`000000oooo0?ooo`020?oooc<00?ol
00<00000003oQ`00ohL04000ohL00`000000o`000?l0001X0?l000030000
0000ohL00?n701000?n700<00000003oo000oo`0<000oo`50?ooo`030000
003oool0oooo00d0oooo001a0?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`L00000
;@00oo`2000001400?n700<000000?l0003o0000IP3o00000`0000000?n7
003oQ`0?003oQ`800000;P00oo`6000000@0oooo00<000000?ooo`3oool0
3@3oool00780oooo0P00000:0?ooo`<00000103oool00`000000oooo0?oo
o`020?ooo`H008ko1@00000Z003oo08000004@00ohL00`000000o`000?l0
001T0?l0000300000000ohL00?n700l00?n70P00000Z003oo0D000001@00
S_l50?ooo`030000003oool0oooo00d0oooo00250?ooo`030000003oool0
oooo0080oooo2`00S_l5000002L00?ol00<00000003oQ`00ohL03P00ohL0
0`000000o`000?l0001T0?l0000300000000ohL00?n700h00?n70P00000V
003oo0D000002P00S_l50?ooo`030000003oool0oooo00d0oooo00250?oo
o`030000003oool0oooo0080oooo4000S_l5000002<00?ol00<00000003o
Q`00ohL03P00ohL00`000000o`000?l0001R0?l0000300000000ohL00?n7
00h00?n700<00000003oo000oo`08@00oo`5000000l008ko1@3oool00`00
0000oooo0?ooo`0=0?ooo`00Q@3oool2000000<0oooo5@00S_l300000240
0?ol00<00000003oQ`00ohL03P00ohL00`000000o`000?l0001Q0?l00003
00000000ohL00?n700d00?n700<00000003oo000oo`07`00oo`3000001@0
08ko103oool2000000l0oooo00250?ooo`030000003oool0oooo0080oooo
6000S_l3000001l00?ol0P00000>003oQ`800000H03o0002000000h00?n7
0P00000O003oo0<000005`00S_l50?ooo`030000003oool0oooo00d0oooo
00250?ooo`030000003oool0oooo0080oooo6`00S_l4000001d00?ol00<0
0000003oQ`00ohL03@00ohL00`000000o`000?l0001M0?l0000300000000
ohL00?n700`00?n70P00000L003oo0@000006P00S_l50?ooo`030000003o
ool0oooo00d0oooo00250?ooo`030000003oool0oooo0080oooo7`00S_l0
0`0000000?ol003oo00K003oo00300000000ohL00?n700`00?n700<00000
0?l0003o0000G03o00000`0000000?n7003oQ`0=003oQ`0300000000oo`0
0?ol01X00?ol00<00000002>o`00S_l07000S_l50?ooo`030000003oool0
oooo00d0oooo00250?ooo`030000003oool0oooo0080oooo8000S_l40000
01T00?ol0P00000>003oQ`030000003o0000o`0005X0o`0000<00000003o
Q`00ohL03@00ohL00`0000000?ol003oo00G003oo0@000007`00S_l50?oo
o`030000003oool0oooo00d0oooo00250?ooo`030000003oool0oooo0080
oooo8`00S_l2000001T00?ol0P00000>003oQ`030000003o0000o`0005P0
o`0000<00000003oQ`00ohL03000ohL2000001T00?ol0P00000R002>o`D0
oooo00<000000?ooo`3oool03@3oool008D0oooo00<000000?ooo`3oool0
0P3ooolU002>o`<000005`00oo`2000000d00?n70P00001H0?l000800000
3@00ohL2000001L00?ol0`00000T002>o`D0oooo00<000000?ooo`3oool0
3@3oool008D0oooo0P0000030?ooobP008ko0P00000G003oo00300000000
ohL00?n700`00?n700<000000?l0003o0000E03o0002000000d00?n70P00
000F003oo08000009`00S_l40?ooo`8000003`3oool008D0oooo00<00000
0?ooo`3oool00P3ooolZ002>o`8000005P00oo`00`0000000?n7003oQ`0<
003oQ`030000003o0000o`000580o`0000<00000003oQ`00ohL03000ohL0
0`0000000?ol003oo00D003oo0800000:@00S_l50?ooo`030000003oool0
oooo00d0oooo00250?ooo`030000003oool0oooo0080oooo;000S_l20000
01D00?ol0P00000=003oQ`030000003o0000o`000500o`0000<00000003o
Q`00ohL02`00ohL2000001D00?ol0P00000[002>o`D0oooo00<000000?oo
o`3oool03@3oool008D0oooo00<000000?ooo`3oool00P3oool^002>o`03
00000000oo`00?ol01<00?ol00<00000003oQ`00ohL03000ohL00`000000
o`000?l0001>0?l0000300000000ohL00?n700`00?n700<00000003oo000
oo`04`00oo`00`00000008ko002>o`0[002>o`D0oooo00<000000?ooo`3o
ool03@3oool008D0oooo00<000000?ooo`3oool00P3oool5000002X008ko
0`00000C003oo08000003@00ohL2000004`0o`000P00000=003oQ`800000
4`00oo`3000002X008ko1@0000040?ooo`030000003oool0oooo00d0oooo
00250?ooo`030000003oool0oooo0080oooo1@006Ol4000002T008ko00<0
0000003oo000oo`04P00oo`00`0000000?n7003oQ`0<003oQ`030000003o
0000o`0004P0o`0000<00000003oQ`00ohL03000ohL00`0000000?ol003o
o00B003oo00300000000S_l008ko02L008ko10000004000Io`D0oooo00<0
00000?ooo`3oool03@3oool008D0oooo0P0000030?ooo`T001Wo1@00000U
002>o`8000004`00oo`2000000`00?n70P0000180?l0008000003000ohL2
000001<00?ol0P00000U002>o`D0000020006Ol40?ooo`8000003`3oool0
08D0oooo00<000000?ooo`3oool00P3oool>000Io`<000009000S_l00`00
00000?ol003oo00B003oo00300000000ohL00?n700/00?n700<000000?l0
003o0000A03o00000`0000000?n7003oQ`0<003oQ`0300000000oo`00?ol
01400?ol00<00000002>o`00S_l08P00S_l3000000d001Wo1@3oool00`00
0000oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooa40
01Wo100000000`00S_l00000002>o`0N002>o`<000004P00oo`00`000000
0?n7003oQ`0;003oQ`030000003o0000o`000480o`0000<00000003oQ`00
ohL02`00ohL2000001400?ol0`00000P002>o`D0000040006Ol50?ooo`03
0000003oool0oooo00d0oooo00250?ooo`030000003oool0oooo0080oooo
5@006Ol4000001l008ko0`00000A003oo08000003000ohL3000003h0o`00
0`00000<003oQ`8000004@00oo`3000001l008ko1000000D000Io`D0oooo
00<000000?ooo`3oool03@3oool008D0oooo00<000000?ooo`3oool00P3o
oolI000Io`<000007P00S_l2000001800?ol00<00000003oQ`00ohL03000
ohL00`000000o`000?l0000j0?l0000300000000ohL00?n700`00?n700<0
0000003oo000oo`04000oo`2000001h008ko0`00000H000Io`D0oooo00<0
00000?ooo`3oool03@3oool008D0oooo00<000000?ooo`3oool00P3ooolL
000Io`<000007@00S_l2000001400?ol0P00000=003oQ`800000>03o0002
000000h00?n700<00000003oo000oo`03`00oo`3000001`008ko0`00000K
000Io`D0oooo00<000000?ooo`3oool03@3oool008D0oooo0P0000030?oo
oal001Wo0`00000L002>o`8000004@00oo`00`0000000?n7003oQ`0<003o
Q`<00000<P3o0003000000h00?n70P00000@003oo08000007000S_l30000
01h001Wo103oool2000000l0oooo00250?ooo`030000003oool0oooo0080
oooo8P006Ol3000001X008ko0`00000@003oo08000003P00ohL200000300
o`000P00000>003oQ`8000004@00oo`2000001X008ko0`00000Q000Io`D0
oooo00<000000?ooo`3oool03@3oool008D0oooo00<000000?ooo`3oool0
0P3ooolT000Io`@000006@00S_l2000001400?ol0P00000>003oQ`<00000
:P3o0003000000h00?n70`00000@003oo08000006P00S_l3000002<001Wo
1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo0?oo
o`020?ooobP001Wo0P00000I002>o`8000004@00oo`2000000l00?n70`00
000T0?l000<000004000ohL00`0000000?ol003oo00?003oo08000006@00
S_l3000002H001Wo1@3oool00`000000oooo0?ooo`0=0?ooo`00O@3oool5
000000<0oooo00<000000?ooo`3oool00P3ooolZ000Io`8000006@00S_l2
000001400?ol00<00000003oQ`00ohL03`00ohL4000001`0o`001000000A
003oQ`8000004@00oo`00`00000008ko002>o`0G002>o`800000:@006Ol5
0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool/000Io`<000006000S_l00`00
00000?ol003oo00?003oo0<000004P00ohL500000180o`001@00000B003o
Q`<000004@00oo`2000001L008ko0`00000[000Io`D0oooo00<000000?oo
o`3oool03@3oool007l0oooo00<000000?ooo`3oool00`3oool2000000<0
oooo0P00000]000Io`8000005`00S_l2000001800?ol0P00000E003oQa80
00005@00ohL2000001800?ol0P00000G002>o`800000;@006Ol2000000<0
oooo0P00000?0?ooo`00O`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo0P1J0?l5000002X001Wo0`00000F002>o`800000
4P00oo`3000003H00?n71000000A003oo08000005P00S_l3000002X001Wo
1@0000000`1J0?l0oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo
001o0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool705X0o`D000009`006Ol3000001H008ko0P00000B003oo0<00000<P00
ohL3000001800?ol0P00000F002>o`<000009`006Ol5000000H0FP3o1@3o
ool00`000000oooo0?ooo`0=0?ooo`00OP3oool2000000D0oooo00<00000
0?ooo`3oool00P3oool<05X0o`@000009P006Ol2000001H008ko0`00000B
003oo0<00000;000ohL3000001<00?ol0P00000G002>o`03000000006Ol0
01Wo02@001Wo1000000;05X0o`D0oooo00<000000?ooo`3oool03@3oool0
08D0oooo00<000000?ooo`3oool00P3oool@05X0o`D000008`006Ol00`00
000008ko002>o`0F002>o`0300000000oo`00?ol01800?ol0`00000V003o
Q`<000005000oo`2000001L008ko0P00000R000Io`D000003`1J0?l50?oo
o`030000003oool0oooo00d0oooo00250?ooo`030000003oool0oooo0080
oooo5@1J0?l40000020001Wo1000000E002>o`<000005000oo`7000001P0
0?n71`00000D003oo0<000005@00S_l40000020001Wo1@00000C05X0o`D0
oooo00<000000?ooo`3oool03@3oool008D0oooo0P0000030?oooaT0FP3o
0`00000Q000Io`8000005@00S_l3000001P00?ol2@000008003oQ`T00000
6000oo`3000001D008ko0P00000Q000Io`<00000601J0?l40?ooo`800000
3`3oool008D0oooo00<000000?ooo`3oool00P3ooolL05X0o`<000008000
6Ol3000001D008ko0`00000N003oo0P000007P00oo`3000001H008ko0P00
000P000Io`<000006`1J0?l50?ooo`030000003oool0oooo00d0oooo0025
0?ooo`030000003oool0oooo0080oooo7`1J0?l30000020001Wo00<00000
002>o`00S_l05@00S_l2000004000?ol0P00000G002>o`8000007`006Ol3
000001h0FP3o1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?ooob80FP3o0`00000N000Io`@000005@00S_l30000
03X00?ol0`00000F002>o`<000007P006Ol300000240FP3o1@3oool00`00
0000oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooobD0
FP3o1000000M000Io`<000005P00S_l5000003000?ol1@00000F002>o`<0
00007@006Ol4000002@0FP3o1@3oool00`000000oooo0?ooo`0=0?ooo`00
Q@3oool00`000000oooo0?ooo`020?ooobT0FP3o0`00000M000Io`<00000
5`00S_l5000002P00?ol1@00000H002>o`8000007@006Ol3000002P0FP3o
1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool2000000<0oooo;01J
0?l3000001d001Wo00<00000002>o`00S_l06@00S_l5000001h00?ol1@00
000K002>o`80000070006Ol3000002/0FP3o103oool2000000l0oooo0025
0?ooo`030000003oool0oooo0080oooo;`1J0?l2000001`001Wo1000000L
002>o`P000003P00oo`8000001d008ko0`00000L000Io`800000;P1J0?l5
0?ooo`030000003oool0oooo00d0oooo00250?ooo`030000003oool0oooo
0080oooo1000000]05X0o`<000007@006Ol30000024008ko3P00000Q002>
o`@0000070006Ol3000002d0FP3o100000040?ooo`030000003oool0oooo
00d0oooo00250?ooo`030000003oool0oooo0080oooo103?0?l5000002/0
FP3o1000000K000Io`@00000BP00S_l4000001/001Wo1000000[05X0o`D0
00000`3?0?l50?ooo`030000003oool0oooo00d0oooo00250?ooo`030000
003oool0oooo0080oooo2@3?0?l5000002X0FP3o0`00000K000Io`@00000
A000S_l4000001/001Wo0`00000Z05X0o`D00000203?0?l50?ooo`030000
003oool0oooo00d0oooo00250?ooo`030000003oool0oooo0080oooo3P3?
0?l3000002X0FP3o0P00000M000Io`@00000?000S_l4000001d001Wo0P00
000Z05X0o`<000003@3?0?l50?ooo`030000003oool0oooo00d0oooo0025
0?ooo`030000003oool0oooo0080oooo4@3?0?l5000002L0FP3o0`00000N
000Io`<00000=P00S_l3000001h001Wo0`00000W05X0o`D00000403?0?l5
0?ooo`030000003oool0oooo00d0oooo00250?ooo`8000000`3ooolF0<l0
o`D000009@1J0?l3000001h001Wo1@00000/002>o`D000007P006Ol30000
02D0FP3o1@00000E0<l0o`@0oooo0P00000?0?ooo`00Q@3oool00`000000
oooo0?ooo`020?oooa/0c`3o1000000T05X0o`@000007`006Ol8000001`0
08ko2000000O000Io`@00000901J0?l4000001X0c`3o1@3oool00`000000
oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooal0c`3o
0`00000U05X0o`<000008`006OlN000002<001Wo0`00000U05X0o`<00000
7P3?0?l50?ooo`030000003oool0oooo00d0oooo00250?ooo`030000003o
ool0oooo0080oooo8P3?0?l5000002<0FP3o0`00001N000Io`<000008`1J
0?l500000240c`3o1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooobL0c`3o0`00000S05X0o`@00000E`006Ol3
000002<0FP3o0`00000V0<l0o`D0oooo00<000000?ooo`3oool03@3oool0
08D0oooo00<000000?ooo`3oool00P3ooolZ0<l0o`@000008`1J0?l30000
050001Wo1000000R05X0o`@00000:@3?0?l50?ooo`030000003oool0oooo
00d0oooo00250?ooo`8000000`3oool^0<l0o`@000008P1J0?l5000004H0
01Wo1@00000R05X0o`@00000;@3?0?l40?ooo`8000003`3oool008D0oooo
00<000000?ooo`3oool00P3ooolb0<l0o`<00000901J0?l5000003`001Wo
1@00000T05X0o`<00000<@3?0?l50?ooo`030000003oool0oooo00d0oooo
00250?ooo`030000003oool0oooo0080oooo0P00000c0<l0o`@000009@1J
0?l50000038001Wo1@00000U05X0o`@00000<`3?0?l2000000@0oooo00<0
00000?ooo`3oool03@3oool008D0oooo00<000000?ooo`3oool00P3oool2
0?l0^`D00000<P3?0?l4000002H0FP3o1P00000V000Io`H000009`1J0?l3
00000380c`3o1@0000000`3o0;/0oooo0?ooo`030?ooo`030000003oool0
oooo00d0oooo001a0?ooo`D000000P3oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo0080oooo1`3o0;/500000340c`3o0`00000Y05X0
o``000003P006Ol<000002T0FP3o1000000`0<l0o`D000001P3o0;/50?oo
o`030000003oool0oooo00d0oooo001c0?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oo
o``0o`2k1`00000]0<l0o`@00000<@1J0?l>00000340FP3o1000000]0<l0
o`L000002`3o0;/50?ooo`030000003oool0oooo00d0oooo001c0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool2000000<0
oooo4`3o0;/5000002`0c`3o1000001X05X0o`@00000;03?0?l500000180
o`2k103oool2000000l0oooo001c0?ooo`030000003oool0oooo00P0oooo
0P0000050?ooo`030000003oool0oooo0080oooo603o0;/3000002d0c`3o
1000001Q05X0o`<00000;@3?0?l3000001L0o`2k1@3oool00`000000oooo
0?ooo`0=0?ooo`00L`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3ooolK0?l0^`D00000;03?
0?l5000005L0FP3o1@00000[0<l0o`D000006P3o0;/50?ooo`030000003o
ool0oooo00d0oooo001b0?ooo`8000002P3oool3000000@0oooo00<00000
0?ooo`3oool00P3ooolP0?l0^`D00000;03?0?l4000004h0FP3o1@00000[
0<l0o`D000007`3o0;/50?ooo`030000003oool0oooo00d0oooo00250?oo
o`030000003oool0oooo0080oooo9@3o0;/5000002/0c`3o1P00001205X0
o`H00000:`3?0?l5000002@0o`2k1@3oool00`000000oooo0?ooo`0=0?oo
o`00Q@3oool00`000000oooo0?ooo`020?ooobX0o`2k1000000]0<l0o`H0
0000=P1J0?l6000002d0c`3o1000000Y0?l0^`D0oooo00<000000?ooo`3o
ool03@3oool008D0oooo0P0000030?ooobh0o`2k1@00000^0<l0o`P00000
9P1J0?l8000002h0c`3o1@00000]0?l0^`@0oooo0P00000?0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?oooc<0o`2k1@00000a0<l0obH00000<P3?
0?l400000380o`2k1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooocP0o`2k0`0000220<l0o`@00000=P3o0;/5
0?ooo`030000003oool0oooo00d0oooo00250?ooo`030000003oool0oooo
0080oooo0`00000h0?l0^`H00000MP3?0?l6000003P0o`2k0`0000040?oo
o`030000003oool0oooo00d0oooo00250?ooo`030000003oool0oooo0080
oooo0`3o0006000003P0o`2k1000001^0<l0o`D00000=`3o0;/600000080
o`001@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo
0?ooo`020?ooo`T0o`001`00000e0?l0^`D00000I03?0?l5000003D0o`2k
1`0000080?l000D0oooo00<000000?ooo`3oool03@3oool008D0oooo0P00
00030?oooa00o`001@00000e0?l0^`L00000E`3?0?l6000003D0o`2k1@00
000?0?l000@0oooo0P00000?0?ooo`00Q@3oool00`000000oooo0?ooo`02
0?oooaD0o`001P00000f0?l0^`@00000CP3?0?l5000003D0o`2k1P00000D
0?l000D0oooo00<000000?ooo`3oool03@3oool008D0oooo00<000000?oo
o`3oool00P3ooolK0?l000D00000=@3o0;/9000003`0c`3o2@00000e0?l0
^`D000006P3o00050?ooo`030000003oool0oooo00d0oooo00250?ooo`03
0000003oool0oooo0080oooo803o0005000003T0o`2k2000000/0<l0o`P0
0000>@3o0;/5000001l0o`001@3oool00`000000oooo0?ooo`0=0?ooo`00
Q@3oool00`000000oooo0?ooo`020?ooobD0o`001@00000l0?l0^a800000
203?0?lB000003`0o`2k1@00000T0?l000D0oooo00<000000?ooo`3oool0
3@3oool008D0oooo00<000000?ooo`3oool00P3ooolZ0?l000L00000A`3o
0;/8000004L0o`2k1`00000Y0?l000D0oooo00<000000?ooo`3oool03@3o
ool008D0oooo00<000000?ooo`3oool00P3ooola0?l000D00000S03o0;/5
00000300o`001@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool20000
00<0oooo=P3o000500000880o`2k1@00000e0?l000@0oooo0P00000?0?oo
o`00Q@3oool00`000000oooo0?ooo`020?oooc/0o`001`00001e0?l0^`H0
0000>P3o00050?ooo`030000003oool0oooo00d0oooo00250?ooo`030000
003oool0oooo0080oooo@P3o0005000006/0o`2k1@0000100?l000D0oooo
00<000000?ooo`3oool03@3oool008D0oooo00<000000?ooo`3oool00P3o
oom70?l000H00000GP3o0;/7000004D0o`001@3oool00`000000oooo0?oo
o`0=0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooodd0o`002000001>
0?l0^`P00000C03o00050?ooo`030000003oool0oooo00d0oooo00250?oo
o`030000003oool0oooo0080ooooE@3o0009000003`0o`2k2@00001D0?l0
00D0oooo00<000000?ooo`3oool03@3oool008D0oooo0P0000030?oooeh0
o`002`00000V0?l0^`/00000G@3o00040?ooo`8000003`3oool008D0oooo
00<000000?ooo`3oool00P3ooomY0?l002H00000J03o00050?ooo`030000
003oool0oooo00d0oooo00250?ooo`030000003oool0oooo0080oooom`3o
00050?ooo`030000003oool0oooo00d0oooo00250?ooo`030000003oool0
oooo0080oooom`3o00050?ooo`030000003oool0oooo00d0oooo001m0?oo
o`@00000103oool00`000000oooo0?ooo`020?ooooL0o`001@3oool00`00
0000oooo0?ooo`0=0?ooo`00O@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooom`3o00050?ooo`030000003oool0oooo00d0
oooo001n0?ooo`030000003oool0oooo00@0oooo0P0000030?ooooL0o`00
103oool2000000l0oooo001o0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3o
ool007d0oooo00@000000?ooo`3oool00000103ooooo000000<000003`3o
ool007h0oooo0P00003o0?oooaL0oooo003o0?oooiL0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{406, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  We use the fact that the conformal mapping  ",
  Cell[BoxData[
      \(w\  = \ \(S \((z)\)\  = \ z + 1\/z\)\)]],
  "  maps the domain  ",
  Cell[BoxData[
      \(D = {z : \(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)}\)]],
  "  one-to-one and onto the w plane slit along the segment  ",
  Cell[BoxData[
      \(\(-2\) \[LessEqual] u \[LessEqual] 2, v = 0\)]],
  ".  The complex potential for a uniform horizontal flow parallel to this \
slit in the w plane is  \n\n\t\t\t",
  Cell[BoxData[
      \(\(F\_1\) \((w)\)\  = \ A\ w\)]],
  ",  \n\nwhere ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " is a positive real number.  The stream function for the flow in the w \
plane is  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPsi]", 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], " ", "=", 
        " ", \(A\ v\)}]]],
  "  so that the slit lies along the streamline  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPsi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        "0"}]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe composite function  ",
  Cell[BoxData[
      \(\(F\_2\) \((z)\)\  = \ \(F\_1\) \((S \((z)\))\)\)]],
  "  determines the fluid flow in the domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", where the complex potential is \n\n\t\t\t",
  Cell[BoxData[
      \(\(F\_2\) \((z)\)\  = \ \(\(F\_1\) \((S \((z)\))\)\ \  = \ \ A\ \((z + 
                1\/z)\)\)\)]],
  ",  \n\nwhere ",
  Cell[BoxData[
      \(A > 0\)]],
  ".  We can use polar coordinates to express ",
  Cell[BoxData[
      \(\(F\_2\) \((z)\)\)]],
  " as \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\(F\_2\) \((z)\)\ \  = \ \ \(\(F\_2\) \((r\ \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Theta]\))\)\ \  = \ \ A\ \((r\ \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Theta]\) + 
                1\/\(r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\))\)\)\)\
\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ \((r\ cos\ \[Theta]\
\  + \ \[ImaginaryI]\ r\ sin\ \[Theta]\  + 
              1\/\(r\ cos\ \[Theta]\  + \ \[ImaginaryI]\ r\ sin\ \
\[Theta]\))\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ \((r\ cos\ \[Theta]\
\  + \ \[ImaginaryI]\ r\ sin\ \[Theta]\  + \(r\ cos\ \[Theta]\  - \ \ \
\[ImaginaryI]\ r\ sin\ \[Theta]\)\/\(\((r\ cos\[Theta]\  + \ \[ImaginaryI]\ r\
\ Sin\ \[Theta])\) \((r\ cos\ \[Theta]\  - \ \[ImaginaryI]\ r\ sin\ \[Theta])\
\)\))\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ \((r\ cos\ \[Theta]\
\  + \ \[ImaginaryI]\ r\ sin\ \[Theta]\  + \(r \((\ cos\ \[Theta]\  - \ \ \
\[ImaginaryI]\ r\ sin\ \[Theta])\)\)\/r\^2)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ \((r + 
                1\/r)\)\ cos\ \[Theta]\ \ \  + \ \ \(\(\[ImaginaryI]\)\(\ \
\)\(A\) \((r - 1\/r)\) \(sin\)\(\ \)\(\[Theta]\)\(\ \)\)\)\)\)}]]
}], "Text"],

Cell[TextData[{
  "The streamline   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{"r", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[Theta]"}], ")"}]}], "  ", "=", 
        "  ", \(A \((r - 1\/r)\) sin\ \[Theta]\ \  = \ \ 0\)}]]],
  "  consists of the rays \n\n\t\t\t",
  Cell[BoxData[
      \(r > 1, \[Theta] = 0\)]],
  "   and   ",
  Cell[BoxData[
      \(r > 1, \[Theta] = \[Pi]\)]],
  " \n\nalong the x axis and the curve  ",
  Cell[BoxData[
      \(r - 1\/r\  = \ 0\)]],
  ",  which is the unit circle  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\)\  = \ \(r\  = \ 1\)\)]],
  ".  Thus the unit circle can be considered as a boundary curve for the \
fluid flow."
}], "Text"],

Cell[TextData[{
  "\tThe approximation  ",
  Cell[BoxData[
      \(\(F\_2\) \((z)\)\  = \ \ A\ \((z + 
                1\/z)\)\ \  \[TildeTilde] \ \ A\ z\)]],
  "  is valid for large values of z, so we can approximate the flow with a \
uniform horizontal flow having speed  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"|", 
          RowBox[{
            StyleBox["V",
              FontWeight->"Bold"], 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "|"}], " ", "=", 
        " ", "A"}]]],
  "  at points that are distant from the origin.  The streamlines  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        "constant"}]]],
  "  and their images  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPsi]", 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], " ", "=", " ", 
        "constant"}]]],
  "  under the mapping ",
  Cell[BoxData[
      \(w = \(S \((z)\) = z + 1\/z\)\)]],
  " are illustrated in Figure 11.51."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.51",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/fluidflow/FluidFlowFigures/\
mat1151.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Fluid flow around a circle.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Consider the complex potential  ",
  Cell[BoxData[
      \(F[z] = A \((z + 1\/z)\)\)],
    AspectRatioFixed->True],
  " where  A  is a positive real number.  The velocity potential and stream \
function are given by  \n",
  Cell[BoxData[
      \(u[x, y] = A\ \((x + x\/\(x\^2 + y\^2\))\), \n
      v[x, y] = A\ \(\((y - y\/\(x\^2 + y\^2\))\)\(.\)\)\)]],
  "  \n",
  "Enter the complex potential and determine the velocity potential and \
stream function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(A = \(x = \(y = \(u = \(v = \(w = \(z = \(Z = 
                      0\)\)\)\)\)\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Remove[A, x, y, u, v, w, z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[cont, f, F, g, g1, g2, solset];\)\ \), "\n", 
    \(\(F[z_]\  = A \((z\  + \ 1\/z)\);\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ 
        ComplexExpand[Re[F[x + \[ImaginaryI]\ y]], 
          TargetFunctions \[Rule] {Re, Im}];\)\ \), "\n", 
    \(\(\[Psi][x_, y_]\  = 
        ComplexExpand[Im[F[x + \[ImaginaryI]\ y]], 
          TargetFunctions \[Rule] {Re, Im}];\)\ \), "\n", 
    \(\(Print["\<The  complex potential is   F[z] = \>", F[z]];\)\ \), "\n", 
    \(\(Print["\<F[z]  =  \[Phi][x,y] + \[ImaginaryI] \[Psi][x,y]\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<F[z]  =  (\>", \[Phi][x, 
          y], "\<) + \[ImaginaryI](\>", \ \[Psi][x, 
          y], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential is \[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\n", 
    \(\(Print["\<The   stream function  is \[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a plot of the stream function.\n\nFor illustration purposes, we \
choose A = 1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(A = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(cont\  = \ Table[0 + 0.2  k, {k, 0, 7}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Psi][x, y], {x, \(-2\), 2}, {y, 0, 
          2}, \[IndentingNewLine]Contours\  \[Rule] cont, 
        PlotPoints \[Rule] 55, 
        AspectRatio \[Rule] 1\/2, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, y]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[Psi][x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The inverse of  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \(z + 
              1\/z\ \ is\ \ z = \(g \((w)\) = \ \(w\  + \ \@\(w\^2\  - \ \
4\)\)\/2\)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_]\  = \ z\  + \ 1\/z;\)\ \), "\n", 
    \(\(solset\  = \ Solve[w \[Equal] f[z], z];\)\ \), "\n", 
    \(\(g[w_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Z\_0\  = \ PowerExpand[ExpandAll[g[f[z]]]];\)\ \), "\n", 
    \(\(Z\_1\  = 
        ReplaceAll[
          Z\_0\ , \@\(1 - 2\ z\^2 + z\^4\)\  \[Rule] \ \(-\((1 - 
                  z\^2)\)\)];\)\ \), "\n", 
    \(\(Z\_2\  = \ Together[Z\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_3 = MapAll[Factor, Z\_2];\)\ \), "\n", 
    \(\(Z\_4 = \(1 + z\^2 + \@\(\((\(-1\) + z)\)\^2\ \((1 + z)\)\^2\)\)\/\(2\ \
z\);\)\ \), "\n", 
    \(\(Z\_5 = PowerExpand[Z\_4];\)\ \), "\n", 
    \(\(Z\_6 = Simplify[Z\_5];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<g[w] = \>", g[w]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", Z\_0];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", Z\_1];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", Z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[f[z]] = \>", Z\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[f[z]] = \>", Z\_4];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[f[z]] = \>", Z\_5];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[f[z]] = \>", Z\_6];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<f[g[w]] = \>", f[g[w]]];\)\ \), "\n", 
    \(\(Print["\<f[g[w]] = \>", 
        Together[f[g[w]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Use conformal mapping  z = g(w)  to make an image of the flow.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(g1[w_]\  = \ \ \(w\  + \ \@\(w\^2\  - \ 4\)\)\/2;\)\ \), "\n", 
    \(\(g2[
          w_]\  = \ \ \(w\  - \ \@\(w\^2\  - \ 4\)\)\/2;\)\ \), "\
\[IndentingNewLine]", 
    \(\(Iden[w_]\  = \ w;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\ \(CartesianMap[Iden, {\(-3.2\), 3.2, 0.2}, {0, 1.2, 0.2}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[0, 2, 1]}, 
        PlotStyle \[Rule] {Blue, Red}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The horizontal flow in the z-plane.\>"];\)\ \), "\n", 
    \(\(gr1\  = \ 
        CartesianMap[g1, {0.00001, 3.20001, 0.2}, {0.00001, 1.20001, 0.2}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr2\  = \ 
        CartesianMap[
          g2, {\(-3.20001\), \(-0.00001\), 0.2}, {\ 0.00001, 1.20001, 0.2}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{\(-3\), 3}, {0, 2}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[0, 2, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The image flow across the complex plane,\>"];\)\ \), "\n", 
    \(\(Print["\<and around the unit circle |z| = 1,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<under the mapping z = g(w) = \>", 
        g1[w]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The velocity potential is \[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\n", 
    \(\(Print["\<The   stream function  is \[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.27.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Schwarz Christoffel formula to verify that  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ \((z\^2 - 1)\)\^\(1\/2\)\)\)]],
  "  maps the upper half plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  onto the upper half plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  "  slit along the line segment from  ",
  Cell[BoxData[
      \(\(\(w = \(0\ \ to\ \ w\_2 = \[ImaginaryI]\)\)\(\ \)\)\)]],
  ".  ",
  " (Use the principal square root throughout.)"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  If we choose  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_3 = 1\)}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \(-d\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_3 = d\)}]]],
  ",  then the formula\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(g' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\ \((z - x\_3)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z - \
\((\(-1\))\))\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - \
0)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\ \((z - 1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\)\
\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \
\((z)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\ \((z - \
1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\)\)}]],
  "\n\nwill determine a mapping ",
  Cell[BoxData[
      \(w\  = \ g \((z)\)\)]],
  " from the upper half-plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  onto the portion of the upper half-plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  "  that lies outside the triangle with vertices  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \(-d\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_3 = d\)}]]],
  "  as indicated in Figure 11.73(a).  If we let ",
  Cell[BoxData[
      \(d \[Rule] 0\)]],
  ",  then  ",
  Cell[BoxData[
      \(w\_1 \[Rule] \(0\ \ and\ \ w\_3 \[Rule] 0\)\)]],
  ", and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "\[Rule]", \(\[Pi]\/2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "\[Rule]", \(-\[Pi]\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "3"], "\[Rule]", \(\[Pi]\/2\)}]}]]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007l0000Nb000`400?l0
0000o`00003oo`3oooom0?ooo`00o`3oooom0?ooo`00o`3oooom0?ooo`00
o`3oooom0?ooo`00o`3oooom0?ooo`00o`3oooom0?ooo`00o`3oooom0?oo
o`00YP3oool400000440oooo1@0000220?ooo`D00000@03oool400000440
oooo002V0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
Q03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0480oooo
002W0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0Q03o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo002P
0?ooo`@00000103oool00`000000oooo0?ooo`0j0?ooo`@00000103oool0
0`000000oooo0?ooo`240?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0@03oool00:H0oooo00@000000?ooo`3oool00000@`3oool0
0`000000oooo0?ooo`240?ooo`030000003oool0oooo0400oooo00@00000
0?ooo`3oool00000@@3oool00:L0oooo0P0000130?ooo`800000Q@3oool2
000004<0oooo0P0000120?ooo`00o`3oooom0?ooo`00o`3oooom0?ooo`00
o`3oooom0?ooo`00o`3oooom0?ooo`00o`3oooom0?ooo`00o`3oooom0?oo
o`00P`3ooonY0000o`<0000000@0003o0?l0000000000000ZP000?lO0?oo
o`00RP3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00T0
oooo00@000000?ooo`3oool0003o3`3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`00
0000oooo0000o`0E0?ooo`030?l0003oool0oooo02L0oooo1`000?lZ0?oo
o`030000o`3oool0oooo01<0oooo00<0o`000000003oool03`3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool0303oool0103o0000oooo0?ooo`00000<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0903oool008X0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`090?ooo`040000003oool0oooo
0000o`l0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00h0oooo00<000000?ooo`000?l05@3oool0
0`3o0000oooo0?ooo`0X0?ooo`<0003o0P3oool00`3o0000oooo0?ooo`0X
0?ooo`030000o`3oool0oooo01<0oooo00<0o`000000003oool03`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool0303oool0103o0000oooo0?ooo`00000<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0903oool008X0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04P3oool2
0?l002T0oooo00@0003o0?ooo`3oool0003o0`3oool00`3o0000oooo0?oo
o`0W0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0903oool008X0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04P3oool0
0`3o0000oooo0?ooo`0W0?ooo`050000o`3oool0oooo0?ooo`000?l0103o
ool00`3o0000oooo0?ooo`0V0?ooo`030000o`3oool0oooo01<0oooo00<0
o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0903o
ool008X0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0V0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0U
0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0903oool008X0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04P3oool00`3o
0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo
01<0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0903oool008X0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0T0?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`0T0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0903oool008<0oooo
A@3o00000`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0T0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0S0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`060?ooodl0o`007`3oool008X0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool03@3ooolM0?l000H0oooo00<0
003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0R0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool00P3o
oolF0?l000T0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0T0?ooo`00RP3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool02@3oool=0?l000l0oooo00<0o`000?ooo`3oool08P3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool08P3oool00`000?l0oooo0?ooo`0?0?ooo`P0o`003P3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0903oool008X0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0103oool60?l0
00T0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool08@3oool00`00
0?l0oooo0?ooo`030?ooo``0o`000`3oool00`3o0000oooo0?ooo`0@0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0T0?ooo`00RP3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0:0?ooo`X0
o`008P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool07P3oool80?l000l0oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0903oool008X0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
4P3oool70?l001`0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo01T0oooo103o00020?ooo`030000
o`3oool0oooo0180oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0903oool008X0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?oo
o`040?ooo`@0o`005`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool05@3oool30?l000L0oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0T0?ooo`00P`3ooolV0000o`l0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`08
0?ooo`80o`00503oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool04@3oool30?l000X0oooo00<0003o
0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=
0?ooobH0003o7`3oool008X0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?oooal0003o00<0oooo0000o`3oool03`3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0180oooo00<0o`000?oo
o`3oool02P3oool30?l00100oooo00<0003o0?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo0P3o000=0?oo
o`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo01d0003o00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
02@0oooo002:0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0
oooo2`000?l60?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`0=0?ooo`80o`003@3oool00`000?l0
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool02`3oool20?l000l0oooo00<0003o0?ooo`3oool04P3oool00`3o0000
oooo0?ooo`0=0?oooaH0003o3@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0T0?ooo`00RP3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00L0oooo4P000?l60?ooo`030000
o`3oool0oooo0180oooo00<0o`000?ooo`3oool0403oool20?l000/0oooo
00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00T0oooo0P3o000B0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool01@3oool80000o`80oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo02@0oooo002:0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`090?ooo`L0003o503oool00`3o0000oooo0?ooo`0B0?ooo`80o`00203o
ool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool01P3oool20?l001@0oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0000o`050000o`X0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo02@0oooo002:0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0?
0?ooo`H0003o3`3oool00`3o0000oooo0?ooo`0D0?ooo`80o`001@3oool0
0`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo0100oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0
oooo00T0oooo2P000?l@0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0T
0?ooo`00RP3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0>0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`030?ooo`H0003o2@3oool00`3o0000oooo0?ooo`0F0?oo
o`050?l0003oool0oooo0?ooo`000?l04P3oool00`000?l0oooo0?ooo`0A
0?ooo`040?l0003oool0oooo0?ooo`80o`005`3oool00`000?l0oooo0?oo
o`060?ooo`<0003o203oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0T0?ooo`00P`3oool:0?l000`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo00T0oooo1@000?l30?ooo`030?l0003oool0
oooo01P0oooo0P3o00000`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0180oooo00<0o`000?ooo`3o00006@3oool010000?l0oooo0?ooo`3o
ool50000o`/0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00X0oooo2P3o
000O0?ooo`00RP3oool00`000?l0oooo0?ooo`0V0?l000@0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool03P3oool40000oa/0oooo00<0003o
0?l0003oool04P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0
oooo01L0oooo1@000?lA0?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00<0oooo9P3o00020?ooo`030?l0003oool0oooo02@0oooo002:0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`080?oooa@0o`0000<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0140oooo00@0o`000000
o`000?l0003o5`3oool010000?l0oooo0?ooo`3o000B0?ooo`030000o`3o
ool0oooo0140oooo0P3o00000`3oool0o`000?ooo`0D0?ooo`<0003o0P3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?l0000C0?l000X0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo02@0oooo002:0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00d0oooo2P3o00070?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo0?ooo`020?ooo`<0003o4`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo00l0oooo0`000?l50?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`050?ooo`X0o`003P3oool0
0`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0T0?ooo`00RP3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00L0oooo2P3o000>0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool01@3oool30000o`l0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`0<0?ooo`80003o203oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00d0oooo2P3o00080?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0903oool008X0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00P0
o`001P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00T0
oooo0P000?l<0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool02P3oool20000o`/0oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`050?ooo`P0o`000P3oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0903oool008X0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00T0oooo1P3o00000`000?l0oooo0?ooo`0@0?ooo`030?l0
003oool0oooo00/0oooo0P000?l90?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool20000o`d0oooo
00<0003o0?ooo`3oool0403oool00`3o0000oooo0?l000050?l000X0oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo02@0oooo002:0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0?0?ooo`D0o`003P3oool00`3o0000oooo0?oo
o`0=0?ooo`80003o1P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`090?ooo`030?l0003oool0oooo00@0oooo0P000?l?0?ooo`030000o`3o
ool0oooo00d0oooo1@3o000@0?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0T0?ooo`00P`3ooolL0000o`T0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`030?ooo`H0o`001`3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool01`3oool6
0?l000<0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`070?oooa`0003o7`3oool008T0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`040?oooa@0003o103oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`@0o`000`3oool00`3o
0000oooo0?ooo`0A0?ooo`80003o00<0oooo0000o`3oool03@3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool02`3oool00`3o0000oooo0?ooo`020000oa<0oooo00@0003o0?oo
o`3oool0oooo1@3o000:0?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00<0oooo4`000?l50?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0903oool008T0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00T0oooo4`000?l00`3o
ool0003o0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool03@3oool40?l001D0oooo0P000?l>0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030?l000000?l0oooo01@0oooo00@0003o0?ooo`3o0000o`003`3oool0
0`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`000?l04`000?l90?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0T0?ooo`00R@3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`X0003o1`3oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0100oooo0`3o000C0?oo
o`80003o3`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool03@3oool00`000?l0o`000?ooo`0C0?oo
o`<0o`004@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00D0oooo2P000?l>0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
02@0oooo00290?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool01P3oool80000oa00oooo00<0003o0?ooo`3o
ool03`3oool0103o0000oooo0?ooo`3oool30?l000l0oooo00@0003o0?oo
o`3oool0003o3P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool02`3oool20000o`80oooo00<0o`00
0?ooo`3oool03P3oool30?l00080oooo00<0003o0?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0>0?ooo`P0003o203oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo02@0oooo00290?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000003o0000o`030000o`/0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`040?ooo`80o`003@3oool01000
0?l0oooo0?ooo`3oool20000o`d0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`80o`001@3oool0
0`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00T0oooo1P000?l?
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0903oool008T0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00<0oooo1@000?l60?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool01P3oool20?l000X0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool02@3oool20?l000P0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`020?ooo`L0003o1@3oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0903oool008<0oooo2P3o000;0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool0203oool60000oa80oooo00<0o`000?ooo`3oool0203oool20?l000P0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool20?l000X0oooo00<0003o0?ooo`3oool03@3oool70000o``0
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0:0?ooo`X0o`007`3oool008T0oooo00@0003o0?ooo`3oool0
oooo6`3o000>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0>0?ooo`H0003o303oool00`3o0000
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool20?l000`0
oooo00<0003o0?ooo`3oool02@3oool40000o`<0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool0303ooolL0?l00080oooo00<0o`000?ooo`3o
ool0903oool008T0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3o0000o`000180o`002P3oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
0`3oool50000o`L0oooo00<0o`000?ooo`3oool0303oool20?l000@0oooo
00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00@0o`000?ooo`3oool0
oooo0P3o000?0?ooo`030000o`3oool0oooo00@0oooo10000?l70?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0:0?oooa<0o`003P3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo02@0oooo00290?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00<0oooo2@3o00000`3oool0003o0?ooo`0>0?ooo`030?l0
003oool0oooo00h0oooo00<0003o0?ooo`3oool0203oool40000o`<0oooo
00<0o`000?ooo`3oool03P3oool20?l000030?ooo`000?l0oooo00X0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`0:0?ooo`<0o`004@3oool010000?l0oooo0?ooo`3oool30000o`/0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0o`0000T0o`000`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0T0?ooo`00R@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`X0o`001`3oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00d0oooo0P000?l00`3oool0o`000?ooo`0A0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`060?ooo`030?l000000?l0003o00P0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`0:0?ooo`<0o`004P3oool010000?l0oooo
0000o`000?l>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool01P3oool:0?l000d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0903oool008T0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`060?ooo`P0o`003`3oool00`000?l0oooo
0?ooo`0?0?ooo`<0003o4@3oool00`000?l0o`000?l0000<0?ooo`030000
o`3oool0oooo00P0oooo00@0o`000?ooo`3oool0oooo1@3o00000`000?l0
oooo0000o`040000o`<0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`090?ooo`80o`000P3oool00`3o0000oooo0?ooo`0?0?ooo`<0
003o403oool00`3o0000oooo0?ooo`0>0?ooo`P0o`00203oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo02@0
oooo00290?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool03@3oool60?l000X0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`020000o`h0oooo00D0003o0?ooo`3oool0
oooo0?l0000<0?ooo`030000o`3oool0oooo00L0oooo103o00050?ooo`03
0000o`3oool0oooo00@0oooo0`000?l00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0<0?ooo`80003o0P3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00T0oooo1@3o00000`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0903oool008<0oooo0`000?l30?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`030?ooo`D0o`001@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
003oool0oooo0080oooo0`000?l:0?ooo`030000o`3oool0oooo00<0oooo
0P3o000:0?ooo`030000o`3oool0oooo00@0oooo103o00080?ooo`030000
o`3oool0oooo00H0oooo00@0o`000?ooo`000?l0003o1P3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3o
ool0203oool30000o`@0oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`030?ooo`D0o`001@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool00`3oool20000oal0oooo00260?oooaT0003o203oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`090?ooo`D0o`0000<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`060?ooo`80003o203oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00P0oooo00@0003o0?ooo`3oool0
oooo0P3o00040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool0103o0000oooo0?ooo`3oool20000o`<0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo0P000?l80?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3o00000`3o000:0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00H0oooo6P000?lQ0?ooo`00R@3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00@0oooo4`000?l40?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>0?ooo`D0
o`00303oool00`3o0000oooo0?ooo`080?ooo`<0003o103oool00`000?l0
oooo0?ooo`070?ooo`80o`002@3oool00`000?l0o`000?l000060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`<0003o2P3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo0080oooo0`000?l:0?ooo`030000o`3oool0oooo00/0
oooo1@3o000>0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`020?oooa<0003o1P3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo02<0oooo00290?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`080?ooo`T0003o2P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool00`3oool40?l000L0oooo
00<0o`000?ooo`3oool0303oool20000o`030?ooo`000?l0oooo00/0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000003o0?ooo`070?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`80003o2@3oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0oooo0080003o3@3oool00`000?l0oooo0?ooo`060?ooo`D0o`00
0`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool02@3oool90000o`X0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo02<0oooo
00290?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo2`00
0?l?0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool01`3o
ool40?l000<0oooo00<0o`000?ooo`3oool03P3oool20000o`d0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0000o`080?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`040000o`3oool0003o0000o`H0oooo00<0o`000?ooo`3oool0
2P3oool00`3o0000003o0000o`0?0?ooo`030000o`3oool0oooo0080oooo
103o00090?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`090000o`@0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool08`3oool008T0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool90000o`L0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0;0?ooo`<0o`004@3oool010000?l0oooo0000
o`000?l<0?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0
oooo0000o`070?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`80
003o00<0o`000?ooo`3oool03`3oool010000?l0o`000?l0003o000=0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool01@3oool:0000
o`d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool08`3oool008T0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`060?ooo`P0003o3`3oool00`000?l0oooo0?ooo`0=0?ooo`<0
o`003`3oool01@000?l0oooo0?ooo`3oool0003o00`0oooo00@0o`000?oo
o`3o0000o`001@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`00303o
ool010000?l0oooo0?ooo`3o000>0?ooo`@0o`00403oool00`3o0000oooo
0?ooo`0=0?ooo`P0003o203oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo02<0oooo00290?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0000o`030000o`X0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`020?l000`0oooo00<0003o0?ooo`3oool00`3o
ool20000o`X0oooo0P3o00080?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0o`000?oo
o`0:0?ooo`80003o103oool00`3o0000oooo0?ooo`080?ooo`<0o`000`3o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00P0oooo1P00
0?l?0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool08`3oool008<0oooo4P3o00020?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool00`3oool5
0000o`D0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`03
0?ooo`<0o`002@3oool00`000?l0oooo0?ooo`050?ooo`80003o203oool2
0?l000P0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030?l000000?l0oooo00P0oooo0P000?l7
0?ooo`030?l0003oool0oooo00D0oooo0P3o00070?ooo`030000o`3oool0
oooo00d0oooo00@0o`000?ooo`3oool0oooo1`000?l50?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00@0003o0?ooo`3oool0oooo
4P3o000O0?ooo`00R@3oool00`000?l0oooo0?ooo`090?oooa<0o`003@3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0203oool60000o`l0oooo00<0o`000?ooo`3oool01P3o
ool30?l000D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`040?ooo`040?l0003oool0oooo0?l000P0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`040?l0
003oool0oooo0000o`L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`030?ooo`80o`002@3oool00`000?l0oooo0?ooo`0;0?ooo`H0
003o303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303ooolC0?l000/0oooo00<0o`000?ooo`3o
ool08`3oool008T0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0o`0000P0o`00103oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
3@3oool50000o`/0oooo00<0o`000?ooo`3oool02@3oool30?l00080oooo
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool00P3o000;0?ooo`030000
o`3oool0oooo00P0oooo0`000?l30?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00<0oooo2P3o000>0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool08`3oool008T0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00P0oooo4@3o
00030?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`020?ooo`@0003o1`3oool00`3o0000oooo0?oo
o`0<0?ooo`80o`003@3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0003o0`3o00020?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool30?l000h0oooo
00<0003o0?ooo`3oool0103oool30000o`H0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0180o`00
2@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool08`3oool008T0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool02P3oool50?l000d0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`060?ooo`@0003o0`3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3o0000o`0000`0oooo0P000?l00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3o
ool010000?l0o`000000o`000?l20?ooo`030000o`3oool0oooo00D0o`00
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo
00@0003o0?ooo`000?l0003o303oool30?l000l0oooo00@0003o0?ooo`3o
ool0oooo0`000?l90?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool01`3oool80?l000`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool08`3oool008T0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`070?l000H0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`<0003o00<0o`000?ooo`3o
ool0303oool010000?l0oooo0?ooo`3oool20?l000/0oooo00<0o`000000
o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`060000o`3oool0003o
0000o`3oool0o`00103oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080o`0000<0oooo0000o`3oool0103oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00X0oooo0P3o00020?ooo`030?l0003o
ool0oooo00d0oooo10000?l=0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool00P3oool50?l000D0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0S0?ooo`00R03oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00L0oooo2@3o000<0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0000o`000?l00P000?l;0?ooo`030000o`3oool0oooo00<0oooo0P3o0009
0?ooo`030?l0003oool0003o00L0oooo00<0o`000?ooo`3oool0103oool2
0000o`@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?l0003oool0103oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0003o00T0oooo0P3o00050?ooo`030?l0003o
ool0oooo00T0oooo1@000?l?0?ooo`030?l0003oool0oooo00X0oooo1`3o
000:0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool08`3oool008<0oooo2@000?l;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00@0o`000?ooo`3oool0oooo1`3o
00050?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool00P3o
ool30000o`P0oooo00<0003o0?ooo`3oool01@3oool20?l000H0oooo00D0
o`000?ooo`3oool0oooo0000o`070?ooo`040?l0003oool0oooo0?ooo`80
003o00<0oooo0000o`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o
00<0oooo00<0o`000?ooo`3oool00`3oool010000?l0oooo0?l0003o0002
0?ooo`030?l0003oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo0000
o`060?ooo`80o`001`3oool00`3o0000oooo0?ooo`060?ooo`<0003o103o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00<0oooo1`3o
00020?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool02P3oool90000oal0oooo00280?ooo`040000o`3oool0
oooo0?oooa80003o203oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`080?ooo`@0o`0000<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`050?ooo`80003o1@3oool00`000?l0oooo0?ooo`080?ooo`80o`000`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`000?l0103oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`070000o`3oool0oooo0?oo
o`3o0000oooo0?l000070?ooo`80003o1@3oool010000?l0oooo0?ooo`3o
ool20?l000X0oooo00<0o`000?ooo`3oool00`3oool20000o`L0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?l000030?l000T0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool01P3ooolB0000o`80oooo00<0
o`000?ooo`3oool08`3oool008P0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`040?oooa<0003o103oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool5
0?l000/0oooo00<0o`000?ooo`3oool0203oool30000o`80oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?l000070?ooo`80003o1P3oool0
0`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o00000`3o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00@0003o0?ooo`3oool0o`00303oool00`3o0000oooo0?ooo`030000o`X0
oooo00<0003o0?ooo`3oool02@3oool50?l000h0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00<0
oooo4P000?l50?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool08`3oool008P0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00P0oooo2@000?l:0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`020?ooo`@0o`001`3oool00`3o0000oooo0?ooo`0;0?ooo`<0003o
3@3oool20?l000T0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?l000050?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool010000?l0
oooo0?ooo`3o00040?ooo`030000o`3oool0oooo0080oooo00@0o`000?oo
o`3o0000o`000`3oool20000o`T0oooo0P3o000=0?ooo`<0003o3@3oool0
0`000?l0oooo0?ooo`050?ooo`@0o`000`3oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02@3oool9
0000o`T0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo02<0oooo00280?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo0080oooo2@000?l00`3oool0003o0?ooo`0=0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool01P3oool40?l0
00<0oooo00<0o`000?ooo`3oool0303oool010000?l0oooo0000o`000?l;
0?ooo`<0o`002@3oool010000?l0oooo0000o`000?l30?ooo`030?l0003o
ool0oooo0080oooo00@0003o0?ooo`3oool0oooo0`3o00030000o`050?l0
003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0003o00T0oooo0P3o00000`000?l0oooo0?ooo`0:0?ooo`80
003o00<0oooo0?l0003oool03@3oool010000?l0oooo0?ooo`3oool40?l0
00L0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0003o00T0003o0`3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0S0?ooo`00R03oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`X0003o1@3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00X0oooo0`3o000?0?ooo`040000o`3oool0oooo0?oo
o`<0003o203oool0103o0000oooo0?ooo`3o00090?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?l000060?ooo`000?l0oooo0?ooo`3o0000003o0P3oool01@000?l0oooo
0?ooo`3oool0o`0000H0oooo00<0003o0?ooo`3oool01`3oool01@3o0000
oooo0?ooo`3oool0003o00P0oooo0`000?l30?ooo`030?l0003oool0oooo
00d0oooo0`3o000<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool01@3oool90000o`d0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool08`3oool008P0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`070?ooo`L0003o3P3oool00`000?l0
oooo0?ooo`0<0?ooo`@0o`002`3oool00`000?l0oooo0?ooo`050?ooo`80
003o1@3oool00`3o0000oooo0?ooo`020?ooo`80o`001`3oool20000o`H0
oooo00D0o`000?ooo`3oool0oooo0000o`020?l000040?ooo`3o0000oooo
0000o`80oooo00@0o`000?ooo`000?l0003o0`3oool00`3o0000oooo0?oo
o`030?ooo`80003o00<0oooo0?l0003oool01@3oool20?l000@0oooo00<0
003o0?ooo`3oool0103oool20000o`H0oooo00<0o`000?ooo`3oool02P3o
ool30?l000030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool80000o`L0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0S0?ooo`00P`3oool20?l000<0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0003o00<0003o2P3oool00`000?l0oooo0?ooo`0<
0?ooo`040?l0003oool0oooo0?ooo`<0o`001`3oool00`000?l0oooo0?oo
o`080?ooo`80003o0P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00<0oooo00@0003o0?ooo`3oool0003o1@3oool01P3o0000oooo
0?ooo`3o0000oooo0000o`80oooo00D0o`000?ooo`000?l0oooo0?l00003
0?ooo`<0003o00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3o
ool0o`0000D0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?oo
o`3oool20000o`T0oooo00<0o`000?ooo`3oool01@3oool40?l000<0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`080?ooo`D0003o
3P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo0080oooo0P3o000O0?ooo`00Q@3ooolI0?l000L0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool00`3oool70000o`80oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`050?ooo`<0o`00103o
ool00`000?l0oooo0?ooo`0:0?ooo`80003o00<0o`000?ooo`3oool01P3o
ool20?l000<0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`80o`00
0`00000010000?l0oooo0?ooo`3o00020000o`040?l0003oool0oooo0000
o`<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo0080o`002@3oool30000o`/0oooo00@0o`000?oo
o`3oool0oooo103o00080?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool01`000?l50?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00L0oooo603o000Q0?ooo`00R03oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00@0oooo2@3o000=0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0:0?oo
o`L0003o2P3oool00`3o0000oooo0?ooo`080?ooo`<0o`0000<0oooo0000
o`3oool0303oool00`3o0000003o0000o`090?ooo`030?l0003oool0003o
00D0oooo00<0003o0?ooo`3oool00P3oool20?l000080000003oool0oooo
0?ooo`000?l0oooo0?l000000?l20?l000030?ooo`000?l0oooo0080oooo
00<0o`000?ooo`000?l00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0o`0000X0oooo0P000?l=0?ooo`@0o`00303oool00`000?l0oooo
0?ooo`090?ooo`H0003o303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool:0?l000D0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0S0?ooo`00R03o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3o00004@3o000:0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`030?ooo`@0003o1P3o
ool00`3o0000oooo0?ooo`0;0?ooo`<0o`00303oool00`3o0000oooo0?oo
o`020000o`P0oooo0P3o00060?ooo`040000o`3oool0oooo0?l00080oooo
0P3o00020?ooo`80003o0`3o000010000000003o0?ooo`3oool20?l000<0
oooo0P000?l70?ooo`80o`002@3oool20000o`80oooo00<0003o0?ooo`3o
ool0203oool20?l000030?ooo`3o0000oooo00d0oooo00<0003o0?ooo`3o
ool01@3oool40000o`<0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00P0oooo4`3o000>0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool08`3oool008P0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool00P3oool90?l000030?oo
o`000?l0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`070?ooo`@0003o00<0oooo0?l0003oool03P3oool00`000?l0oooo
0?l000030?l000P0oooo00<0o`000?ooo`3oool00P3oool20000o`D0oooo
00<0003o0?ooo`3oool00P3o00050?ooo`80003o0`3oool010000000oooo
0?l0003oool60000o`030?ooo`3o0000o`0000D0oooo00<0003o0?ooo`3o
ool0103oool20?l00080oooo00<0o`000?ooo`3oool0103oool20000o`@0
oooo00<0003o0?ooo`3oool01@3oool30?l000<0oooo00<0o`000?ooo`3o
ool0303oool010000?l0oooo0?ooo`3oool40000o`L0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0o`00
00P0o`00103oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0R0?oo
o`00R03oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`P0
o`001`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo0P000?l>0?ooo`030000o`3oool0oooo00@0oooo0P3o00050?ooo`03
0?l0003oool0oooo00D0oooo0P000?l20?ooo`030000o`3oool0oooo00<0
oooo0P3o00040?ooo`050?l000000?l0oooo0?ooo`0000000P3oool20?l0
0080oooo00<0o`000?ooo`3oool00P3o00050?ooo`030000o`3oool0003o
00@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`80003o1`3oool010000?l0oooo0?ooo`3oool30?l000L0oooo00<0o`00
0?ooo`3oool02`3oool40000o`/0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`070?ooo`L0o`003@3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0R0?ooo`00R03oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00D0oooo103o00030?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0103o
0000003o0000o`000?l;0?ooo`030000o`3oool0oooo00H0oooo0P3o0003
0?ooo`030?l0003oool0oooo00L0oooo0`000?l70?ooo`040?l0003oool0
oooo0?l00080oooo0P000?l01@000000oooo0?ooo`000?l0oooo00H0o`00
00@0oooo0?l0003oool0oooo0P000?l20?ooo`050000o`3oool0oooo0?oo
o`3o00001P3oool0103o0000oooo0000o`000?l90?ooo`040000o`3oool0
o`000?l000X0oooo00<0o`000?ooo`3oool02@3oool30000o`l0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`030?ooo`@0o`001@3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo0280oooo00280?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool02@3oool60?l000`0oooo00<0003o
0?ooo`3oool0303oool0103o0000oooo0?ooo`3oool40000o`H0oooo00<0
003o0?ooo`3oool02@3oool30?l000/0oooo0`000?l70?ooo`80o`001@3o
ool40000o`<0oooo00<0o`000?ooo`3oool00P3oool30000o`D0oooo00<0
003o0?l0003o00001`3oool20000o`/0oooo0P3o000<0?ooo`030?l0003o
ool0oooo00H0oooo0`000?l30?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool02P3oool70?l000T0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0R0?ooo`00P`3ooolA
0000o`80oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`070?l000D0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`050?ooo`@0003o0P3oool00`000?l0oooo0?ooo`0;
0?ooo`80o`002P3oool00`000?l0oooo0?ooo`020000o`D0oooo00@0o`00
0?ooo`3o0000o`001@3oool:0000o`030?ooo`3o0000oooo00@0oooo0P3o
00070?ooo`80003o00<0oooo0?l0003oool01`3oool30?l000030?ooo`00
0?l0oooo00`0oooo00@0o`000?ooo`3oool0oooo10000?l60?ooo`030000
o`3oool0oooo00`0oooo00@0o`000?ooo`3oool0oooo2@3o00020?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00@0003o0?ooo`3o
ool0oooo4@000?lO0?ooo`00U03ooolB0000o`h0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00L0
oooo103o00000`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0
oooo10000?l;0?ooo`030?l0003oool0oooo00<0o`001P3oool00`000?l0
oooo0?ooo`030?ooo`80003o0`3oool0103o0000oooo0?ooo`3oool20?l0
0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`040?l0003oool0oooo0?ooo`80o`000P3oool010000?l0oooo0?ooo`3o
ool30000o`<0oooo00<0o`000?ooo`3oool0103oool20?l000@0oooo00<0
003o0?ooo`3oool02`3oool40000o`X0oooo00<0003o0?ooo`3oool02@3o
ool70?l000/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo4P000?l`0?ooo`00Y@3oool;
0000o`<0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00/0oooo1`3o00080?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool00P000?l90?ooo`030?l0003oool0
oooo00<0oooo0`3o00030?ooo`030000o`3oool0oooo00D0oooo0P000?l0
0`3oool0o`000?ooo`040?ooo`@0o`00103oool00`3o0000oooo0?ooo`03
0?ooo`@0o`00103oool010000?l0oooo0000o`000?l70?ooo`040?l0003o
ool0oooo0?ooo`80o`001`3oool00`000?l0oooo0?ooo`060?ooo`@0003o
00<0oooo0?l0003oool0303oool00`000?l0oooo0?ooo`040?ooo`@0o`00
0`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`030?ooo`T0003o
00<0o`000?ooo`3oool0?`3oool00;00oooo20000?l:0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`040?ooo`L0o`0000<0oooo0?l0003oool0303oool00`000?l0oooo0?oo
o`020?ooo`80003o1`3oool00`3o0000oooo0?ooo`060?ooo`<0o`002P3o
ool20000o`L0oooo00<0003o0?ooo`3o00002@3o00000`3oool0o`000?oo
o`040?ooo`<0003o2@3oool0103o0000oooo0?l0003o00090?ooo`030000
o`3oool0oooo0080oooo10000?l50?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3o0000103o00070?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`080?ooo`T0003o
B`3oool00;P0oooo2@000?l00`3oool0003o0?ooo`0=0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool40?l000/0oooo00<0
003o0?ooo`3oool0103oool30000o`<0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0o`000?l000080?ooo`040?l0003oool0003o0000o`D0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`040?l0
003oool0oooo0?ooo`80003o0`3oool00`000?l0oooo0?ooo`060?ooo`80
o`00303oool010000?l0oooo0000o`000?l90?ooo`030?l0003oool0oooo
00T0oooo103o000=0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0000o`080000oe@0oooo00310?ooo`X0
003o1@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00@0o`000?ooo`3oool0oooo103o00060?ooo`030000o`3oool0oooo
00P0oooo10000?l;0?ooo`030000o`3oool0oooo0080o`001@3oool00`3o
0000oooo0?ooo`020?ooo`D0003o1P3oool00`3o0000oooo0?ooo`040?oo
o`040?l0003oool0003o0000o`D0oooo00<0003o0?ooo`3oool0103oool2
0?l000030?ooo`3o0000oooo00X0oooo0`000?l;0?ooo`030?l0003oool0
oooo00D0oooo103o00020?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`T0003oG@3oool0
0</0oooo20000?l<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool01@3oool40?l00080oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0000o`030000o`L0oooo00<0003o0?ooo`3oool00P3oool30?l0
0080oooo00<0o`000?ooo`3oool01P3oool@0000o`L0oooo00@0003o0?oo
o`3oool0oooo0`3o00040?ooo`030?l0003oool0oooo00D0oooo0`000?l0
0`3oool0003o0?ooo`0;0?ooo`040?l0003oool0oooo0?ooo`@0o`001P3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo2@00
0?mV0?ooo`00d`3oool70000o`@0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`090?ooo`@0o`002`3oool00`3o0000oooo0?ooo`03
0?ooo`<0003o0`3oool00`000?l0oooo0?ooo`060?ooo`<0o`00203oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool010000?l0oooo0?l0003o00070?ooo`040?l0003o
ool0oooo0?ooo`@0003o103oool00`000?l0oooo0?ooo`0:0?ooo`@0o`00
2`3oool00`000?l0oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?ooo`T0
003oK`3oool00=X0oooo1@000?l>0?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool00P3o00080?ooo`030?l0003oool0oooo00L0oooo
10000?l:0?ooo`@0o`001@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool40?l000X0oooo
0`000?l80?ooo`030000o`3oool0oooo00H0oooo103o00000`3oool0o`00
0?ooo`0<0?ooo`030000o`3oool0oooo00T0oooo1P000?mh0?ooo`00gP3o
ool60000o`T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`020?ooo`80o`001P3oool00`3o0000oooo0?ooo`0:0?ooo`80003o203o
ool00`3o0000oooo0?ooo`020?ooo`@0o`0000<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0o`0000<0o`000`3o
ool00`000?l0oooo0?ooo`050?ooo`<0003o00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`020?ooo`<0o`001@3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00D0oooo10000?mn0?ooo`00i03oool7
0000o`030?ooo`3o0000oooo00`0oooo00<0003o0?ooo`3oool0103oool3
0?l000<0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`02
0000o`H0oooo00<0o`000?ooo`3oool01P3ooolB0?l000L0oooo00<0003o
0?ooo`3oool00P3oool30000o`<0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`020?l000P0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0000o`040000oh80oooo003[0?ooo`@0003o2`3oool00`00
0?l0oooo0?ooo`070?ooo`@0o`002`3oool00`000?l0oooo0?ooo`020?oo
o`@0003o0P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0003o0080003o1P3oool00`3o0000oooo0?ooo`090?oo
o`<0o`002`3oool00`3o0000oooo0?ooo`090?ooo`@0003oQ`3oool00>l0
oooo10000?l70?ooo`030000o`3oool0oooo00X0oooo1@3o00060?ooo`03
0000o`3oool0oooo00L0oooo1P000?l50?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`@0
003o2@3oool00`3o0000oooo0?ooo`060?ooo`<0o`0000<0oooo0000o`3o
ool02`3oool00`3o0000oooo0?ooo`050?ooo`@0003oR`3oool00?<0oooo
10000?l20?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
0`3oool40?l00080oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`020?ooo`@0003o00<0oooo0000o`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`030?l000000?l0003o00<0003o0`3oool00`000?l0oooo
0?ooo`080?ooo`040?l0003oool0oooo0?ooo`@0o`00103oool00`000?l0
oooo0?ooo`0:0?ooo`040?l0003oool0oooo0?ooo`@0003oS`3oool00?L0
oooo10000?l;0?ooo`030?l0003oool0oooo00L0oooo0`3o000:0?ooo`03
0?l0003oool0oooo00H0oooo4`000?l80?ooo`030000o`3oool0oooo00L0
oooo1@3o00090?ooo`030000o`3oool0oooo00T0oooo10000?nC0?ooo`00
n`3oool40000o`L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0o`00
0?l000020?l000H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool010000?l0oooo0?ooo`3oool50?l00080oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`050?ooo`@0003oU`3oool00?l0oooo
1P000?l00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo
103o00020?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00@0003o0?l0003o0000o`001`3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0003o00D0003oV`3oool00?l0oooo1P3oool50000o`L0oooo
00<0003o0?ooo`3oool01`3oool60?l000D0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo
103o000:0?ooo`030?l0003oool0oooo00D0oooo1P000?nQ0?ooo`00o`3o
ool;0?ooo`@0003o0`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo0080oooo1`3o00070?ooo`030?l0003oool0oooo00H0oooo1`3o
00030?ooo`030000o`3oool0oooo00P0oooo00@0o`000?ooo`3oool0oooo
10000?nW0?ooo`00o`3oool?0?ooo`@0003o2P3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0o`0000l0o`0000<0oooo0?l0003oool01`3o
ool00`000?l0oooo0?ooo`090?ooo`<0003oZ`3oool00?l0oooo4P3oool4
0000o`L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`040?ooo`@0003o00<0o`000?ooo`3oool0Z`3oool0
0?l0oooo5P3oool50000o`030?ooo`3o0000oooo00T0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool010000?nb0?ooo`00o`3ooolK0?ooo`H0
003o1@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool0103oool60000okH0oooo003o0?ooob40oooo
30000?l30?ooo`030?l0003oool0oooo0080oooo30000?nl0?ooo`00o`3o
ool]0?ooo`P0003ob03oool00?l0oooo<03oool00`000000oooo0?ooo`3:
0?ooo`00o`3oool`0?ooo`030000003oool0oooo0<X0oooo003o0?oooc00
oooo00<000000?ooo`3oool0bP3oool00?l0oooo<03oool00`000000oooo
0?ooo`3:0?ooo`00o`3oool`0?ooo`030000003oool0oooo0<X0oooo0000
\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{508, 123},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.73",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/schwarzchristoffel/\
SchwarzChristoffelFigures/mat1173.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "   The region with ",
  Cell[BoxData[
      RowBox[{\(w\_1 \[Rule] 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_3 \[Rule] 0\)}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "\[Rule]", \(\[Pi]\/2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "\[Rule]", \(-\[Pi]\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "3"], "\[Rule]", \(\[Pi]\/2\)}]}]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe limiting formula for the derivative ",
  Cell[BoxData[
      \(g' \((z)\)\)]],
  " becomes    \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z + 
                  1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \
\((z)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\ \((z - \
1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(\(-\(\[Pi]\/2\)\)/\[Pi]\)\) \((z)\)\^\(\(-\((\(-\
\[Pi]\))\)\)/\[Pi]\)\ \((z - 1)\)\^\(\(-\(\[Pi]\/2\)\)/\[Pi]\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(-\(1\/2\)\)\) \((z)\)\^1\ \((z - \
1)\)\^\(-\(1\/2\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ z \((z\^2 - \
1)\)\^\(-\(1\/2\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ z\/\((z\^2 - 1)\)\^\
\(1\/2\)\)\)\)}]],
  "\n\nwhich will determine a mapping ",
  Cell[BoxData[
      \(w\  = \ f \((z)\)\)]],
  " from the upper half-plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  onto the upper half plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  "  slit along the line segment from  ",
  Cell[BoxData[
      \(\(\(w = \(0\ \ to\ \ w\_2 = \[ImaginaryI]\)\)\(\ \)\)\)]],
  " as indicated in Figure 11.73(b).  An easy integration reveals that ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " is given by  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\ \  = \ \ A\ \(\[Integral]\(z\/\((z\^2 - 1)\)\^\(1\/2\)\
\) \[DifferentialD]z\)\ \  + \ \ B\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ \((z\^2 - \
1)\)\^\(1\/2\)\ \  + \ \ B\)\)\)}],
    AspectRatioFixed->True],
  "  \n\nand the boundary values  ",
  Cell[BoxData[
      \(f \((\(\[PlusMinus]1\))\) = \(0\ \ and\ \ f \((0)\) = \[ImaginaryI]\)\
\)]],
  "  lead to system of equations \n\n\t\t\t",
  Cell[BoxData[
      \(A\ \((\((\(\[PlusMinus]1\))\)\^2 - 1)\)\^\(1\/2\)\  + \ B\  = \ 0\)],
    AspectRatioFixed->True],
  "   and   ",
  Cell[BoxData[
      \(A\ \((0 - 1)\)\^\(1\/2\)\  + \ B\  = \ \[ImaginaryI]\)],
    AspectRatioFixed->True],
  "\n\nthe solution is easily found to be ",
  Cell[BoxData[
      \(A = \(1\ \ and\ \ B = 0\)\)]],
  " and the desired function  is  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\  = \ \((z\^2 - 1)\)\^\(1\/2\)\)],
    AspectRatioFixed->True],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.27.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the formula ",
  Cell[BoxData[
      \(\(f'\)[
          z] = \(\(\ \)\(A\ z\)\)\/\(\@\(z\  + \ 1\)\ \@\(z\  - \ 1\)\)\)],
    AspectRatioFixed->True],
  " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f1, A, B, z, F];\)\ \), "\n", 
    \(\(f1[
          z_]\  = \(\(\ \)\(A\ z\)\)\/\(\@\(z\  + \ 1\)\ \@\(z\  - \ 1\)\);\)\
\ \), "\n", 
    \(\(f[z_]\  = \ 
        B\  + \ \[Integral]\(\(\(\ \)\(A\ z\)\)\/\(\@\(z\  + \ 1\)\ \@\(z\  - \
\ 1\)\)\) \[DifferentialD]z;\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = B + \[Integral] \>", 
        f1[z], "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
This is one, formula for the integral.   However, we will use the following \
form of the integral to continue the computations.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f1, F];\)\ \), "\n", 
    \(\(f1[z_]\  = \ \(A\ z\)\/\@\(z\^2\  - \ 1\);\)\ \), "\n", 
    \(\(F[z_]\  = \ 
        B\  + \ \[Integral]\(\(A\ z\)\/\@\(z\^2\  - \ 1\)\) \
\[DifferentialD]z;\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = B + \[Integral] \>", 
        f1[z], "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(eq1\  = \ F[1] \[Equal] 0;\)\ \), "\n", 
    \(\(eq2\  = \ F[0] \[Equal] \[ImaginaryI];\)\ \), "\n", 
    \(solset\  = \ Solve[{eq1, eq2}, {A, B}]\), "\n", 
    \(\(f[z_]\  = \ 
        ReplaceAll[F[z], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \), "\n", 
    \(\(Print[eq1];\)\ \), "\n", 
    \(\(Print[eq2];\)\ \), "\n", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<f[z] = B + A \!\(\@\(z\^2 - 1\)\)\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph conformal mapping  w = f(z).  We will need to use two branches \
of f(z) to form the graph."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f1, f2, z];\)\ \), "\n", 
    \(\(f1[z_]\  = \ \ \ \@\(z\^2\  - \ 1\);\)\ \), "\n", 
    \(\(f2[z_]\  = \ \[ImaginaryI]\ \@\(1\  - \ z\^2\);\)\ \), "\n", 
    \(\(gr1\  = \ 
        CartesianMap[f1, {0, 3, 0.2}, {0.00001, 1.00001, 0.1}, 
          PlotRange \[Rule] {{\(-2\), 2}, {0, 1.5}}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(gr2\  = \ 
        CartesianMap[f2, {\(-3\), 0, 0.2}, {0.00001, 1.00001, 0.1}, 
          PlotRange \[Rule] {{\(-2\), 2}, {0, 1.5}}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{\(-2.5\), 2.5}, {0, 1.5}}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, \[IndentingNewLine]Ticks \
\[Rule] {Range[\(-2\), 2, 1], Range[0, 2, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<is upper half plane Im[w] > 0 slit\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<along the line segment from w = 0 to \!\(w\_2\) = \
\[ImaginaryI],\>\""];\)\ \), "\n", 
    \(\(Print["\<where  w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that  ",
  Cell[BoxData[
      \(w = \@\(z\^2 - 1\)\)]],
  "  maps the upper half plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  onto the upper half plane  ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  "  slit along the line segment from  ",
  Cell[BoxData[
      \(\(\(w = \(0\ \ to\ \ w\_2 = \[ImaginaryI]\)\)\(\ \)\)\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.29.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the mapping  ",
  Cell[BoxData[
      \(w\  = \ \(1\/\[Pi]\) \((\((z\^2 - 1)\)\^\(1\/2\) + 
              Log \((z + \((z\^2 - 1)\)\^\(1\/2\))\))\)\)]],
  "  maps the upper half plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  onto the domain in the w-plane that lies above the boundary curve \
consisting of the rays  ",
  Cell[BoxData[
      RowBox[{\(u \[LessEqual] 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"v", "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "u"}], "\[GreaterEqual]", 
            "0"}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(v = 0\)}]]],
  " and the segment  ",
  Cell[BoxData[
      RowBox[{\(u = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\(-1\) \[LessEqual] v \[LessEqual] 
          0\)}]]],
  "   (see Figure 11.87)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008o0000/R000`400?l0
0000o`00003oo`3ooooo0?oood40oooo003o0?ooool0oooo@@3oool00?l0
ooooo`3ooom10?ooo`00o`3ooooo0?oood40oooo003o0?ooool0oooo@@3o
ool00?l0ooooo`3ooom10?ooo`00o`3ooooo0?oood40oooo003o0?ooool0
oooo@@3oool007<0oooo1@00002a0?ooo`D00000F03oool400000180oooo
2`000?nH0?ooo`00M@3oool00`000000oooo0?ooo`2c0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool07P3oool80000oi00oooo001e
0?ooo`030000003oool0oooo05H0oooo00<00?l00?ooo`3oool0FP3oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02D0oooo1`000?n9
0?ooo`00K@3oool4000000@0oooo00<000000?ooo`3oool0EP3oool00`00
o`00oooo0?ooo`1J0?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool04@3oool;0?l000l0oooo20000?n10?ooo`00M@3oool00`000000
oooo0?ooo`1F0?ooo`03003o003oool0oooo05X0oooo00<000000?ooo`3o
ool0F03oool010000000oooo0?ooo`00000M0?ooo`l0o`00203oool70000
ogX0oooo001d0?ooo`800000F03oool00`00o`00oooo0?ooo`1I0?ooo`80
0000F`3oool2000002d0oooo1`3o00080?ooo`D0003oM@3oool00<h0oooo
00<00?l00?ooo`3oool0b`3oool;0000oaH0oooo1`3o00060?ooo`@0003o
L@3oool00<h0oooo00<00?l00?ooo`3oool0eP3oool?0000o`h0oooo1@3o
00050?ooo`<0003oKP3oool00<h0oooo00<00?l00?ooo`3oool0b`3oool4
0?l001H0oooo1`000?l<0?ooo`@0o`00103oool40000ofX0oooo003>0?oo
o`03003o003oool0oooo0<l0oooo3P3o000?0?ooo`L0003o2@3oool30?l0
00D0oooo0`000?mW0?ooo`00cP3oool00`00o`00oooo0?ooo`3M0?ooo`L0
o`003`3oool50000o`L0oooo103o00040?ooo`@0003oH`3oool00780oooo
G000o`2k0?l001<0oooo0`000?lF0?ooo`d0o`001`3oool40000o`L0oooo
0`3o00050?ooo`80003oH@3oool00780ooooG03`oo000`3o0000oooo0?oo
o`1J0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0503o
ool?0000oa@0oooo0`3o00080?ooo`<0003o1`3oool20?l000D0oooo0P00
0?mO0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo05X0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`0S0?ooo`h0003o2@3oool5
0?l000H0oooo0`000?l60?ooo`80o`001@3oool20000oed0oooo001b0?oo
oe`0l?o`00<0o`000?ooo`3oool0b`3oool:0?l001H0oooo1`000?l70?oo
o`D0o`00103oool30000o`D0oooo0P3o00050?ooo`80003oF`3oool00780
ooooG03`oo000`3o0000oooo0?ooo`3E0?ooo`l0o`003P3oool50000o`L0
oooo0`3o00040?ooo`80003o1@3oool20?l000D0oooo0`000?mH0?ooo`00
LP3ooomL0?3ol0030?l0003oool0oooo0>@0oooo3@3o00060?ooo`H0003o
103oool30?l000<0oooo0P000?l50?ooo`80o`001P3oool20000oeH0oooo
001b0?oooe`0l?o`00<0o`000?ooo`3oool0b`3ooolB0000oa@0oooo1@3o
00070?ooo`<0003o103oool20?l000<0oooo0`000?l40?ooo`80o`001P3o
ool30000oe<0oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool0g@3oool>
0000o`/0oooo0`3o00070?ooo`80003o103oool20?l000@0oooo0P000?l4
0?ooo`<0o`001P3oool30000oe00oooo001b0?oooe`0l?o`00<0o`000?oo
o`3oool0ZP3oool30000och0oooo1P000?l80?ooo`@0o`001@3oool20000
o`@0oooo0P3o00040?ooo`80003o1@3oool20?l000L0oooo0P000?m>0?oo
o`00LP3ooomL0?3ol0030?l0003oool0oooo07/0oooo;`000?lQ0?oooaT0
o`003@3oool80000o`@0oooo0`3o00040?ooo`80003o103oool20?l000@0
oooo0P000?l50?ooo`80o`001`3oool20000od`0oooo001b0?oooe`0l?o`
00<0o`000?ooo`3oool0I@3ooolF0000ofT0oooo3@3o00080?ooo`<0003o
103oool20?l000@0oooo0P000?l40?ooo`80o`00103oool20000o`D0oooo
0P3o00070?ooo`80003oBP3oool00780ooooG03`oo000`3o0000oooo0?oo
o`1D0?oooa40003oS03oool50?l000H0oooo0`000?l30?ooo`80o`00103o
ool20000o`@0oooo0P3o00040?ooo`80003o1@3oool20?l000L0oooo0`00
0?m70?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo04/0oooo2@000?mg
0?oooah0003o3@3oool50?l000@0oooo0`000?l20?ooo`80o`00103oool2
0000o`@0oooo00<0o`000?ooo`3oool00`3oool20000o`D0oooo0P3o0008
0?ooo`80003oA@3oool00780ooooG03`oo000`3o0000oooo0?ooo`120?oo
o`T0003oWP3oool<0000o`H0oooo0`3o00040?ooo`80003o0P3oool00`3o
0000oooo0?ooo`030?ooo`80003o0`3oool20?l000D0oooo0P000?l50?oo
o`80o`00203oool30000od80oooo001b0?oooe`0l?o`00<0o`000?ooo`3o
ool0>P3oool80000ohT0oooo2P3o000P0?ooo`H0003o0`3oool20?l000@0
oooo00<0003o0?ooo`3oool00P3o00050?ooo`030000o`3oool0oooo0080
oooo0P3o00050?ooo`80003o1@3oool20?l000T0oooo0P000?m00?ooo`00
LP3ooomL0?3ol0030?l0003oool0oooo03D0oooo1@000?nK0?oooa/0o`00
2`3oool40000o`040?ooo`3o0000o`000?l00080oooo00@0003o0?ooo`3o
ool0oooo0P3o00040?ooo`030000o`3oool0oooo00<0oooo0P3o00050?oo
o`80003o1@3oool30?l000P0oooo0`000?lm0?ooo`00LP3ooomL0?3ol003
0?l0003oool0oooo0300oooo1@000?me0?ooo`<0o`00@`3oool<0?l000<0
oooo0P000?l20?ooo`80o`0000<0oooo0000o`3oool00`3oool20?l000<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`80
003o1P3oool20?l000T0oooo10000?li0?ooo`00LP3ooomL0?3ol0030?l0
003oool0oooo02h0oooo0P000?mP0?oooaX0o`008@3ooolM0000oa@0oooo
103o00000`3oool0003o0?ooo`020?ooo`040?l0003oool0003o0000o`@0
oooo00@0o`000?ooo`3oool0oooo0P000?l50?ooo`80o`001P3oool20000
o`H0oooo0P3o000;0?ooo`@0003o=@3oool00780ooooG03`oo000`3o0000
oooo0?ooo`0[0?ooo`<0003oC@3ooolE0?l005P0oooo5@000?l30?ooo`03
0?l0003oool0003o0080oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo0P3o000=0?oo
o`<0003o<P3oool00780ooooG03`oo000`3o0000oooo0?ooo`0W0?ooo`@0
003o@P3oool>0?l00880oooo10000?l00`3o0000oooo0000o`020?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00@0oooo0P3o00060?ooo`80003o1`3oool30?l0
00d0oooo10000?l^0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo02@0
oooo0`000?ln0?ooo`P0o`00GP3ooole0?l000050000o`3oool0o`000?oo
o`000?l00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo0P000?l80?ooo`@0o`003@3oool40000obX0oooo001b0?oo
oe`0l?o`00<0o`000?ooo`3oool08P3oool20000ocT0oooo203o001V0?oo
oc@0l?o`00@0o`000000o`3oool0o`000P3oool010000?l0oooo0?ooo`3o
00030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool20000o`H0oooo0P3o00070?ooo`80003o2P3oool40?l000d0oooo1000
0?lV0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo0200oooo0P000?lc
0?ooo`P0o`00KP3ooold0?3ol0050?l0003oool0003o0?ooo`3o00000P3o
ool010000?l0oooo0?ooo`3o00030?ooo`80003o0`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool20000o``0oooo103o000=0?ooo`H0003o803oool00780ooooG03`
oo000`3o0000oooo0?ooo`0N0?ooo`80003o;P3oool70?l007H0oooo=03`
oo001@3o0000oooo0000o`3oool0o`0000<0oooo00@0003o0?ooo`3oool0
o`00103oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo0P000?l60?oo
o`80o`00203oool30000o`d0oooo103o000?0?ooo`D0003o6`3oool00780
ooooG03`oo000`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo02X0
oooo103o001m0?oooc@0l?o`00<0o`000?ooo`000?l00P3oool0103o0000
oooo0?ooo`000?l30?ooo`030?l0003oool0oooo0080oooo00@0003o0?oo
o`3oool0oooo0P3o00050?ooo`030000o`3oool0oooo00D0oooo0P3o0009
0?ooo`<0003o3P3oool40?l00100oooo1P000?lE0?ooo`00LP3ooomL0?3o
l0030?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool09P3oool50?l0
04d0oooo5`000?lM0?oooc@0l?o`00<0o`000?ooo`000?l00P3oool01@3o
0000oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo0P000?l7
0?ooo`80o`002P3oool30000o`l0oooo103o000B0?ooo`P0003o3@3oool0
0780ooooG03`oo000`3o0000oooo0?ooo`0J0?ooo`80003o9@3oool40?l0
04D0oooo3@000?ld0?oooc@0l?o`00<0o`000?ooo`000?l00`3oool0103o
0000oooo0?ooo`000?l30?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00H0oooo0P3o000;0?ooo`<0003o403oool60?l001@0oooo1P000?l7
0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo01T0oooo00<0003o0?oo
o`3oool0803oool50?l003/0oooo3P000?m10?oooc@0l?o`00@0o`000?oo
o`3oool0003o0P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80o`001@3o
ool20000o`P0oooo0`3o000;0?ooo`@0003o4P3oool50?l001`0oooo001b
0?oooe`0l?o`00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0M
0?ooo`@0o`00>@3oool70000odl0oooo=03`oo00103o0000oooo0?ooo`00
0?l20?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool20000o`T0oooo0`3o000<0?ooo`H0003o4@3oool60?l001H0oooo
001b0?oooe`0l?o`00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?oo
o`0L0?ooo`80o`00=P3oool70000oeH0oooo=03`oo00103o0000oooo0?oo
o`000?l30?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo0P3o00060?ooo`<0
003o2@3oool30?l000l0oooo10000?lC0?ooo`P0o`003P3oool00780oooo
G03`oo000`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01X0oooo
0`3o000`0?ooo`P0003oG@3ooold0?3ol0040?l0003oool0oooo0000o`<0
oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`00
00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?oo
o`80003o2P3oool30?l00100oooo10000?lG0?ooo`H0o`00203oool00780
ooooG03`oo000`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01T0
oooo0P3o000/0?ooo`L0003oI@3ooold0?3ol0050?l0003oool0oooo0?oo
o`000?l00`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool0103oool20000o`D0oooo0P3o00080?ooo`<0003o2P3oool3
0?l00140oooo10000?lQ0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo
01@0oooo00<0003o0?ooo`3oool0603oool20?l002H0oooo20000?m<0?oo
o`<0o`007@3ooold0?3ol0050?l0003oool0oooo0?ooo`000?l00`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`80o`002@3oool3
0000o`X0oooo103o000A0?ooo`L0003o6P3oool00780ooooG03`oo000`3o
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01L0oooo0P3o000R0?oo
o`H0003oA`3oool=0?l00200oooo=03`oo001@3o0000oooo0?ooo`3oool0
003o00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`090?ooo`<0003o2`3oool40?l001@0oooo30000?l>
0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool05P3oool20?l00200oooo10000?m00?ooo`d0o`00;@3ooold0?3o
l0050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`80o`00303oool30000o``0oooo1@3o000K
0?ooo`H0003o203oool00780ooooG03`oo000`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool0703oool40000
ocH0oooo3P3o000j0?oooc@0l?o`00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`050?ooo`80003o1`3oool20?l000d0oooo0`000?l>
0?ooo`H0o`008`3oool00780ooooG03`oo000`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo01@0oooo0P3o000L0?ooo`<0003o=03oool60?l0
04P0oooo=03`oo000`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool30?l0
00d0oooo0`000?lA0?ooo`T0o`006P3oool00780ooooG03`oo000`3o0000
oooo0?ooo`0@0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3o
ool06@3oool30000oc00oooo1`3o001>0?oooc@0l?o`00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00P0oooo0`3o000=0?ooo`@0003o5P3oool90?l00140
oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0C0?ooo`030?l0003oool0oooo01L0oooo0`000?l/0?ooo`L0o`00
E@3ooold0?3ol0030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
0P3o00070?ooo`80003o2`3oool30?l000h0oooo1P000?lI0?ooo`D0o`00
303oool00780ooooG03`oo000`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo0180oooo0P3o000H0?ooo`80003o9`3oool80?l005`0oooo=03`
oo000`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo0P000?l<0?ooo`<0o`004@3oool60000oaP0oooo0`3o
00090?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool0403oool20?l001L0oooo0`000?lT0?ooo`D0o`00A03oool3
0000oad0oooo=03`oo000`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`80o`00203oool30000o``0oooo103o000C0?ooo`H0003o7P3oool0
0780ooooG03`oo000`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo
0100oooo00<0o`000?ooo`3oool05@3oool20000ob<0oooo103o000m0?oo
o``0003o803ooold0?3ol0030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool0203oool30000o`d0oooo1@3o000D0?oo
o`H0003o603oool00780ooooG03`oo000`3o0000oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0503oool20000ob00
oooo1@3o000d0?ooo`d0003o;03ooold0?3ol0030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00H0oooo0P3o000;0?ooo`<0003o3`3oool40?l001H0
oooo2@000?l?0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0D0?ooo`030000
o`3oool0oooo01X0oooo1P3o000b0?ooo`L0003o>@3ooold0?3ol0030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00L0oooo0P3o000<0?ooo`80003o
4@3oool40?l001/0oooo1P000?l90?ooo`00LP3ooomL0?3ol0030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0C0?ooo`80003o6`3oool20?l00340oooo1`000?m00?oooc@0l?o`00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0203oool20?l000`0oooo0P00
0?lC0?ooo`H0o`00903oool00780ooooG03`oo000`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool04P3oool2
0000oa/0oooo0P3o000]0?ooo`H0003oA`3ooold0?3ol0030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00T0oooo0P3o000<0?ooo`D0003o503oool9
0?l001/0oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool0603oool30?l002P0oooo1`000?m=0?oooc@0l?o`00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo0P000?l;0?ooo`80o`003`3oool60000oaL0oooo303o000?0?oo
o`00LP3ooomL0?3ol0030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0@0?ooo`80003o5`3oool40?l002@0
oooo1`000?mD0?oooc@0l?o`00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo0P000?l;0?ooo`80
o`004`3oool70000oa`0oooo1P3o00090?ooo`00LP3ooomL0?3ol0030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo01@0oooo0`3o000Q0?ooo`L0003o
?03oool30?l001`0oooo=03`oo000`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool20000o`/0oooo
0`3o000G0?ooo`H0003o9@3oool00780ooooG03`oo000`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03`3o
ool20000oaD0oooo0P3o000O0?ooo`D0003o=`3oool<0?l001l0oooo=03`
oo000`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`@0o`006@3o
ool90000oa`0oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00h0oooo0P000?lE
0?ooo`80o`007@3oool40000ocD0oooo1`3o000[0?oooc@0l?o`00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`80o`002P3oool2
0000o`l0oooo103o000N0?ooo`/0003o4@3oool00780ooooG03`oo000`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0C0?ooo`80o`006`3oool40000
ob`0oooo3@3o000b0?oooc@0l?o`00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo0`000?l@0?oo
o`L0o`008P3oool70000o`X0oooo001b0?oooe`0l?o`00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool04@3oool30?l001X0oooo0`000?lY0?ooo`L0
o`00?`3ooold0?3ol0030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0;0?ooo`<0003o503oool70?l002`0
oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
403oool20?l001X0oooo0`000?lV0?ooo`H0o`00AP3ooold0?3ol0030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool20?l000h0oooo
0P000?lI0?ooo`L0o`009@3oool00780ooooG03`oo000`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3o
ool20000oa40oooo0P3o000H0?ooo`@0003o8P3oool70?l004`0oooo=03`
oo000`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo0P3o
000>0?ooo`<0003o7@3oool90?l001`0oooo001b0?oooe`0l?o`00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool03`3oool20?l001H0oooo10000?lQ
0?ooo`D0o`00D`3ooold0?3ol0030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool0303oool20?l000l0oooo1P000?lP0?oooa80o`002P3oool0
0780ooooG03`oo000`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0>0?oo
o`80o`005P3oool20000ob40oooo103o000j0?ooo`<0003o6`3ooold0?3o
l0030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool03@3oool20?l0
01<0oooo1`000?le0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0503oool20000oah0
oooo1@3o000a0?ooo`d0003o7P3ooold0?3ol0030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool03P3oool20?l001P0oooo1`000?l^0?ooo`00
LP3ooomL0?3ol0030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool04P3oool30000oa/0oooo1@3o000`0?ooo`H0003o
:`3ooold0?3ol0030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
403oool30?l001`0oooo40000?lN0?ooo`00LP3ooomL0?3ol0030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00d0oooo0P3o000C0?ooo`80003o6`3o
ool30?l002h0oooo1`000?la0?oooc@0l?o`00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0B0?ooo`H0o`009P3oool<0000oa80oooo001b
0?oooe`0l?o`00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0A0?ooo`80003o6P3oool30?l002@0oooo3@000?lh
0?oooc@0l?o`00<0o`000?ooo`3oool03P3oool20000oaP0oooo1P3o000/
0?ooo`P0003o2P3oool00780ooooG03`oo000`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0;0?ooo`80o`004@3oool30000oaP0oooo103o000Q0?oo
o`H0003oA@3ooold0?3ol0030?l0003oool0oooo0100oooo0`000?lK0?oo
o`X0o`00=03oool00780ooooG03`oo000`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00l0oooo0P000?lH0?ooo`<0
o`00803oool50000od/0oooo=03`oo000`3o0000oooo0?ooo`0C0?ooo`<0
003o8P3oool70?l002d0oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0>0?ooo`80003o
5P3oool40?l00200oooo0`000?m@0?oooc@0l?o`00<0o`000?ooo`3oool0
5P3oool40000obD0oooo4@3o000D0?ooo`@00000103oool00780ooooG03`
oo000`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0:0?ooo`80o`003`3o
ool20000oaD0oooo0`3o000O0?ooo`D0003o;`3oool90?l001/0oooo=03`
oo000`3o0000oooo0?ooo`0J0?ooo`@0003o<P3ooolB0?l00080oooo00<0
00000?ooo`3oool01@3oool00780ooooG03`oo000`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00d0oooo0P000?lE
0?ooo`80o`007@3oool50000obh0oooo1P3o000T0?oooc@0l?o`00<0o`00
0?ooo`3oool07P3oool80000ocl0oooo00<000000?ooo`3oool0103oool0
0780ooooG03`oo000`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool04`3oool20?l0
01/0oooo10000?l]0?ooo`H0o`00:P3ooold0?3ol0030?l0003oool0oooo
02H0oooo1P000?lj0?ooo`030000003oool0oooo00<0oooo001b0?oooe`0
l?o`00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0<0?ooo`80003o4`3oool30?l001T0oooo10000?lZ0?ooo`L0
o`00<03ooold0?3ol0030?l0003oool0oooo02`0oooo4@000?lW0?ooo`04
0000003oool0oooo000000@0oooo001b0?oooe`0l?o`00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo0100oooo0`3o000G0?ooo`D0003o8`3oool;0?l003L0
oooo=03`oo000`3o0000oooo0?ooo`0m0?ooobD0003o0`3oool2000000D0
oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00l0oooo
0P3o000F0?ooo`@0003o9@3oool30?l00480oooo=03`oo000`3o0000oooo
0?ooo`1/0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0>0?ooo`80o`005@3oool30000ob@0oooo1@3o00150?oooc@0l?o`00<0
o`000?ooo`3oool0K03oool00780ooooG03`oo000`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00/0oooo0P000?l?
0?ooo`80o`00503oool30000ob40oooo1P3o001:0?oooc@0l?o`00<0o`00
0?ooo`3oool0K03oool00780ooooG03`oo000`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool03@3oool20?l001<0oooo0`000?lM0?ooo`L0o`00;@3oool90000
oaX0oooo=03`oo000`3o0000oooo0?ooo`1/0?ooo`00LP3ooomL0?3ol003
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo0140
oooo0P000?lK0?ooo`D0o`00;P3oool60000ob<0oooo=000o`1Z0?l000D0
oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`0:0?ooo`80003o3P3oool20?l00180oooo
0P000?lJ0?ooo`<0o`00;@3oool60000obT0oooo=03`oo000`3o0000oooo
0?ooo`1V0?ooo`030000003oool0oooo00<0oooo001b0?oooe`0l?o`00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00`0oooo0P3o000A0?ooo`<0003o6@3o
ool30?l002<0oooo3@000?l_0?oooc@0l?o`00<0o`000?ooo`3oool0K03o
ool00780ooooG03`oo000`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00T0oooo0P000?l=0?ooo`80o`00403oool3
0000oaT0oooo0`3o000Q0?ooo`D0003o?03ooold0?3ol0030?l0003oool0
oooo06`0oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00/0oooo0P3o000@0?ooo`80003o603oool40?l00240oooo0`000?m10?oo
oc@0l?o`00<0o`000?ooo`3oool0A03ooolN0000o`X0oooo001b0?oooe`0
l?o`00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool03P3oool20000oaD0oooo1@3o000Q0?ooo`@0003oA03ooold0?3ol003
0?l0003oool0oooo0300oooo50000?lX0?ooo`00LP3ooomL0?3ol0030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool20000o``0oooo0P3o000?0?ooo`80003o4`3oool40?l00200oooo
1P000?l/0?ooo`<0o`006@3ooold0?3ol0030?l0003oool0oooo02H0oooo
2P000?ll0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00d0oooo0P000?lC0?ooo`80o`007@3o
ool70000ob`0oooo1P3o000L0?oooc@0l?o`00<0o`000?ooo`3oool07P3o
ool80000odH0oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool20000oa<0oooo0P3o000J
0?ooo`D0003o9`3oool<0?l00280oooo=03`oo000`3o0000oooo0?ooo`0J
0?ooo`@0003o?P3oool60?l000X0oooo001b0?oooe`0l?o`00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00X0oooo0P3o000>0?ooo`030000o`3oool0oooo
0140oooo0P3o000I0?ooo`<0003o9@3oool70?l002h0oooo=03`oo000`3o
0000oooo0?ooo`0F0?ooo`@0003o;03ooolF0?l00100oooo001b0?oooe`0
l?o`00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool0303oool20000oa40oooo0`3o000H0?ooo`<0003o8P3oool60?l003D0
oooo=03`oo000`3o0000oooo0?ooo`0D0?ooo`80003o8P3oool>0?l002H0
oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0>0?ooo`<0o`00
603oool30000oal0oooo1P3o000k0?oooc@0l?o`00<0o`000?ooo`3oool0
4P3oool20000oa/0oooo2@3o000d0?ooo`00LP3ooomL0?3ol0030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`080?ooo`80o`003@3oool20000o`l0oooo0P3o
000G0?ooo`@0003o703oool60?l00440oooo=03`oo000`3o0000oooo0?oo
o`0?0?ooo`<0003o5`3oool60?l003d0oooo001b0?oooe`0l?o`00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00L0oooo0P3o000=0?ooo`80003o3`3oool2
0?l001@0oooo1@000?lK0?ooo`D0o`00A`3ooold0?3ol0030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool04P3oool60?l002H0oooo4`000?l:
0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00/0oooo0P000?l?0?ooo`80o`004`3oool30000
oad0oooo0`3o000[0?ooo`P0003o6@3ooold0?3ol0030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool0403oool30?l00280oooo2P000?lM0?oo
o`00LP3ooomL0?3ol0030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00X0oooo0P000?l?0?ooo`80o`004`3oool20000oa`0
oooo103o000X0?ooo`H0003o8@3ooold0?3ol0030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool03`3oool20?l001L0oooo3P000?lW0?ooo`00
LP3ooomL0?3ol0050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`80o`002`3oool20000o`l0
oooo0P3o000C0?ooo`80003o6@3oool50?l002H0oooo1P000?lW0?oooc@0
l?o`00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0=0?ooo`<0
o`00503oool50000ocD0oooo001b0?oooe`0l?o`00D0o`000?ooo`3oool0
oooo0000o`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`80
o`004`3oool20000oaP0oooo0`3o000U0?ooo`H0003o;@3ooold0?3ol003
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0303oool20?l001<0
oooo10000?lZ0?ooo`H0o`002P3oool00780ooooG03`oo001@3o0000oooo
0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`090?ooo`80003o3P3oool20?l00180
oooo0`000?lF0?ooo`@0o`008P3oool60000oc<0oooo=03`oo000`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo0P3o000B0?ooo`<0
003o6@3ooolE0?l00100oooo001b0?oooe`0l?o`00D0o`000?ooo`3oool0
oooo0000o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool0203oool20000o`h0oooo0P3o000A0?ooo`<0
003o503oool50?l001l0oooo1`000?li0?oooc@0l?o`00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00h0
oooo10000?lE0?ooo`L0o`009@3oool00780ooooG03`oo00103o0000oooo
0?ooo`000?l40?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`80003o203oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00`0oooo0P3o000@0?ooo`<0
003o503oool30?l001h0oooo1P000?m00?oooc@0l?o`00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`090?ooo`80o`003@3oool40000oa80
oooo1`3o000/0?ooo`00LP3ooomL0?3ol0040?l0003oool0oooo0000o`<0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool03@3oool30000oa@0oooo0`3o000L0?ooo`D0003oAP3ooold0?3ol003
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0:0?ooo`<0003o4@3oool50?l002<0oooo1P000?l:0?ooo`00
LP3ooomL0?3ol0040?l0003oool0oooo0000o`<0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`80
003o3@3oool20?l000h0oooo0P000?lD0?ooo`<0o`006P3oool50000od/0
oooo=03`oo000`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool02@3oool20000oa40oooo0`3o000L0?ooo``0
003o403oool00780ooooG03`oo000`3o0000oooo0000o`030?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0;0?ooo`80o`003P3oool20000oa<0oooo
0`3o000I0?ooo`@0003oD03ooold0?3ol0030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01P3oool20?l000X0oooo0P000?l@0?ooo`<0o`00
5`3oool80000oa`0oooo001b0?oooe`0l?o`00<0o`000?ooo`000?l00`3o
ool01@3o0000oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`80o`002@3oool00`000?l0oooo
0?ooo`0:0?ooo`80o`003P3oool20000oa80oooo0`3o000H0?ooo`@0003o
E03ooold0?3ol0030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`080?ooo`80003o3P3oool40?l001<0oooo
1`000?lT0?ooo`00LP3ooomM0?l000050?ooo`000?l0oooo0?ooo`3o0000
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool30000oa40oooo
0`3o000G0?ooo`@0003oF03ooold0?3ol0030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00/0oooo0`3o000A0?ooo`H0003o703oool60?l000T0oooo
003?0?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`070?ooo`80003o2`3oool20?l000`0oooo
0P000?lA0?ooo`<0o`005`3oool30000oe`0oooo=03`oo000`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`@0o`003`3oool50000oaX0oooo
203o000?0?ooo`00cP3oool20000o`80oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02P3oool20000oa00oooo0`3o000G0?ooo`<0003o
G`3ooold0?3ol0030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`070?ooo`80003o2@3oool20?l000l0oooo
10000?lI0?ooo`H0o`005`3oool00<P0oooo1P000?l20?ooo`80o`000`3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00T0oooo0P3o000;0?ooo`80003o403oool20?l001L0oooo0`00
0?mR0?oooc@0l?o`00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3o
ool20?l000h0oooo0`000?lD0?ooo`T0o`007@3oool00;d0oooo2`000?l7
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool20000o`X0oooo0P3o000;0?ooo`80003o403oool2
0?l001D0oooo10000?mU0?oooc@0l?o`00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo0P000?l8
0?ooo`80o`00303oool40000o`l0oooo203o000V0?ooo`00RP3ooolc0000
o`l0oooo0`3o00040?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00h0oooo0P3o000B0?ooo`D0003oJ@3ooold0?3o
l0030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo0P3o000;0?oo
o`<0003o3`3oool40?l001l0oooo1P000?l90?ooo`00LP3ooolH0000ocl0
oooo0`3o00060?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool0203oool20?l000/0oooo0P000?l?0?ooo`80
o`004@3oool30000ofh0oooo=03`oo000`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo0`000?l>0?ooo`@0
o`00603oool;0000o`l0oooo00330?ooo`H0o`001`3oool20000o`@0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo0P000?l90?ooo`80o`002`3oool20000o`h0oooo
0`3o000@0?ooo`<0003oL@3ooold0?3ol0030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo0P3o00090?ooo`80003o303oool50?l001<0oooo
2@000?lJ0?ooo`00_@3oool60?l000X0oooo0`000?l50?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3o
ool20000o`h0oooo0P3o000A0?ooo`80003oM03ooold0?3ol0030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3o
ool20000o``0oooo0P3o000B0?ooo`H0003o8`3oool00:`0oooo4@3o000=
0?ooo`<0003o1P3oool20?l000H0oooo00<0003o0?ooo`3oool0103oool2
0?l000L0oooo00<0003o0?ooo`3oool01`3oool20?l000X0oooo0P000?l>
0?ooo`80o`00403oool30000ogH0oooo=03`oo000`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`80o`00203oool20000o``0oooo0P3o000?
0?ooo`D0003o6`3oool50?l000T0oooo002:0?ooob80o`006`3oool30000
o`P0oooo00<0o`000?ooo`3oool0103oool20000o`H0oooo00<0o`000?oo
o`3oool01@3oool20000o`P0oooo0P3o000:0?ooo`80003o3P3oool20?l0
00l0oooo0`000?mi0?oooc@0l?o`00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`060?ooo`80003o2`3oool30?l0
00h0oooo0`000?lE0?ooo`/0o`003P3oool00780oooo603o000h0?ooo`D0
003o2@3oool20?l000D0oooo0P000?l70?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`80
003o3P3oool20?l000l0oooo0P000?ml0?oooc@0l?o`00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00T0oooo0P3o000=0?ooo`@0003o3`3oool90?l001T0
oooo002m0?ooo`D0003o303oool20?l000D0oooo0P000?l70?ooo`80o`00
1`3oool00`000?l0oooo0?ooo`060?ooo`80o`002@3oool20000o`h0oooo
0P3o000?0?ooo`80003oOP3ooold0?3ol0030?l0003oool0oooo0080oooo
00D0003o0?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool01@3oool20000o`T0oooo0`3o000:0?ooo`D0
003o3@3oool60?l00280oooo002d0?ooo`T0003o3`3oool20?l000H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`80003o
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00`0oooo
0P3o000?0?ooo`80003oP03ooold0?3ol0050?l0003oool0oooo0?ooo`00
0?l0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`<0
o`002P3oool30000o`d0oooo1@3o000J0?ooo`H0003o203oool00:@0oooo
40000?lD0?ooo`@0o`001P3oool20000o`L0oooo0P3o00070?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`0:0?ooo`<0o`003`3oool20000oh80oooo=03`oo001@3o0000oooo
0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool20?l000X0oooo0`000?l<0?ooo`@0o`005`3oool80000o`h0
oooo002:0?oooaX0003o7`3oool50?l000P0oooo0P000?l70?ooo`80o`00
203oool00`000?l0oooo0?ooo`060?ooo`80o`002@3oool20000o`/0oooo
0P3o000?0?ooo`<0003oQ03ooold0?3ol0050?l0003oool0oooo0?ooo`00
0?l00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00L0oooo0`000?l;0?ooo`@0o`005@3oool60000oaH0
oooo001b0?oooaP0003o<P3oool70?l000/0oooo0P000?l70?ooo`80o`00
203oool20000o`P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`090?ooo`80o`003P3oool30000ohL0oooo=03`oo001@3o0000oooo
0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`030?l0003oool0oooo00@0oooo0P000?l60?ooo`80o`00203oool20000
o`X0oooo103o000C0?ooo`H0003o703oool00;@0oooo203o000@0?ooo`80
003o1`3oool20?l000T0oooo00<0003o0?ooo`3oool01P3oool20?l000T0
oooo0P000?l:0?ooo`80o`003P3oool20000ohX0oooo=03`oo00103o0000
oooo0?ooo`000?l30?ooo`030?l0003oool0oooo0080oooo00D0003o0?oo
o`3oool0oooo0?l000060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool20000o`X0oooo0P3o000A0?ooo`H0003o5@3oool5
0?l000P0oooo002]0?ooo`L0o`005P3oool20000o`L0oooo0P3o00090?oo
o`80003o1`3oool20?l000T0oooo0P000?l:0?ooo`80o`003@3oool30000
oh`0oooo=03`oo00103o0000oooo0?ooo`000?l30?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool20000o`X0oooo0P3o
000?0?ooo`@0003o4`3oool80?l000d0oooo002T0?ooo`T0o`005`3oool6
0000o`L0oooo0P3o00090?ooo`80003o1`3oool20?l000T0oooo0P000?l;
0?ooo`030?l0003oool0oooo00/0oooo0P000?n?0?oooc@0l?o`00@0o`00
0?ooo`3oool0003o0`3oool0103o0000oooo0?ooo`000?l40?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool20?l000L0oooo
00<0003o0?ooo`3oool01`3oool30?l000d0oooo10000?lA0?ooo`H0o`00
5@3oool008X0oooo6P3o000K0?ooo`D0003o2P3oool30?l000T0oooo0P00
0?l70?ooo`80o`002@3oool20000o`/0oooo0P3o000<0?ooo`80003oT@3o
oold0?3ol0040?l0003oool0oooo0000o`80oooo00D0o`000?ooo`3oool0
oooo0000o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00`3oool20?l000L0oooo0P000?l80?ooo`80o`00303oool40000o`l0
oooo1P3o000K0?ooo`00LP3ooolH0?l00340oooo10000?l=0?ooo`80o`00
2@3oool30000o`P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`090?ooo`80o`00303oool20000oi<0oooo=03`oo000`3o0000oooo
0000o`030?ooo`040?l0003oool0oooo0000o`<0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00D0
oooo0P000?l70?ooo`<0o`002`3oool30000o`d0oooo1P3o000D0?ooo`H0
003o1`3oool00;D0oooo1P000?l?0?ooo`80o`002@3oool20000o`T0oooo
0P3o00090?ooo`80003o2P3oool20?l000`0oooo0P000?nE0?oooc@0l?o`
00<0o`000?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l20?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool20?l000H0
oooo0P000?l70?ooo`80o`002`3oool30000o``0oooo103o000B0?ooo`P0
003o3@3oool00:d0oooo20000?lB0?ooo`<0o`002@3oool20000o`T0oooo
0P3o00090?ooo`80003o2P3oool20?l000`0oooo0P000?nG0?oooc@0l?o`
00<0o`000?ooo`000?l00P3oool0103o0000oooo0?ooo`000?l30?ooo`03
0?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0oooo0P3o00060?oo
o`80003o1P3oool30?l000X0oooo0`000?l;0?ooo`@0o`00403oool60000
oaD0oooo002L0?oooa40003o5P3oool40?l000T0oooo0`000?l90?ooo`80
o`002@3oool20000o`X0oooo0P3o000<0?ooo`80003oV@3ooold0?3ol003
0?l0003oool0003o0080oooo00@0o`000?ooo`3oool0003o0P3oool00`3o
0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00001`3oool0
0`000?l0oooo0?ooo`040?ooo`80o`002P3oool30000o`X0oooo103o000?
0?ooo`D0003o6`3oool008X0oooo4P000?lQ0?ooo`H0o`002`3oool20000
o`X0oooo0P3o00090?ooo`80003o2P3oool20?l000`0oooo0P000?nK0?oo
oc@0l?o`00D0o`000?ooo`000?l0oooo0?l000020?ooo`040000o`3oool0
oooo0?l000<0oooo0P000?l30?ooo`030?l0003oool0oooo00@0oooo0P00
0?l50?ooo`80o`002@3oool30000o`X0oooo0`3o000=0?ooo`H0003o803o
ool007P0oooo4P000?l[0?ooo`P0o`003P3oool30000o`X0oooo0P3o000:
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool2
0000oid0oooo=03`oo00103o0000oooo0000o`3o00020?ooo`040000o`3o
ool0oooo0?l000<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo0P3o00090?ooo`80003o
2@3oool40?l000`0oooo10000?lV0?ooo`00LP3oool60000ocD0oooo203o
000C0?ooo`<0003o2`3oool20?l000X0oooo0P000?l:0?ooo`80o`002P3o
ool30000oil0oooo=@3o00000`000?l0oooo0?l000020?ooo`030000o`3o
ool0o`0000<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`80003o1@3oool00`3o0000oooo0?ooo`060?ooo`<0003o1`3o
ool40?l000`0oooo10000?lZ0?ooo`00Y03oool90?l001L0oooo10000?l<
0?ooo`80o`002P3oool20000o`X0oooo0P3o000:0?ooo`80003oe@3oool3
0000o`040?l0003oool0oooo0000o`80oooo00@0o`000?ooo`3oool0003o
103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
0P3o00070?ooo`80003o1`3oool30?l000`0oooo10000?l^0?ooo`00W03o
ool80?l001`0oooo10000?l=0?ooo`<0o`002P3oool20000o`X0oooo0P3o
000:0?ooo`80003ob`3oool=0000o`030?ooo`3o0000oooo0080003o0P3o
ool0103o0000oooo0?ooo`000?l40?ooo`030?l0003oool0oooo0080oooo
0P000?l50?ooo`030?l0003oool0oooo00D0oooo0P000?l70?ooo`80o`00
303oool30000oc80oooo002C0?ooo`T0o`00803oool40000o`d0oooo103o
000:0?ooo`<0003o2P3oool20?l000X0oooo0P000?nV0?ooobL0003o303o
ool20?l000030?ooo`000?l0oooo0080oooo00@0o`000?ooo`3oool0003o
103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo
0P3o00060?ooo`80003o1`3oool20?l000X0oooo10000?le0?ooo`00N03o
oolK0?l002<0oooo1P000?l=0?ooo`@0o`00303oool20000o`X0oooo0`3o
000:0?ooo`80003odP3oool90?l000030?ooo`000?l0003o00<0oooo00@0
o`000?ooo`3oool0003o0`3oool20?l000@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`80003o1`3oool20?l000P0oooo
10000?li0?ooo`00LP3oool60?l003H0oooo20000?lA0?ooo`80o`003@3o
ool30000o`X0oooo0P3o000;0?ooo`80003o``3ooolA0?l000P0oooo0P00
0?l30?ooo`80o`000P3oool00`000?l0oooo0?ooo`020?l000@0oooo0P00
0?l40?ooo`80o`001@3oool20000o`L0oooo0P3o00070?ooo`<0003o?@3o
ool00:D0oooo2@000?lF0?ooo`<0o`00303oool30000o`X0oooo0`3o000;
0?ooo`80003o[03ooolI0?l001@0oooo1@000?l40?ooo`060?l0003oool0
oooo0?ooo`000?l0oooo0P3o00050?ooo`030000o`3oool0oooo0080oooo
0P3o00050?ooo`80003o1`3oool20?l000L0oooo0P000?m00?ooo`00W03o
ool90000oaX0oooo1@3o000<0?ooo`<0003o2P3oool30?l000`0oooo0P00
0?o?0?ooo``0003o1P3oool30?l000060?ooo`000?l0003o0000o`3oool0
o`001@3oool20000o`<0oooo0P3o00060?ooo`030000o`3oool0oooo00D0
oooo0P3o00060?ooo`<0003o@P3oool009<0oooo2@000?lM0?ooo`H0o`00
3P3oool30000o`/0oooo0P3o000=0?ooo`80003o^P3ooolG0000o`d0oooo
1@3o0000103oool0003o0000o`000?l20?ooo`80o`00103oool20000o`@0
oooo00<0o`000?ooo`3oool0103oool20000o`D0oooo0`3o00060?ooo`80
003oA@3oool00880oooo4@000?lR0?ooo`@0o`004@3oool30000o``0oooo
0P3o000<0?ooo`<0003o/P3oool:0000oa`0oooo203o00030?ooo`<0003o
0`3oool20?l000@0oooo0P000?l40?ooo`80o`001@3oool20000o`D0oooo
0P3o00060?ooo`<0003oA`3oool00780oooo40000?l/0?ooo`L0o`004@3o
ool40000o`d0oooo0P3o000<0?ooo`80003ocP3oool=0?l000P0oooo0`00
0?l50?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool20?l000D0oooo0P000?l50?ooo`80o`001P3oool20000odX0oooo002U
0?ooo`T0o`00503oool40000o`h0oooo0`3o000;0?ooo`<0003o]`3ooolI
0?l000h0oooo1`000?l60?ooo`80o`00103oool20000o`<0oooo0P3o0005
0?ooo`80003o1@3oool20?l000H0oooo0P000?m<0?ooo`00W@3oool80?l0
01T0oooo10000?l@0?ooo`80o`002`3oool30000omX0oooo1`000?l80?oo
o`D0o`00103oool20000o`<0oooo0P3o00050?ooo`80003o1@3oool20?l0
00H0oooo0P000?m>0?ooo`00U03oool90?l001d0oooo10000?lA0?ooo`<0
o`002`3oool20000oll0oooo3P000?l;0?ooo`@0o`001P3oool30000o`<0
oooo0P3o00050?ooo`80003o1@3oool20?l000H0oooo0P000?m@0?ooo`00
PP3ooolB0?l00280oooo10000?lA0?ooo`@0o`00303oool20000okl0oooo
4P000?lE0?ooo`@0o`001`3oool30000o`@0oooo0P3o00050?ooo`80003o
1@3oool20?l000H0oooo0P000?mB0?ooo`00LP3oool@0?l002d0oooo1`00
0?lA0?ooo`@0o`003P3oool20000omX0oooo3P3o00080?ooo`<0003o103o
ool30?l000D0oooo0P000?l50?ooo`80o`001P3oool20000oe@0oooo002V
0?ooo`T0003o503oool40?l000h0oooo10000?o>0?ooo`h0o`003P3oool8
0000o`@0oooo0`3o00060?ooo`80003o103oool30?l000H0oooo0P000?mF
0?ooo`00W@3oool90000oaT0oooo103o000>0?ooo`@0003oa`3oool;0?l0
01D0oooo1`000?l90?ooo`<0o`001`3oool20000o`<0oooo0`3o00060?oo
o`<0003oF03oool009@0oooo2@000?lK0?ooo`L0o`003P3oool40000on@0
oooo1`000?l<0?ooo`@0o`001`3oool30000o`<0oooo0P3o00070?ooo`80
003oF`3oool008/0oooo2@000?lN0?ooo`H0o`004P3oool30000omX0oooo
3P000?l?0?ooo`@0o`00203oool30000o`@0oooo0P3o00060?ooo`<0003o
G@3oool007T0oooo4P000?lS0?ooo`@0o`005@3oool30000om80oooo2`00
0?lF0?ooo`L0o`001`3oool50000o`@0oooo0`3o00050?ooo`<0003oH03o
ool00780oooo1`000?l^0?ooo`L0o`005P3oool30000onL0oooo3`3o0007
0?ooo`L0003o1@3oool40?l000H0oooo0P000?mS0?ooo`00WP3oool90?l0
01T0oooo10000?oL0?ooo`h0o`003`3oool70000o`T0oooo0`3o00080?oo
o`80003oI@3oool009D0oooo2@3o000K0?ooo`L0003og03oool40?l001H0
oooo1`000?l<0?ooo`@0o`00203oool30000ofL0oooo002<0?ooo`T0o`00
7@3oool70000ooH0oooo1`000?l>0?ooo`D0o`00203oool40000ofX0oooo
001i0?oooa<0o`008P3oool40000onh0oooo3`000?l>0?ooo`L0o`00203o
ool50000ofh0oooo001b0?ooo`L0o`00;P3oool70000onh0oooo10000?lF
0?ooo`L0o`002P3oool50000og<0oooo002N0?ooo`T0003oo`3oool90?oo
o`L0o`003@3oool40000ogP0oooo002E0?ooo`T0003oo`3oool30?ooo`l0
o`003`3oool50000og`0oooo002<0?ooo`T0003oo`3oool80?ooo`@0o`00
5`3oool70000oh40oooo00230?ooo`T0003oo`3ooolM0?ooo`l0003oR03o
ool007@0oooo3`000?oo0?oooaX0oooo30000?nG0?ooo`00LP3oool20000
ool0ooooc03oool00?l0ooooo`3ooom10?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{575, 178},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.87",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/fluidflowimage/\
FluidFlowImageFigures/mat1187.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  (a) Flow over a step.\n\t\t\t\t\t(b) Flow around a blunt object."
}], "Text"],

Cell[TextData[{
  "Hint:  Set  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 1\)}]]],
  "  and   ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \(-\[ImaginaryI]\)\)}]]],
  ".  In the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  "-plane ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = 0\)}]]],
  ", and the exterior angles are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(-\(\[Pi]\/2\)\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(\[Pi]\/2\)}]}]]],
  ",  and the formula for the derivative ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " is  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z - \
\((\(-1\))\))\)\^\(\(-\((\(-\(\[Pi]\/2\)\))\)\)/\[Pi]\)\) \((z - \
1)\)\^\(\(-\((\[Pi]\/2)\)\)/\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(1\/2\)\) \((z - 1)\)\^\(-\(1\/2\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \((z + \
1)\)\^\(1\/2\)\/\((z - 1)\)\^\(1\/2\)\)\)\)}]],
  "\n"
}], "Text"],

Cell[TextData[{
  "Integrate and get  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\ \  = \ \ B\ \  + \ \ A\ \(\[Integral]\(\((z + \
1)\)\^\(1\/2\)\/\((z - 1)\)\^\(1\/2\)\) \[DifferentialD]z\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(B\ \  + \ 
          A\ \((\((z\^2 - 1)\)\^\(1\/2\) + 
                Log \((z + \((z\^2 - 1)\)\^\(1\/2\))\))\)\)\)\)}]],
  " \n\nSolve for the coefficients A and B and obtain \n\n\t\t\t",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\ \  = \ \(1\/\[Pi]\) \((\((z\^2 - 1)\)\^\(1\/2\) \
+ Log \((z + \((z\^2 - 1)\)\^\(1\/2\))\))\)\)\)]]
}], "Text"],

Cell[TextData[{
  "It maps the upper half-plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  onto the domain in the w plane that lies above the boundary curve \
consisting of the rays  ",
  Cell[BoxData[
      RowBox[{\(u \[LessEqual] 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"v", "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "u"}], "\[GreaterEqual]", 
            "0"}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(v = 0\)}]]],
  " and the segment  ",
  Cell[BoxData[
      RowBox[{\(u = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\(-1\) \[LessEqual] v \[LessEqual] 
          0\)}]]],
  ".  Furthermore, the image of horizontal streamlines in the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane are curves in the w plane given by the parametric equation \n\n\t\t\
",
  Cell[BoxData[{
      \(\(\(w\ \  = \ \ \(u\  + \ \[ImaginaryI]\ v\ \  = \ \ f \((t + \
\[ImaginaryI]\ c)\)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(\(=\)\(\ \ \)\(\(1\/\[Pi]\) \((\((\((t + \[ImaginaryI]\ \
c)\)\^2 - 1)\)\^\(1\/2\) + 
              Log \((t + \[ImaginaryI]\ c + \((\((t + \[ImaginaryI]\ c)\)\^2 \
- 1)\)\^\(1\/2\))\))\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\ \ \)\(\(1\/\[Pi]\) \((\((\ t\^2 - c\^2 - 1 + \ \
\[ImaginaryI]\ 2  c\ t)\)\^\(1\/2\) + 
              Log \((t + \[ImaginaryI]\ c + \((\ t\^2 - c\^2 - 1 + \ \
\[ImaginaryI]\ 2  c\ t)\)\^\(1\/2\))\))\)\)\)\)}]],
  "\n\nfor  ",
  Cell[BoxData[
      \(\(-\[Infinity]\) < t < \[Infinity]\)]],
  ".  The new flow is that of a step in the bed of a deep stream and is \
illustrated in Figure 11.87(a).  The function ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  " is also defined for values of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " in the lower half-plane, and the images of horizontal streamlines that \
lie above or below the ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " axis are mapped onto streamlines that flow past a long rectangular \
obstacle, which is illustrated in Figure 11.87(b)."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.29.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Use the Schwarz Christoffel formula, enter the formula  ",
  Cell[BoxData[
      \(\(f'\)[z] = \(A \((z + 1)\)\^\(1\/2\)\)\/\((z - 1)\)\^\(1\/2\)\)],
    AspectRatioFixed->True],
  "  and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[A, B, z, f, f1, F];\)\ \), "\n", 
    \(\(f1[
          z_]\  = \ \(A \((z + 1)\)\^\(1\/2\)\)\/\((z - 1)\)\^\(1\/2\);\)\ \
\), "\n", 
    \(\(f[z_]\  = \ 
        B\  + \ A \(\[Integral]\(\((z + 1)\)\^\(1\/2\)\/\((z - 1)\)\^\(1\/2\)\
\) \[DifferentialD]z\);\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = B + \[Integral] \>", 
        f1[z], "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
This is one, formula for the integral.   However, we will use the following \
form of the integral to continue the computations.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f1[
          z_]\  = \ \(A\ \((z\  + \ 1)\)\)\/\@\(z\^2\  - \ 1\);\)\ \), "\n", 
    \(\(F[z_]\  = \ 
        B\  + \ \[Integral]\(\(A\ \((z\  + \ 
                        1)\)\)\/\@\(z\^2\  - \ 1\)\) \[DifferentialD]z;\)\ \
\), "\n", 
    \(\(Print["\<f'[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = B + \[Integral] \>", 
        f1[z], "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(eq1\  = \ F[\(-1\)]\  \[Equal] \ \ 0;\)\ \), "\n", 
    \(\(eq2\  = \ \ F[1]\  \[Equal] \ \(-\[ImaginaryI]\);\)\ \), "\n", 
    \(\(solset\  = \ Solve[{eq1, eq2}, {A, B}];\)\ \), "\n", 
    \(\(f[z_]\  = \ 
        ReplaceAll[F[z], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \), "\n", 
    \(\(Print[eq1];\)\ \), "\n", 
    \(\(Print[eq2];\)\ \), "\n", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<f[z] = B + A \!\(\@\(\(-1\) + z\^2\)\)+ A Log[z+\!\(\@\(\
\(-1\) + z\^2\)\)]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Unfortunately, the branch cuts don't work out right and we will have to do \
this one by hand.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[z_]\  = \ 
        ReplaceAll[F[z], {A \[Rule] 1\/\[Pi], B \[Rule] 0}];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Using this formula in the book we form the two branches of the function.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[f1, f2];\)\ \), "\n", 
    \(\(f1[
          z_]\  = \ \(\(\ \)\(\@\((z\^2 - 1)\) + Log[z + \@\(z\^2 - \
1\)]\)\)\/\[Pi];\)\ \), "\n", 
    \(\(f2[
          z_]\  = \ \(\(-\@\((z\^2 - 1)\)\) + Log[z - \@\(z\^2 - \
1\)]\)\/\[Pi];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_1\)[z] = \>\"", f1[z]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_2\)[z] = \>\"", 
        f2[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(g1\  = \ 
        CartesianMap[
          f1, {0, 2, 0.25}, {0.00001, 1.20001, 
            0.2}, \[IndentingNewLine]PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(g2\  = \ 
        CartesianMap[
          f2, {\(-6.00001\), \(-0.00001\), 0.25}, \[IndentingNewLine]{\ 
            0.00001, 1.20001, 0.2}, PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[g1, g2, Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1, 0.5]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<is the domain that lies above the boundary curve \
consisting\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<of the rays u\[LessEqual]0,v=1 and u\[GreaterEqual]0,v=0 and \
the segment u=0,-1\[LessEqual]v\[LessEqual]0,\>"];\)\ \), "\n", 
    \(\(Print["\<where  w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        Table[{Re[f1[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f1[x + \[ImaginaryI]\ 0.2  k]]}, {k, 1, 11, 2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {x, 0, 4}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[f1[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f1[x + \[ImaginaryI]\ 0.2  k]]}, {k, 2, 11, 2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {x, 0, 4}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns3\  = \ 
        Table[{Re[f2[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f2[x + \[ImaginaryI]\ 0.2  k]]}, {k, 1, 11, 2}];\)\ \), "\n", 
    \(\(graph3 = 
        ParametricPlot[Evaluate[eqns3], {x, \(-9\), 0}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns4\  = \ 
        Table[{Re[f2[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f2[x + \[ImaginaryI]\ 0.2  k]]}, {k, 2, 11, 2}];\)\ \), "\n", 
    \(\(graph4 = 
        ParametricPlot[Evaluate[eqns4], {x, \(-9\), 0}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Red, 
            Line[{{\(-1\), 1}, {0, 1}, {0, 0}, {2, 
                  0}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, graph4, boundary, 
        PlotRange \[Rule] {{\(-1\), 2}, {\(-0.1\), 1.6}}, 
        AspectRatio \[Rule] 1.8\/3, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0, 1, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0,\>"];\)\ \), "\n\
", 
    \(\(Print["\<under w = f[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We have shown that the mapping  ",
  Cell[BoxData[
      \(w = \(1\/\[Pi]\) \((\@\(z\^2 - 1\) + 
                Log[z + \@\(z\^2 - 1\)])\) - \[ImaginaryI]\)]],
  "  maps the upper half plane ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  onto the domain in the w-plane that lies above the boundary curve \
consisting of the rays  ",
  Cell[BoxData[
      \(u \[LessEqual] 0, v = 1\ \ and\ \ u \[GreaterEqual] 0, v = 0\)]],
  " and the segment  ",
  Cell[BoxData[
      \(u = 0, \(-1\) \[LessEqual] v \[LessEqual] 0\)]],
  ".    "
}], "Text"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Here is another function that produces the desired result.  The graph is \
drawn parametrically in this case."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[
          z_]\  = \ \(\[ImaginaryI] \@\( 1\  - \ z\^2\)\  + \ \(\[ImaginaryI]\
\ \[Pi]\)\/2\  - \ \[ImaginaryI]\ ArcSin[z]\)\/\[Pi];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.2  k]]}, {k, 1, 11, 2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {x, \(-9\), 4}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.2  k]]}, {k, 2, 11, 2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {x, \(-9\), 4}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Red, 
            Line[{{\(-1\), 1}, {0, 1}, {0, 0}, {2, 
                  0}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, boundary, 
        PlotRange \[Rule] {{\(-1\), 2}, {\(-0.1\), 1.6}}, 
        AspectRatio \[Rule] 1.8\/3, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0, 1, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0,\>"];\)\ \), "\n\
", 
    \(\(Print["\<under w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[
          z_]\  = \ \(\[ImaginaryI] \@\( 1\  - \ z\^2\)\  + \ \(\[ImaginaryI]\
\ \[Pi]\)\/2\  - \ \[ImaginaryI]\ ArcSin[z]\)\/\[Pi];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.2  k]]}, {k, 1, 11, 2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {x, \(-9\), 4}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.2  k]]}, {k, 2, 11, 2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {x, \(-9\), 4}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns3\  = \ 
        Table[{Re[
              f[x + \[ImaginaryI]\ 0.2  k]], \(-Im[
                f[x + \[ImaginaryI]\ 0.2  k]]\)}, {k, 1, 11, 
            2}];\)\ \), "\n", 
    \(\(graph3 = 
        ParametricPlot[Evaluate[eqns3], {x, \(-9\), 4}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns4\  = \ 
        Table[{Re[
              f[x + \[ImaginaryI]\ 0.2  k]], \(-Im[
                f[x + \[ImaginaryI]\ 0.2  k]]\)}, {k, 2, 11, 
            2}];\)\ \), "\n", 
    \(\(graph4 = 
        ParametricPlot[Evaluate[eqns4], {x, \(-9\), 4}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Red, Line[{{\(-1\), 1}, {0, 1}, {0, 0}, {2, 0}}], 
            Line[{{\(-1\), \(-1\)}, {0, \(-1\)}, {0, 0}, {2, 
                  0}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, graph4, boundary, 
        PlotRange \[Rule] {{\(-1\), 2}, {\(-1.6\), 1.6}}, 
        AspectRatio \[Rule] 3.2\/3, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0, 1, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the z-plane,\>"];\)\ \), "\n", 
    \(\(Print["\<under w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Also, we have shown that the mapping  ",
  Cell[BoxData[
      \(w = \(\(\[ImaginaryI]\ \[Pi]\)\/2 + \[ImaginaryI]\ \@\(1 - z\^2\) - \
\[ImaginaryI]\ ArcSin[z]\)\/\[Pi]\)]],
  "  maps the upper half plane ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  onto the domain in the w-plane that lies above the boundary curve \
consisting of the rays  ",
  Cell[BoxData[
      \(u \[LessEqual] 0, v = 1\ \ and\ \ u \[GreaterEqual] 0, v = 0\)]],
  " and the segment  ",
  Cell[BoxData[
      \(u = 0, \(-1\) \[LessEqual] v \[LessEqual] 0\)]],
  ".    "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.30.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox["(Source and sink of equal strength)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let a source and sink of unit strength be located at the points ",
  Cell[BoxData[
      \(z\_1 = \(+1\)\)]],
  " and ",
  Cell[BoxData[
      \(z\_2 = \(-1\)\)]],
  ", respectively.  The complex potential for a fluid flowing from the source \
at  ",
  Cell[BoxData[
      \(z\_1 = \(+1\)\)]],
  "  to the sink at  ",
  Cell[BoxData[
      \(z\_2 = \(-1\)\)]],
  "  is  \n\n\t\t\t",
  Cell[BoxData[
      \(F \((z)\)\ \  = \ \ \(log \((z - 1)\)\  - \ 
            log \((z + 1)\)\ \  = \ \ log \((\(z - 1\)\/\(z + 1\))\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005B0000i2000`400?l0
0000o`00003oo`3ooomC0?ooo`00o`3ooomC0?ooo`00o`3ooomC0?ooo`00
o`3ooomC0?ooo`00o`3ooomC0?ooo`00R@3oool00`000?l0oooo0?ooo`2P
0?ooo`030000o`3oool0oooo02<0oooo00280?ooo`030000o`3oool0oooo
0:80oooo00<0003o0?ooo`3oool08P3oool008P0oooo00<0003o0?ooo`3o
ool0XP3oool00`000?l0oooo0?ooo`0R0?ooo`00Q`3oool00`000?l0oooo
0?ooo`2S0?ooo`030000o`3oool0oooo0280oooo00270?ooo`030000o`3o
ool0oooo04`0oooo2@3o001?0?ooo`030000o`3oool0oooo0240oooo0026
0?ooo`030000o`3oool0oooo04H0oooo1`3o00090?ooo`T0o`00AP3oool0
0`000?l0oooo0?ooo`0Q0?ooo`00QP3oool00`000?l0oooo0?ooo`120?oo
o`@0o`006@3oool30?l004<0oooo00<0003o0?ooo`3oool08@3oool008H0
oooo00<0003o0?ooo`3oool0?P3oool40?l00200oooo103o000o0?ooo`03
0000o`3oool0oooo0240oooo00260?ooo`030000o`3oool0oooo03`0oooo
0P3o000X0?ooo`<0o`00?@3oool00`000?l0oooo0?ooo`0P0?ooo`00Q@3o
ool00`000?l0oooo0?ooo`0k0?ooo`80o`00;@3oool20?l003/0oooo00<0
003o0?ooo`3oool0803oool008D0oooo00<0003o0?ooo`3oool0>03oool3
0?l00340oooo0P3o000j0?ooo`030000o`3oool0oooo01l0oooo00250?oo
o`030000o`3oool0oooo03H0oooo0P3o000f0?ooo`80o`00>03oool00`00
0?l0oooo0?ooo`0O0?ooo`00Q@3oool00`000?l0oooo0?ooo`0d0?ooo`80
o`00>P3oool20?l003H0oooo00<0003o0?ooo`3oool07`3oool008@0oooo
00<0003o0?ooo`3oool0<`3oool20?l003h0oooo0P3o000e0?ooo`030000
o`3oool0oooo01h0oooo00240?ooo`030000o`3oool0oooo0340oooo0P3o
00120?ooo`80o`00<`3oool00`000?l0oooo0?ooo`0N0?ooo`00Q03oool0
0`000?l0oooo0?ooo`0`0?ooo`030?l0003oool0oooo04@0oooo00<0o`00
0?ooo`3oool0<03oool00`000?l0oooo0?ooo`0N0?ooo`00Q03oool00`00
0?l0oooo0?ooo`0_0?ooo`030?l0003oool0oooo04H0oooo0P3o000`0?oo
o`030000o`3oool0oooo01h0oooo00230?ooo`030000o`3oool0oooo02h0
oooo0P3o001;0?ooo`030?l0003oool0oooo02h0oooo00<0003o0?ooo`3o
ool07@3oool008<0oooo00<0003o0?ooo`3oool0;@3oool00`3o0000oooo
0?ooo`1<0?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0
7@3oool008<0oooo00<0003o0?ooo`3oool0;03oool00`3o0000oooo0?oo
o`1>0?ooo`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool07@3o
ool008<0oooo00<0003o0?ooo`3oool0:P3oool20?l00580oooo0P3o000/
0?ooo`030000o`3oool0oooo01d0oooo00220?ooo`030000o`3oool0oooo
02X0oooo00<0o`000?ooo`3oool0E03oool00`3o0000oooo0?ooo`0Y0?oo
o`030000o`3oool0oooo01d0oooo00220?ooo`030000o`3oool0oooo02T0
oooo00<0o`000?ooo`3oool0EP3oool00`3o0000oooo0?ooo`0X0?ooo`03
0000o`3oool0oooo01d0oooo00220?ooo`030000o`3oool0oooo02P0oooo
00<0o`000?ooo`3oool0E`3oool00`3o0000oooo0?ooo`0X0?ooo`030000
o`3oool0oooo01d0oooo00220?ooo`030000o`3oool0oooo02P0oooo00<0
o`000?ooo`3oool0F03oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3o
ool0oooo01`0oooo00220?ooo`030000o`3oool0oooo02L0oooo00<0o`00
0?ooo`3oool0FP3oool00`3o0000oooo0?ooo`0W0?ooo`030000o`3oool0
oooo01`0oooo00220?ooo`030000o`3oool0oooo02H0oooo00<0o`000?oo
o`3oool0G03oool00`3o0000oooo0?ooo`0V0?ooo`030000o`3oool0oooo
01`0oooo00220?ooo`030000o`3oool0oooo02D0oooo00<0o`000?ooo`3o
ool0GP3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo01`0
oooo00220?ooo`030000o`3oool0oooo02D0oooo00<0o`000?ooo`3oool0
GP3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo01`0oooo
00220?ooo`030000o`3oool0oooo02@0oooo00<0o`000?ooo`3oool0H03o
ool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo01`0oooo0022
0?ooo`030000o`3oool0oooo02<0oooo00<0o`000?ooo`3oool0HP3oool0
0`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo01`0oooo00220?oo
o`030000o`3oool0oooo02<0oooo00<0o`000?ooo`3oool0H`3oool00`3o
0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo01`0oooo00220?ooo`03
0000o`3oool0oooo0280oooo00<0o`000?ooo`3oool0I03oool00`3o0000
oooo0?ooo`0R0?ooo`030000o`3oool0oooo01`0oooo00220?ooo`030000
o`3oool0oooo0240oooo00<0o`000?ooo`3oool0IP3oool00`3o0000oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo01`0oooo00220?ooo`030000o`3o
ool0oooo0240oooo00<0o`000?ooo`3oool0IP3oool00`3o0000oooo0?oo
o`0Q0?ooo`030000o`3oool0oooo01`0oooo00220?ooo`030000o`3oool0
oooo0200oooo00<0o`000?ooo`3oool0:@3ooolD0000ob/0oooo00<0o`00
0?ooo`3oool0803oool00`000?l0oooo0?ooo`0L0?ooo`00PP3oool00`00
0?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo02H0oooo0`000?lD0?oo
o`@0003o:03oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo
01`0oooo00220?ooo`030000o`3oool0oooo01l0oooo00<0o`000?ooo`3o
ool08`3oool40000oa/0oooo0`000?lU0?ooo`030?l0003oool0oooo01l0
oooo00<0003o0?ooo`3oool0703oool00880oooo00<0003o0?ooo`3oool0
7P3oool00`3o0000oooo0?ooo`0Q0?ooo`<0003o8P3oool30000ob<0oooo
00<0o`000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0L0?ooo`00PP3o
ool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo01l0oooo0P00
0?lX0?ooo`80003o8@3oool00`3o0000oooo0?ooo`0N0?ooo`030000o`3o
ool0oooo01`0oooo00220?ooo`030000o`3oool0oooo01d0oooo00<0o`00
0?ooo`3oool07P3oool20000ob`0oooo0P000?lP0?ooo`030?l0003oool0
oooo01d0oooo00<0003o0?ooo`3oool0703oool00880oooo00<0003o0?oo
o`3oool07@3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo
02h0oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`0M0?oo
o`030000o`3oool0oooo01`0oooo00220?ooo`030000o`3oool0oooo01`0
oooo00<0o`000?ooo`3oool0703oool20000oc80oooo0P000?lN0?ooo`03
0?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool0703oool00880oooo
00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0K0?ooo`030000
o`3oool0oooo03@0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo
0?ooo`0L0?ooo`030000o`3oool0oooo01`0oooo00220?ooo`030000o`3o
ool0oooo01/0oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?oo
o`0f0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool06`3o
ool00`000?l0oooo0?ooo`0L0?ooo`00PP3oool00`000?l0oooo0?ooo`0K
0?ooo`030?l0003oool0oooo01T0oooo0P000?lj0?ooo`80003o6`3oool0
0`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo01`0oooo00220?oo
o`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3oool06@3oool00`00
0?l0oooo0?ooo`0l0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?oo
o`3oool06`3oool00`000?l0oooo0?ooo`0L0?ooo`00P`3oool00`000?l0
oooo0?ooo`0I0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3o
ool0?P3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo01X0
oooo00<0003o0?ooo`3oool0703oool008<0oooo00<0003o0?ooo`3oool0
6@3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0400oooo
00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0I0?ooo`030000
o`3oool0oooo01d0oooo00230?ooo`030000o`3oool0oooo01P0oooo00<0
o`000?ooo`3oool05P3oool20000od@0oooo0P000?lG0?ooo`030?l0003o
ool0oooo01T0oooo00<0003o0?ooo`3oool07@3oool008<0oooo00<0003o
0?ooo`3oool0603oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0
oooo04H0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0I
0?ooo`030000o`3oool0oooo01d0oooo00230?ooo`030000o`3oool0oooo
01P0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`180?oo
o`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0603oool00`00
0?l0oooo0?ooo`0M0?ooo`00P`3oool00`000?l0oooo0?ooo`0G0?ooo`03
0?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0BP3oool00`000?l0
oooo0?ooo`0C0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3o
ool07@3oool008<0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo
0?ooo`0C0?ooo`030000o`3oool0oooo04`0oooo00<0003o0?ooo`3oool0
4P3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo01h0oooo
00230?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`0L0?oooa40o`007`3oool00`000?l0oooo0?oo
o`0C0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool07P3o
ool008@0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo01T0oooo103o000A0?ooo`@0o`00703oool0
0`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo01H0oooo00<0003o
0?ooo`3oool07P3oool008@0oooo00<0003o0?ooo`3oool05P3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo01P0oooo0P3o000I0?oo
o`<0o`006P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
01D0oooo00<0003o0?ooo`3oool07`3oool008@0oooo00<0003o0?ooo`3o
ool05P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo01H0
oooo0`3o000N0?ooo`<0o`00603oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool07`3oool008D0oooo
00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo01@0oooo0P3o000T0?ooo`<0o`005@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0
7`3oool008D0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo01<0oooo0P3o000Y0?ooo`80o`00503o
ool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01@0oooo00<0
003o0?ooo`3oool07`3oool008H0oooo00<0003o0?ooo`3oool04`3oool0
0`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0180oooo0P3o000]
0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo01l0oooo00260?oo
o`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo02h0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
01<0oooo00<0003o0?ooo`3oool0803oool008H0oooo00<0003o0?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0100
oooo0P3o000b0?ooo`80o`004P3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0803oool008L0oooo
00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00h0oooo0P3o000f0?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0C0?ooo`030000
o`3oool0oooo0200oooo00270?ooo`030000o`3oool0oooo0180oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo03L0oooo0P3o000@0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0Q0?ooo`00Q`3oool0
0`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0j0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo0240oooo00270?ooo`030000o`3oool0oooo
0180oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo03`0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool08P3oool008P0oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0603oool<0000oaX0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool08P3oool008P0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
4`3oool60000o``0oooo1P000?lE0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo02<0oooo00290?ooo`030000o`3oool0oooo0100oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo0140oooo0`000?lH0?ooo`<0003o4`3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0S0?ooo`00R@3oool00`000?l0oooo0?ooo`0@
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0?0?ooo`80003o7P3oool20000oa80oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool0903oool008X0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool03P3oool20000ob80oooo0P000?l@0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo02@0oooo002:0?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o
ool0903oool20000o`l0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o
ool09@3oool008/0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
3@3oool20000obT0oooo0P000?l>0?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo02D0oooo002;0?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00/0oooo0P000?l]0?ooo`80003o3@3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`0U0?ooo`00S03oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo02l0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0V
0?ooo`00K03oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00T0oooo0P000?lc0?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool09P3oool006d0
oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`080?ooo`80003o603oool60?l001P0oooo0P000?l:0?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo01l0oooo00<0o`000?ooo`3o
ool01@3oool006h0oooo00<0o`000?ooo`3oool0703oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo0140oooo
203o00050?ooo`L0o`004`3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0
1P3oool006l0oooo00<0o`000?ooo`3oool0703oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00l0oooo0`3o
000D0?ooo`@0o`00403oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo01d0oooo0P3o00090?ooo`00L03oool0
0`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool03P3oool20?l001/0oooo0`3o000>
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0703oool00`3o0000oooo0?ooo`090?ooo`00L@3oool00`3o
0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool02`3oool30?l00200oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool02P3oool00780
oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00X0oooo0P3o000T0?ooo`80
o`003@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo01/0oooo0P3o000=0?ooo`00L`3oool00`3o0000oooo
0?ooo`0J0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool02@3oool20?l002P0oooo0P3o000<0?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
6P3oool00`3o0000oooo0?ooo`0=0?ooo`00M03oool20?l001/0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`080?ooo`80o`00;03oool20?l000X0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0I0?ooo`80o`00403o
ool007H0oooo0P3o000J0?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01`3oool20?l00300oooo0P3o0009
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool0603oool20?l00180oooo001h0?ooo`030?l0003oool0oooo
01L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`80o`004P3oool?0000oa<0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool04P3oool007T0
oooo0P3o000H0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0=0?ooo`D0
003o3`3oool50000o`l0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo01H0
oooo0P3o000E0?ooo`00N`3oool00`3o0000oooo0?ooo`0F0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`0;0?ooo`<0003o6@3oool40000o``0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool0
5@3oool007`0oooo0P3o000G0?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`090?ooo`<0003o803oool30000o`X0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo01D0oooo0P3o000H0?ooo`00OP3oool20?l001D0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00P0oooo0P000?lV0?ooo`80003o2@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool04`3oool20?l001X0oooo00200?oo
o`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00L0oooo0P000?lZ0?ooo`80003o203oool20?l000H0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0C0?oo
o`030?l0003oool0oooo01X0oooo00210?ooo`80o`00503oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool01P3oool20000obh0oooo0P000?l80?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0B0?ooo`80o`007@3oool008<0oooo
0P3o000C0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo0100oooo3P3o000B0?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo0140oooo0P3o000O0?ooo`00Q@3o
ool20?l00180oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo0P00
0?l<0?ooo`L0o`003P3oool70?l000`0oooo0P000?l70?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`0@0?ooo`80o`008@3oool008L0oooo00<0o`00
0?ooo`3oool0403oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00D0oooo00<0o`000?ooo`3oool00`3oool20000o`X0oooo103o
000L0?ooo`@0o`002P3oool20000o`D0oooo00<0o`000?ooo`3oool00`3o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0100oooo
00<0o`000?ooo`3oool08@3oool008P0oooo0P3o000@0?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo
0?ooo`020?ooo`80003o2P3oool20?l002@0oooo0P3o000:0?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00l0oooo0P3o000T0?ooo`00
RP3oool20?l000l0oooo00<0003o0?ooo`3oool01P3oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00@0o`000?ooo`3oool0003o103oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo0P3o000X0?oo
o`80o`002@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo00@0003o0?ooo`3oool0o`00103oool01@000?l0oooo0?ooo`3o
ool0o`0000L0oooo00<0003o0?ooo`3oool03P3oool20?l002H0oooo002<
0?ooo`80o`003P3oool00`000?l0oooo0?ooo`050?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool0103o0000oooo0?ooo`000?l30?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool30?l002`0oooo
0`3o00070?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0
oooo0000o`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3o
ool0oooo0?l000060?ooo`030000o`3oool0oooo00d0oooo0P3o000X0?oo
o`00SP3oool20?l000d0oooo00<0003o0?ooo`3oool01@3oool01@3o0000
oooo0?ooo`3oool0003o00<0oooo00@0o`000?ooo`3oool0003o0`3oool0
1@3o0000oooo0?ooo`3oool0003o00L0oooo0P3o000b0?ooo`80o`001P3o
ool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0
0P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0<0?ooo`80o`00:P3oool00900oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`040?ooo`050?l0
003oool0oooo0?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l20?oo
o`050?l0003oool0oooo0?ooo`000?l01P3oool20?l000h0oooo6P000?l>
0?ooo`80o`001@3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0
oooo0000o`80oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0Z0?ooo`00T@3oool20?l000`0oooo00<0003o0?ooo`3oool0103o
ool0103o0000oooo0?ooo`000?l30?ooo`030?l0003oool0003o00<0oooo
00@0o`000?ooo`3oool0003o1@3oool20?l000/0oooo1@000?lJ0?ooo`<0
003o3@3oool20?l000@0oooo0P000?l30?ooo`030?l0003oool0003o0080
oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool02`3oool20?l002d0oooo002C0?ooo`80
o`002`3oool20000o`@0oooo00D0o`000?ooo`3oool0oooo0000o`020?oo
o`030?l0003oool0003o0080oooo00@0o`000?ooo`3oool0003o103oool2
0?l000P0oooo1@000?lR0?ooo`L0003o203oool20?l000@0oooo00@0003o
0?ooo`3oool0o`000P3oool00`000?l0oooo0?l000020?ooo`040000o`3o
ool0oooo0?l000D0oooo00<0003o0?ooo`3oool02P3oool20?l002l0oooo
002E0?ooo`80o`002`3oool00`000?l0oooo0?ooo`020?ooo`040?l0003o
ool0oooo0000o`80oooo00D0o`000?ooo`000?l0oooo0?l000020?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool30000obh0
oooo0P000?l80?ooo`80o`000`3oool020000?l0oooo0?ooo`3o0000oooo
0000o`3oool0o`000P3oool010000?l0oooo0?ooo`3o00040?ooo`030000
o`3oool0oooo00T0oooo0P3o000a0?ooo`00U`3oool20?l000X0oooo00D0
003o0?ooo`3oool0oooo0?l000020?ooo`080000o`3oool0oooo0?l0003o
ool0003o0?ooo`3o00020?ooo`030000o`3oool0oooo0080o`001@3oool3
0000oc<0oooo10000?l60?ooo`80o`0000T0oooo0000o`3oool0oooo0?l0
003oool0003o0?ooo`3o00000P3oool00`000?l0oooo0?l000040?ooo`03
0000o`3oool0oooo00P0oooo0P3o000c0?ooo`00V@3oool30?l000P0oooo
0P000?l20?ooo`090?l0003oool0oooo0000o`3oool0o`000?ooo`000?l0
o`000080oooo00@0003o0?ooo`3oool0o`00103oool30000ocX0oooo0`00
0?l50?ooo`0=0?l0003oool0003o0?ooo`3o0000oooo0000o`3oool0o`00
0?ooo`000?l0oooo0?l000030?ooo`80003o203oool30?l003D0oooo002L
0?ooo`@0o`001P3oool03P000?l0oooo0?ooo`3o0000oooo0000o`3oool0
o`000000o`3oool0o`000?ooo`000?l0oooo0P3o00030?ooo`80003o3P3o
oolR0?l00100oooo0P000?l40?ooo`0<0?l0003oool0003o0?ooo`3o0000
003o0?ooo`3o0000oooo0000o`3oool0o`000P3oool00`000?l0oooo0?oo
o`040?ooo`@0o`00>03oool00:00oooo0P3o00050?ooo`80003o00/0oooo
0?l0003oool0003o0?l000000?l0o`000?ooo`000?l0oooo0?l000030?oo
o`80003o2P3oool60?l00280oooo1`3o000;0?ooo`80003o0`3oool02`3o
0000oooo0000o`3oool0o`000000o`3o0000003o0?ooo`3o0000oooo0080
003o1@3oool20?l003`0oooo002R0?ooo`80o`001@3oool02P000?l0oooo
0?l000000?l0o`000000o`3o0000003o0?ooo`3o00020?ooo`80003o103o
ool80?l002l0oooo2@3o00040?ooo`80003o0P3oool0103o0000oooo0000
o`3o00020000o`040?ooo`3o0000oooo0000o`D0oooo0P3o000n0?ooo`00
Y03oool30?l000<0oooo00<0003o0?ooo`3o00000P000?l00`3o0000003o
0?l000030000o`<0oooo0`3o00100?ooo`<0o`000`3oool30000o`030?l0
00000?l0o`000080003o00<0o`000?ooo`000?l00`3oool30?l00400oooo
002W0?ooo`@0o`001`000?l60?l004H0oooo1P3o00070000o`@0o`00@`3o
ool006`0oooo@@000?l20?oooeL0003o0P3ooom30000o`L0oooo002[0?oo
o`80o`000P3oool00`000?l0o`000?l0001B0?ooo`80o`000P3oool00`00
0?l0o`000?l000170?ooo`00Y`3oool40?l000L0003o1@3o00180?ooo`D0
o`001`000?l40?l004<0oooo002U0?ooo`80o`000`3oool00`000?l0oooo
0?l000020000o`030?l000000?l0o`000080003o0`3oool30?l00480oooo
0`3o00030?ooo`80003o00<0o`000000o`3o00000P000?l00`3o0000oooo
0000o`030?ooo`80o`00@@3oool00:<0oooo0P3o00040?ooo`0;0000o`3o
ool0o`000000o`3o0000003o0?l000000?l0oooo0?l0003oool00`000?l3
0?ooo`T0o`00;`3oool:0?l000<0oooo0`000?l01@3oool0o`000?ooo`00
0?l0o`000080003o00@0oooo0?l0003oool0003o103oool20?l003l0oooo
002P0?ooo`<0o`00103oool20000o`0;0?ooo`3o0000oooo0000o`3o0000
003o0?l0003oool0003o0?ooo`3o00000`3oool20000o`X0oooo1P3o000R
0?ooo`L0o`002`3oool20000o`<0oooo00/0o`000?ooo`000?l0oooo0?l0
00000?l0o`000000o`3oool0o`000?ooo`020000o`@0oooo0`3o000l0?oo
o`00W03oool40?l000H0oooo00l0003o0?ooo`3oool0o`000?ooo`000?l0
oooo0?l000000?l0oooo0?l0003oool0003o0?ooo`3o0000103oool20000
o`h0oooo8P3o000@0?ooo`80003o103oool0303o0000oooo0000o`3oool0
o`000000o`3oool0o`000?ooo`000?l0oooo0?l00080oooo00<0003o0?oo
o`3oool0103oool40?l003P0oooo002J0?ooo`80o`00203oool20000o`80
oooo00T0o`000?ooo`3oool0003o0?ooo`3o0000oooo0000o`3o00000P3o
ool010000?l0oooo0?l0003o00040?ooo`80003o>`3oool30000o`D0oooo
00d0o`000?ooo`000?l0oooo0?l0003oool0003o0?ooo`3o0000oooo0000
o`3oool0o`0000<0oooo0P000?l80?ooo`80o`00=P3oool009P0oooo0P3o
00090?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool020000?l0oooo
0?ooo`3o0000oooo0000o`3oool0o`000P3oool010000?l0oooo0?ooo`3o
00050?ooo`@0003o<`3oool40000o`L0oooo00<0o`000?ooo`000?l00P3o
ool01@3o0000oooo0000o`3oool0o`000080oooo00<0003o0?ooo`3o0000
103oool00`000?l0oooo0?ooo`070?ooo`80o`00=03oool009H0oooo0P3o
000:0?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0003o
0P3oool01@3o0000oooo0000o`3oool0o`000080oooo00@0003o0?ooo`3o
ool0oooo0P3o00070?ooo`<0003o;P3oool20000o`T0oooo0P3o00020?oo
o`080000o`3oool0oooo0?l0003oool0003o0?ooo`3o00020?ooo`040000
o`3oool0oooo0?l000@0oooo00<0003o0?ooo`3oool0203oool20?l00380
oooo002D0?ooo`80o`002P3oool20000o`@0oooo00D0o`000?ooo`3oool0
oooo0000o`020?ooo`030?l0003oool0003o0080oooo00@0o`000?ooo`3o
ool0003o103oool00`3o0000oooo0?ooo`070?ooo`@0003o903oool60000
o`T0oooo0P3o00030?ooo`040000o`3oool0oooo0?l00080oooo00<0003o
0?ooo`3o00000P3oool010000?l0oooo0?ooo`3o00050?ooo`030000o`3o
ool0oooo00T0oooo0P3o000`0?ooo`00TP3oool20?l000/0oooo00<0003o
0?ooo`3oool0103oool0103o0000oooo0?ooo`000?l30?ooo`030?l0003o
ool0003o00<0oooo00@0o`000?ooo`3oool0003o103oool20?l000/0oooo
1@000?lK0?ooo`@0003o3@3oool20?l000<0oooo0P000?l30?ooo`030?l0
003oool0003o0080oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool02P3oool20?l002h0
oooo002@0?ooo`80o`00303oool00`000?l0oooo0?ooo`040?ooo`050?l0
003oool0oooo0?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l20?oo
o`050?l0003oool0oooo0?ooo`000?l01@3oool30?l000d0oooo6`000?l>
0?ooo`<0o`00103oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0
oooo0000o`80oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool02`3oool20?l002`0oooo
002>0?ooo`80o`003@3oool00`000?l0oooo0?ooo`050?ooo`050?l0003o
ool0oooo0?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l30?ooo`05
0?l0003oool0oooo0?ooo`000?l01`3oool20?l00380oooo0P3o00060?oo
o`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`02
0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00`0oooo0P3o000Z0?ooo`00S03oool2
0?l000h0oooo00<0003o0?ooo`3oool01@3oool01@3o0000oooo0?ooo`3o
ool0003o00@0oooo00@0o`000?ooo`3oool0003o0`3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00H0oooo0`3o000]0?ooo`80o`00
1`3oool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`00
0?l00P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?oo
o`3o00001P3oool00`000?l0oooo0?ooo`0=0?ooo`80o`00:03oool008X0
oooo0P3o000?0?ooo`030000o`3oool0oooo00H0oooo00D0o`000?ooo`3o
ool0oooo0000o`040?ooo`040?l0003oool0oooo0000o`@0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`80o`00:@3oool2
0?l000P0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`040000o`3oool0oooo0?l000@0oooo00D0003o0?ooo`3oool0oooo
0?l000070?ooo`030000o`3oool0oooo00h0oooo0P3o000V0?ooo`00R@3o
ool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00T0oooo0P3o000T0?ooo`<0o`002@3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo02<0
oooo00270?ooo`80o`004@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo
0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool00P3oool20000o`/0
oooo0`3o000N0?ooo`<0o`002P3oool20000o`D0oooo00<0o`000?ooo`3o
ool00`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00l0oooo0P3o000S0?ooo`00Q@3oool20?l00180oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo00@0oooo0P000?l<0?ooo`L0o`003`3oool80?l000/0
oooo0P000?l70?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0@0?ooo`80
o`008@3oool008<0oooo0P3o000C0?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`050?ooo`80003o4@3oool?0?l00180oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool04@3oool20?l001l0oooo
00210?ooo`80o`00503oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01P3o
ool20000obh0oooo0P000?l80?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0B0?ooo`80o`007@3oool00800oooo00<0o`000?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0Z
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo01<0oooo00<0o`000?ooo`3oool06P3oool007h0oooo0P3o000E0?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`070?ooo`80003o:03oool20000
o`P0oooo0P3o00060?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool04`3oool20?l001X0oooo001l0?ooo`80
o`005`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0203oool30000ob40
oooo10000?l90?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0E0?ooo`80
o`00603oool007/0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool02P3oool40000oaX0oooo0`000?l<0?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo01D0oooo
001i0?ooo`80o`00603oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool03@3o
ool40000oa40oooo1@000?l>0?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0F0?ooo`80o`005@3oool007P0oooo00<0o`000?ooo`3oool05`3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo0P3o000A0?oooa40003o4P3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0B0?ooo`00MP3oool20?l0
01X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo02l0oooo0P3o00090?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool0603oool20?l00180oooo001d0?ooo`80o`006`3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo0P3o000]0?ooo`80o`002P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo01T0oooo0P3o000@0?ooo`00
L`3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool30?l002P0oooo
0P3o000<0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0=0?ooo`00LP3o
ool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool02P3oool20?l002D0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool0303o
ool00740oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00/0oooo0P3o000Q
0?ooo`80o`003@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo01/0oooo0P3o000<0?ooo`00L03oool00`3o
0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool03@3oool30?l001/0oooo0`3o000>0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0703oool00`3o0000oooo0?ooo`090?ooo`00K`3oool00`3o0000
oooo0?ooo`0K0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool03`3oool30?l001@0oooo103o000@0?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool07@3oool00`3o0000oooo0?ooo`080?ooo`00KP3oool00`3o0000oooo
0?ooo`0L0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool04@3oool80?l000D0oooo1`3o000C0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
7@3oool20?l000P0oooo001]0?ooo`030?l0003oool0oooo01`0oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0203oool20000oaP0oooo1P3o
000H0?ooo`80003o2P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0O0?ooo`030?l0003oool0oooo00D0oooo001/0?ooo`030?l0003oool0
oooo01d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool2
0000oc<0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0V0?ooo`00R`3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo02l0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0V0?oo
o`00R`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0;0?ooo`80
003o;@3oool20000o`d0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o
ool09@3oool008X0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
3@3oool20000obT0oooo0P000?l>0?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo02D0oooo002:0?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool0903oool20000o`l0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool09@3oool008T0oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool03P3oool20000ob80oooo0P000?l@
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo02@0oooo00290?oo
o`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00l0oooo0P000?lN0?oo
o`80003o4P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0T0?oo
o`00R03oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0A0?ooo`<0
003o6@3oool20000oa<0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool08`3oool008P0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
4`3oool60000o`d0oooo1P000?lD0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo02<0oooo00280?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo01P0oooo3@000?lI0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0280oooo00270?ooo`030000o`3oool0oooo0180oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo03`0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool08P3oool0
08L0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0>P3oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0Q0?ooo`00Q`3oool00`000?l0
oooo0?ooo`0B0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0g0?ooo`80o`00403oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o
ool08@3oool008L0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
=@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0P0?ooo`00QP3o
ool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool03`3oool20?l003<0oooo0P3o000B0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`0P0?ooo`00QP3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool0403oool20?l00300oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo01<0oooo00<0003o0?ooo`3oool0803oool008H0oooo00<0003o0?oo
o`3oool04`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
0180oooo0P3o000]0?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo
01l0oooo00250?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0C0?ooo`80o`00:@3oool20?l001@0
oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo01l0oooo00250?ooo`030000o`3oool0oooo01@0oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0D0?ooo`80o`00
9@3oool20?l001D0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0D0?ooo`030000o`3oool0oooo01l0oooo00240?ooo`030000o`3o
ool0oooo01H0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0F0?ooo`80o`007`3oool40?l001L0oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo01l0oooo0024
0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0G0?ooo`80o`006`3oool20?l001X0oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0
oooo01l0oooo00240?ooo`030000o`3oool0oooo01H0oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0H0?ooo`@0o`004P3oool50?l0
01/0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0F0?oo
o`030000o`3oool0oooo01h0oooo00230?ooo`030000o`3oool0oooo01L0
oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0K0?oooa80
o`007`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo01H0
oooo00<0003o0?ooo`3oool07P3oool008<0oooo00<0003o0?ooo`3oool0
5`3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo04`0oooo
00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0G0?ooo`030000
o`3oool0oooo01h0oooo00230?ooo`030000o`3oool0oooo01L0oooo00<0
o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`1:0?ooo`030000o`3o
ool0oooo01<0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?oo
o`0M0?ooo`00P`3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0
oooo01@0oooo00<0003o0?ooo`3oool0B03oool00`000?l0oooo0?ooo`0D
0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool07@3oool0
08<0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0E0?oo
o`030000o`3oool0oooo04H0oooo00<0003o0?ooo`3oool0503oool00`3o
0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01d0oooo00230?ooo`03
0000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool05P3oool20000od@0
oooo0P000?lG0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3o
ool07@3oool008<0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo
0?ooo`0G0?ooo`030000o`3oool0oooo0400oooo00<0003o0?ooo`3oool0
5`3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01d0oooo
00230?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0603o
ool00`000?l0oooo0?ooo`0n0?ooo`030000o`3oool0oooo01P0oooo00<0
o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0L0?ooo`00PP3oool0
0`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo01T0oooo00<0003o
0?ooo`3oool0?03oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0
oooo01/0oooo00<0003o0?ooo`3oool0703oool00880oooo00<0003o0?oo
o`3oool06`3oool00`3o0000oooo0?ooo`0I0?ooo`80003o>P3oool20000
oa/0oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0L0?oo
o`00PP3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo01/0
oooo00<0003o0?ooo`3oool0=P3oool00`000?l0oooo0?ooo`0K0?ooo`03
0?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool0703oool00880oooo
00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0K0?ooo`030000
o`3oool0oooo03@0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo
0?ooo`0L0?ooo`030000o`3oool0oooo01`0oooo00220?ooo`030000o`3o
ool0oooo01`0oooo00<0o`000?ooo`3oool0703oool20000oc80oooo0P00
0?lN0?ooo`030?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool0703o
ool00880oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`0M
0?ooo`030000o`3oool0oooo02h0oooo00<0003o0?ooo`3oool07@3oool0
0`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo01`0oooo00220?oo
o`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool07P3oool20000
ob`0oooo0P000?lP0?ooo`030?l0003oool0oooo01d0oooo00<0003o0?oo
o`3oool0703oool00880oooo00<0003o0?ooo`3oool07P3oool00`3o0000
oooo0?ooo`0O0?ooo`80003o:03oool20000ob40oooo00<0o`000?ooo`3o
ool07P3oool00`000?l0oooo0?ooo`0L0?ooo`00PP3oool00`000?l0oooo
0?ooo`0N0?ooo`030?l0003oool0oooo0240oooo0`000?lR0?ooo`<0003o
8`3oool00`3o0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo01`0oooo
00220?ooo`030000o`3oool0oooo01l0oooo00<0o`000?ooo`3oool08`3o
ool30000oa`0oooo0`000?lU0?ooo`030?l0003oool0oooo01l0oooo00<0
003o0?ooo`3oool0703oool00880oooo00<0003o0?ooo`3oool0803oool0
0`3o0000oooo0?ooo`0U0?ooo`<0003o5P3oool30000obP0oooo00<0o`00
0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0L0?ooo`00PP3oool00`00
0?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo02P0oooo5P000?lZ0?oo
o`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0703oool00880
oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?ooo`1V0?ooo`03
0?l0003oool0oooo0240oooo00<0003o0?ooo`3oool0703oool00880oooo
00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?ooo`1V0?ooo`030?l0
003oool0oooo0240oooo00<0003o0?ooo`3oool0703oool00880oooo00<0
003o0?ooo`3oool08P3oool00`3o0000oooo0?ooo`1T0?ooo`030?l0003o
ool0oooo0280oooo00<0003o0?ooo`3oool0703oool00880oooo00<0003o
0?ooo`3oool08`3oool00`3o0000oooo0?ooo`1S0?ooo`030?l0003oool0
oooo0280oooo00<0003o0?ooo`3oool0703oool00880oooo00<0003o0?oo
o`3oool08`3oool00`3o0000oooo0?ooo`1R0?ooo`030?l0003oool0oooo
02<0oooo00<0003o0?ooo`3oool0703oool00880oooo00<0003o0?ooo`3o
ool0903oool00`3o0000oooo0?ooo`1P0?ooo`030?l0003oool0oooo02@0
oooo00<0003o0?ooo`3oool0703oool00880oooo00<0003o0?ooo`3oool0
9@3oool00`3o0000oooo0?ooo`1N0?ooo`030?l0003oool0oooo02D0oooo
00<0003o0?ooo`3oool0703oool00880oooo00<0003o0?ooo`3oool09P3o
ool00`3o0000oooo0?ooo`1M0?ooo`030?l0003oool0oooo02D0oooo00<0
003o0?ooo`3oool0703oool00880oooo00<0003o0?ooo`3oool09`3oool0
0`3o0000oooo0?ooo`1K0?ooo`030?l0003oool0oooo02H0oooo00<0003o
0?ooo`3oool0703oool00880oooo00<0003o0?ooo`3oool09`3oool00`3o
0000oooo0?ooo`1J0?ooo`030?l0003oool0oooo02L0oooo00<0003o0?oo
o`3oool0703oool00880oooo00<0003o0?ooo`3oool0:03oool00`3o0000
oooo0?ooo`1H0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3o
ool0703oool00880oooo00<0003o0?ooo`3oool0:@3oool00`3o0000oooo
0?ooo`1F0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool0
7@3oool00880oooo00<0003o0?ooo`3oool0:P3oool00`3o0000oooo0?oo
o`1E0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool07@3o
ool00880oooo00<0003o0?ooo`3oool0:`3oool00`3o0000oooo0?ooo`1C
0?ooo`030?l0003oool0oooo02T0oooo00<0003o0?ooo`3oool07@3oool0
08<0oooo00<0003o0?ooo`3oool0:`3oool00`3o0000oooo0?ooo`1A0?oo
o`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool07@3oool008<0
oooo00<0003o0?ooo`3oool0;03oool00`3o0000oooo0?ooo`1>0?ooo`80
o`00;@3oool00`000?l0oooo0?ooo`0M0?ooo`00P`3oool00`000?l0oooo
0?ooo`0]0?ooo`80o`00C@3oool00`3o0000oooo0?ooo`0]0?ooo`030000
o`3oool0oooo01d0oooo00230?ooo`030000o`3oool0oooo02l0oooo00<0
o`000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0^0?ooo`030000o`3o
ool0oooo01d0oooo00240?ooo`030000o`3oool0oooo02l0oooo00<0o`00
0?ooo`3oool0AP3oool20?l00300oooo00<0003o0?ooo`3oool07P3oool0
08@0oooo00<0003o0?ooo`3oool0<03oool00`3o0000oooo0?ooo`140?oo
o`030?l0003oool0oooo0300oooo00<0003o0?ooo`3oool07P3oool008@0
oooo00<0003o0?ooo`3oool0<@3oool20?l00480oooo0P3o000c0?ooo`03
0000o`3oool0oooo01h0oooo00240?ooo`030000o`3oool0oooo03<0oooo
0P3o000n0?ooo`80o`00=@3oool00`000?l0oooo0?ooo`0N0?ooo`00Q@3o
ool00`000?l0oooo0?ooo`0d0?ooo`80o`00>P3oool20?l003H0oooo00<0
003o0?ooo`3oool07`3oool008D0oooo00<0003o0?ooo`3oool0=P3oool2
0?l003H0oooo0P3o000h0?ooo`030000o`3oool0oooo01l0oooo00250?oo
o`030000o`3oool0oooo03P0oooo0P3o000b0?ooo`80o`00>P3oool00`00
0?l0oooo0?ooo`0O0?ooo`00Q@3oool00`000?l0oooo0?ooo`0j0?ooo`80
o`00;P3oool20?l003/0oooo00<0003o0?ooo`3oool0803oool008H0oooo
00<0003o0?ooo`3oool0>`3oool20?l002T0oooo0`3o000m0?ooo`030000
o`3oool0oooo0200oooo00260?ooo`030000o`3oool0oooo03d0oooo103o
000R0?ooo`<0o`00?`3oool00`000?l0oooo0?ooo`0Q0?ooo`00QP3oool0
0`000?l0oooo0?ooo`110?ooo`D0o`006@3oool40?l00480oooo00<0003o
0?ooo`3oool08@3oool008L0oooo00<0003o0?ooo`3oool0A@3oool70?l0
00X0oooo203o00160?ooo`030000o`3oool0oooo0240oooo00270?ooo`03
0000o`3oool0oooo04`0oooo2P3o001>0?ooo`030000o`3oool0oooo0240
oooo00280?ooo`030000o`3oool0oooo0:80oooo00<0003o0?ooo`3oool0
8P3oool008P0oooo00<0003o0?ooo`3oool0XP3oool00`000?l0oooo0?oo
o`0R0?ooo`00R@3oool00`000?l0oooo0?ooo`2P0?ooo`80003o903oool0
0001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{338, 228},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.95 (a)",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/sourcesink/SourceSinkFigures/\
mat1195.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Source and sink of unit strength."
}], "Text"],

Cell[TextData[{
  "The velocity potential and stream function are  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\ \  = \ \ ln | \(z - 1\)\/\(z + 1\) | \)]],
  ",   and  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Psi] \((x, y)\)\ \  = \ \ arg \((\(z - 1\)\/\(z + 1\))\)\)]],
  ",  \n\nrespectively.  Solving for the streamline  ",
  Cell[BoxData[
      \(\[Psi] \((x, y)\)\  = \ c\)]],
  ",  we start with   \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(c\ \  = \ \ \(arg \((\(z - 1\)\/\(z + 1\))\)\ \  = \ \ arg \
\((\(\((x + \[ImaginaryI]\ y - 1)\) \((x - \[ImaginaryI]\ y + 1)\)\)\/\(\((x \
+ \[ImaginaryI]\ y + 1)\) \((x - \[ImaginaryI]\ y + 1)\)\))\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \(\(\(=\)\(\ \ \)\(arg \((\(x\^2 + y\^2 - 1 + \ \
\[ImaginaryI]\ 2  y\)\/\(\(x\^2\)\(+\)\(2\ x\)\(+\)\(1\)\(+\)\(y\^2\)\(\ \
\)\))\)\ \  = \ \ arg \((\(x\^2 + y\^2 - 1 + \ \[ImaginaryI]\ 2  \
y\)\/\(\(\((x + 1)\)\^2\)\(+\)\(y\^2\)\(\ \)\))\)\)\)\(\ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \(\(=\)\(\ \ \)\(arctan \((\(2  \
y\)\/\(\(x\^2\)\(+\)\(y\^2\)\(-\)\(1\)\(\ \)\))\)\)\)\)}]],
  "  \n\nand obtain the equation\n\n\t\t\t",
  Cell[BoxData[
      \(\((tan\ c)\) \((x\^2 + y\^2 - 1)\)\ \  = \ \ 2  y\)]],
  ". \n\nA straightforward calculation shows that points on the streamline \
must satisfy the equation  \n\n\t\t\t",
  Cell[BoxData[
      \(x\^2\  + \ \((y - cot\ c)\)\^2\ \  = \ \ 1\  + \ \(cot\^2\) c\)]],
  ",  \n\nwhich is the equation of a circle with center at  ",
  Cell[BoxData[
      \(\((0, cot\ c)\)\)]],
  "  that passes through the points  ",
  Cell[BoxData[
      \(\((\(\[PlusMinus]1\), 0)\)\)]],
  ".  Several streamlines are indicated in Figure 11.95(a)."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.30.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the formula for the complex potential F[z].", "Text"],

Cell[BoxData[{
    \(\(Clear[f, F, \[Phi], \[Psi], W, x, y, z, Z];\)\ \), "\n", 
    \(\(F[Z_]\  = \ 
        Log[\(Z\  - \ 1\)\/\(Z\  + \ 1\)];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi][x_, y_] = 
        ComplexExpand[Re[F[x + \[ImaginaryI]\ y]], 
          TargetFunctions \[Rule] {Re, Im}];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Psi][x_, y_] = 
        Simplify[
          ComplexExpand[Im[F[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Re, Im}]];\)\ \), "\n", 
    \(\(Print["\<W = F[Z] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The velocity potential is:\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = Re[F[x + \[ImaginaryI]y]]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        Re[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The stream function is:\>"];\)\ \), "\n", 
    \(\(Print["\<\[Psi][x,y] = Im[F[x + \[ImaginaryI]y]]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", 
        Im[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Psi][x_, y_] = 
        ArcTan[\(-1\) + x\^2 + y\^2, 2\ y];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a density plot of the velocity potential."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(DensityPlot[\[Phi][x, y], {x, \(-1.5\), 1.5}, {y, \(-1.5\), 1.5}, 
        PlotPoints \[Rule] 100, Mesh \[Rule] False, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential for the\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<source at \!\(z\_1\)=+1 and sink at \
\!\(z\_2\)=-1.\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", Re[F[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        Re[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the stream function."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ContourPlot[\[Psi][x, y], {x, \(-1.5\), 1.5}, {y, 0, 
            1.5}, \[IndentingNewLine]Contours \[Rule] 11, 
          PlotPoints \[Rule] 40, ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ContourPlot[\[Psi][x, y], {x, \(-1.5\), 
            1.5}, {y, \(-1.50001\), \(-0.00001\)}, \
\[IndentingNewLine]Contours \[Rule] 11, PlotPoints \[Rule] 40, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The stream function for the\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<source at \!\(z\_1\)=+1 and sink at \
\!\(z\_2\)=-1.\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", Im[F[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", 
        Im[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the velocity potential."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Phi][x, y], {x, \(-1.5\), 1.5}, {y, \(-1.5\), 1.5}, 
        Contours \[Rule] 11, PlotPoints \[Rule] 40, AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential for the\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<source at \!\(z\_1\)=+1 and sink at \
\!\(z\_2\)=-1.\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", Re[F[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        Re[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Find the inverse of the function F[Z].", "Text"],

Cell[BoxData[{
    \(\(solset\  = \ Solve[F[Z]\  \[Equal] \ W, Z];\)\ \), "\n", 
    \(\(f[x_, y_]\  = \ \ ReplaceAll[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), 
          W \[Rule] x\  + \ \[ImaginaryI]\ y];\)\ \), "\n", 
    \(\(Print["\<W = F[Z] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The inverse function is:\>"];\)\ \), "\n", 
    \(\(Print["\<f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph the stream functions using  f[x,y]."
}], "Text"],

Cell[BoxData[{
    \(\(n\  = \ 12;\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[k];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(eqns1\  = \ 
        N[Table[{Re[f[x, \(\(\ \)\(k\ \[Pi]\)\)\/n]], 
              Im[f[x, \(k\ \[Pi]\)\/n]]}, {k, 1, 2  n, 
              2}]];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ParametricPlot[Evaluate[eqns1], {x, \(-4\), 4}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        N[Table[{Re[f[x, \(\(\ \)\(k\ \[Pi]\)\)\/n]], 
              Im[f[x, \(k\ \[Pi]\)\/n]]}, {k, 0, 2  n, 
              2}]];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ParametricPlot[Evaluate[eqns2], {x, \(-4\), 4}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{\(-2.5\), 2.5}, {\(-2.5\), 2.5}}, 
        AspectRatio \[Rule] 1, Axes \[Rule] None, Ticks \[Rule] None, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The streamlines for the\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<source at \!\(z\_1\)=+1 and sink at \
\!\(z\_2\)=-1.\>\""];\)\ \), "\n", 
    \(\(Print["\<w = f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The stream function for a fluid flowing from the source at  z = +1  to the \
sink at  z = -1.  \
\>", "Text"],

Cell[BoxData[{
    \(\(n\  = \ 12;\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[k];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(eqns3\  = \ 
        N[Table[{Re[f[k, y]], Im[f[k, y]]}, {k, \(-3\), 3, 
              1}]];\)\ \), "\[IndentingNewLine]", 
    \(\(gr3 = 
        ParametricPlot[Evaluate[eqns3], {y, \(-4\), 4}, 
          PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns4\  = \ 
        N[Table[{Re[f[k, y]], Im[f[k, y]]}, {k, \(-4\) + 1\/2, 4 - 1\/2, 
              1}]];\)\ \), "\[IndentingNewLine]", 
    \(\(gr4 = 
        ParametricPlot[Evaluate[eqns4], {y, \(-4\), 4}, 
          PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr4, PlotRange \[Rule] {{\(-2.5\), 2.5}, {\(-2.5\), 2.5}}, 
        AspectRatio \[Rule] 1, Axes \[Rule] None, Ticks \[Rule] None, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential for the\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<source at \!\(z\_1\)=+1 and sink at \
\!\(z\_2\)=-1.\>\""];\)\ \), "\n", 
    \(\(Print["\<w = f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The velocity potential for a fluid flowing from the source at  z = +1  to the \
sink at  z = -1.  \
\>", "Text"],

Cell[BoxData[{
    \(\(Show[gr1, gr2, gr3, gr4, 
        PlotRange \[Rule] {{\(-2.5\), 2.5}, {\(-2.5\), 2.5}}, 
        AspectRatio \[Rule] 1, Axes \[Rule] None, Ticks \[Rule] None, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The streamlines and velocity potential for the\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<source at \!\(z\_1\)=+1 and sink at \
\!\(z\_2\)=-1.\>\""];\)\ \), "\n", 
    \(\(Print["\<w = f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The streamlines and velocity potential for a fluid flowing from the source at \
 z = +1  to the sink at  z = -1.  \
\>", "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Dirichlet Problem",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/DirichletProblemBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Neumann Problem",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/NeumannProblemBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Poisson Integral",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/PoissonIntegralBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Electrostatics",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ElectrostaticsBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Ideal Fluid Flow",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/FluidFlowBib.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Steady State Temperature",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/TemperaturesBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Joukowski Transformation and Airfoils",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/JoukowskiTransBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Schwarz-Christoffel Transformation",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/SchwarzChristoffelBib.html"]\
, None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Potential",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexPotentialBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Green's Function",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/GreensFunctionBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1001, 649},
WindowMargins->{{3, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[18916, 533, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 381485, 7884}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 131, 2, 33, "Text"],
Cell[2236, 66, 605, 15, 71, "Text",
  Evaluatable->False],
Cell[2844, 83, 1734, 45, 128, "Text",
  Evaluatable->False],
Cell[4581, 130, 4911, 130, 90, "Text",
  Evaluatable->False],
Cell[9495, 262, 5113, 139, 280, "Text"],
Cell[14611, 403, 3954, 114, 71, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[18590, 521, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[18738, 527, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[18916, 533, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[CellGroupData[{
Cell[19298, 547, 151, 3, 30, "Text"],
Cell[19452, 552, 427, 13, 33, "Text",
  Evaluatable->False],
Cell[19882, 567, 64, 1, 30, "Input"],
Cell[19949, 570, 1345, 26, 270, "Input"],
Cell[21297, 598, 209, 7, 33, "Text",
  Evaluatable->False],
Cell[21509, 607, 646, 12, 117, "Input"],
Cell[22158, 621, 409, 14, 41, "Text",
  Evaluatable->False],
Cell[22570, 637, 462, 8, 75, "Input"],
Cell[23035, 647, 142, 4, 33, "Text",
  Evaluatable->False],
Cell[23180, 653, 1416, 33, 157, "Input"],
Cell[24599, 688, 373, 14, 41, "Text",
  Evaluatable->False]
}, Closed]],
Cell[24987, 705, 1440, 33, 68, "Text"],
Cell[26430, 740, 523, 11, 71, "Text"],
Cell[26956, 753, 11199, 276, 349, "Text"],
Cell[38158, 1031, 279, 11, 33, "Text"],
Cell[38440, 1044, 220, 6, 71, "Text"],
Cell[38663, 1052, 8705, 226, 107, "Text",
  Evaluatable->False],
Cell[47371, 1280, 24997, 413, 163, 24883, 409, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[72371, 1695, 1558, 37, 256, "Text"],
Cell[73932, 1734, 6883, 191, 289, "Text"],
Cell[80818, 1927, 884, 27, 40, "Text"],

Cell[CellGroupData[{
Cell[81727, 1958, 113, 2, 33, "Text"],
Cell[81843, 1962, 112, 3, 33, "Text"],
Cell[81958, 1967, 1158, 26, 353, "Input"],
Cell[83119, 1995, 86, 2, 33, "Text"],
Cell[83208, 1999, 852, 15, 271, "Input"],
Cell[84063, 2016, 137, 5, 33, "Text"],
Cell[84203, 2023, 732, 13, 225, "Input"],
Cell[84938, 2038, 343, 9, 68, "Text"]
}, Closed]],
Cell[85296, 2050, 5480, 150, 95, "Text",
  Evaluatable->False],
Cell[90779, 2202, 40100, 660, 254, 39986, 656, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[130882, 2864, 3463, 103, 191, "Text"],
Cell[134348, 2969, 1528, 29, 319, "Text"],
Cell[135879, 3000, 3717, 104, 180, "Text"],
Cell[139599, 3106, 1169, 37, 33, "Text"],

Cell[CellGroupData[{
Cell[140793, 3147, 113, 2, 33, "Text"],
Cell[140909, 3151, 116, 3, 33, "Text"],
Cell[141028, 3156, 1272, 29, 333, "Input"],
Cell[142303, 3187, 447, 11, 59, "Text"],
Cell[142753, 3200, 923, 18, 223, "Input"],
Cell[143679, 3220, 140, 4, 33, "Text",
  Evaluatable->False],
Cell[143822, 3226, 1337, 32, 345, "Input"],
Cell[145162, 3260, 1071, 23, 238, "Input"],
Cell[146236, 3285, 271, 7, 40, "Text"]
}, Closed]],
Cell[146522, 3295, 360, 11, 30, "Text",
  Evaluatable->False],
Cell[146885, 3308, 21869, 361, 163, 21755, 357, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[168757, 3671, 1735, 49, 131, "Text"],
Cell[170495, 3722, 2024, 43, 333, "Text"],
Cell[172522, 3767, 1010, 30, 115, "Text"],
Cell[173535, 3799, 2043, 58, 77, "Text"],
Cell[175581, 3859, 337, 11, 33, "Text"],

Cell[CellGroupData[{
Cell[175943, 3874, 113, 2, 33, "Text"],
Cell[176059, 3878, 534, 15, 107, "Text",
  Evaluatable->False],
Cell[176596, 3895, 1205, 23, 264, "Input"],
Cell[177804, 3920, 230, 8, 71, "Text",
  Evaluatable->False],
Cell[178037, 3930, 813, 15, 266, "Input"],
Cell[178853, 3947, 249, 9, 42, "Text",
  Evaluatable->False],
Cell[179105, 3958, 1550, 31, 529, "Input"],
Cell[180658, 3991, 134, 4, 33, "Text",
  Evaluatable->False],
Cell[180795, 3997, 2014, 39, 452, "Input"]
}, Closed]],
Cell[182824, 4039, 646, 20, 53, "Text",
  Evaluatable->False],
Cell[183473, 4061, 4207, 121, 205, "Text"],
Cell[187683, 4184, 55062, 906, 137, 54948, 902, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[242748, 5092, 1972, 61, 36, "Text"],
Cell[244723, 5155, 2661, 68, 581, "Text"],

Cell[CellGroupData[{
Cell[247409, 5227, 113, 2, 33, "Text"],
Cell[247525, 5231, 230, 7, 43, "Text"],
Cell[247758, 5240, 702, 15, 235, "Input"],
Cell[248463, 5257, 200, 5, 33, "Text",
  Evaluatable->False],
Cell[248666, 5264, 626, 13, 235, "Input"],
Cell[249295, 5279, 106, 2, 33, "Text",
  Evaluatable->False],
Cell[249404, 5283, 797, 19, 254, "Input"],
Cell[250204, 5304, 195, 6, 33, "Text"],
Cell[250402, 5312, 1364, 27, 296, "Input"],
Cell[251769, 5341, 375, 14, 33, "Text"]
}, Closed]],
Cell[252159, 5358, 1975, 58, 59, "Text",
  Evaluatable->False],
Cell[254137, 5418, 43146, 710, 192, 43032, 706, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[297286, 6130, 382, 11, 52, "Text"],
Cell[297671, 6143, 2599, 76, 245, "Text"],
Cell[300273, 6221, 659, 14, 235, "Text"],
Cell[300935, 6237, 3135, 82, 271, "Text"],

Cell[CellGroupData[{
Cell[304095, 6323, 113, 2, 33, "Text"],
Cell[304211, 6327, 252, 6, 55, "Text"],
Cell[304466, 6335, 695, 15, 267, "Input"],
Cell[305164, 6352, 200, 5, 33, "Text",
  Evaluatable->False],
Cell[305367, 6359, 654, 14, 213, "Input"],
Cell[306024, 6375, 106, 2, 33, "Text",
  Evaluatable->False],
Cell[306133, 6379, 867, 19, 254, "Input"],
Cell[307003, 6400, 167, 5, 33, "Text",
  Evaluatable->False],
Cell[307173, 6407, 224, 5, 83, "Input"],
Cell[307400, 6414, 147, 4, 33, "Text",
  Evaluatable->False],
Cell[307550, 6420, 478, 12, 180, "Input"],
Cell[308031, 6434, 132, 5, 33, "Text"],
Cell[308166, 6441, 1268, 24, 250, "Input"],
Cell[309437, 6467, 2061, 42, 325, "Input"],
Cell[311501, 6511, 561, 16, 55, "Text"],
Cell[312065, 6529, 294, 9, 71, "Text",
  Evaluatable->False],
Cell[312362, 6540, 1555, 33, 290, "Input"],
Cell[313920, 6575, 2350, 50, 370, "Input"],
Cell[316273, 6627, 574, 16, 65, "Text"]
}, Closed]],
Cell[316862, 6646, 821, 28, 91, "Text",
  Evaluatable->False],
Cell[317686, 6676, 47343, 779, 242, "Text"],
Cell[365032, 7457, 347, 11, 33, "Text"],
Cell[365382, 7470, 1772, 39, 484, "Text"],

Cell[CellGroupData[{
Cell[367179, 7513, 113, 2, 33, "Text"],
Cell[367295, 7517, 65, 0, 33, "Text"],
Cell[367363, 7519, 1698, 35, 425, "Input"],
Cell[369064, 7556, 144, 5, 33, "Text"],
Cell[369211, 7563, 777, 14, 170, "Input"],
Cell[369991, 7579, 141, 5, 33, "Text"],
Cell[370135, 7586, 1278, 25, 250, "Input"],
Cell[371416, 7613, 144, 5, 33, "Text"],
Cell[371563, 7620, 800, 14, 170, "Input"],
Cell[372366, 7636, 54, 0, 33, "Text"],
Cell[372423, 7638, 554, 11, 150, "Input"],
Cell[372980, 7651, 139, 5, 33, "Text"],
Cell[373122, 7658, 1432, 29, 298, "Input"],
Cell[374557, 7689, 119, 3, 33, "Text"],
Cell[374679, 7694, 1358, 28, 284, "Input"],
Cell[376040, 7724, 122, 3, 33, "Text"],
Cell[376165, 7729, 588, 12, 130, "Input"],
Cell[376756, 7743, 138, 3, 33, "Text"]
}, Closed]],
Cell[376909, 7749, 290, 7, 30, "Text"],
Cell[377202, 7758, 291, 7, 33, "Text"],
Cell[377496, 7767, 287, 7, 33, "Text"],
Cell[377786, 7776, 289, 7, 33, "Text"],
Cell[378078, 7785, 286, 7, 33, "Text"],
Cell[378367, 7794, 278, 6, 33, "Text"],
Cell[378648, 7802, 294, 7, 33, "Text"],
Cell[378945, 7811, 309, 7, 33, "Text"],
Cell[379257, 7820, 307, 7, 33, "Text"],
Cell[379567, 7829, 291, 7, 33, "Text"],
Cell[379861, 7838, 288, 7, 33, "Text"],
Cell[380152, 7847, 257, 5, 33, "Text"],
Cell[380412, 7854, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

