(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    345036,       7411]*)
(*NotebookOutlinePosition[    346058,       7448]*)
(*  CellTagsIndexPosition[    345981,       7442]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["11.5  Steady State Temperatures",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tIn the theory of heat conduction, an assumption is made that heat flows \
in the direction of decreasing temperature.  Another assumption is that the \
time rate at which heat flows across a surface area is proportional to the \
component of the temperature gradient in the direction perpendicular to the \
surface area.  If the temperature ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " does not depend on time, then the heat flow at the point ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " is given by the vector  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            OverscriptBox[
              StyleBox["V",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", " ", 
        RowBox[{
          RowBox[{\(-\ K\), "  ", "grad", " ", "T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", " ", 
          RowBox[{\(-\ K\), 
            RowBox[{"(", " ", 
              RowBox[{
                RowBox[{\(T\_x\), 
                  RowBox[{"(", 
                    RowBox[{"x", 
                      StyleBox[",",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], "y"}], ")"}]}], " ", "+", 
                " ", 
                RowBox[{"\[ImaginaryI]", "  ", \(T\_y\), 
                  RowBox[{"(", 
                    RowBox[{"x", 
                      StyleBox[",",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], "y"}], ")"}]}]}], 
              ")"}]}]}]}]]],
  ",  \n\nwhere K is the thermal conductivity of the medium and is assumed to \
be constant.  If ",
  Cell[BoxData[
      \(\[CapitalDelta]z\)]],
  " denotes a straight-line segment of length ",
  Cell[BoxData[
      \(\[CapitalDelta]s\)]],
  ", then the amount of heat flowing across the segment per unit of time is\n\
\n",
  StyleBox["(11-19)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          OverscriptBox[
            StyleBox["V",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], "\[FilledSmallCircle]", " ", 
        StyleBox[
          OverscriptBox[
            StyleBox["N",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], "\[CapitalDelta]s"}]]],
  "  \n\nwhere ",
  Cell[BoxData[
      RowBox[{" ", 
        StyleBox[
          OverscriptBox[
            StyleBox["N",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"]}]]],
  " is a unit vector perpendicular to the segment. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tIf we assume that no thermal energy is created or destroyed within the \
region, then the net amount of heat flowing through any small rectangle with \
sides of length ",
  Cell[BoxData[
      \(\[CapitalDelta]x\)]],
  " and ",
  Cell[BoxData[
      \(\[CapitalDelta]y\)]],
  " is identically zero (see Figure 11.16(a)).  This leads to the conclusion \
that ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " is a harmonic function.  The following heuristic argument is often used \
to suggest that ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " satisfies Laplace's equation.  Using Expression ",
  StyleBox["(11-19)",
    FontColor->RGBColor[0, 0, 1]],
  " we find that the amount of heat flowing out of the right edge of the \
rectangle in Figure 11.16(a) is approximately  \n\n",
  StyleBox["(11-20)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox[\(V\_1\),
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "\[FilledSmallCircle]", " ", 
            StyleBox[
              OverscriptBox[
                StyleBox[\(N\_1\),
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "\[CapitalDelta]s"}], "   ", "=", "  ", 
          RowBox[{\(-\ K\), 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(T\_x\), 
                  RowBox[{"(", 
                    RowBox[{\(x + \[CapitalDelta]x\), 
                      StyleBox[",",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], "y"}], ")"}]}], "+", 
                RowBox[{"\[ImaginaryI]", " ", \(T\_x\), 
                  RowBox[{"(", 
                    RowBox[{\(x + \[CapitalDelta]x\), 
                      StyleBox[",",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], "y"}], ")"}]}]}], ")"}], 
            "\[FilledSmallCircle]", \((1 + 0  \[ImaginaryI])\), 
            "\[CapitalDelta]y"}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"                      ", 
        RowBox[{"=", " ", 
          RowBox[{\(-\ K\), " ", \(T\_x\), 
            RowBox[{"(", 
              RowBox[{\(x + \[CapitalDelta]x\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}], 
            "\[CapitalDelta]y"}]}]}]}]],
  "  \n\nand the amount of heat flowing out of the left edge is  \n\n",
  StyleBox["(11-21)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox[\(V\_2\),
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "\[FilledSmallCircle]", " ", 
            StyleBox[
              OverscriptBox[
                StyleBox[\(N\_2\),
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], "\[CapitalDelta]s"}], "   ", "=", "  ", 
          RowBox[{\(-\ K\), 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(T\_x\), 
                  RowBox[{"(", 
                    RowBox[{"x", 
                      StyleBox[",",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], "y"}], ")"}]}], "+", 
                RowBox[{"\[ImaginaryI]", " ", \(T\_x\), 
                  RowBox[{"(", 
                    RowBox[{"x", 
                      StyleBox[",",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], "y"}], ")"}]}]}], ")"}], 
            "\[FilledSmallCircle]", \((\(-1\) + 0  \[ImaginaryI])\), 
            "\[CapitalDelta]y"}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{"                      ", 
        RowBox[{"=", "  ", 
          RowBox[{"K", " ", \(T\_x\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}], 
            "\[CapitalDelta]y"}]}]}]}]],
  "  "
}], "Text"],

Cell[TextData[{
  "\tIf we add the contributions in Equations ",
  StyleBox["(11-20)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(11-21)",
    FontColor->RGBColor[0, 0, 1]],
  ", the result is  \n\n",
  StyleBox["(11-22)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{\(\(-\ \ K\) \((\(\(T\_x\) \((x + \[CapitalDelta]x, y)\)\  - \ \
\(T\_x\) \((x, y)\)\)\/\[CapitalDelta]x)\) \[CapitalDelta]x\ \[CapitalDelta]y\
\), "  ", "\[TildeTilde]", "  ", 
        RowBox[{\(-\ \ K\), " ", \(T\_xx\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}], "\[CapitalDelta]x", 
          " ", "\[CapitalDelta]y"}]}]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.16",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/temperature/\
TemperaturesFigures/mat1116.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Steady state temperatures."
}], "Text"],

Cell[TextData[{
  "\tSimilarly, the contribution for the amount of heat flowing out of the \
top and bottom edges is  \n\n",
  StyleBox["(11-23)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{\(\(-\ \ K\) \((\(\(T\_y\) \((x, y + \[CapitalDelta]y)\)\  - \ \
\(T\_x\) \((x, y)\)\)\/\[CapitalDelta]y)\) \[CapitalDelta]x\ \[CapitalDelta]y\
\), "  ", "\[TildeTilde]", "  ", 
        RowBox[{\(-\ \ K\), " ", \(T\_yy\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}], "\[CapitalDelta]x", 
          " ", "\[CapitalDelta]y"}]}]]],
  ". \n\nAdding the quantities in Equations ",
  StyleBox["(11-22)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(11-23)",
    FontColor->RGBColor[0, 0, 1]],
  ", we find that the net heat flowing out of the rectangle is approximated \
by the equation  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(-\ \ K\), " ", 
          RowBox[{"(", 
            RowBox[{
              RowBox[{\(T\_xx\), 
                RowBox[{"(", 
                  RowBox[{"x", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "y"}], ")"}]}], " ", "+", " ",
               
              RowBox[{\(T\_yy\), 
                RowBox[{"(", 
                  RowBox[{"x", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "y"}], ")"}]}]}], ")"}], 
          "\[CapitalDelta]x", " ", "\[CapitalDelta]y"}], "  ", "=", "  ", 
        "0"}]]],
  ",  \n\nwhich implies that  \n\n    \t\t\t",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{
          RowBox[{
            RowBox[{\(T\_xx\), 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], " ", "+", "  ", 
            
            RowBox[{\(T\_yy\), 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}]}], "=", 
          "0"}]}]]],
  ".  \n\nHence  ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  satisfies Laplace's equation and is a harmonic function."
}], "Text"],

Cell[TextData[{
  "\tIf the domain in which  ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  is defined is simply connected, then a conjugate harmonic function  ",
  Cell[BoxData[
      RowBox[{"S", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  exists, and    \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(F \((z)\)\), "  ", "=", "  ", 
        RowBox[{
          RowBox[{"T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "+", "  ", 
          RowBox[{"\[ImaginaryI]", "  ", "S", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  "  \n\nis an analytic function.  The curves  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", \(K\_1\)}]]],
  "  are ca",
  "lled isothermals and",
  " are lines connecting points of the same temperature.  The curves  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"S", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", \(K\_2\)}]]],
  "  are cal",
  "led the heat flow lines, and ",
  "one can visualize the heat flowing along these curves from points of \
higher temperature to points of lower temperature.  The situation is \
illustrated in Figure 11.16(b)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tBoundary value problems for steady state temperatures are realizations \
of the Dirichlet problem where the value of the harmonic function ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " is interpreted as the temperature at the point ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"x", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "y"}], ")"}]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 11.14.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Suppose that two parallel planes are perpendicular to the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane and pass through the horizontal lines ",
  Cell[BoxData[
      \(y = a\)]],
  " and ",
  Cell[BoxData[
      \(y = b\)]],
  " and that the temperature is held constant at the values  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "a"}], ")"}]}], "=", \(T\_1\)}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "b"}], ")"}]}], "=", \(T\_2\)}]]],
  ",  respectively, on these planes.  Then ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " is given by  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
        "  ", \(T\_1\ \  + \ \ \(\(T\_2\  - \ T\_1\)\/\(b\  - \ 
                  a\)\) \((y\  - \ a)\)\)}]],
    AspectRatioFixed->True],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00S03oool20000
02H0oooo1000000U0?ooo`D000008`3oool2000002H0oooo1@00000T0?oo
o`@000009P3oool200000140oooo002;0?ooo`040000003oool0oooo0000
02D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0R0?oo
o`040000003oool0oooo000002L0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0V0?ooo`040000003oool0oooo00000100oooo002=
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000002L0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo00l0oooo00250?ooo`@000001@3oool00`000000oooo0?ooo`0M
0?ooo`@00000103oool00`000000oooo0?ooo`0N0?ooo`@00000103oool0
0`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000002L0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo00h0oooo002;0?ooo`040000003oool0oooo000002D0oooo00@0
00000?ooo`3oool000009`3oool00`000000oooo0?ooo`0R0?ooo`040000
003oool0oooo000002L0oooo00<000000?ooo`3oool0903oool010000000
oooo0?ooo`00000U0?ooo`040000003oool0oooo00000100oooo002<0?oo
o`8000009`3oool2000002L0oooo0P00000U0?ooo`8000009`3oool20000
02L0oooo0P00000W0?ooo`8000004@3oool00?l0ooooU03oool00?l0oooo
U03oool00?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03oool00?l0
ooooU03oool007h0oooo0P0000050?ooool000000`00000<0?ooo`00O@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0:0?ooo`00O@3oool010000000oooo0?ooo`0000040?ooo`800000
oP3oool2000000`0oooo001m0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00P3oooog0?l000D0oooo00<000000?ooo`3oool0
2P3oool007d0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`020?ooooL0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00OP3o
ool2000000D0oooo00<000000?ooo`3oool00P3oooog0?l000D0oooo00<0
00000?ooo`3oool02P3oool008D0oooo0P0000030?ooooL0o`00103oool2
000000`0oooo00250?ooo`030000003oool0oooo0080oooom`3o00050?oo
o`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080
oooom`3o00050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000
003oool0oooo0080oooom`3o00050?ooo`030000003oool0oooo00X0oooo
00250?ooo`8000000`3oooog0?l000@0oooo0P00000<0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooooL0o`001@3oool00`000000oooo0?ooo`0:
0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooooL0o`001@3oool00`00
0000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooooL0
o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo
0?ooo`020?ooooL0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3o
ool2000000<0oooom`3o00040?ooo`800000303oool008D0oooo00<00000
0?ooo`3oool00P3oooog0?l000D0oooo00<000000?ooo`3oool02P3oool0
08D0oooo00<000000?ooo`3oool00P3oooog0?l000D0oooo00<000000?oo
o`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3oooog0?l000D0
oooo00<000000?ooo`3oool02P3oool008D0oooo0P0000030?ooooL0o`00
103oool2000000`0oooo00250?ooo`030000003oool0oooo0080oooom`3o
00050?ooo`030000003oool0oooo00X0oooo001b0?ooo`800000103oool2
000000@0oooo0P0000050?ooo`030000003oool0oooo0080oooom`3o0005
0?ooo`030000003oool0oooo00X0oooo001a0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`020?ooooL0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00L@3oool0
10000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo0P00
00030?ooooL0o`00103oool2000000`0oooo001a0?ooo`040000003oool0
oooo000000T0oooo0P0000050?ooo`030000003oool0oooo0080oooom`3o
00050?ooo`030000003oool0oooo00X0oooo001a0?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooooL0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00LP3oool2
000000X0oooo0`0000040?ooo`030000003oool0oooo0080oooom`3o0005
0?ooo`030000003oool0oooo00X0oooo00250?ooo`8000000`3oooog0?l0
00@0oooo0P00000<0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooooL0
o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo
0?ooo`020?ooooL0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?ooooL0o`001@3oool00`000000oooo0?oo
o`0:0?ooo`00Q@3oool2000000<0oooom`3o00040?ooo`800000303oool0
08D0oooo00<000000?ooo`3oool00P3oooog0?l000D0oooo00<000000?oo
o`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3oooog0?l000D0
oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool0
0P3oooog0?l000D0oooo00<000000?ooo`3oool02P3oool008D0oooo0P00
00030?ooooL0o`00103oool2000000`0oooo00250?ooo`030000003oool0
oooo0080oooom`3o00050?ooo`030000003oool0oooo00X0oooo00250?oo
o`030000003oool0oooo0080oooom`3o00050?ooo`030000003oool0oooo
00X0oooo00250?ooo`030000003oool0oooo0080oooom`3o00050?ooo`03
0000003oool0oooo00X0oooo00250?ooo`8000000`3oooog0?l000@0oooo
0P00000<0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooooL0o`001@3o
ool00`000000oooo0?ooo`0:0?ooo`00O@3oool5000000<0oooo00<00000
0?ooo`3oool00P3oooog0?l000D0oooo00<000000?ooo`3oool02P3oool0
07l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
ooL0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00O`3oool00`000000
oooo0?ooo`030?ooo`8000000`3ooooh000000<0oooo0P00000<0?ooo`00
O`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
m`1B0?l50?ooo`030000003oool0oooo00X0oooo001o0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3oooog0580o`D0oooo00<0
00000?ooo`3oool02P3oool007h0oooo0P0000050?ooo`030000003oool0
oooo0080oooom`1B0?l50?ooo`030000003oool0oooo00X0oooo00250?oo
o`030000003oool0oooo0080oooom`1B0?l50?ooo`030000003oool0oooo
00X0oooo00250?ooo`8000000`3oooog0580o`@0oooo0P00000<0?ooo`00
Q@3oool00`000000oooo0?ooo`020?ooooL0DP3o1@3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooooL0DP3o1@3o
ool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`02
0?ooooL0DP3o1@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool20000
00<0oooom`1B0?l40?ooo`800000303oool008D0oooo00<000000?ooo`3o
ool00P3oooog0580o`D0oooo00<000000?ooo`3oool02P3oool008D0oooo
00<000000?ooo`3oool00P3oooog0580o`D0oooo00<000000?ooo`3oool0
2P3oool008D0oooo00<000000?ooo`3oool00P3oooog0580o`D0oooo00<0
00000?ooo`3oool02P3oool008D0oooo0P0000030?ooooL0DP3o103oool2
000000`0oooo00250?ooo`030000003oool0oooo0080oooom`1B0?l50?oo
o`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080
oooom`1B0?l50?ooo`030000003oool0oooo00X0oooo00250?ooo`030000
003oool0oooo0080oooom`1B0?l50?ooo`030000003oool0oooo00X0oooo
00250?ooo`8000000`3oooog0580o`@0oooo0P00000<0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooooL0DP3o1@3oool00`000000oooo0?ooo`0:
0?ooo`00L@3oool500000080oooo0P0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`020?ooooL0DP3o1@3oool00`000000oooo0?ooo`0:0?oo
o`00L`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00P3oooog0580o`D0oooo00<000000?oo
o`3oool02P3oool007<0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`020?ooo`8000000`3ooooh000000<0oooo0P00000<0?ooo`00
L`3oool00`000000oooo0?ooo`080?ooo`8000001@3oool00`000000oooo
0?ooo`020?ooooL00;co1@3oool00`000000oooo0?ooo`0:0?ooo`00L`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oooog002lo`D0oooo00<000000?ooo`3oool02P3o
ool00780oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`02
0?ooooL00;co1@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool20000
00<0oooom`00_?l40?ooo`800000303oool008D0oooo00<000000?ooo`3o
ool00P3oooog002lo`D0oooo00<000000?ooo`3oool02P3oool008D0oooo
00<000000?ooo`3oool00P3oooog002lo`D0oooo00<000000?ooo`3oool0
2P3oool008D0oooo00<000000?ooo`3oool00P3oooog002lo`D0oooo00<0
00000?ooo`3oool02P3oool008D0oooo0P0000030?ooooL00;co103oool2
000000`0oooo00250?ooo`030000003oool0oooo0080oooom`00_?l50?oo
o`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080
oooom`00_?l50?ooo`030000003oool0oooo00X0oooo00250?ooo`030000
003oool0oooo0080oooom`00_?l50?ooo`030000003oool0oooo00X0oooo
00250?ooo`8000000`3oooog002lo`@0oooo0P00000<0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooooL00;co1@3oool00`000000oooo0?ooo`0:
0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooooL00;co1@3oool00`00
0000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooooL0
0;co1@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo
0?ooo`020?ooooL00;co1@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3o
ool2000000<0oooom`00_?l40?ooo`800000303oool008D0oooo00<00000
0?ooo`3oool00P3oooog002lo`D0oooo00<000000?ooo`3oool02P3oool0
07d0oooo100000040?ooo`030000003oool0oooo0080oooom`00_?l50?oo
o`030000003oool0oooo00X0oooo001m0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oooog002lo`D0oooo00<000000?ooo`3o
ool02P3oool007h0oooo00<000000?ooo`3oool0103oool2000000<0oooo
n00000030?ooo`800000303oool007l0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooooL00?ld1@3oool00`000000oooo0?oo
o`0:0?ooo`00O@3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0080oooom`00oc@50?ooo`030000003oool0oooo00X0oooo001n
0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooooL00?ld1@3oool0
0`000000oooo0?ooo`0:0?ooo`00Q@3oool2000000<0oooom`00oc@40?oo
o`800000303oool008D0oooo00<000000?ooo`3oool00P3oooog003o=0D0
oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool0
0P3oooog003o=0D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<0
00000?ooo`3oool00P3oooog003o=0D0oooo00<000000?ooo`3oool02P3o
ool008D0oooo0P0000030?ooooL00?ld103oool2000000`0oooo00250?oo
o`030000003oool0oooo0080oooom`00oc@50?ooo`030000003oool0oooo
00X0oooo00250?ooo`030000003oool0oooo0080oooom`00oc@50?ooo`03
0000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo
m`00oc@50?ooo`030000003oool0oooo00X0oooo00250?ooo`8000000`3o
ooog003o=0@0oooo0P00000<0?ooo`00Q@3oool00`000000oooo0?ooo`02
0?ooooL00?ld1@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?ooooL00?ld1@3oool00`000000oooo0?ooo`0:0?oo
o`00Q@3oool00`000000oooo0?ooo`020?ooooL00?ld1@3oool00`000000
oooo0?ooo`0:0?ooo`00Q@3oool2000000<0oooom`00oc@40?ooo`800000
303oool008D0oooo00<000000?ooo`3oool00P3oooog003o=0D0oooo00<0
00000?ooo`3oool02P3oool00740oooo100000030?ooo`800000103oool2
000000D0oooo00<000000?ooo`3oool00P3oooog003o=0D0oooo00<00000
0?ooo`3oool02P3oool00740oooo00<000000?ooo`3oool02@3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooom`00oc@5
0?ooo`030000003oool0oooo00X0oooo001b0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool2000000<0oooon00000030?oo
o`800000303oool007<0oooo00<000000?ooo`3oool0203oool2000000D0
oooo00<000000?ooo`3oool00P3oooog0=Wo00D0oooo00<000000?ooo`3o
ool02P3oool00740oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooom`3Io`050?ooo`03
0000003oool0oooo00X0oooo001b0?ooo`8000002P3oool3000000@0oooo
00<000000?ooo`3oool00P3oooog0=Wo00D0oooo00<000000?ooo`3oool0
2P3oool008D0oooo0P0000030?ooooL0fOl0103oool2000000`0oooo0025
0?ooo`030000003oool0oooo0080oooom`3Io`050?ooo`030000003oool0
oooo00X0oooo00250?ooo`030000003oool0oooo0080oooom`3Io`050?oo
o`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080
oooom`3Io`050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000
003oool0oooo0080oooom`3Io`050?ooo`030000003oool0oooo00X0oooo
00250?ooo`8000000`3oooog0=Wo00@0oooo0P00000<0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooooL0fOl01@3oool00`000000oooo0?ooo`0:
0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooooL0fOl01@3oool00`00
0000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooooL0
fOl01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool2000000<0oooo
m`3Io`040?ooo`800000303oool008D0oooo00<000000?ooo`3oool00P3o
ooog0=Wo00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<00000
0?ooo`3oool00P3oooog0=Wo00D0oooo00<000000?ooo`3oool02P3oool0
08D0oooo00<000000?ooo`3oool00P3oooog0=Wo00D0oooo00<000000?oo
o`3oool02P3oool008D0oooo0P0000030?ooooL0fOl0103oool2000000`0
oooo00250?ooo`030000003oool0oooo0080oooom`3Io`050?ooo`030000
003oool0oooo00X0oooo001n0?ooo`8000001@3oool00`000000oooo0?oo
o`020?ooooL0fOl01@3oool00`000000oooo0?ooo`0:0?ooo`00O@3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooom`3I
o`050?ooo`030000003oool0oooo00X0oooo001o0?ooo`030000003oool0
oooo00<0oooo0P0000030?ooooP000000`3oool2000000`0oooo00200?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00X0oooo001m0?ooo`040000003oool0oooo0000
00@0ooooo`000003000000`0oooo001n0?ooo`800000o`3ooolD0?ooo`00
o`3ooonD0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The two-dimensional solution is constructed at points in the \
horizontal strip  ",
  Cell[BoxData[
      \(a < Im \((z)\) < b\)]],
  "  in the complex plane.  A reasonable assumption is that the temperature \
at all points on the plane passing through the line ",
  Cell[BoxData[
      \(y = y\_0\)]],
  " is constant.  Hence  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        "=", \(t \((y)\)\)}]]],
  ",  where ",
  Cell[BoxData[
      \(t \((y)\)\)]],
  " is a function of ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " alone.  Laplace's equation implies that  ",
  Cell[BoxData[
      \(t'' \((y)\) = 0\)]],
  ",  and an argument similar to that in Example 11.1 will show that the \
solution ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " has the form given in the preceding equation."
}], "Text"],

Cell[TextData[{
  "\tThe isothermals  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        "\[Alpha]"}]]],
  "  are easily seen to be horizontal lines.  The conjugate harmonic function \
is  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"S", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        "=", \(\(\(T\_1\  - \ T\_2\)\/\(b\  - \ a\)\) x\)}]]],
  ",  \n\nand the heat flow lines  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"S", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "\[Beta]"}]]],
  "  are vertical segments between the horizontal lines.  If  ",
  Cell[BoxData[
      \(T\_1\  > \ T\_2\)]],
  ",  then the heat flows along these segments from the plane through ",
  Cell[BoxData[
      \(y = a\)]],
  " to the plane through ",
  Cell[BoxData[
      \(y = b\)]],
  ", as illustrated in Figure 11.17.  "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.17",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/temperature/\
TemperaturesFigures/mat1117.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The temperature between parallel planes where  ",
  Cell[BoxData[
      \(T\_1\  > \ T\_2\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.14.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Show that ",
  Cell[BoxData[
      \(S \((x, y)\)\)]],
  " is the harmonic conjugate of ",
  Cell[BoxData[
      \(T \((x, y)\)\)]],
  "."
}], "Text"],

Cell["\<\
Enter the formula for the temperature function.  This is similar to Example \
11.1, and Example 11.18.\
\>", "Text"],

Cell[BoxData[{
    \(T - 0; \ Remove[T]; \ 
    Clear[a, b, x, y, T];\ \), "\[IndentingNewLine]", 
    \(\(Clear[\[Alpha], \[Beta], cont];\)\ \), "\n", 
    \(\(T[x_, y_]\  = \ 
        T\_1\  + \ \(T\_2\  - \ T\_1\)\/\(b\  - \ a\)\ \((y\  - \ 
                a)\);\)\ \), "\n", 
    \(\(S[x_, y_]\  = \(\(T\_1\  - \ T\_2\)\/\(b\  - \ a\)\) 
          x;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<T[x,y] = \>", T[x, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[x,y] = \>", S[x, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(T\_x\)[x,y] = \>\"", \[PartialD]\_x\ 
          T[x, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(S\_y\)[x,y] = \>\"", \[PartialD]\_y\ 
          S[x, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \!\(T\_x\)[x,y] = \!\(S\_y\)[x,y] ?\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\ \[PartialD]\_x\ T[x, y] \[Equal] \[PartialD]\_y\ 
            S[x, y]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\< \!\(T\_y\)[x,y] = \>\"", \[PartialD]\_y\ 
          T[x, y]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<-\!\(S\_x\)[x,y] = \>\"", \(-\[PartialD]\_x\ 
            S[x, y]\)\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \!\(T\_y\)[x,y] = -\!\(S\_x\)[x,y] ?\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[\ 
        Simplify[\[PartialD]\_y\ 
              T[x, y] \[Equal] \(-\[PartialD]\_x\ 
                S[x, y]\)]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Solve  ",
  Cell[BoxData[
      \(T \((x, y)\) = \(\[Alpha]\  = \ 
          T\_1\  + \ \(T\_2\  - \ T\_1\)\/\(b\  - \ a\)\ \((y\  - \ 
                  a)\)\)\)]],
  " to get the isothermals."
}], "Text"],

Cell[BoxData[{
    \(\(solset = 
        Solve[\[Alpha]\  \[Equal] \ 
            T\_1\  + \ \(T\_2\  - \ T\_1\)\/\(b\  - \ a\)\ \((y\  - \ a)\), 
          y];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The isothermals are\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<T(x,y) = \[Alpha]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        Simplify[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1\)\(\[RightDoubleBracket]\)\
\)]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<They are horizontal lines.\>"];\)\)}], "Input"],

Cell[TextData[{
  "Solve  ",
  Cell[BoxData[
      \(S \((x, y)\) = \(\[Beta]\  = \ \(\(T\_1\  - \ T\_2\)\/\(b\  - \ a\)\) 
            x\)\)]],
  " to get the heat flow lines."
}], "Text"],

Cell[BoxData[{
    \(\(solset = 
        Solve[\[Beta]\  \[Equal] \ \(\(T\_1\  - \ T\_2\)\/\(b\  - \ a\)\) x, 
          x];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The heat flow lines are\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<S(x,y) = \[Beta]\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        Simplify[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1\)\(\[RightDoubleBracket]\)\
\)]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<They are vertical lines.\>"];\)\)}], "Input"],

Cell[TextData[{
  "For illustration we choose  ",
  Cell[BoxData[
      \(a = 1, \ \ b = 3, \ \ T\_1 = \(50\ \ and\ \ T\_2 = 10\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(a\  = \ 1;\)\ \), "\n", 
    \(\(b\  = \ 3;\)\ \), "\n", 
    \(\(T\_1\  = \ 50;\)\ \), "\n", 
    \(\(T\_2\  = \ 10;\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\n", 
    \(\(Print["\<T[x,1] = \>", T[x, 1]];\)\ \), "\n", 
    \(\(Print["\<T[x,2] = \>", T[x, 2]];\)\ \), "\n", 
    \(\(Print["\<T[x,3] = \>", T[x, 3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the temperature."
}], "Text"],

Cell[BoxData[{
    \(\(cont\  = \ {10, 20, 30, 40, 50};\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[T[x, y], {x, \(-3\), 3}, {y, 0, 3}, 
        Contours\  \[Rule] \ cont, PlotPoints \[Rule] 10, 
        AspectRatio \[Rule] 1\/2, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The contours are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[T[x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  " Hence the temperature function  T[x,y] = 50 - 20 (-1+y)  is harmonic in \
the horizontal strip  ",
  Cell[BoxData[
      \(1 < Im[z] < 3\)]],
  "  and has the desired boundary values.  \n"
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.15.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the temperature ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " at each point in the upper half plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  ,  if the temperature at points on the x-axis on the boundary satisfy \n\
\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"T", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "0"}], ")"}]}], "=", \(T\_1\)}],
           
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "   ", "x"}], ">", "0"}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[";",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}], "\n"}], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{"T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", \(T\_2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "   ", "x"}], "<", " ", 
          RowBox[{"0", 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00S03oool20000
02H0oooo1000000U0?ooo`D000008`3oool2000002H0oooo1@00000T0?oo
o`@000009P3oool200000140oooo002;0?ooo`040000003oool0oooo0000
02D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0R0?oo
o`040000003oool0oooo000002L0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0V0?ooo`040000003oool0oooo00000100oooo002=
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000002L0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo00l0oooo00250?ooo`@000001@3oool00`000000oooo0?ooo`0M
0?ooo`@00000103oool00`000000oooo0?ooo`0N0?ooo`@00000103oool0
0`000000oooo0?ooo`0R0?ooo`040000003oool0oooo000002L0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo00h0oooo002;0?ooo`040000003oool0oooo000002D0oooo00@0
00000?ooo`3oool000009`3oool00`000000oooo0?ooo`0R0?ooo`040000
003oool0oooo000002L0oooo00<000000?ooo`3oool0903oool010000000
oooo0?ooo`00000U0?ooo`040000003oool0oooo00000100oooo002<0?oo
o`8000009`3oool2000002L0oooo0P00000U0?ooo`8000009`3oool20000
02L0oooo0P00000W0?ooo`8000004@3oool00?l0ooooU03oool00?l0oooo
U03oool00?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03oool00?l0
ooooU03oool007h0oooo0P0000050?ooool000000`00000<0?ooo`00O@3o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0:0?ooo`00O@3oool010000000oooo0?ooo`0000040?ooo`800000
0`3ooooh000000<0oooo0P00000<0?ooo`00O@3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0080ooooN@3oL007000007L0o`1`
1@3oool00`000000oooo0?ooo`0:0?ooo`00O@3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0080ooooN03oL0020000000501Wo
0000000000000000003D0?l00P00001f0?l0L0D0oooo00<000000?ooo`3o
ool02P3oool007h0oooo0P0000050?ooo`030000003oool0oooo0080oooo
M@3oL003000000030=Co00000000000000@000000P3D0?l2000007@0o`1`
1@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool2000000<0ooooLP3o
L003000000<0e?l000@0000001Wo000000000?nR0P0000000`0I0?l00000
000000020=@0o`<00000L@3o07040?ooo`800000303oool008D0oooo00<0
00000?ooo`3oool00P3ooom_0?m`00<000001@3Do`002@0000006Ol001Wo
000000000?nR00000000X_l0000001T0o`02000000@0e03o0`00001^0?l0
L0D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3o
ool00P3ooom/0?m`00<000001P3Do`02000000806Ol000H00000003oXP00
oj800000002Ro`00000301T0o`030000003D0?l0e03o00@0e03o0`00001[
0?l0L0D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?oo
o`3oool00P3ooom[0?m`00030000003Do`00e?l000H0e?l000D0000001Wo
000Io`006Ol000000003003oXP0300000000X_l0000000<06@3o00<00000
0=@0o`3D0?l01`3D0?l00`000000o`1`0?l0L01X0?l0L0D0oooo00<00000
0?ooo`3oool02P3oool008D0oooo0P0000030?ooofP0og000`0000090=Co
00050000000Io`006Ol001Wo000000000`00oj80100000000:;o002Ro`00
000301T0o`030000003D0?l0e03o00L0e03o0`00001W0?l0L0@0oooo0P00
000<0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooofH0og000P00000;
0=Co00030000000Io`006Ol000806Ol000D00000003oXP00oj800?nR0000
0002002Ro`030000000I0?l06@3o00806@3o0P00000:0=@0o`800000I@3o
07050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0
oooo0080ooooH`3oL003000000`0e?l000<0000001Wo000Io`000P0Io`00
0`0000000?nR003oXP02003oXP0500000000X_l00:;o002Ro`000000100I
0?l2000000/0e03o0`00001R0?l0L0D0oooo00<000000?ooo`3oool02P3o
ool008D0oooo00<000000?ooo`3oool00P3ooomP0?m`00<000003@3Do`02
000000D06Ol000<00000003oXP00oj800P00oj801@0000000:;o002Ro`00
X_l0000000H06@3o00<000000=@0o`3D0?l02`3D0?l3000005l0o`1`1@3o
ool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`02
0?oooel0og0000<000000=Co003Do`003@3Do`000`0000006Ol001Wo0004
01Wo000300000000oj800?nR00<00?nR00D00000002Ro`00X_l00:;o0000
000601T0o`030000003D0?l0e03o00h0e03o00<000000?l0L03o0700G03o
07050?ooo`030000003oool0oooo00X0oooo00250?ooo`8000000`3ooomL
0?m`00<00000403Do`000`0000006Ol001Wo000401Wo000300000000oj80
0?nR00<00?nR00<00000002Ro`00X_l00P00X_l00`0000006@3o01T0o`04
01T0o`030000003D0?l0e03o00h0e03o0`00001K0?l0L0@0oooo0P00000<
0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooeT0og000`00000B0=Co
00030000000Io`006Ol000D06Ol000<00000003oXP00oj800`00oj800`00
00000:;o002Ro`02002Ro`030000000I0?l06@3o00D06@3o0P00000A0=@0
o`<00000F03o07050?ooo`030000003oool0oooo00X0oooo00250?ooo`03
0000003oool0oooo0080ooooE`3oL002000001@0e?l000<0000001Wo000I
o`001@0Io`000`0000000?nR003oXP04003oXP0300000000X_l00:;o00<0
0:;o00<0000001T0o`0I0?l01@0I0?l2000001<0e03o0P00001F0?l0L0D0
oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool0
0P3ooomD0?m`00<00000503Do`02000000P06Ol000<00000003oXP00oj80
1000oj800`0000000:;o002Ro`03002Ro`030000000I0?l06@3o00L06@3o
00<000000=@0o`3D0?l04P3D0?l3000005<0o`1`1@3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool2000000<0ooooDP3oL002000001H0e?l000<0
000001Wo000Io`001`0Io`000`0000000?nR003oXP05003oXP0300000000
X_l00:;o00<00:;o00<0000001T0o`0I0?l01`0I0?l00`000000e03o0=@0
o`0E0=@0o`800000D@3o07040?ooo`800000303oool008D0oooo00<00000
0?ooo`3oool00P3ooom@0?m`00800000603Do`000`0000006Ol001Wo0007
01Wo000300000000oj800?nR00D00?nR00<00000002Ro`00X_l01000X_l0
0`0000006@3o01T0o`0701T0o`030000003D0?l0e03o01H0e03o0P00001?
0?l0L0D0oooo00<000000?ooo`3oool02P3oool00780oooo0P0000040?oo
o`800000103oool2000000D0oooo00<000000?ooo`3oool00P3ooom=0?m`
00<000006@3Do`000`0000006Ol001Wo000801Wo000300000000oj800?nR
00D00?nR00<00000002Ro`00X_l01000X_l00`0000006@3o01T0o`0801T0
o`800000603D0?l3000004`0o`1`1@3oool00`000000oooo0?ooo`0:0?oo
o`00L@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3ooom:0?m`00<000006`3Do`00
0`0000006Ol001Wo000801Wo000300000000oj800?nR00H00?nR00<00000
002Ro`00X_l01@00X_l00`0000006@3o01T0o`0801T0o`8000006P3D0?l3
000004T0o`1`1@3oool00`000000oooo0?ooo`0:0?ooo`00L@3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo0P000003
0?ooodP0og000P00000L0=Co008000002`0Io`000`0000000?nR003oXP06
003oXP0300000000X_l00:;o00D00:;o00<0000001T0o`0I0?l02P0I0?l0
0`000000e03o0=@0o`0J0=@0o`800000A`3o07040?ooo`800000303oool0
0740oooo00@000000?ooo`3oool000002@3oool2000000D0oooo00<00000
0?ooo`3oool00P3ooom60?m`008000007@3Do`000`0000006Ol001Wo000:
01Wo000300000000oj800?nR00L00?nR00<00000002Ro`00X_l01@00X_l0
0`0000006@3o01T0o`0:01T0o`030000003D0?l0e03o01`0e03o0P000015
0?l0L0D0oooo00<000000?ooo`3oool02P3oool00740oooo00@000000?oo
o`3oool000002@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0080ooooA@3oL0000`000000e?l00=Co000M0=Co00030000000Io`00
6Ol000X06Ol000<00000003oXP00oj801`00oj800`0000000:;o002Ro`06
002Ro`030000000I0?l06@3o00X06@3o00<000000=@0o`3D0?l07@3D0?l0
0`000000o`1`0?l0L0120?l0L0D0oooo00<000000?ooo`3oool02P3oool0
0780oooo0P00000:0?ooo`<00000103oool00`000000oooo0?ooo`020?oo
od80og000`00000O0=Co00030000000Io`006Ol000/06Ol000<00000003o
XP00oj801`00oj800`0000000:;o002Ro`06002Ro`030000000I0?l06@3o
00/06@3o0P00000N0=@0o`<00000@@3o07050?ooo`030000003oool0oooo
00X0oooo00250?ooo`8000000`3ooolo0?m`00<000008@3Do`000`000000
6Ol001Wo000;01Wo000300000000oj800?nR00P00?nR00<00000002Ro`00
X_l01`00X_l00`0000006@3o01T0o`0;01T0o`800000803D0?l3000003h0
o`1`103oool2000000`0oooo00250?ooo`030000003oool0oooo0080oooo
?03oL00300000280e?l00P00000>01Wo000300000000oj800?nR00P00?nR
00<00000002Ro`00X_l01`00X_l00`0000006@3o01T0o`0=01T0o`030000
003D0?l0e03o0200e03o0`00000k0?l0L0D0oooo00<000000?ooo`3oool0
2P3oool008D0oooo00<000000?ooo`3oool00P3ooolk0?m`008000008`3D
o`000`0000006Ol001Wo000=01Wo000300000000oj800?nR00T00?nR00<0
0000002Ro`00X_l02000X_l00`0000006@3o01T0o`0<01T0o`030000003D
0?l0e03o0280e03o0P00000j0?l0L0D0oooo00<000000?ooo`3oool02P3o
ool008D0oooo00<000000?ooo`3oool00P3oooli0?m`008000009@3Do`00
0`0000006Ol001Wo000=01Wo000300000000oj800?nR00T00?nR00<00000
002Ro`00X_l02000X_l00`0000006@3o01T0o`0=01T0o`030000003D0?l0
e03o02<0e03o0P00000h0?l0L0D0oooo00<000000?ooo`3oool02P3oool0
08D0oooo0P0000030?ooocH0og000`00000V0=Co00030000000Io`006Ol0
00h06Ol000<00000003oXP00oj802@00oj800`0000000:;o002Ro`08002R
o`030000000I0?l06@3o00h06@3o0P00000U0=@0o`<00000=@3o07040?oo
o`800000303oool008D0oooo00<000000?ooo`3oool00P3ooolc0?m`00<0
0000:03Do`000`0000006Ol001Wo000>01Wo000300000000oj800?nR00X0
0?nR00<00000002Ro`00X_l02@00X_l00`0000006@3o01T0o`0>01T0o`80
00009`3D0?l300000380o`1`1@3oool00`000000oooo0?ooo`0:0?ooo`00
Q@3oool00`000000oooo0?ooo`020?oooc00og000`00000Y0=Co00800000
4@0Io`000`0000000?nR003oXP0:003oXP0300000000X_l00:;o00T00:;o
00<0000001T0o`0I0?l0400I0?l00`000000e03o0=@0o`0W0=@0o`<00000
;`3o07050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003o
ool0oooo0080oooo;`3oL0000`000000e?l00=Co000Y0=Co00030000000I
o`006Ol001006Ol000<00000003oXP00oj802`00oj800`0000000:;o002R
o`09002Ro`030000000I0?l06@3o01006@3o00<000000=@0o`3D0?l0:P3D
0?l00`000000o`1`0?l0L00/0?l0L0D0oooo00<000000?ooo`3oool02P3o
ool008D0oooo0P0000030?ooob`0og000`00000/0=Co00030000000Io`00
6Ol001006Ol000<00000003oXP00oj802`00oj800`0000000:;o002Ro`0:
002Ro`030000000I0?l06@3o01006@3o00<000000=@0o`3D0?l0:P3D0?l3
000002/0o`1`103oool2000000`0oooo00250?ooo`030000003oool0oooo
0080oooo:P3oL002000002h0e?l000<0000001Wo000Io`004@0Io`000`00
00000?nR003oXP0;003oXP0300000000X_l00:;o00/00:;o00<0000001T0
o`0I0?l0400I0?l2000002d0e03o0P00000Y0?l0L0D0oooo00<000000?oo
o`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3ooolW0?m`00<0
0000;`3Do`000`0000006Ol001Wo000A01Wo000300000000oj800?nR00`0
0?nR00<00000002Ro`00X_l02`00X_l00`0000006@3o01T0o`0A01T0o`80
0000;P3D0?l3000002H0o`1`1@3oool00`000000oooo0?ooo`0:0?ooo`00
Q@3oool00`000000oooo0?ooo`020?ooob@0og000`00000`0=Co00800000
500Io`000`0000000?nR003oXP0<003oXP0300000000X_l00:;o00`00:;o
00<0000001T0o`0I0?l04P0I0?l00`000000e03o0=@0o`0^0=@0o`<00000
8`3o07050?ooo`030000003oool0oooo00X0oooo00250?ooo`8000000`3o
oolS0?m`00030000003Do`00e?l00300e?l000<0000001Wo000Io`004`0I
o`000`0000000?nR003oXP0=003oXP0300000000X_l00:;o00`00:;o00<0
000001T0o`0I0?l04P0I0?l00`000000e03o0=@0o`0a0=@0o`030000003o
0700o`1`0200o`1`103oool2000000`0oooo00250?ooo`030000003oool0
oooo0080oooo803oL003000003<0e?l000<0000001Wo000Io`004`0Io`00
0`0000000?nR003oXP0=003oXP0300000000X_l00:;o00`00:;o00<00000
01T0o`0I0?l04`0I0?l00`000000e03o0=@0o`0a0=@0o`<000007`3o0705
0?ooo`030000003oool0oooo00X0oooo001m0?ooo`D000000`3oool00`00
0000oooo0?ooo`020?oooad0og000`00000e0=Co00030000000Io`006Ol0
01<06Ol000<00000003oXP00oj803P00oj800`0000000:;o002Ro`0=002R
o`030000000I0?l06@3o01<06@3o0P00000d0=@0o`<00000703o07050?oo
o`030000003oool0oooo00X0oooo001o0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3ooolK0?m`00800000=`3Do`000`000000
6Ol001Wo000D01Wo000300000000oj800?nR00h00?nR00<00000002Ro`00
X_l03@00X_l00`0000006@3o01T0o`0D01T0o`800000=P3D0?l2000001X0
o`1`1@3oool00`000000oooo0?ooo`0:0?ooo`00O`3oool00`000000oooo
0?ooo`030?ooo`8000000`3ooolH0?m`00<00000=`3Do`02000001H06Ol0
00<00000003oXP00oj803`00oj800`0000000:;o002Ro`0>002Ro`030000
000I0?l06@3o01D06@3o00<000000=@0o`3D0?l0=@3D0?l3000001L0o`1`
103oool2000000`0oooo001o0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3ooolF0?m`00800000>@3Do`000`0000006Ol001Wo
000F01Wo000300000000oj800?nR00l00?nR00<00000002Ro`00X_l03P00
X_l00`0000006@3o01T0o`0E01T0o`030000003D0?l0e03o03P0e03o0P00
000E0?l0L0D0oooo00<000000?ooo`3oool02P3oool007l0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?oooa@0og000P00000k
0=Co00030000000Io`006Ol001H06Ol000<00000003oXP00oj803`00oj80
0`0000000:;o002Ro`0>002Ro`030000000I0?l06@3o01H06@3o00<00000
0=@0o`3D0?l0>@3D0?l2000001<0o`1`1@3oool00`000000oooo0?ooo`0:
0?ooo`00OP3oool2000000D0oooo00<000000?ooo`3oool00P3ooolA0?m`
00<00000?03Do`000`0000006Ol001Wo000F01Wo000300000000oj800?nR
01000?nR00<00000002Ro`00X_l03`00X_l00`0000006@3o01T0o`0F01T0
o`800000>`3D0?l300000100o`1`1@3oool00`000000oooo0?ooo`0:0?oo
o`00Q@3oool00`000000oooo0?ooo`020?ooo`h0og000`00000n0=Co0003
0000000Io`006Ol001L06Ol000<00000003oXP00oj804000oj800`000000
0:;o002Ro`0?002Ro`030000000I0?l06@3o01L06@3o0P00000m0=@0o`<0
00003@3o07050?ooo`030000003oool0oooo00X0oooo00250?ooo`800000
0`3oool<0?m`00800000?`3Do`02000001T06Ol000<00000003oXP00oj80
4@00oj800`0000000:;o002Ro`0@002Ro`030000000I0?l06@3o01P06@3o
00<000000=@0o`3D0?l0?@3D0?l2000000/0o`1`103oool2000000`0oooo
00250?ooo`030000003oool0oooo0080oooo2P3oL00200000400e?l000<0
000001Wo000Io`006@0Io`000`0000000?nR003oXP0A003oXP0300000000
X_l00:;o01000:;o00<0000001T0o`0I0?l0600I0?l00`000000e03o0=@0
o`0o0=@0o`8000002@3o07050?ooo`030000003oool0oooo00X0oooo0025
0?ooo`030000003oool0oooo0080oooo1`3oL00300000480e?l000<00000
01Wo000Io`006@0Io`000`0000000?nR003oXP0A003oXP0300000000X_l0
0:;o01000:;o00<0000001T0o`0I0?l06@0I0?l00`000000e03o0=@0o`10
0=@0o`<000001P3o07050?ooo`030000003oool0oooo00X0oooo00250?oo
o`030000003oool0oooo0080oooo1@3oL002000004@0e?l000<0000001Wo
000Io`006@0Io`000`0000000?nR003oXP0B003oXP0300000000X_l00:;o
01400:;o00<0000001T0o`0I0?l06@0I0?l2000004<0e03o0P0000040?l0
L0D0oooo00<000000?ooo`3oool02P3oool008D0oooo0P0000030?ooo`80
og000`0000150=Co00030000000Io`006Ol001X06Ol000<00000003oXP00
oj804P00oj800`0000000:;o002Ro`0A002Ro`030000000I0?l06@3o01X0
6@3o0P0000140=@0o`<0000000<0o`1`0?ooo`3oool00P3oool2000000`0
oooo00250?ooo`030000003oool0oooo0080oooo0P0000160=Co00800000
700Io`000`0000000?nR003oXP0C003oXP0300000000X_l00:;o01800:;o
00<0000001T0o`0I0?l06`0I0?l00`000000e03o0=@0o`140=@0o`<00000
0`3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?oo
o`020?ooodL0e?l000<0000001Wo000Io`00700Io`000`0000000?nR003o
XP0C003oXP0300000000X_l00:;o01800:;o00<0000001T0o`0I0?l06`0I
0?l00`000000e03o0=@0o`150=@0o`D0oooo00<000000?ooo`3oool02P3o
ool008D0oooo00<000000?ooo`3oool00P3ooom70=Co00030000000Io`00
6Ol001`06Ol000<00000003oXP00oj804`00oj800`0000000:;o002Ro`0B
002Ro`030000000I0?l06@3o01`06@3o00<000000=@0o`3D0?l0A03D0?l5
0?ooo`030000003oool0oooo00X0oooo00250?ooo`8000000`3ooom60=Co
00030000000Io`006Ol001`06Ol000<00000003oXP00oj805000oj800`00
00000:;o002Ro`0C002Ro`030000000I0?l06@3o01`06@3o0P0000140=@0
o`@0oooo0P00000<0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooodD0
e?l000<0000001Wo000Io`007@0Io`000`0000000?nR003oXP0D003oXP03
00000000X_l00:;o01<00:;o00<0000001T0o`0I0?l07@0I0?l2000004<0
e03o1@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo
0?ooo`020?oood<0e?l00P00000O01Wo000300000000oj800?nR01D00?nR
00<00000002Ro`00X_l05000X_l00`0000006@3o01T0o`0N01T0o`030000
003D0?l0e03o0400e03o1@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?oood80e?l000<0000001Wo000Io`007`0I
o`000`0000000?nR003oXP0E003oXP0300000000X_l00:;o01@00:;o00<0
000001T0o`0I0?l07P0I0?l00`000000e03o0=@0o`100=@0o`D0oooo00<0
00000?ooo`3oool02P3oool008D0oooo0P0000030?oood80e?l000<00000
01Wo000Io`007`0Io`000`0000000?nR003oXP0E003oXP0300000000X_l0
0:;o01@00:;o00<0000001T0o`0I0?l07`0I0?l00`000000e03o0=@0o`0o
0=@0o`@0oooo0P00000<0?ooo`00Q@3oool00`000000oooo0?ooo`020?oo
od40e?l000<0000001Wo000Io`007`0Io`000`0000000?nR003oXP0F003o
XP0300000000X_l00:;o01D00:;o00<0000001T0o`0I0?l07`0I0?l20000
03l0e03o1@3oool00`000000oooo0?ooo`0:0?ooo`00L@3oool500000080
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`020?oood00
e?l000<0000001Wo000Io`00800Io`000`0000000?nR003oXP0F003oXP03
00000000X_l00:;o01D00:;o00<0000001T0o`0I0?l0800I0?l2000003h0
e03o1@3oool00`000000oooo0?ooo`0:0?ooo`00L`3oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3oooln0=Co008000008P0Io`000`0000000?nR003oXP0G003oXP03
00000000X_l00:;o01H00:;o00<0000001T0o`0I0?l08@0I0?l00`000000
e03o0=@0o`0k0=@0o`D0oooo00<000000?ooo`3oool02P3oool007<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`800000
0`3ooolm0=Co00030000000Io`006Ol002806Ol000<00000003oXP00oj80
5`00oj800`0000000:;o002Ro`0F002Ro`030000000I0?l06@3o02406@3o
00<000000=@0o`3D0?l0>`3D0?l40?ooo`800000303oool007<0oooo00<0
00000?ooo`3oool0203oool2000000D0oooo00<000000?ooo`3oool00P3o
oolm0=Co00030000000Io`006Ol002806Ol000<00000003oXP00oj805`00
oj800`0000000:;o002Ro`0F002Ro`030000000I0?l06@3o02806@3o00<0
00000=@0o`3D0?l0>P3D0?l50?ooo`030000003oool0oooo00X0oooo001c
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?oooc`0e?l000<0000001Wo000Io`008P0Io`00
0`0000000?nR003oXP0H003oXP0300000000X_l00:;o01L00:;o00<00000
01T0o`0I0?l08P0I0?l2000003X0e03o1@3oool00`000000oooo0?ooo`0:
0?ooo`00LP3oool2000000X0oooo0`0000040?ooo`030000003oool0oooo
0080oooo>`3Do`000`0000006Ol001Wo000S01Wo000300000000oj800?nR
01P00?nR00<00000002Ro`00X_l05`00X_l00`0000006@3o01T0o`0S01T0
o`800000>@3D0?l50?ooo`030000003oool0oooo00X0oooo00250?ooo`80
00000`3oooli0=Co008000009@0Io`000`0000000?nR003oXP0I003oXP03
00000000X_l00:;o01P00:;o00<0000001T0o`0I0?l0900I0?l00`000000
e03o0=@0o`0f0=@0o`@0oooo0P00000<0?ooo`00Q@3oool00`000000oooo
0?ooo`020?ooocP0e?l000<0000001Wo000Io`009@0Io`000`0000000?nR
003oXP0I003oXP0300000000X_l00:;o01P00:;o00<0000001T0o`0I0?l0
900I0?l00`000000e03o0=@0o`0f0=@0o`D0oooo00<000000?ooo`3oool0
2P3oool008D0oooo00<000000?ooo`3oool00P3ooolh0=Co00030000000I
o`006Ol002D06Ol000<00000003oXP00oj806@00oj800`0000000:;o002R
o`0I002Ro`030000000I0?l06@3o02@06@3o00<000000=@0o`3D0?l0=@3D
0?l50?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0
oooo0080oooo=`3Do`000`0000006Ol001Wo000U01Wo000300000000oj80
0?nR01X00?nR00<00000002Ro`00X_l06@00X_l00`0000006@3o01T0o`0U
01T0o`800000=@3D0?l50?ooo`030000003oool0oooo00X0oooo00250?oo
o`8000000`3ooolf0=Co00030000000Io`006Ol002H06Ol000<00000003o
XP00oj806P00oj800`0000000:;o002Ro`0I002Ro`8000009`0I0?l20000
03@0e03o103oool2000000`0oooo00250?ooo`030000003oool0oooo0080
oooo=03Do`02000002P06Ol000<00000003oXP00oj806`00oj800`000000
0:;o002Ro`0J002Ro`030000000I0?l06@3o02L06@3o00<000000=@0o`3D
0?l0<@3D0?l50?ooo`030000003oool0oooo00X0oooo00250?ooo`030000
003oool0oooo0080oooo<`3Do`000`0000006Ol001Wo000X01Wo00030000
0000oj800?nR01/00?nR00<00000002Ro`00X_l06P00X_l00`0000006@3o
01T0o`0W01T0o`030000003D0?l0e03o0340e03o1@3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooc<0e?l000<0
000001Wo000Io`00:00Io`000`0000000?nR003oXP0K003oXP0300000000
X_l00:;o01/00:;o00<0000001T0o`0I0?l09`0I0?l00`000000e03o0=@0
o`0`0=@0o`D0oooo00<000000?ooo`3oool02P3oool008D0oooo0P000003
0?oooc80e?l000<0000001Wo000Io`00:00Io`000`0000000?nR003oXP0L
003oXP0300000000X_l00:;o01/00:;o00<0000001T0o`0I0?l0:00I0?l2
00000300e03o103oool2000000`0oooo00250?ooo`030000003oool0oooo
0080oooo<@3Do`000`0000006Ol001Wo000X01Wo000300000000oj800?nR
01d00?nR00<00000002Ro`00X_l07000X_l00`0000006@3o01T0o`0X01T0
o`800000;`3D0?l50?ooo`030000003oool0oooo00X0oooo00250?ooo`03
0000003oool0oooo0080oooo;`3Do`02000002/06Ol000<00000003oXP00
oj807@00oj800`0000000:;o002Ro`0L002Ro`030000000I0?l06@3o02X0
6@3o00<000000=@0o`3D0?l0;03D0?l50?ooo`030000003oool0oooo00X0
oooo00250?ooo`030000003oool0oooo0080oooo;P3Do`000`0000006Ol0
01Wo000Z01Wo000300000000oj800?nR01h00?nR00<00000002Ro`00X_l0
7000X_l00`0000006@3o01T0o`0Z01T0o`030000003D0?l0e03o02`0e03o
1@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?oo
o`020?ooobh0e?l000<0000001Wo000Io`00:P0Io`000`0000000?nR003o
XP0N003oXP0300000000X_l00:;o01d00:;o00<0000001T0o`0I0?l0:P0I
0?l00`000000e03o0=@0o`0[0=@0o`D0oooo00<000000?ooo`3oool02P3o
ool008D0oooo0P0000030?ooobd0e?l000<0000001Wo000Io`00:`0Io`00
0`0000000?nR003oXP0N003oXP0300000000X_l00:;o01d00:;o00<00000
01T0o`0I0?l0:`0I0?l2000002/0e03o103oool2000000`0oooo00250?oo
o`030000003oool0oooo0080oooo;03Do`000`0000006Ol001Wo000[01Wo
000300000000oj800?nR01l00?nR00<00000002Ro`00X_l07P00X_l00`00
00006@3o01T0o`0[01T0o`800000:P3D0?l50?ooo`030000003oool0oooo
00X0oooo001m0?ooo`@00000103oool00`000000oooo0?ooo`020?ooobX0
e?l00P00000^01Wo000300000000oj800?nR01l00?nR00<00000002Ro`00
X_l07P00X_l00`0000006@3o01T0o`0]01T0o`030000003D0?l0e03o02L0
e03o1@3oool00`000000oooo0?ooo`0:0?ooo`00O@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo:@3Do`000`0000006Ol0
01Wo000^01Wo000300000000oj800?nR01l00?nR00<00000002Ro`00X_l0
7P00X_l00`0000006@3o01T0o`0]01T0o`030000003D0?l0e03o02L0e03o
1@3oool00`000000oooo0?ooo`0:0?ooo`00OP3oool00`000000oooo0?oo
o`040?ooo`8000000`3ooolY0=Co00030000000Io`006Ol002d06Ol000<0
0000003oXP00oj808000oj800`0000000:;o002Ro`0O002Ro`030000000I
0?l06@3o02d06@3o00<000000=@0o`3D0?l09P3D0?l40?ooo`800000303o
ool007l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooobP0e?l000<0000001Wo000Io`00;P0Io`000`0000000?nR003oXP0P
003oXP0300000000X_l00:;o01l00:;o00<0000001T0o`0I0?l0;P0I0?l2
000002H0e03o1@3oool00`000000oooo0?ooo`0:0?ooo`00O@3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo9`3Do`00
0`0000006Ol001Wo000^01Wo000300000000oj800?nR02400?nR00<00000
002Ro`00X_l08000X_l00`0000006@3o01T0o`0^01T0o`8000009@3D0?l5
0?ooo`030000003oool0oooo00X0oooo001n0?ooo`8000001@3oool00`00
0000oooo0?ooo`020?ooobD0e?l00P00000a01Wo000300000000oj800?nR
02400?nR00<00000002Ro`00X_l08000X_l00`0000006@3o01T0o`0`01T0
o`030000003D0?l0e03o0280e03o1@3oool00`000000oooo0?ooo`0:0?oo
o`00Q@3oool2000000<0oooo903Do`000`0000006Ol001Wo000`01Wo0080
00008`00oj800`0000000:;o002Ro`0P002Ro`030000000I0?l06@3o0300
6@3o00<000000=@0o`3D0?l08P3D0?l40?ooo`800000303oool008D0oooo
00<000000?ooo`3oool00P3ooolT0=Co00030000000Io`006Ol003006Ol0
00<00000003oXP00oj808P00oj800`0000000:;o002Ro`0Q002Ro`030000
000I0?l06@3o03006@3o00<000000=@0o`3D0?l08@3D0?l50?ooo`030000
003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo8`3D
o`000`0000006Ol001Wo000a01Wo000300000000oj800?nR02800?nR00<0
0000002Ro`00X_l08@00X_l00`0000006@3o01T0o`0a01T0o`8000008@3D
0?l50?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0
oooo0080oooo8P3Do`000`0000006Ol001Wo000a01Wo000300000000oj80
0?nR02<00?nR00<00000002Ro`00X_l08P00X_l00`0000006@3o01T0o`0a
01T0o`800000803D0?l50?ooo`030000003oool0oooo00X0oooo00250?oo
o`8000000`3ooolP0=Co00800000=00Io`000`0000000?nR003oXP0S003o
XP0300000000X_l00:;o02800:;o00<0000001T0o`0I0?l0<`0I0?l00`00
0000e03o0=@0o`0M0=@0o`@0oooo0P00000<0?ooo`00Q@3oool00`000000
oooo0?ooo`020?oooal0e?l000<0000001Wo000Io`00<`0Io`000`000000
0?nR003oXP0T003oXP0300000000X_l00:;o02800:;o00<0000001T0o`0I
0?l0<`0I0?l00`000000e03o0=@0o`0M0=@0o`D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo00<000000?ooo`3oool00P3ooolO0=Co00030000
000Io`006Ol003<06Ol000<00000003oXP00oj809000oj800`0000000:;o
002Ro`0S002Ro`030000000I0?l06@3o03<06@3o00<000000=@0o`3D0?l0
703D0?l50?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003o
ool0oooo0080oooo7P3Do`000`0000006Ol001Wo000d01Wo000300000000
oj800?nR02@00?nR00<00000002Ro`00X_l08`00X_l00`0000006@3o01T0
o`0d01T0o`800000703D0?l50?ooo`030000003oool0oooo00X0oooo0025
0?ooo`8000000`3ooolM0=Co00030000000Io`006Ol003@06Ol000<00000
003oXP00oj809@00oj800`0000000:;o002Ro`0T002Ro`030000000I0?l0
6@3o03@06@3o0P00000K0=@0o`@0oooo0P00000<0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?oooa/0e?l00P00000g01Wo000300000000oj800?nR
02D00?nR00<00000002Ro`00X_l09000X_l00`0000006@3o01T0o`0f01T0
o`030000003D0?l0e03o01P0e03o1@3oool00`000000oooo0?ooo`0:0?oo
o`00Q@3oool00`000000oooo0?ooo`020?oooaX0e?l000<0000001Wo000I
o`00=P0Io`000`0000000?nR003oXP0V003oXP0300000000X_l00:;o02@0
0:;o00<0000001T0o`0I0?l0=P0I0?l00`000000e03o0=@0o`0H0=@0o`D0
oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool0
0P3ooolJ0=Co00030000000Io`006Ol003H06Ol000<00000003oXP00oj80
9P00oj800`0000000:;o002Ro`0U002Ro`030000000I0?l06@3o03H06@3o
00<000000=@0o`3D0?l05`3D0?l50?ooo`030000003oool0oooo00X0oooo
00250?ooo`8000000`3ooolI0=Co00030000000Io`006Ol003L06Ol000<0
0000003oXP00oj809P00oj800`0000000:;o002Ro`0U002Ro`030000000I
0?l06@3o03L06@3o0P00000G0=@0o`@0oooo0P00000<0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?oooaP0e?l000<0000001Wo000Io`00=`0Io`00
0`0000000?nR003oXP0W003oXP0300000000X_l00:;o02H00:;o00<00000
01T0o`0I0?l0=`0I0?l2000001H0e03o1@3oool00`000000oooo0?ooo`0:
0?ooo`00L@3oool4000000<0oooo0P0000040?ooo`8000001@3oool00`00
0000oooo0?ooo`020?oooaH0e?l00P00000j01Wo000300000000oj800?nR
02L00?nR00<00000002Ro`00X_l09`00X_l00`0000006@3o01T0o`0h01T0
o`030000003D0?l0e03o01<0e03o1@3oool00`000000oooo0?ooo`0:0?oo
o`00L@3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00P3ooolE0=Co00030000000Io`006Ol0
03T06Ol000<00000003oXP00oj80:000oj800`0000000:;o002Ro`0W002R
o`030000000I0?l06@3o03P06@3o00<000000=@0o`3D0?l04`3D0?l50?oo
o`030000003oool0oooo00X0oooo001b0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00P3oool2000000<0oooo5@3Do`000`000000
6Ol001Wo000i01Wo000300000000oj800?nR02P00?nR00<00000002Ro`00
X_l09`00X_l00`0000006@3o01T0o`0i01T0o`030000003D0?l0e03o0180
e03o103oool2000000`0oooo001c0?ooo`030000003oool0oooo00P0oooo
0P0000050?ooo`030000003oool0oooo0080oooo503Do`000`0000006Ol0
01Wo000j01Wo000300000000oj800?nR02P00?nR00<00000002Ro`00X_l0
:000X_l00`0000006@3o01T0o`0i01T0o`8000004P3D0?l50?ooo`030000
003oool0oooo00X0oooo001a0?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oooa<0e?l0
00<0000001Wo000Io`00>P0Io`000`0000000?nR003oXP0Y003oXP030000
0000X_l00:;o02P00:;o00<0000001T0o`0I0?l0>P0I0?l200000140e03o
1@3oool00`000000oooo0?ooo`0:0?ooo`00LP3oool2000000X0oooo0`00
00040?ooo`030000003oool0oooo0080oooo4@3Do`02000003d06Ol000<0
0000003oXP00oj80:@00oj800`0000000:;o002Ro`0X002Ro`800000?@0I
0?l00`000000e03o0=@0o`0>0=@0o`D0oooo00<000000?ooo`3oool02P3o
ool008D0oooo0P0000030?oooa00e?l000<0000001Wo000Io`00?00Io`00
0`0000000?nR003oXP0Z003oXP0300000000X_l00:;o02T00:;o00<00000
01T0o`0I0?l0>`0I0?l00`000000e03o0=@0o`0>0=@0o`@0oooo0P00000<
0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooa00e?l000<0000001Wo
000Io`00?00Io`000`0000000?nR003oXP0Z003oXP0300000000X_l00:;o
02T00:;o00<0000001T0o`0I0?l0?00I0?l00`000000e03o0=@0o`0=0=@0
o`D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3o
ool00P3oool?0=Co00030000000Io`006Ol003`06Ol000<00000003oXP00
oj80:`00oj800`0000000:;o002Ro`0Z002Ro`030000000I0?l06@3o03`0
6@3o0P00000=0=@0o`D0oooo00<000000?ooo`3oool02P3oool008D0oooo
00<000000?ooo`3oool00P3oool>0=Co00030000000Io`006Ol003d06Ol0
00<00000003oXP00oj80:`00oj800`0000000:;o002Ro`0Z002Ro`030000
000I0?l06@3o03d06@3o0P00000<0=@0o`D0oooo00<000000?ooo`3oool0
2P3oool008D0oooo00<000000?ooo`3oool00P3oool<0=Co00800000?`0I
o`000`0000000?nR003oXP0/003oXP0300000000X_l00:;o02/00:;o00<0
000001T0o`0I0?l0?P0I0?l00`000000e03o0=@0o`090=@0o`D0oooo00<0
00000?ooo`3oool02P3oool008D0oooo0P0000030?ooo`/0e?l000<00000
01Wo000Io`00?`0Io`000`0000000?nR003oXP0/003oXP0300000000X_l0
0:;o02/00:;o00<0000001T0o`0I0?l0?P0I0?l00`000000e03o0=@0o`09
0=@0o`@0oooo0P00000<0?ooo`00Q@3oool00`000000oooo0?ooo`020?oo
o`/0e?l000<0000001Wo000Io`00?`0Io`000`0000000?nR003oXP0/003o
XP0300000000X_l00:;o02/00:;o00<0000001T0o`0I0?l0?`0I0?l00`00
0000e03o0=@0o`080=@0o`D0oooo00<000000?ooo`3oool02P3oool008D0
oooo00<000000?ooo`3oool00P3oool:0=Co00030000000Io`006Ol003l0
6Ol000<00000003oXP00oj80;@00oj800`0000000:;o002Ro`0/002Ro`03
0000000I0?l06@3o03l06@3o0P0000080=@0o`D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo00<000000?ooo`3oool00P3oool80=Co00800000
@P0Io`000`0000000?nR003oXP0]003oXP0300000000X_l00:;o02`00:;o
00<0000001T0o`0I0?l0@00I0?l2000000L0e03o1@3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool2000000<0oooo1`3Do`000`0000006Ol001Wo
001101Wo000300000000oj800?nR02h00?nR00<00000002Ro`00X_l0;@00
X_l00`0000006@3o01T0o`1101T0o`030000003D0?l0e03o00@0e03o103o
ool2000000`0oooo00250?ooo`030000003oool0oooo0080oooo1P3Do`00
0`0000006Ol001Wo001201Wo000300000000oj800?nR02h00?nR00<00000
002Ro`00X_l0;@00X_l00`0000006@3o01T0o`1101T0o`030000003D0?l0
e03o00@0e03o1@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?ooo`H0e?l000<0000001Wo000Io`00@P0Io`000`00
00000?nR003oXP0^003oXP0300000000X_l00:;o02d00:;o00<0000001T0
o`0I0?l0@P0I0?l00`000000e03o0=@0o`030=@0o`D0oooo00<000000?oo
o`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3oool50=Co0003
0000000Io`006Ol004806Ol000<00000003oXP00oj80;`00oj800`000000
0:;o002Ro`0^002Ro`030000000I0?l06@3o04806@3o0P0000030=@0o`D0
oooo00<000000?ooo`3oool02P3oool008D0oooo0P0000030?ooo`<0e?l0
0P00001501Wo000300000000oj800?nR02l00?nR00<00000002Ro`00X_l0
;P00X_l00`0000006@3o01T0o`1301T0o`8000000P3D0?l40?ooo`800000
303oool008D0oooo00<000000?ooo`3oool00P3oool20=Co00030000000I
o`006Ol004@06Ol000<00000003oXP00oj80<000oj800`0000000:;o002R
o`0_002Ro`030000000I0?l06@3o04@06@3o00<000000=@0o`3oool0103o
ool00`000000oooo0?ooo`0:0?ooo`00OP3oool2000000D0oooo00<00000
0?ooo`3oool00P3oool00`3Do`00000001Wo001601Wo000300000000oj80
0?nR03000?nR00<00000002Ro`00X_l0;`00X_l00`0000006@3o01T0o`14
01T0o`030000003D0?l0oooo00@0oooo00<000000?ooo`3oool02P3oool0
07d0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`02
0?ooo`030=Co000000006Ol004H06Ol000<00000003oXP00oj80<000oj80
0`0000000:;o002Ro`0_002Ro`030000000I0?l06@3o04D06@3o00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`00O`3oool00`00
0000oooo0?ooo`030?ooo`8000000`3oool00`0000006Ol001Wo001501Wo
00800000<P00oj800`0000000:;o002Ro`0`002Ro`030000000I0?l06@3o
04D06@3o00@000000?ooo`3oool0oooo0P00000<0?ooo`00P03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0:0?ooo`00O@3oool010000000oooo0?ooo`0000040?oo
ool000000`00000<0?ooo`00OP3oool200000?l0oooo503oool00?l0oooo
U03oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  Since ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " is a harmonic function, this problem is an example of a Dirichlet \
problem.  From Example 11.2, it follows that the solution is  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
        " ", \(T\_1\  + \ \(\(T\_2\  - T\_1\)\/\[Pi]\) 
            Arg \((x + \[ImaginaryI]\ y)\)\)}]],
    AspectRatioFixed->True],
  "\n\nThe isotherms  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        "\[Alpha]"}]],
    AspectRatioFixed->True],
  "  are rays emanating from the origin.  The conjugate harmonic function is  \
\n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"S", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
        " ", \(\(T\_1\  - T\_2\)\/\[Pi]\)}]]],
  Cell[BoxData[
      \(ln | x + \[ImaginaryI]\ y | \)]],
  ",\n\nand the heat flow lines  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"S", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        "\[Beta]"}]],
    AspectRatioFixed->True],
  "  are semicircles centered at the origin.  If  ",
  Cell[BoxData[
      \(T\_1\  > T\_2\)],
    AspectRatioFixed->True],
  ",  then the heat flows counterclockwise along the semicircles, as shown in \
Figure 11.18. "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.18",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/temperature/\
TemperaturesFigures/mat1118.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The temperature ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " in the upper half-plane where ",
  Cell[BoxData[
      \(T\_1\  > T\_2\)],
    AspectRatioFixed->True],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.15.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Verify that  ",
  Cell[BoxData[
      RowBox[{"S", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]],
    AspectRatioFixed->True],
  "  is the harmonic conjugate of  ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]],
    AspectRatioFixed->True],
  "  ."
}], "Text"],

Cell[BoxData[{
    \(\(Print[\*"\"\<Does  \!\(\[PartialD]\_x\) (\!\(\(T\_2\\\  - T\_1\)\/\
\[Pi]\)ArcTan[\!\(y\/x\)])\[Equal]\!\(\[PartialD]\_y\) (\!\(\(T\_1\\\  - T\_2\
\)\/\(2  \[Pi]\)\)Log[\!\(x\^2\)+\!\(y\^2\)])  ?\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[
        Simplify[\ \[PartialD]\_x\ \((\(\(T\_2\  - T\_1\)\/\[Pi]\) 
                  ArcTan[y\/x])\) \[Equal] \[PartialD]\_y\ \((\(\(T\_1\  - 
                        T\_2\)\/\(2  \[Pi]\)\) 
                  Log[x\^2 + y\^2])\)\ ]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does  \!\(\[PartialD]\_y\) (\!\(\(T\_2\\\  - T\_1\)\/\
\[Pi]\)ArcTan[\!\(y\/x\)])\[Equal]-\!\(\[PartialD]\_x\) (\!\(\(T\_1\\\  - \
T\_2\)\/\(2  \[Pi]\)\)Log[\!\(x\^2\)+\!\(y\^2\)])  ?\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print[
        Simplify[\ \[PartialD]\_y\ \((\(\(T\_2\  - T\_1\)\/\[Pi]\) 
                  ArcTan[y\/x])\) \[Equal] \(-\[PartialD]\_x\ \((\(\(T\_1\  - 
                          T\_2\)\/\(2  \[Pi]\)\) 
                    Log[x\^2 + y\^2])\)\)\ ]\ ];\)\)}], "Input"],

Cell["\<\
Enter the formula for the temperature function.  This is similar to Example \
11.2.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[a, b, x, y, T];\)\ \), "\n", 
    \(\(T[x_, y_]\  = \ 
        T\_1\  + \ \(\(T\_2\  - T\_1\)\/\[Pi]\) 
            Arg[x\  + \ \[ImaginaryI]\ y];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "For illustration we choose  ",
  Cell[BoxData[
      \(T\_1 = \(50\ \ and\ \ T\_2 = 10\)\)]],
  ".  \nThen we can check out the temperature at points whose argument is  ",
  Cell[BoxData[
      \(Arg[z] = 0, \[Pi]\/4, \[Pi]\/2, \(3\ \[Pi]\)\/4, \[Pi]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(T\_1\  = \ 50;\)\ \), "\n", 
    \(\(T\_2\  = \ 10;\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(For[k = 0, 
        k \[LessEqual] 4, \(k++\), \[IndentingNewLine]X = 
          Cos[\(\[Pi]\ k\)\/4]; \ 
        Y = Sin[\(\[Pi]\ k\)\/4]; \ \[IndentingNewLine]Print["\< T[\>", 
          X, "\<,\>", Y, "\<] = \>", 
          T[X, Y]];\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the temperature."
}], "Text"],

Cell[BoxData[{
    \(\(cont\  = \ Table[10 + 5  k, {k, 0, 8}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[T[x, y], {x, \(-3\), 3}, {y, 0, 3}, 
        Contours\  \[Rule] \ cont, PlotPoints \[Rule] 35, 
        AspectRatio \[Rule] 1\/2, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\n", 
    \(\(Print["\<The contours are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[T[x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Hence the temperature function  ",
  Cell[BoxData[
      \(T[x, y] = 50 - \(40\ Arg[x\  + \ \[ImaginaryI]\ y]\)\/\[Pi]\)]],
  "  is harmonic in the upper half plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  and has the desired boundary values.  "
}], "Text"],

Cell[TextData[{
  "Then use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[T[x, y], {x, \(-2\), 2}, {y, 0.00001, 1.5}, 
        PlotPoints \[Rule] {41, 16}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\[Phi]\>"}, 
        ColorFunction \[Rule] Hue, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 1.5, 0.5], 
            Range[0, 50, 25]}, ViewPoint \[Rule] {\(-2.5\), \(-3\), 2}, 
        AxesEdge \[Rule] {{\(-1\), \(-1\)}, {\(-1\), \(-1\)}, {1, \
\(-1\)}}];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Hence the temperature function  ",
  Cell[BoxData[
      \(T[x, y] = 50 - \(40\ Arg[x\  + \ \[ImaginaryI]\ y]\)\/\[Pi]\)]],
  "  is harmonic in the upper half plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.16.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the temperature ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " at each point in the upper half-disk  ",
  Cell[BoxData[
      \(H : y > 0, \(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ",  if the temperature at points on the boundary satisfies \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"T", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], "=", "100"}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "   ", "x"}], 
              "+", \(\[ImaginaryI]\ y\)}], 
            "=", \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", 
          RowBox[{
            RowBox[{"0", "<", "\[Theta]", "<", 
              RowBox[{
                RowBox[{"\[Pi]", "   ", 
                  StyleBox["on",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["the",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["upper",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  StyleBox["semi",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}], 
                StyleBox["-",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                StyleBox["circle",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}]}], 
            StyleBox[";",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{"T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", "  ", "50"}],
         
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "-", "1"}], "<", "x", "<", 
          RowBox[{"1", "  ", 
            StyleBox["on",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["the",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[\(\(diameter\)\(.\)\),
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "    "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00R`3oool50000
03@0oooo0P0000040?ooo`800000103oool2000003<0oooo0P00000e0?oo
o`800000103oool2000000@0oooo0P00000e0?ooo`D000003`3oool008d0
oooo00<000000?ooo`3oool0<`3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo00000340oooo00@000000?ooo`3oool00000<`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000003H0
oooo00<000000?ooo`3oool03`3oool008d0oooo00<000000?ooo`3oool0
<`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo02l0
oooo00@000000?ooo`3oool00000<`3oool010000000oooo0?ooo`00000;
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool03`3oool0
08D0oooo100000040?ooo`030000003oool0oooo02d0oooo100000020?oo
o`040000003oool0oooo000000T0oooo0P00000b0?ooo`040000003oool0
oooo000003<0oooo00@000000?ooo`3oool000002@3oool2000003L0oooo
00<000000?ooo`3oool03`3oool008d0oooo00<000000?ooo`3oool0<`3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0340oooo
00@000000?ooo`3oool00000<`3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool03`3oool008`0
oooo0P00000f0?ooo`8000002P3oool300000380oooo0P00000e0?ooo`80
00002P3oool3000003D0oooo0P00000A0?ooo`00o`3ooonD0?ooo`00o`3o
oonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
OP3oool200000?l0oooo503oool007d0oooo00@000000?ooo`3oool00000
103ooooo000000<00000303oool007d0oooo00@000000?ooo`3oool00000
103oool2000000<0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`040000003oool0oooo0?ooo`800000303oool007d0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`80
00000P3oool00`000000oooo0?ooo`3/0?ooo`030000003oool0oooo0080
0000103oool00`000000oooo0?ooo`0:0?ooo`00O@3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0080oooo100000000`1Zo`00
00000000000200000>H0ohl0100000000`1Zo`00000000000002000000@0
oooo00<000000?ooo`3oool02P3oool007h0oooo0P0000050?ooo`030000
003oool0oooo0080oooo1P00000206[o00@00000h03oS`0400000080J_l0
1P0000040?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003o
ool0oooo0080oooo0P0000000`00G_l00000003oV`02000000D0J_l00`00
003J0?n?00<000001@1Zo`0200000003003oV`000000000000800000103o
ool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`02
0?ooo`80000000<005ko0000000000000P00oi/00`000000J_l006[o0005
06[o00<00000e03oS`03000000L0J_l000H00000003oV`00oi/00?nK0000
0000G_l2000000@0oooo00<000000?ooo`3oool02P3oool008D0oooo0P00
00030?ooo`040000002V0?l00000001No`8000000P00oi/2000000P0J_l0
1000003<0?n?00@00000201Zo`02000000800?nK0P0000001000G_l00000
0:H0o`0000030?ooo`800000303oool008D0oooo00<000000?ooo`3oool0
0P3oool00`000000YP3o00000002001No`0300000000oi/00?nK00800?nK
0P00000:06[o00@00000a03oS`04000000X0J_l00P000004003oV`060000
0000G_l005ko0000002V0?l00000103oool00`000000oooo0?ooo`0:0?oo
o`00Q@3oool00`000000oooo0?ooo`020?ooo`040000002V0?l0YP3o0000
008005ko00<00000003oV`00oi/00P00oi/2000000d0J_l01@00002j0?n?
00D000003@1Zo`02000000@00?nK00@00000001No`00G_l000000P2V0?l0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00250?oo
o`030000003oool0oooo0080oooo00@000000:H0o`2V0?l000000P00G_l2
000000D00?nK0P00000?06[o00@00000]03oS`0400000100J_l00P000004
003oV`8000000P00G_l010000000YP3o0:H0o`0000040?ooo`030000003o
ool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo00@00000
0:H0o`2V0?l000000`00G_l2000000H00?nK00<0000006[o001Zo`00401Z
o`0500000:X0ohl01@00000B06[o008000001P00oi/01@00000005ko001N
o`00G_l000000080YP3o00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`050000002V
0?l0YP3o0:H0o`0000000`00G_l2000000H00?nK0P00000D06[o00D00000
XP3oS`05000001@0J_l00P000006003oV`8000000`00G_l01@000000YP3o
0:H0o`2V0?l0000000@0oooo00<000000?ooo`3oool02P3oool008D0oooo
0P0000030?ooo`050000002V0?l0YP3o0:H0o`0000001000G_l2000000L0
0?nK0P00000G06[o00D00000V03oS`05000001L0J_l00P000007003oV`80
00001000G_l01@000000YP3o0:H0o`2V0?l0000000<0oooo0P00000<0?oo
o`00Q@3oool00`000000oooo0?ooo`020?ooo`030000002V0?l0YP3o0080
YP3o00<00000001No`00G_l00P00G_l00`0000000?nK003oV`07003oV`03
0000001Zo`00J_l001T0J_l01P00002<0?n?00H000006`1Zo`000`000000
0?nK003oV`07003oV`0300000000G_l005ko008005ko00<000000:H0o`2V
0?l00P2V0?l00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0
oooo00250?ooo`030000003oool0oooo0080oooo0P0000030:H0o`030000
0000G_l005ko00<005ko00<00000003oV`00oi/01`00oi/2000001l0J_l0
1@0000220?n?00D000007`1Zo`02000000T00?nK00<00000001No`00G_l0
0`00G_l00`000000YP3o0:H0o`020:H0o`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3o
ool00`3o000000000:H0o`030:H0o`0300000000G_l005ko00<005ko00<0
0000003oV`00oi/02000oi/00`000000J_l006[o000Q06[o00H00000MP3o
S`06000002<0J_l000<00000003oV`00oi/02000oi/00`00000005ko001N
o`04001No`050000002V0?l0YP3o0:H0o`0000001@3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`030?l00000
0000YP3o00<0YP3o00<00000001No`00G_l01000G_l00`0000000?nK003o
V`08003oV`<000009P1Zo`08000006H0ohl02000000V06[o00<000002P00
oi/2000000D005ko00<000000:H0o`2V0?l00P2V0?l00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0
oooo0080oooo00<0o`000000002V0?l00`2V0?l2000000H005ko00<00000
003oV`00oi/02P00oi/2000002`0J_l02@00001D0?n?00T00000;01Zo`02
000000`00?nK00<00000001No`00G_l01000G_l2000000@0YP3o00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?ooo`030?l000000000YP3o00@0YP3o00<00000001N
o`00G_l01@00G_l00`0000000?nK003oV`0:003oV`<00000<`1Zo`0;0000
03h0ohl02`00000c06[o00<000003000oi/00`00000005ko001No`05001N
o`030000002V0?l0YP3o00<0YP3o00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0:0?ooo`00Q@3oool2000000<0oooo00<0o`000000002V
0?l0102V0?l2000000L005ko00<00000003oV`00oi/02`00oi/3000003`0
J_l04@00000L0?n?01400000?01Zo`03000000d00?nK0P000006001No`80
00001@2V0?l00`000000oooo0?ooo`020?ooo`800000303oool008D0oooo
00<000000?ooo`3oool00P3oool00`3o000000000:H0o`050:H0o`030000
0000G_l005ko00H005ko00<00000003oV`00oi/03@00oi/2000004/0J_l0
7000001;06[o008000003`00oi/00`00000005ko001No`06001No`030000
002V0?l0YP3o00@0YP3o00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`80o`0000<0
00000:H0o`2V0?l00`2V0?l2000000P005ko00<00000003oV`00oi/03P00
oi/200000:h0J_l00`00000?003oV`0300000000G_l005ko00H005ko0P00
00060:H0o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3o
ool008D0oooo00<000000?ooo`3oool00P3oool20?l000030000002V0?l0
YP3o00@0YP3o00<00000001No`00G_l01`00G_l00`0000000?nK003oV`0?
003oV`800000ZP1Zo`02000001400?nK00<00000001No`00G_l01`00G_l0
0`000000YP3o0:H0o`040:H0o`030000003o0000oooo00@0oooo00<00000
0?ooo`3oool02P3oool00780oooo0P0000040?ooo`8000000`3oool40000
00@0oooo00<000000?ooo`3oool00P3oool20?l000030000002V0?l0YP3o
00D0YP3o00<00000001No`00G_l01`00G_l00`0000000?nK003oV`0@003o
V`<00000Y01Zo`03000001800?nK00<00000001No`00G_l01`00G_l00`00
0000YP3o0:H0o`050:H0o`030000003o0000oooo00@0oooo00<000000?oo
o`3oool02P3oool00740oooo00@000000?ooo`3oool00000203oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo0P3o00000`00
0000YP3o0:H0o`050:H0o`0300000000G_l005ko00P005ko00<00000003o
V`00oi/04@00oi/300000:40J_l00P00000C003oV`0300000000G_l005ko
00P005ko00<000000:H0o`2V0?l01@2V0?l00`000000o`000?ooo`040?oo
o`030000003oool0oooo00X0oooo001a0?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0103oool2000000<0oooo0P3o00000`00
0000YP3o0:H0o`060:H0o`0300000000G_l005ko00P005ko0P00000C003o
V`@00000V`1Zo`03000001<00?nK0P00000:001No`030000002V0?l0YP3o
00H0YP3o00<000000?l0003oool00`3oool2000000`0oooo001a0?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`80o`0000<000000:H0o`2V0?l01P2V0?l00`00
000005ko001No`09001No`8000005@00oi/2000009P0J_l00P00000F003o
V`0300000000G_l005ko00T005ko00<000000:H0o`2V0?l01P2V0?l00`00
0000o`000?ooo`040?ooo`030000003oool0oooo00X0oooo001a0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`020?ooo`<0o`0000<000000:H0o`2V0?l01P2V0?l0
0`00000005ko001No`09001No`8000005P00oi/400000900J_l01000000F
003oV`8000002`00G_l00`000000YP3o0:H0o`060:H0o`030000003o0000
o`0000D0oooo00<000000?ooo`3oool02P3oool00780oooo0P00000:0?oo
o`8000001@3oool00`000000oooo0?ooo`020?ooo`<0o`0000<000000:H0
o`2V0?l01`2V0?l00`00000005ko001No`0:001No`0300000000oi/00?nK
01L00?nK0P00002<06[o008000006@00oi/00`00000005ko001No`0;001N
o`030000002V0?l0YP3o00H0YP3o00<000000?l0003o00001@3oool00`00
0000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`<0
o`0000<000000:H0o`2V0?l01`2V0?l00`00000005ko001No`0:001No`80
00006P00oi/3000008H0J_l00`00000J003oV`8000003000G_l00`000000
YP3o0:H0o`070:H0o`030000003o0000o`0000D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo00<000000?ooo`3oool00P3oool30?l000800000
2@2V0?l00`00000005ko001No`0;001No`8000006`00oi/300000800J_l0
0`00000K003oV`8000003@00G_l00`000000YP3o0:H0o`080:H0o`030000
003o0000o`0000D0oooo00<000000?ooo`3oool02P3oool008D0oooo0P00
00030?ooo`@0o`0000<000000:H0o`2V0?l01`2V0?l2000000h005ko00<0
0000003oV`00oi/06`00oi/3000007X0J_l00`00000M003oV`8000003@00
G_l2000000T0YP3o00@000000?l0003o0000o`00103oool2000000`0oooo
00250?ooo`030000003oool0oooo0080oooo103o00000`000000YP3o0:H0
o`080:H0o`0300000000G_l005ko00`005ko0P00000O003oV`@00000LP1Z
o`04000001l00?nK0P00000>001No`030000002V0?l0YP3o00P0YP3o00@0
00000?l0003o0000o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?ooo`@0o`0000<000000:H0o`2V0?l02@2V
0?l00`00000005ko001No`0=001No`0300000000oi/00?nK02000?nK0`00
001/06[o00<000008P00oi/00`00000005ko001No`0=001No`030000002V
0?l0YP3o00T0YP3o00@000000?l0003o0000o`001@3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`@0o`0000<0
00000:H0o`2V0?l02@2V0?l2000000l005ko0P00000S003oV`@00000I01Z
o`04000002<00?nK0P00000@001No`030000002V0?l0YP3o00T0YP3o00@0
00000?l0003o0000o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?ooo`D0o`0000<000000:H0o`2V0?l02@2V
0?l00`00000005ko001No`0>001No`8000009P00oi/4000005`0J_l01000
000V003oV`8000004000G_l00`000000YP3o0:H0o`090:H0o`030000003o
0000o`000080o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooo`D0o`0000<000000:H0o`2V0?l02P2V0?l0
0`00000005ko001No`0?001No`0300000000oi/00?nK02L00?nK1@00001B
06[o00D00000:@00oi/00`00000005ko001No`0?001No`030000002V0?l0
YP3o00X0YP3o00<000000?l0003o00000P3o00050?ooo`030000003oool0
oooo00X0oooo00250?ooo`8000000`3oool50?l000030000002V0?l0YP3o
00X0YP3o0P00000A001No`800000;000oi/5000004P0J_l01@00000/003o
V`8000004@00G_l2000000`0YP3o00<000000?l0003o00000P3o00040?oo
o`800000303oool008D0oooo00<000000?ooo`3oool00P3oool60?l00003
0000002V0?l0YP3o00X0YP3o0P00000B001No`800000;`00oi/6000003`0
J_l01P00000`003oV`0300000000G_l005ko014005ko00<000000:H0o`2V
0?l02`2V0?l00`000000o`000?l000020?l000D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo00<000000?ooo`3oool00P3oool60?l000030000
002V0?l0YP3o00/0YP3o00<00000001No`00G_l04@00G_l2000003@00?nK
2@00000Z06[o00T00000=000oi/2000001<005ko00<000000:H0o`2V0?l0
2`2V0?l00`000000o`000?l000030?l000D0oooo00<000000?ooo`3oool0
2P3oool008D0oooo00<000000?ooo`3oool00P3oool60?l000030000002V
0?l0YP3o00`0YP3o00<00000001No`00G_l04P00G_l2000003/00?nK3`00
000<06[o00l00000>`00oi/2000001@005ko0P00000=0:H0o`030000003o
0000o`0000<0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooo`L0o`0000<000000:H0o`2V0?l0302V0?l0
0`00000005ko001No`0B001No`<00000B000oi/<000004T00?nK0P00000E
001No`030000002V0?l0YP3o00/0YP3o00<000000?l0003o0000103o0005
0?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo
0080oooo1`3o00000`000000YP3o0:H0o`0<0:H0o`8000005@00G_l20000
09X00?nK0P00000F001No`030000002V0?l0YP3o00`0YP3o00<000000?l0
003o0000103o00050?ooo`030000003oool0oooo00X0oooo00250?ooo`03
0000003oool0oooo0080oooo1`3o00000`000000YP3o0:H0o`0=0:H0o`80
00005P00G_l2000009H00?nK0P00000G001No`030000002V0?l0YP3o00d0
YP3o00<000000?l0003o0000103o00050?ooo`030000003oool0oooo00X0
oooo00250?ooo`8000000`3oool80?l000030000002V0?l0YP3o00d0YP3o
00<00000001No`00G_l05@00G_l3000009<00?nK0P00000G001No`030000
002V0?l0YP3o00d0YP3o00<000000?l0003o00001@3o00040?ooo`800000
303oool008D0oooo00<000000?ooo`3oool00P3oool80?l000030000002V
0?l0YP3o00h0YP3o00<00000001No`00G_l05P00G_l2000009000?nK0P00
000H001No`8000003`2V0?l00`000000o`000?l000050?l000D0oooo00<0
00000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3oool8
0?l000030000002V0?l0YP3o00l0YP3o00<00000001No`00G_l05`00G_l2
000008`00?nK0P00000I001No`030000002V0?l0YP3o00l0YP3o00<00000
0?l0003o00001@3o00050?ooo`030000003oool0oooo00X0oooo00250?oo
o`030000003oool0oooo0080oooo2@3o00000`000000YP3o0:H0o`0>0:H0
o`8000006P00G_l2000008P00?nK0P00000J001No`800000402V0?l00`00
0000o`000?l000060?l000D0oooo00<000000?ooo`3oool02P3oool00780
oooo0P0000040?ooo`8000001@3oool3000000<0oooo00<000000?ooo`3o
ool00P3oool90?l000030000002V0?l0YP3o00l0YP3o0P00000K001No`80
0000Q000oi/2000001/005ko0P00000A0:H0o`030000003o0000o`0000H0
o`001@3oool00`000000oooo0?ooo`0:0?ooo`00L@3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool:0?l000030000002V0?l0YP3o00l0YP3o00<00000001No`00
G_l06`00G_l2000008000?nK0P00000M001No`030000002V0?l0YP3o00l0
YP3o0P0000080?l000D0oooo00<000000?ooo`3oool02P3oool00740oooo
00@000000?ooo`3oool00000203oool5000000<0oooo0P0000030?ooo`X0
o`0000<000000:H0o`2V0?l0402V0?l2000001d005ko0P00001l003oV`80
00007@00G_l200000180YP3o00<000000?l0003o00001`3o00040?ooo`80
0000303oool00740oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo2`3o00000`00
0000YP3o0:H0o`0@0:H0o`0300000000G_l005ko01d005ko0P00001h003o
V`8000007`00G_l00`000000YP3o0:H0o`0A0:H0o`030000003o0000o`00
00L0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00L@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0000000@0oooo00<000000?oo
o`3oool00P3oool;0?l000030000002V0?l0YP3o0140YP3o00<00000001N
o`00G_l07P00G_l3000007800?nK0`00000P001No`030000002V0?l0YP3o
0140YP3o00<000000?l0003o0000203o00050?ooo`030000003oool0oooo
00X0oooo001b0?ooo`8000002`3oool2000000@0oooo00<000000?ooo`3o
ool00P3oool;0?l0008000004`2V0?l20000024005ko0`00001/003oV`<0
00008@00G_l2000001<0YP3o0P00000:0?l000D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo00<000000?ooo`3oool00P3oool<0?l000030000
002V0?l0YP3o0180YP3o00<00000001No`00G_l08@00G_l3000006P00?nK
0`00000S001No`030000002V0?l0YP3o0180YP3o00<000000?l0003o0000
2@3o00050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003o
ool0oooo0080oooo303o0002000001@0YP3o0P00000T001No`<00000HP00
oi/3000002@005ko0P00000E0:H0o`030000003o0000o`0000T0o`001@3o
ool00`000000oooo0?ooo`0:0?ooo`00Q@3oool2000000<0oooo3@3o0000
0`000000YP3o0:H0o`0C0:H0o`8000009P00G_l3000005`00?nK0`00000V
001No`8000005@2V0?l00`000000o`000?l0000:0?l000@0oooo0P00000<
0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`d0o`0000<000000:H0
o`2V0?l0502V0?l2000002P005ko1000001D003oV`@00000:000G_l20000
01H0YP3o00<000000?l0003o00002P3o00050?ooo`030000003oool0oooo
00X0oooo00250?ooo`030000003oool0oooo0080oooo3P3o00000`000000
YP3o0:H0o`0D0:H0o`800000:`00G_l3000004h00?nK0`00000[001No`80
00005P2V0?l00`000000o`000?l0000;0?l000D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo00<000000?ooo`3oool00P3oool>0?l000800000
5P2V0?l2000002`005ko1@000016003oV`D00000;000G_l2000001H0YP3o
0P00000=0?l000D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<0
00000?ooo`3oool00P3oool?0?l000030000002V0?l0YP3o01D0YP3o0P00
000`001No`@00000?P00oi/40000030005ko0P00000G0:H0o`030000003o
0000o`0000`0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooo`l0o`0000<000000:H0o`2V0?l05`2V0?l0
0`00000005ko001No`0a001No`H00000<P00oi/6000003<005ko00<00000
0:H0o`2V0?l05`2V0?l00`000000o`000?l0000<0?l000D0oooo00<00000
0?ooo`3oool02P3oool008D0oooo0P0000030?oooa00o`0000<000000:H0
o`2V0?l05`2V0?l00`00000005ko001No`0e001No`L000009P00oi/70000
03L005ko00<000000:H0o`2V0?l05`2V0?l00`000000o`000?l0000=0?l0
00@0oooo0P00000<0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooa40
o`0000<000000:H0o`2V0?l05`2V0?l2000003`005ko2`00000@003oV`/0
0000?000G_l2000001T0YP3o0P00000?0?l000D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo00<000000?ooo`3oool00P3ooolA0?l000030000
002V0?l0YP3o01T0YP3o00<00000001No`00G_l0A000G_l@000004H005ko
0P00000J0:H0o`030000003o0000o`0000h0o`001@3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooa80o`0000<0
00000:H0o`2V0?l06@2V0?l00`00000005ko001No`2H001No`030000002V
0?l0YP3o01T0YP3o00<000000?l0003o00003`3o00050?ooo`030000003o
ool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo4P3o0000
0`000000YP3o0:H0o`0J0:H0o`0300000000G_l005ko09H005ko00<00000
0:H0o`2V0?l06P2V0?l00`000000o`000?l0000?0?l000D0oooo00<00000
0?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3ooolC0?l0
00030000002V0?l0YP3o01X0YP3o0`00002C001No`800000702V0?l00`00
0000o`000?l0000@0?l000D0oooo00<000000?ooo`3oool02P3oool008D0
oooo00<000000?ooo`3oool00P3ooolD0?l000030000002V0?l0YP3o01/0
YP3o0P00002@001No`8000007@2V0?l200000180o`001@3oool00`000000
oooo0?ooo`0:0?ooo`00Q@3oool2000000<0oooo503o00000`000000YP3o
0:H0o`0M0:H0o`0300000000G_l005ko08`005ko00<000000:H0o`2V0?l0
7@2V0?l00`000000o`000?l0000A0?l000@0oooo0P00000<0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?oooaD0o`0000<000000:H0o`2V0?l07@2V
0?l2000008X005ko0P00000O0:H0o`030000003o0000o`000180o`001@3o
ool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`02
0?oooaH0o`0000<000000:H0o`2V0?l07@2V0?l3000008H005ko0`00000O
0:H0o`800000503o00050?ooo`030000003oool0oooo00X0oooo00250?oo
o`030000003oool0oooo0080oooo5P3o00000`000000YP3o0:H0o`0O0:H0
o`800000Q000G_l200000240YP3o00<000000?l0003o00004`3o00050?oo
o`030000003oool0oooo00X0oooo001b0?ooo`800000103oool2000000<0
oooo0`0000050?ooo`030000003oool0oooo0080oooo5`3o00000`000000
YP3o0:H0o`0P0:H0o`800000P000G_l200000280YP3o00<000000?l0003o
0000503o00050?ooo`030000003oool0oooo00X0oooo001a0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`020?oooaP0o`0000<000000:H0o`2V0?l0802V0?l30000
07`005ko0`00000R0:H0o`030000003o0000o`0001D0o`001@3oool00`00
0000oooo0?ooo`0:0?ooo`00L@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000000@0oooo0P0000030?oooaP0o`000P00000S
0:H0o`800000NP00G_l2000002<0YP3o0P00000G0?l000@0oooo0P00000<
0?ooo`00L@3oool010000000oooo0?ooo`0000080?ooo`<000001@3oool0
0`000000oooo0?ooo`020?oooaT0o`000P00000T0:H0o`<00000M@00G_l2
000002@0YP3o0P00000H0?l000D0oooo00<000000?ooo`3oool02P3oool0
0740oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo6P3o00000`000000YP3o0:H0o`0T
0:H0o`<00000L000G_l3000002H0YP3o00<000000?l0003o00005`3o0005
0?ooo`030000003oool0oooo00X0oooo001b0?ooo`8000002P3oool30000
00@0oooo00<000000?ooo`3oool00P3ooolK0?l000030000002V0?l0YP3o
02D0YP3o0P00001^001No`8000009`2V0?l2000001T0o`001@3oool00`00
0000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooa`0
o`0000<000000:H0o`2V0?l09P2V0?l3000006P005ko0`00000Y0:H0o`03
0000003o0000o`0001P0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00
Q@3oool00`000000oooo0?ooo`020?oooa`0o`000P00000Y0:H0o`800000
IP00G_l2000002T0YP3o0P00000K0?l000D0oooo00<000000?ooo`3oool0
2P3oool008D0oooo0P0000030?oooad0o`000P00000Z0:H0o`<00000H000
G_l3000002X0YP3o0P00000L0?l000@0oooo0P00000<0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?oooah0o`0000<000000:H0o`2V0?l0:`2V0?l2
000005`005ko0P00000]0:H0o`030000003o0000o`0001/0o`001@3oool0
0`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oo
oal0o`0000<000000:H0o`2V0?l0;02V0?l4000005@005ko1000000^0:H0
o`030000003o0000o`0001`0o`001@3oool00`000000oooo0?ooo`0:0?oo
o`00Q@3oool00`000000oooo0?ooo`020?ooob00o`0000<000000:H0o`2V
0?l0;`2V0?l20000050005ko0P00000a0:H0o`030000003o0000o`0001d0
o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo
0?ooo`020?ooob00o`000P00000b0:H0o`@00000B000G_l400000380YP3o
0P00000O0?l000D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<0
00000?ooo`3oool00P3ooolQ0?l000800000=@2V0?l30000048005ko0`00
000e0:H0o`800000803o00050?ooo`030000003oool0oooo00X0oooo0025
0?ooo`8000000`3ooolS0?l000030000002V0?l0YP3o03D0YP3o1000000j
001No`D00000=P2V0?l200000240o`00103oool2000000`0oooo00250?oo
o`030000003oool0oooo0080oooo8`3o0002000003X0YP3o1@00000`001N
o`D00000>P2V0?l200000280o`001@3oool00`000000oooo0?ooo`0:0?oo
o`00Q@3oool00`000000oooo0?ooo`020?ooobD0o`0000<000000:H0o`2V
0?l0?02V0?l500000003001No`00000005ko02<005ko1@00000n0:H0o`80
00008`3o00050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000
003oool0oooo0080oooo9@3o000200000480YP3o2P00000B001No`X00000
@P2V0?l2000002@0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?ooobH0o`000P00001;0:H0oa800000B`2V
0?l2000002D0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooobP0o`0000<000000:H0o`2V0?l0Y02V0?l2
000002H0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?ooobP0o`000P00002T0:H0o`8000009`3o00050?oo
o`030000003oool0oooo00X0oooo00250?ooo`8000000`3ooolZ0?l00003
0000002V0?l0YP3o0:00YP3o00<000000?l0003o00009`3o00040?ooo`80
0000303oool008D0oooo00<000000?ooo`3oool00P3oool[0?l000800000
W`2V0?l2000002T0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?ooob`0o`000P00002L0:H0o`800000:`3o
00050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0
oooo0080oooo;@3o0002000009X0YP3o0P00000/0?l000D0oooo00<00000
0?ooo`3oool02P3oool00780oooo0P0000040?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool00P3oool^0?l000800000V02V0?l20000
02d0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00L@3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00P3oool`0?l000800000U02V0?l2000002l0o`001@3oool0
0`000000oooo0?ooo`0:0?ooo`00L@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000@0oooo0P0000030?oooc40o`000P00
002C0:H0o`030000003o0000o`0002h0o`00103oool2000000`0oooo001a
0?ooo`040000003oool0oooo000000T0oooo0P0000050?ooo`030000003o
ool0oooo0080oooo<P3o000200000900YP3o0P00000a0?l000D0oooo00<0
00000?ooo`3oool02P3oool00740oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo
=03o00000`000000YP3o0:H0o`2<0:H0o`030000003o0000o`000340o`00
1@3oool00`000000oooo0?ooo`0:0?ooo`00LP3oool2000000X0oooo0P00
00050?ooo`030000003oool0oooo0080oooo=@3o0002000008X0YP3o0P00
000d0?l000D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<00000
0?ooo`3oool00P3ooolf0?l000<00000Q`2V0?l2000003D0o`001@3oool0
0`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oo
ocP0o`000P0000240:H0o`800000=`3o00050?ooo`030000003oool0oooo
00X0oooo00250?ooo`8000000`3oooli0?l000800000PP2V0?l2000003P0
o`00103oool2000000`0oooo00250?ooo`030000003oool0oooo0080oooo
>`3o0002000007l0YP3o00<000000?l0003o0000>03o00050?ooo`030000
003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo?03o
0003000007X0YP3o0`00000k0?l000D0oooo00<000000?ooo`3oool02P3o
ool008D0oooo00<000000?ooo`3oool00P3ooolo0?l000800000MP2V0?l2
000003h0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?oood00o`000P00001d0:H0o`800000?`3o00050?oo
o`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080
oooo@P3o000200000700YP3o0P0000110?l000D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo0P0000030?oood@0o`000P00001/0:H0o`800000
@`3o00040?ooo`800000303oool008D0oooo00<000000?ooo`3oool00P3o
oom60?l000800000J02V0?l2000004D0o`001@3oool00`000000oooo0?oo
o`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooodP0o`000`00001R
0:H0o`<00000A`3o00050?ooo`030000003oool0oooo00X0oooo00250?oo
o`030000003oool0oooo0080ooooBP3o0003000005h0YP3o0`0000190?l0
00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3o
ool00P3ooom=0?l000800000FP2V0?l2000004`0o`001@3oool00`000000
oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooodl0o`00
0`00001D0:H0o`<00000CP3o00050?ooo`030000003oool0oooo00X0oooo
00250?ooo`030000003oool0oooo0080ooooD@3o000300000500YP3o0`00
001@0?l000D0oooo00<000000?ooo`3oool02P3oool008D0oooo0P000003
0?oooe@0o`00100000180:H0o`@00000D`3o00040?ooo`800000303oool0
08D0oooo00<000000?ooo`3oool00P3ooomH0?l000@00000@@2V0?l30000
05L0o`001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000
oooo0?ooo`020?oooe/0o`001000000j0:H0o`@00000FP3o00050?ooo`03
0000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo
G`3o000400000380YP3o1000001N0?l000D0oooo00<000000?ooo`3oool0
2P3oool007d0oooo1@0000030?ooo`030000003oool0oooo0080ooooH`3o
0006000002H0YP3o1P00001R0?l000D0oooo00<000000?ooo`3oool02P3o
ool007l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooofT0o`002000000F0:H0o`P00000J03o00050?ooo`030000003oool0
oooo00X0oooo001o0?ooo`030000003oool0oooo00<0oooo0P0000030?oo
og40o`005P00001`0?l000@0oooo0P00000<0?ooo`00O`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00X0oooo001o0?ooo`030000003oool0oooo00<0oooo
o`000003000000`0oooo001n0?ooo`800000o`3ooolD0?ooo`00o`3ooonD
0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  As discussed in Example 11.9, the transformation  \n\n\t\t\t",
  Cell[BoxData[
      \(w\ \  = \ \ \(u + \[ImaginaryI]\ v\ \  = \ \ \(\(\[ImaginaryI] \((1 - \
z)\)\)\/\(1 + z\)\ \  = \ \ \(\[ImaginaryI] \((1 - x - \[ImaginaryI]\ \
y)\)\)\/\(1 + x + \[ImaginaryI]\ y\)\)\)\)]],
  " \n\nis a one-to-one conformal mapping of the half-disk ",
  StyleBox["H",
    FontFamily->"Courier New"],
  " onto the first quadrant ",
  Cell[BoxData[
      RowBox[{\(Q : \ u > 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(v > 0\)}]]],
  ", and can be written as \n\n",
  StyleBox["(11-24)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[{
      \(u + \[ImaginaryI]\ v\ \  = \ \ \(\[ImaginaryI] \((1 - x - \
\[ImaginaryI]\ y)\) \((1 + x - \[ImaginaryI]\ y)\)\)\/\(\((1 + x + \
\[ImaginaryI]\ y)\) \((1 + x - \[ImaginaryI]\ y)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(2\ y + \[ImaginaryI]\
\ \((1 - x\^2 - y\^2)\)\)\/\(1 + 2\ x + x\^2 + 
              y\^2\)\)\)\(\[IndentingNewLine]\)\)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(2\ y\)\/\(\((x + \
1)\)\^2 + y\^2\)\ \  + \ \ \[ImaginaryI] \( 1 - x\^2 - y\^2\)\/\(\((x + \
1)\)\^2 + y\^2\)\)\)\)}]],
  "    "
}], "Text"],

Cell[TextData[{
  "The conformal map given by Equation ",
  StyleBox["(11-24)",
    FontColor->RGBColor[0, 0, 1]],
  " gives rise to a new problem of finding the temperature ",
  Cell[BoxData[
      RowBox[{\(T\^*\), 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  " that satisfies the boundary conditions  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{\(T\^*\), 
              RowBox[{"(", 
                RowBox[{"u", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "0"}], ")"}]}], "=", "100"}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "   ", "u"}], ">", "0"}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[";",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{\(T\^*\), 
            RowBox[{"(", 
              RowBox[{"0", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "v"}], ")"}]}], "=", "  ", "50"}],
         
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "   ", "v"}], ">", 
          RowBox[{"0", 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "\n\n If we use Example 11.2, the harmonic function ",
  Cell[BoxData[
      RowBox[{\(T\^*\), 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  " is given by  \n \n",
  StyleBox["(11-25)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(T\^*\), 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], "  ", "=", 
        "  ", \(100\  + \ \(\(50 - 100\)\/\(\[Pi]/2\)\) 
              Arg \((u + \[ImaginaryI]\ v)\)\ \  = \ \ 100\  - \ \(100\/\[Pi]\
\) Arctan \((v\/u)\)\)}]]],
  ".  \n\nSubstituting the expressions for u and v from Equation ",
  StyleBox["(11-24)",
    FontColor->RGBColor[0, 0, 1]],
  " into Equation ",
  StyleBox["(11-25)",
    FontColor->RGBColor[0, 0, 1]],
  " yields the desired solution:  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
        "  ", \(100\  - \ \(100\/\[Pi]\) 
            Arctan \((\(1 - x\^2 - y\^2\)\/\(2\ y\))\)\)}]]],
  ".\nThe isothermals  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        "constant"}]],
    AspectRatioFixed->True],
  "  are circles that pass through the points \[PlusMinus]1, as shown in \
Figure 11.19. "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.19",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/temperature/\
TemperaturesFigures/mat1119.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The temperature ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], 
        "=", \(100 - \(100\/\[Pi]\) 
            Arctan \((\(1 - x\^2 - y\^2\)\/\(2\ y\))\)\)}]]],
  " in a half-disk."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.16.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Construct the solution via a known conformal mapping. This is similar to \
Example 11.9.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[T, U, V, x, y, w, W];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, cont];\)\ \), "\n", 
    \(\(f[
          z_]\  = \(\(\ \)\(\[ImaginaryI] \((1\  - \ z)\)\)\)\/\(1\  + \ z\);\
\)\ \), "\n", 
    \(\(W\  = \ ComplexExpand[f[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(U\  = \ 
        Together[
          ComplexExpand[Re[W], 
            TargetFunctions \[Rule] {Re, Im}]];\)\ \), "\n", 
    \(\(\(V\  = \ 
          Together[
            ComplexExpand[Im[W], 
              TargetFunctions \[Rule] {Re, Im}]];\)\ ;\)\ \), "\n", 
    \(\(T[x_, y_]\  = \ 100\  - \ 100\/\[Pi]\ ArcTan[V\/U];\)\ \), "\n", 
    \(\(Print["\<w = \>", f[z], "\< = \>", 
        U\  + \ \[ImaginaryI]\ V];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u = \>", U\ ];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<v = \>", \ V];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<T[x,y] = 100 - \!\(100\/\[Pi]\) \
ArcTan[\!\(v\/u\)]\>\""];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
We can check out some of the boundary values by taking limits.\
\>", "Text"],

Cell[BoxData[{
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) T[\!\(\(-1\)\/2\),y] = \
\>\"", Limit[T[\(-1\)\/2, y], \ y \[Rule] 0]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) T[0,y] = \>\"", 
        Limit[T[0, y], \ y \[Rule] 0]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(lim\+\(y \[Rule] 0\)\) T[\!\(1\/2\),y] = \>\"", 
        Limit[T[1\/2, y], \ y \[Rule] 0]];\)\ \), "\n", 
    \(\(Print[\*"\"\< T[\!\(\@2\/2\),\!\(\@2\/2\)] = \>\"", 
        T[\@2\/2, \@2\/2]];\)\ \), "\n", 
    \(\(Print["\<       T[0,1] = \>", T[0, 1]];\)\ \), "\n", 
    \(\(Print[\*"\"\<T[\!\(\(-\@2\)\/2\),\!\(\@2\/2\)] = \>\"", 
        T[\(-\@2\)\/2, \@2\/2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the temperature."
}], "Text"],

Cell[BoxData[{
    \(\(cont\  = \ Table[50 + 10  k, {k, 0, 5}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[T[x, y], {x, \(-1\), 1}, {y, 0.01, 1}, 
        Contours\  \[Rule] \ cont, \[IndentingNewLine]PlotPoints \[Rule] 35, 
        AspectRatio \[Rule] 1\/2, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\n", 
    \(\(Print["\<The contours are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[T[x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nHence the temperature function  ",
  Cell[BoxData[
      \(T[x, y] = 
        100 - \(100\ ArcTan[\(1 - \ x\^2 - \ y\^2\)\/\(2\ y\)]\)\/\[Pi]\)]],
  "  is harmonic in the upper half-disk  ",
  Cell[BoxData[
      \(H : y > 0, \(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ",  and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["11.5.1  An Insulated Segment on the Boundary",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tWe now turn to the problem of finding the steady state temperature \
function ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " inside the simply connected domain D whose boundary consists of three \
adjacent curves ",
  Cell[BoxData[
      \(C\_1\)]],
  ", ",
  Cell[BoxData[
      \(C\_2\)]],
  ", and ",
  Cell[BoxData[
      \(C\_3\)]],
  ", where  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", \(T\_1\)}]]],
  "  along  ",
  Cell[BoxData[
      \(C\_1\)]],
  ";  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", \(T\_2\)}]]],
  "  along  ",
  Cell[BoxData[
      \(C\_2\)]],
  ",  and the region is insulated along ",
  Cell[BoxData[
      \(C\_3\)]],
  ".  Zero heat flowing across ",
  Cell[BoxData[
      \(C\_3\)]],
  " implies that  \n\t\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox[
            OverscriptBox[
              StyleBox["V",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}], 
          "\[FilledSmallCircle]", " ", 
          StyleBox[
            OverscriptBox[
              StyleBox["N",
                FontWeight->"Bold"], "\[RightVector]"],
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(-K\), "  ", 
            StyleBox[
              OverscriptBox[
                StyleBox["N",
                  FontWeight->"Bold"], "\[RightVector]"],
              FontWeight->"Bold"], 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}], 
            "\[FilledSmallCircle]", " ", "grad", " ", "T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", "  ", 
          "0"}]}]]],
  ",  \n\nwhere  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[
          OverscriptBox[
            StyleBox["N",
              FontWeight->"Bold"], "\[RightVector]"],
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " is perpendicular to ",
  Cell[BoxData[
      \(C\_3\)]],
  ". Thus the direction of heat flow must be parallel to this portion of the \
boundary.  In other words, ",
  Cell[BoxData[
      \(C\_3\)]],
  " must be part of a heat flow line  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"S", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        "constant"}]]],
  "  and the isothermals  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        "constant"}]]],
  "  intersect ",
  Cell[BoxData[
      \(C\_3\)]],
  " orthogonally."
}], "Text"],

Cell[TextData[{
  " \tWe can solve this problem by finding a conformal mapping  \n\n",
  StyleBox["(11-26)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{"w", "  ", "=", "  ", 
        RowBox[{\(f \((z)\)\), "  ", "=", "  ", 
          RowBox[{
            RowBox[{"u", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], " ", "+", " ", 
            RowBox[{"\[ImaginaryI]", " ", "v", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}]}]}]}]]],
  "\n\nfrom D onto the semi-infinite strip  ",
  Cell[BoxData[
      \(G : \ 0 < u < 1, v > 0\)]],
  "  so that the image of the curve ",
  Cell[BoxData[
      \(C\_1\)]],
  " is the ray  ",
  Cell[BoxData[
      \(u = 0, v > 0\)]],
  ";  the image of the curve ",
  Cell[BoxData[
      \(C\_2\)]],
  " is the ray given by  ",
  Cell[BoxData[
      \(u = 1, v > 0\)]],
  ";  and the thermally insulated curve ",
  Cell[BoxData[
      \(C\_3\)]],
  " is mapped onto the thermally insulated segment  ",
  Cell[BoxData[
      \(0 < u < 1\)]],
  "  of the ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " axis, as shown in Figure 11.20."
}], "Text"],

Cell[TextData[{
  "\tThe new problem in G is to find the steady state temperature function ",
  Cell[BoxData[
      RowBox[{\(T\^*\), 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  " so that along the rays, we have the boundary values  \n\n",
  StyleBox["(11-27)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{\(T\^*\), 
              RowBox[{"(", 
                RowBox[{"0", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "v"}], ")"}]}], "=", \(T\_1\)}],
           
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "   ", "v"}], ">", "0"}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[";",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{\(T\^*\), 
            RowBox[{"(", 
              RowBox[{"1", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "v"}], ")"}]}], "=", \(T\_2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "   ", "v"}], ">", 
          RowBox[{"0", 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "  "
}], "Text"],

Cell[TextData[{
  "\tThe condition that a segment of the boundary is insulated can be \
expressed mathematically by saying that the normal derivative of  ",
  Cell[BoxData[
      RowBox[{\(T\^*\), 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  " is zero. That is,  \n\n",
  StyleBox["(11-28)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{\(\[PartialD]\(T\^*\)\/\[PartialD]n\), "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(T\_v\%*\), 
            RowBox[{"(", 
              RowBox[{"u", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "  ", "=", "  ", 
          "0"}]}]]],
  "\n\nwhere ",
  StyleBox["n",
    FontFamily->"Courier New"],
  " is a coordinate measured perpendicular to the segment.  We can easily \
verify that the function  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(T\^*\), 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], " ", "=", 
        " ", \(T\_1\  + \ \((T\_2 - T\_1)\) u\)}]]],
  " \n\nsatisfies the conditions stated in Equations ",
  StyleBox["(11-27)",
    FontColor->RGBColor[0, 0, 1]],
  " and ",
  StyleBox["(11-28)",
    FontColor->RGBColor[0, 0, 1]],
  " for region G.  Therefore, using Equation ",
  StyleBox["(11-26)",
    FontColor->RGBColor[0, 0, 1]],
  ", we find that the solution in D is  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        RowBox[{\(T\_1\), " ", "+", " ", 
          RowBox[{\((T\_2 - T\_1)\), "u", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "The isothermals  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        "constant"}]]],
  "  and their images under  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  are also illustrated in Figure 11.20."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.20",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/temperature/\
TemperaturesFigures/mat1120.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Steady state temperatures with one boundary portion insulated."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 11.17.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the temperature ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " for the domain D consisting of the the upper half-plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "   where the temperature at points on the boundary satisfies  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"T", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "0"}], ")"}]}], "=", "  ", 
            "1"}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "   ", "x"}], " ", ">", " ", 
              "1"}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[";",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}], "\n"}], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"T", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "0"}], ")"}]}], "=", \(-1\)}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "   ", "x"}], "<", " ", \(-1\)}], 
            
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[";",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{\(\[PartialD]T\/\[PartialD]N\), "=", 
          RowBox[{
            RowBox[{\(T\_y\), 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "0"}], ")"}]}], "=", "0"}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "   ", "-", "1"}], "<", "x", "<", 
          RowBox[{"1", 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00Q`3oool30000
03T0oooo1000000h0?ooo`800000>P3oool4000003`0oooo0`00000E0?oo
o`00R03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo03P0
oooo00@000000?ooo`3oool00000>@3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo01@0oooo00250?ooo`D00000>P3oool00`000000
oooo0?ooo`0g0?ooo`040000003oool0oooo000003X0oooo00<000000?oo
o`3oool0>P3oool5000001D0oooo001o0?ooo`@000000P3oool010000000
oooo0?ooo`00000d0?ooo`@00000103oool00`000000oooo0?ooo`0f0?oo
o`040000003oool0oooo000003/0oooo00<000000?ooo`3oool0>@3oool0
10000000oooo0?ooo`00000F0?ooo`00QP3oool00`000000oooo0000000j
0?ooo`040000003oool0oooo000003L0oooo00@000000?ooo`3oool00000
>@3oool010000000oooo0?ooo`00000k0?ooo`030000003oool0000001H0
oooo00270?ooo`800000>`3oool2000003T0oooo0P00000k0?ooo`800000
?@3oool2000001H0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oo
oi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo003o0?oooi@0oooo001h
0?ooo`8000001@3ooooo000000<000004P3oool007L0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`00M`3oool01000
0000oooo0?ooo`0000040?ooo`800000H@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`050000003oool0
oooo0?ooo`000000H@3oool200000180oooo001g0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00P3ooomN0?mM00050000003o
l`00oo<00?oc000000001P1fo`000`0000000?lO003o7`06003o7`030000
0000ok@00?nd00L00?nd00<00000002do`00]?l01P00]?l00`00000001oo
000Oo`06000Oo`030000001f0?l0MP3o00@0MP3o00D000000?l0l`3o0?<0
o`3c0000001M0?l0G@D0oooo00<000000?ooo`3oool0403oool007L0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oooed0
oed000<000000?oc003ol`000P3ol`000`000000M_l007Ko000407Ko0003
00000000oal00?lO00H00?lO00<00000003o]000ok@01`00ok@00`000000
0;Co002do`06002do`03000000007ol001oo00H001oo00<0000007H0o`1f
0?l0101f0?l01@000000o`3c0?l0l`3o0?<0000005d0o`1M1@3oool00`00
0000oooo0?ooo`0@0?ooo`00N03oool2000000D0oooo00<000000?ooo`3o
ool00P3ooomM0?mM00030000003ol`00oo<00080oo<000<0000007Ko001f
o`00101fo`000`0000000?lO003o7`06003o7`0300000000ok@00?nd00L0
0?nd00<00000002do`00]?l01P00]?l00`00000001oo000Oo`06000Oo`03
0000001f0?l0MP3o00@0MP3o00<000000?l0l`3o0?<00P3o0?<00`000000
o`1M0?l0G@1J0?l0G@D0oooo00<000000?ooo`3oool0403oool007l0oooo
00<000000?ooo`3oool00P3ooomL0?mM00030000003ol`00oo<000<0oo<0
00<0000007Ko001fo`00101fo`000`0000000?lO003o7`06003o7`030000
0000ok@00?nd00L00?nd00<00000002do`00]?l01P00]?l00`00000001oo
000Oo`06000Oo`030000001f0?l0MP3o00@0MP3o00<000000?l0l`3o0?<0
0`3o0?<00`000000o`1M0?l0G@1I0?l0G@D0oooo00<000000?ooo`3oool0
403oool007l0oooo00<000000?ooo`3oool00P3ooomJ0?mM008000001P3o
l`000`000000M_l007Ko000407Ko000300000000oal00?lO00H00?lO00<0
0000003o]000ok@01`00ok@00`0000000;Co002do`06002do`0300000000
7ol001oo00H001oo00<0000007H0o`1f0?l01@1f0?l00`000000o`3c0?l0
l`030?l0l`800000F@3o05d50?ooo`030000003oool0oooo0100oooo001o
0?ooo`8000000`3ooomH0?mM00<000001P3ol`000`000000M_l007Ko0005
07Ko000300000000oal00?lO00H00?lO00<00000003o]000ok@01`00ok@0
0`0000000;Co002do`06002do`03000000007ol001oo00H001oo0P000006
07H0o`030000003o0?<0o`3c00@0o`3c0`00001G0?l0G@@0oooo0P00000B
0?ooo`00O`3oool00`000000oooo0?ooo`020?oooeL0oed000<000000?oc
003ol`001P3ol`000`000000M_l007Ko000607Ko000300000000oal00?lO
00H00?lO00<00000003o]000ok@01`00ok@00`0000000;Co002do`06002d
o`03000000007ol001oo00H001oo00<0000007H0o`1f0?l01@1f0?l00`00
0000o`3c0?l0l`070?l0l`030000003o05d0o`1M05@0o`1M1@3oool00`00
0000oooo0?ooo`0@0?ooo`00O`3oool00`000000oooo0?ooo`020?oooeD0
oed00P0000090?oc00030000001fo`00M_l000H0M_l000<00000003o7`00
oal01P00oal00`0000000?nd003o]007003o]00300000000]?l00;Co00H0
0;Co00<00000000Oo`007ol01`007ol00`000000MP3o07H0o`0507H0o`03
0000003o0?<0o`3c00L0o`3c0P00001D0?l0G@D0oooo00<000000?ooo`3o
ool0403oool007l0oooo00<000000?ooo`3oool00P3ooomD0?mM00030000
003ol`00oo<000T0oo<000<0000007Ko001fo`001@1fo`000`0000000?lO
003o7`07003o7`0300000000ok@00?nd00L00?nd00<00000002do`00]?l0
1`00]?l00`00000001oo000Oo`06000Oo`030000001f0?l0MP3o00D0MP3o
00<000000?l0l`3o0?<02@3o0?<00`000000o`1M0?l0G@1A0?l0G@D0oooo
00<000000?ooo`3oool0403oool007l0oooo00<000000?ooo`3oool00P3o
oomA0?mM00<000002`3ol`000`000000M_l007Ko000607Ko000300000000
oal00?lO00H00?lO00<00000003o]000ok@02000ok@00`0000000;Co002d
o`07002do`03000000007ol001oo00H001oo00<0000007H0o`1f0?l01P1f
0?l00`000000o`3c0?l0l`090?l0l`<00000D03o05d50?ooo`030000003o
ool0oooo0100oooo001o0?ooo`030000003oool0oooo0080ooooCP3oG@03
000000d0oo<000<0000007Ko001fo`001`1fo`000`0000000?lO003o7`06
003o7`0300000000ok@00?nd00P00?nd00<00000002do`00]?l01`00]?l0
0`00000001oo000Oo`06000Oo`030000001f0?l0MP3o00L0MP3o00<00000
0?l0l`3o0?<02`3o0?<3000004d0o`1M1@3oool00`000000oooo0?ooo`0@
0?ooo`00O`3oool00`000000oooo0?ooo`020?ooodd0oed000<000000?oc
003ol`003@3ol`000`000000M_l007Ko000707Ko000300000000oal00?lO
00L00?lO00<00000003o]000ok@02000ok@00`0000000;Co002do`07002d
o`03000000007ol001oo00H001oo00<0000007H0o`1f0?l01`1f0?l00`00
0000o`3c0?l0l`0>0?l0l`030000003o05d0o`1M04X0o`1M1@3oool00`00
0000oooo0?ooo`0@0?ooo`00O`3oool2000000<0ooooBP3oG@0300000100
oo<000<0000007Ko001fo`001`1fo`000`0000000?lO003o7`07003o7`03
00000000ok@00?nd00P00?nd00<00000002do`00]?l01`00]?l00`000000
01oo000Oo`07000Oo`030000001f0?l0MP3o00L0MP3o00<000000?l0l`3o
0?<03P3o0?<3000004T0o`1M103oool200000180oooo001o0?ooo`030000
003oool0oooo0080ooooB03oG@0200000180oo<000<0000007Ko001fo`00
201fo`000`0000000?lO003o7`07003o7`0300000000ok@00?nd00P00?nd
00<00000002do`00]?l01`00]?l00`00000001oo000Oo`07000Oo`030000
001f0?l0MP3o00P0MP3o00<000000?l0l`3o0?<0403o0?<2000004L0o`1M
1@3oool00`000000oooo0?ooo`0@0?ooo`00O`3oool00`000000oooo0?oo
o`020?ooodD0oed00`00000C0?oc00030000001fo`00M_l000P0M_l000<0
0000003o7`00oal02000oal00`0000000?nd003o]008003o]00300000000
]?l00;Co00L00;Co00<00000000Oo`007ol020007ol00`000000MP3o07H0
o`0807H0o`030000003o0?<0o`3c0140o`3c0`0000140?l0G@D0oooo00<0
00000?ooo`3oool0403oool007l0oooo00<000000?ooo`3oool00P3ooom1
0?mM00@000005@3ol`000`000000M_l007Ko000907Ko000300000000oal0
0?lO00P00?lO00<00000003o]000ok@02000ok@00`0000000;Co002do`07
002do`03000000007ol001oo00P001oo00<0000007H0o`1f0?l02@1f0?l0
0`000000o`3c0?l0l`0C0?l0l`@00000@03o05d50?ooo`030000003oool0
oooo0100oooo001o0?ooo`030000003oool0oooo0080oooo@03oG@020000
01P0oo<000<0000007Ko001fo`00201fo`000`0000000?lO003o7`08003o
7`0300000000ok@00?nd00T00?nd00<00000002do`00]?l01`00]?l00`00
000001oo000Oo`08000Oo`030000001f0?l0MP3o00T0MP3o00<000000?l0
l`3o0?<05P3o0?<2000003l0o`1M1@3oool00`000000oooo0?ooo`0@0?oo
o`00O`3oool00`000000oooo0?ooo`020?oooch0oed00P00000I0?oc0003
0000001fo`00M_l000T0M_l000<00000003o7`00oal02000oal00`000000
0?nd003o]009003o]00300000000]?l00;Co00P00;Co00<00000000Oo`00
7ol020007ol00`000000MP3o07H0o`0907H0o`030000003o0?<0o`3c01L0
o`3c0P00000m0?l0G@D0oooo00<000000?ooo`3oool0403oool007l0oooo
0P0000030?ooocT0oed01@00000I0?oc00800000301fo`000`0000000?lO
003o7`08003o7`0300000000ok@00?nd00T00?nd00<00000002do`00]?l0
2000]?l00`00000001oo000Oo`08000Oo`030000001f0?l0MP3o00X0MP3o
0P00000I0?l0l`D00000>03o05d40?ooo`8000004P3oool007l0oooo00<0
00000?ooo`3oool00P3ooolf0?mM00<000007@3ol`000`000000M_l007Ko
000;07Ko000300000000oal00?lO00T00?lO00<00000003o]000ok@02@00
ok@00`0000000;Co002do`08002do`03000000007ol001oo00T001oo00<0
000007H0o`1f0?l02`1f0?l00`000000o`3c0?l0l`0K0?l0l`<00000=@3o
05d50?ooo`030000003oool0oooo0100oooo001o0?ooo`030000003oool0
oooo0080oooo=03oG@02000001l0oo<000<0000007Ko001fo`00301fo`00
0`0000000?lO003o7`09003o7`0300000000ok@00?nd00T00?nd00<00000
002do`00]?l02000]?l00`00000001oo000Oo`09000Oo`030000001f0?l0
MP3o00`0MP3o00<000000?l0l`3o0?<07@3o0?<2000003<0o`1M1@3oool0
0`000000oooo0?ooo`0@0?ooo`00O`3oool00`000000oooo0?ooo`020?oo
oc80oed00P00000Q0?oc00030000001fo`00M_l000/0M_l000<00000003o
7`00oal02P00oal00`0000000?nd003o]009003o]00300000000]?l00;Co
00P00;Co00<00000000Oo`007ol02@007ol00`000000MP3o07H0o`0<07H0
o`030000003o0?<0o`3c01l0o`3c0P00000a0?l0G@D0oooo00<000000?oo
o`3oool0403oool007l0oooo00<000000?ooo`3oool00P3oool_0?mM00<0
00008P3ol`000`000000M_l007Ko000<07Ko000300000000oal00?lO00X0
0?lO00<00000003o]000ok@02@00ok@00`0000000;Co002do`09002do`03
000000007ol001oo00T001oo00<0000007H0o`1f0?l0301f0?l00`000000
o`3c0?l0l`0P0?l0l`<00000;P3o05d50?ooo`030000003oool0oooo0100
oooo001o0?ooo`030000003oool0oooo0080oooo;03oG@03000002<0oo<0
0P00000>07Ko000300000000oal00?lO00X00?lO00<00000003o]000ok@0
2P00ok@00`0000000;Co002do`09002do`03000000007ol001oo00X001oo
00<0000007H0o`1f0?l0301f0?l2000002<0o`3c0`00000[0?l0G@D0oooo
00<000000?ooo`3oool0403oool007l0oooo0P0000030?ooobT0oed00`00
000U0?oc00030000001fo`00M_l000h0M_l000<00000003o7`00oal02P00
oal00`0000000?nd003o]00:003o]00300000000]?l00;Co00T00;Co00<0
0000000Oo`007ol02P007ol00`000000MP3o07H0o`0>07H0o`030000003o
0?<0o`3c02<0o`3c0`00000X0?l0G@@0oooo0P00000B0?ooo`00O`3oool0
0`000000oooo0?ooo`020?ooobH0oed00`00000W0?oc00030000001fo`00
M_l000h0M_l000<00000003o7`00oal02`00oal00`0000000?nd003o]00:
003o]00300000000]?l00;Co00T00;Co00<00000000Oo`007ol02`007ol0
0`000000MP3o07H0o`0>07H0o`8000009P3o0?<4000002@0o`1M1@3oool0
0`000000oooo0?ooo`0@0?ooo`00O`3oool00`000000oooo0?ooo`020?oo
ob<0oed00`00000Y0?oc00030000001fo`00M_l000l0M_l000<00000003o
7`00oal02P00oal00`0000000?nd003o]00;003o]00300000000]?l00;Co
00T00;Co00<00000000Oo`007ol02`007ol00`000000MP3o07H0o`0?07H0
o`030000003o0?<0o`3c02L0o`3c0`00000R0?l0G@D0oooo00<000000?oo
o`3oool0403oool007l0oooo00<000000?ooo`3oool00P3ooolP0?mM00<0
0000:P3ol`0200000180M_l000<00000003o7`00oal02P00oal00`000000
0?nd003o]00;003o]00300000000]?l00;Co00X00;Co00<00000000Oo`00
7ol02`007ol00`000000MP3o07H0o`0?07H0o`800000:P3o0?<3000001l0
o`1M1@3oool00`000000oooo0?ooo`0@0?ooo`00M`3oool5000000<0oooo
00<000000?ooo`3oool00P3ooolM0?mM00<00000;@3ol`000`000000M_l0
07Ko000@07Ko000300000000oal00?lO00/00?lO00<00000003o]000ok@0
2`00ok@00`0000000;Co002do`0:002do`03000000007ol001oo00/001oo
00<0000007H0o`1f0?l0401f0?l00`000000o`3c0?l0l`0[0?l0l`<00000
703o05d50?ooo`030000003oool0oooo0100oooo001i0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00P3ooolK0?mM00800000;P3o
l`0200000180M_l000<00000003o7`00oal03000oal00`0000000?nd003o
]00;003o]00300000000]?l00;Co00X00;Co00<00000000Oo`007ol03000
7ol00`000000MP3o07H0o`0@07H0o`800000;P3o0?<2000001X0o`1M1@3o
ool00`000000oooo0?ooo`0@0?ooo`00N@3oool00`000000oooo0?ooo`03
0?ooo`8000000`3ooolG0?mM00@00000;`3ol`0200000180M_l00P00000>
003o7`0300000000ok@00?nd00/00?nd00<00000002do`00]?l02P00]?l2
000000d001oo0P00000B07H0o`800000;`3o0?<4000001H0o`1M103oool2
00000180oooo001i0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3ooolF0?mM00030000003ol`00oo<00300oo<000<0000007Ko
001fo`004P1fo`000`0000000?lO003o7`0<003o7`0300000000ok@00?nd
00`00?nd00<00000002do`00]?l02`00]?l00`00000001oo000Oo`0<000O
o`030000001f0?l0MP3o0180MP3o0P00000a0?l0l`030000003o05d0o`1M
01<0o`1M1@3oool00`000000oooo0?ooo`0@0?ooo`00N@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo4@3oG@0500000380
oo<000<0000007Ko001fo`004`1fo`000`0000000?lO003o7`0<003o7`03
00000000ok@00?nd00`00?nd00<00000002do`00]?l02`00]?l00`000000
01oo000Oo`0<000Oo`030000001f0?l0MP3o01<0MP3o00<000000?l0l`3o
0?<0<03o0?<500000100o`1M1@3oool00`000000oooo0?ooo`0@0?ooo`00
N03oool2000000D0oooo00<000000?ooo`3oool00P3oool>0?mM00<00000
=P3ol`000`000000M_l007Ko000C07Ko000300000000oal00?lO00d00?lO
00<00000003o]000ok@03000ok@00`0000000;Co002do`0;002do`030000
00007ol001oo00d001oo00<0000007H0o`1f0?l04`1f0?l00`000000o`3c
0?l0l`0d0?l0l`<000003@3o05d50?ooo`030000003oool0oooo0100oooo
001o0?ooo`030000003oool0oooo0080oooo303oG@02000003L0oo<00P00
000E07Ko008000003`00oal00`0000000?nd003o]00<003o]00300000000
]?l00;Co00/00;Co00<00000000Oo`007ol03P007ol00`000000MP3o07H0
o`0C07H0o`800000=`3o0?<2000000/0o`1M1@3oool00`000000oooo0?oo
o`0@0?ooo`00O`3oool00`000000oooo0?ooo`020?ooo`P0oed01000000h
0?oc00030000001fo`00M_l001D0M_l000<00000003o7`00oal03@00oal0
0`0000000?nd003o]00=003o]00300000000]?l00;Co00`00;Co00<00000
000Oo`007ol03P007ol00`000000MP3o07H0o`0D07H0o`030000003o0?<0
o`3c03H0o`3c100000070?l0G@D0oooo00<000000?ooo`3oool0403oool0
07l0oooo0P0000030?ooo`L0oed000<000000?oc003ol`00>@3ol`000`00
0000M_l007Ko000E07Ko000300000000oal00?lO00h00?lO00<00000003o
]000ok@03@00ok@00`0000000;Co002do`0<002do`03000000007ol001oo
00h001oo00<0000007H0o`1f0?l05@1f0?l00`000000o`3c0?l0l`0i0?l0
l`030000003o05d0o`1M00@0o`1M103oool200000180oooo001o0?ooo`03
0000003oool0oooo0080oooo0P3oG@05000003/0oo<000<0000007Ko001f
o`005P1fo`000`0000000?lO003o7`0>003o7`0300000000ok@00?nd00d0
0?nd00<00000002do`00]?l03000]?l00`00000001oo000Oo`0>000Oo`03
0000001f0?l0MP3o01H0MP3o00<000000?l0l`3o0?<0>@3o0?<500000003
0?l0G@3oool0oooo00<0oooo00<000000?ooo`3oool0403oool007l0oooo
00<000000?ooo`3oool00P3oool2000003l0oo<000<0000007Ko001fo`00
5P1fo`000`0000000?lO003o7`0?003o7`0300000000ok@00?nd00d00?nd
00<00000002do`00]?l03000]?l00`00000001oo000Oo`0?000Oo`030000
001f0?l0MP3o01H0MP3o00<000000?l0l`3o0?<0?@3o0?<2000000@0oooo
00<000000?ooo`3oool0403oool007l0oooo00<000000?ooo`3oool00P3o
oolo0?oc00800000601fo`000`0000000?lO003o7`0?003o7`0300000000
ok@00?nd00h00?nd00<00000002do`00]?l03@00]?l00`00000001oo000O
o`0?000Oo`030000001f0?l0MP3o01H0MP3o0P00000n0?l0l`D0oooo00<0
00000?ooo`3oool0403oool007l0oooo00<000000?ooo`3oool00P3ooolm
0?oc008000006@1fo`000`0000000?lO003o7`0@003o7`0300000000ok@0
0?nd00h00?nd00<00000002do`00]?l03@00]?l00`00000001oo000Oo`0@
000Oo`030000001f0?l0MP3o01L0MP3o0P00000l0?l0l`D0oooo00<00000
0?ooo`3oool0403oool007l0oooo00<000000?ooo`3oool00P3oooll0?oc
00030000001fo`00M_l001T0M_l000<00000003o7`00oal04000oal00`00
00000?nd003o]00>003o]00300000000]?l00;Co00d00;Co00<00000000O
o`007ol040007ol00`000000MP3o07H0o`0H07H0o`030000003o0?<0o`3c
03X0o`3c1@3oool00`000000oooo0?ooo`0@0?ooo`00O`3oool00`000000
oooo0?ooo`020?oooc`0oo<000<0000007Ko001fo`00601fo`0200000180
0?lO00<00000003o]000ok@03P00ok@00`0000000;Co002do`0=002do`03
000000007ol001oo010001oo0P00000J07H0o`030000003o0?<0o`3c03T0
o`3c1@3oool00`000000oooo0?ooo`0@0?ooo`00O`3oool2000000<0oooo
>P3ol`02000001/0M_l000<00000003o7`00oal04000oal00`0000000?nd
003o]00?003o]00300000000]?l00;Co00h00;Co00<00000000Oo`007ol0
40007ol00`000000MP3o07H0o`0I07H0o`800000>@3o0?<40?ooo`800000
4P3oool007l0oooo00<000000?ooo`3oool00P3oooli0?oc00030000001f
o`00M_l001X0M_l000<00000003o7`00oal04@00oal00`0000000?nd003o
]00?003o]00300000000]?l00;Co00h00;Co00<00000000Oo`007ol04@00
7ol00`000000MP3o07H0o`0J07H0o`030000003o0?<0o`3c03H0o`3c1@3o
ool00`000000oooo0?ooo`0@0?ooo`00O`3oool00`000000oooo0?ooo`02
0?ooocL0oo<00P00000L07Ko000300000000oal00?lO01800?lO00<00000
003o]000ok@03`00ok@00`0000000;Co002do`0>002do`03000000007ol0
01oo018001oo00<0000007H0o`1f0?l06P1f0?l2000003H0o`3c1@3oool0
0`000000oooo0?ooo`0@0?ooo`00O`3oool00`000000oooo0?ooo`020?oo
ocL0oo<000<0000007Ko001fo`006`1fo`000`0000000?lO003o7`0A003o
7`0300000000ok@00?nd01000?nd00<00000002do`00]?l03P00]?l00`00
000001oo000Oo`0B000Oo`030000001f0?l0MP3o01/0MP3o00<000000?l0
l`3o0?<0=03o0?<50?ooo`030000003oool0oooo0100oooo001o0?ooo`03
0000003oool0oooo0080oooo=P3ol`000`000000M_l007Ko000L07Ko0003
00000000oal00?lO01400?lO00<00000003o]000ok@04000ok@00`000000
0;Co002do`0?002do`03000000007ol001oo018001oo00<0000007H0o`1f
0?l06`1f0?l2000003@0o`3c1@3oool00`000000oooo0?ooo`0@0?ooo`00
O`3oool00`000000oooo0?ooo`020?oooc@0oo<00P00000N07Ko00030000
0000oal00?lO01800?lO00<00000003o]000ok@04000ok@00`0000000;Co
002do`0?002do`03000000007ol001oo018001oo00<0000007H0o`1f0?l0
7@1f0?l00`000000o`3c0?l0l`0a0?l0l`D0oooo00<000000?ooo`3oool0
403oool007l0oooo0P0000030?oooc80oo<00P00000O07Ko000300000000
oal00?lO01<00?lO00<00000003o]000ok@04000ok@00`0000000;Co002d
o`0?002do`03000000007ol001oo01<001oo00<0000007H0o`1f0?l07@1f
0?l200000340o`3c103oool200000180oooo001o0?ooo`030000003oool0
oooo0080oooo<@3ol`02000001l0M_l000<00000003o7`00oal04`00oal0
0`0000000?nd003o]00A003o]00300000000]?l00;Co01000;Co00<00000
000Oo`007ol04`007ol00`000000MP3o07H0o`0M07H0o`800000<03o0?<5
0?ooo`030000003oool0oooo0100oooo001o0?ooo`030000003oool0oooo
0080oooo<03ol`000`000000M_l007Ko000N07Ko000300000000oal00?lO
01@00?lO00<00000003o]000ok@04@00ok@00`0000000;Co002do`0@002d
o`03000000007ol001oo01<001oo00<0000007H0o`1f0?l07`1f0?l00`00
0000o`3c0?l0l`0]0?l0l`D0oooo00<000000?ooo`3oool0403oool007l0
oooo00<000000?ooo`3oool00P3oool_0?oc00030000001fo`00M_l001l0
M_l000<00000003o7`00oal05000oal00`0000000?nd003o]00A003o]003
00000000]?l00;Co01000;Co00<00000000Oo`007ol050007ol00`000000
MP3o07H0o`0O07H0o`030000003o0?<0o`3c02`0o`3c1@3oool00`000000
oooo0?ooo`0@0?ooo`00O`3oool00`000000oooo0?ooo`020?ooobd0oo<0
0P00000Q07Ko000300000000oal00?lO01D00?lO00<00000003o]000ok@0
4@00ok@00`0000000;Co002do`0@002do`03000000007ol001oo01D001oo
00<0000007H0o`1f0?l07`1f0?l2000002`0o`3c1@3oool00`000000oooo
0?ooo`0@0?ooo`00O`3oool00`000000oooo0?ooo`020?ooob`0oo<000<0
000007Ko001fo`008@1fo`000`0000000?lO003o7`0D003o7`0300000000
ok@00?nd01800?nd00<00000002do`00]?l04@00]?l00`00000001oo000O
o`0D000Oo`030000001f0?l0MP3o0240MP3o00<000000?l0l`3o0?<0:@3o
0?<50?ooo`030000003oool0oooo0100oooo001o0?ooo`8000000`3ooolZ
0?oc008000008`1fo`000`0000000?lO003o7`0E003o7`0300000000ok@0
0?nd01800?nd00<00000002do`00]?l04@00]?l00`00000001oo000Oo`0E
000Oo`030000001f0?l0MP3o0240MP3o0P00000Y0?l0l`@0oooo0P00000B
0?ooo`00O`3oool00`000000oooo0?ooo`020?ooobT0oo<000<0000007Ko
001fo`008P1fo`000`0000000?lO003o7`0F003o7`0300000000ok@00?nd
01800?nd00<00000002do`00]?l04@00]?l00`00000001oo000Oo`0E000O
o`030000001f0?l0MP3o02<0MP3o00<000000?l0l`3o0?<09P3o0?<50?oo
o`030000003oool0oooo0100oooo001o0?ooo`030000003oool0oooo0080
oooo:03ol`02000002@0M_l000<00000003o7`00oal05P00oal00`000000
0?nd003o]00B003o]00300000000]?l00;Co01800;Co00<00000000Oo`00
7ol05@007ol00`000000MP3o07H0o`0S07H0o`030000003o0?<0o`3c02D0
o`3c1@3oool00`000000oooo0?ooo`0@0?ooo`00O`3oool00`000000oooo
0?ooo`020?ooobL0oo<000<0000007Ko001fo`008`1fo`000`0000000?lO
003o7`0F003o7`0300000000ok@00?nd01<00?nd00<00000002do`00]?l0
4P00]?l00`00000001oo000Oo`0F000Oo`030000001f0?l0MP3o02<0MP3o
00<000000?l0l`3o0?<0903o0?<50?ooo`030000003oool0oooo0100oooo
001g0?ooo`@00000103oool00`000000oooo0?ooo`020?ooobD0oo<00P00
000U07Ko000300000000oal00?lO01L00?lO00<00000003o]000ok@04`00
ok@00`0000000;Co002do`0B002do`03000000007ol001oo01L001oo00<0
000007H0o`1f0?l08`1f0?l2000002@0o`3c1@3oool00`000000oooo0?oo
o`0@0?ooo`00M`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo903ol`000`000000M_l007Ko000T07Ko000300000000oal0
0?lO01L00?lO00<00000003o]000ok@05000ok@00`0000000;Co002do`0C
002do`03000000007ol001oo01L001oo00<0000007H0o`1f0?l0901f0?l2
00000280o`3c1@3oool00`000000oooo0?ooo`0@0?ooo`00N03oool00`00
0000oooo0?ooo`040?ooo`8000000`3ooolS0?oc00030000001fo`00M_l0
02D0M_l000<00000003o7`00oal05`00oal00`0000000?nd003o]00D003o
]00300000000]?l00;Co01<00;Co00<00000000Oo`007ol05`007ol00`00
0000MP3o07H0o`0U07H0o`030000003o0?<0o`3c0200o`3c103oool20000
0180oooo001i0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3ooolR0?oc00030000001fo`00M_l002H0M_l000<00000003o7`00
oal05`00oal00`0000000?nd003o]00D003o]00300000000]?l00;Co01<0
0;Co00<00000000Oo`007ol05`007ol00`000000MP3o07H0o`0V07H0o`03
0000003o0?<0o`3c01l0o`3c1@3oool00`000000oooo0?ooo`0@0?ooo`00
M`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo803ol`02000002P0M_l000<00000003o7`00oal06000oal00`000000
0?nd003o]00D003o]00300000000]?l00;Co01<00;Co00<00000000Oo`00
7ol060007ol00`000000MP3o07H0o`0V07H0o`8000007`3o0?<50?ooo`03
0000003oool0oooo0100oooo001h0?ooo`8000001@3oool00`000000oooo
0?ooo`020?oooal0oo<000<0000007Ko001fo`009`1fo`000`0000000?lO
003o7`0H003o7`0300000000ok@00?nd01D00?nd00<00000002do`00]?l0
5000]?l00`00000001oo000Oo`0H000Oo`030000001f0?l0MP3o02L0MP3o
00<000000?l0l`3o0?<0703o0?<50?ooo`030000003oool0oooo0100oooo
001o0?ooo`030000003oool0oooo0080oooo7@3ol`02000002T0M_l000<0
0000003o7`00oal06@00oal00`0000000?nd003o]00E003o]00300000000
]?l00;Co01@00;Co00<00000000Oo`007ol06@007ol00`000000MP3o07H0
o`0W07H0o`800000703o0?<50?ooo`030000003oool0oooo0100oooo001o
0?ooo`030000003oool0oooo0080oooo703ol`000`000000M_l007Ko000X
07Ko000300000000oal00?lO01X00?lO00<00000003o]000ok@05@00ok@0
0`0000000;Co002do`0D002do`03000000007ol001oo01T001oo00<00000
07H0o`1f0?l0:@1f0?l00`000000o`3c0?l0l`0I0?l0l`D0oooo00<00000
0?ooo`3oool0403oool007l0oooo0P0000030?oooa/0oo<000<0000007Ko
001fo`00:@1fo`000`0000000?lO003o7`0J003o7`0300000000ok@00?nd
01D00?nd00<00000002do`00]?l05000]?l00`00000001oo000Oo`0J000O
o`030000001f0?l0MP3o02T0MP3o00<000000?l0l`3o0?<0603o0?<40?oo
o`8000004P3oool007l0oooo00<000000?ooo`3oool00P3ooolJ0?oc0003
0000001fo`00M_l002T0M_l000<00000003o7`00oal06P00oal00`000000
0?nd003o]00F003o]00300000000]?l00;Co01D00;Co00<00000000Oo`00
7ol06P007ol00`000000MP3o07H0o`0Y07H0o`030000003o0?<0o`3c01L0
o`3c1@3oool00`000000oooo0?ooo`0@0?ooo`00O`3oool00`000000oooo
0?ooo`020?oooaP0oo<00P00000/07Ko000300000000oal00?lO01X00?lO
00<00000003o]000ok@05P00ok@00`0000000;Co002do`0E002do`030000
00007ol001oo01X001oo0P00000[07H0o`8000005`3o0?<50?ooo`030000
003oool0oooo0100oooo001o0?ooo`030000003oool0oooo0080oooo5P3o
l`02000002d0M_l000<00000003o7`00oal06P00oal00`0000000?nd003o
]00G003o]00300000000]?l00;Co01H00;Co00<00000000Oo`007ol06P00
7ol00`000000MP3o07H0o`0[07H0o`8000005@3o0?<50?ooo`030000003o
ool0oooo0100oooo001o0?ooo`030000003oool0oooo0080oooo5P3ol`00
0`000000M_l007Ko000[07Ko000300000000oal00?lO01/00?lO00<00000
003o]000ok@05`00ok@00`0000000;Co002do`0F002do`03000000007ol0
01oo01X001oo00<0000007H0o`1f0?l0;01f0?l00`000000o`3c0?l0l`0C
0?l0l`D0oooo00<000000?ooo`3oool0403oool007l0oooo00<000000?oo
o`3oool00P3ooolD0?oc00800000;@1fo`02000001d00?lO00<00000003o
]000ok@05`00ok@00`0000000;Co002do`0F002do`03000000007ol001oo
01/001oo0P00000]07H0o`8000004`3o0?<50?ooo`030000003oool0oooo
0100oooo001o0?ooo`8000000`3ooolC0?oc00030000001fo`00M_l002d0
M_l000<00000003o7`00oal07000oal00`0000000?nd003o]00G003o]003
00000000]?l00;Co01H00;Co00<00000000Oo`007ol070007ol00`000000
MP3o07H0o`0]07H0o`030000003o0?<0o`3c0100o`3c103oool200000180
oooo001o0?ooo`030000003oool0oooo0080oooo4@3ol`02000002l0M_l0
00<00000003o7`00oal07000oal00`0000000?nd003o]00H003o]0030000
0000]?l00;Co01L00;Co00<00000000Oo`007ol070007ol00`000000MP3o
07H0o`0]07H0o`800000403o0?<50?ooo`030000003oool0oooo0100oooo
001o0?ooo`030000003oool0oooo0080oooo403ol`000`000000M_l007Ko
000^07Ko000300000000oal00?lO01d00?lO00<00000003o]000ok@06000
ok@00`0000000;Co002do`0G002do`03000000007ol001oo01d001oo00<0
000007H0o`1f0?l0;P1f0?l00`000000o`3c0?l0l`0=0?l0l`D0oooo00<0
00000?ooo`3oool0403oool007l0oooo00<000000?ooo`3oool00P3oool?
0?oc00030000001fo`00M_l002l0M_l000<00000003o7`00oal07@00oal0
0`0000000?nd003o]00H003o]00300000000]?l00;Co01L00;Co00<00000
000Oo`007ol07@007ol00`000000MP3o07H0o`0_07H0o`030000003o0?<0
o`3c00`0o`3c1@3oool00`000000oooo0?ooo`0@0?ooo`00O`3oool00`00
0000oooo0?ooo`020?ooo`h0oo<000<0000007Ko001fo`00;`1fo`000`00
00000?lO003o7`0N003o7`0300000000ok@00?nd01P00?nd00<00000002d
o`00]?l05`00]?l00`00000001oo000Oo`0N000Oo`030000001f0?l0MP3o
02l0MP3o00<000000?l0l`3o0?<02`3o0?<50?ooo`030000003oool0oooo
0100oooo001o0?ooo`030000003oool0oooo0080oooo303ol`0200000340
M_l000<00000003o7`00oal07P00oal00`0000000?nd003o]00I003o]003
00000000]?l00;Co01P00;Co00<00000000Oo`007ol07P007ol00`000000
MP3o07H0o`0_07H0o`8000002`3o0?<50?ooo`030000003oool0oooo0100
oooo001o0?ooo`030000003oool0oooo0080oooo2`3ol`000`000000M_l0
07Ko000a07Ko000300000000oal00?lO01h00?lO00<00000003o]000ok@0
6@00ok@00`0000000;Co002do`0H002do`03000000007ol001oo01h001oo
00<0000007H0o`1f0?l0<@1f0?l2000000T0o`3c1@3oool00`000000oooo
0?ooo`0@0?ooo`00O`3oool2000000<0oooo2@3ol`02000003<0M_l000<0
0000003o7`00oal07P00oal00`0000000?nd003o]00J003o]00300000000
]?l00;Co01T00;Co00<00000000Oo`007ol07P007ol00`000000MP3o07H0
o`0a07H0o`800000203o0?<40?ooo`8000004P3oool007l0oooo00<00000
0?ooo`3oool00P3oool70?oc00800000=01fo`000`0000000?lO003o7`0O
003o7`0300000000ok@00?nd01X00?nd00<00000002do`00]?l06@00]?l0
0`00000001oo000Oo`0N000Oo`030000001f0?l0MP3o03<0MP3o00<00000
0?l0l`3o0?<01@3o0?<50?ooo`030000003oool0oooo0100oooo001o0?oo
o`030000003oool0oooo0080oooo1`3ol`000`000000M_l007Ko000c07Ko
000300000000oal00?lO01l00?lO00<00000003o]000ok@06P00ok@00`00
00000;Co002do`0I002do`03000000007ol001oo01l001oo00<0000007H0
o`1f0?l0<`1f0?l00`000000o`3c0?l0l`040?l0l`D0oooo00<000000?oo
o`3oool0403oool007l0oooo00<000000?ooo`3oool00P3oool60?oc0003
0000001fo`00M_l003<0M_l000<00000003o7`00oal08000oal00`000000
0?nd003o]00J003o]00300000000]?l00;Co01T00;Co00<00000000Oo`00
7ol080007ol00`000000MP3o07H0o`0c07H0o`800000103o0?<50?ooo`03
0000003oool0oooo0100oooo001o0?ooo`030000003oool0oooo0080oooo
103ol`02000003D0M_l000<00000003o7`00oal08000oal00`0000000?nd
003o]00K003o]00300000000]?l00;Co01X00;Co00<00000000Oo`007ol0
80007ol00`000000MP3o07H0o`0c07H0o`8000000`3o0?<50?ooo`030000
003oool0oooo0100oooo001o0?ooo`030000003oool0oooo0080oooo0P3o
l`02000003H0M_l000<00000003o7`00oal08@00oal00`0000000?nd003o
]00K003o]00300000000]?l00;Co01X00;Co00<00000000Oo`007ol08@00
7ol00`000000MP3o07H0o`0d07H0o`80000000<0o`3c0?ooo`3oool00`3o
ool00`000000oooo0?ooo`0@0?ooo`00O`3oool2000000<0oooo00<0oo<0
0000001fo`00=P1fo`000`0000000?lO003o7`0R003o7`0300000000ok@0
0?nd01/00?nd00<00000002do`00]?l06P00]?l00`00000001oo000Oo`0Q
000Oo`030000001f0?l0MP3o03H0MP3o00<000000?ooo`3oool00P3oool2
00000180oooo001o0?ooo`030000003oool0oooo0080oooo00<0000007Ko
001fo`00=P1fo`000`0000000?lO003o7`0R003o7`0300000000ok@00?nd
01/00?nd00<00000002do`00]?l06`00]?l00`00000001oo000Oo`0Q000O
o`030000001f0?l0MP3o03H0MP3o00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`00O`3oool00`000000oooo0?ooo`020?ooocT0
M_l000<00000003o7`00oal08@00oal00`0000000?nd003o]00L003o]003
00000000]?l00;Co01/00;Co00<00000000Oo`007ol08P007ol00`000000
MP3o07H0o`0e07H0o`D0oooo00<000000?ooo`3oool0403oool007l0oooo
00<000000?ooo`3oool00P3ooolh07Ko000300000000oal00?lO02800?lO
00<00000003o]000ok@07000ok@00`0000000;Co002do`0K002do`030000
00007ol001oo028001oo00<0000007H0o`1f0?l0=@1f0?l50?ooo`030000
003oool0oooo0100oooo001h0?ooo`8000001@3oool00`000000oooo0?oo
o`020?ooocL0M_l000<00000003o7`00oal08P00oal00`0000000?nd003o
]00M003o]00300000000]?l00;Co01`00;Co00<00000000Oo`007ol08P00
7ol2000003D0MP3o1@3oool00`000000oooo0?ooo`0@0?ooo`00M`3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo=P1f
o`000`0000000?lO003o7`0S003o7`0300000000ok@00?nd01d00?nd00<0
0000002do`00]?l07000]?l00`00000001oo000Oo`0R000Oo`030000001f
0?l0MP3o03@0MP3o1@3oool00`000000oooo0?ooo`0@0?ooo`00N@3oool0
0`000000oooo0?ooo`030?ooo`8000000`3ooolf07Ko000300000000oal0
0?lO02<00?lO00<00000003o]000ok@07@00ok@00`0000000;Co002do`0L
002do`03000000007ol001oo02<001oo00<0000007H0o`1f0?l0<`1f0?l4
0?ooo`8000004P3oool007X0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooocD0M_l000<00000003o7`00oal09000oal00`00
00000?nd003o]00M003o]00300000000]?l00;Co01`00;Co00<00000000O
o`007ol090007ol00`000000MP3o07H0o`0b07H0o`D0oooo00<000000?oo
o`3oool0403oool007L0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`020?oooc@0M_l000<00000003o7`00oal09000oal00`00
00000?nd003o]00N003o]00300000000]?l00;Co01d00;Co00<00000000O
o`007ol090007ol00`000000MP3o07H0o`0a07H0o`D0oooo00<000000?oo
o`3oool0403oool007P0oooo0P0000050?ooo`030000003oool0oooo0080
oooo<`1fo`000`0000000?lO003o7`0U003o7`0300000000ok@00?nd01h0
0?nd00<00000002do`00]?l07@00]?l00`00000001oo000Oo`0U000Oo`03
0000001f0?l0MP3o0300MP3o1@3oool00`000000oooo0?ooo`0@0?ooo`00
O`3oool00`000000oooo0?ooo`020?oooc80M_l000<00000003o7`00oal0
9@00oal00`0000000?nd003o]00O003o]00300000000]?l00;Co01d00;Co
00<00000000Oo`007ol09@007ol00`000000MP3o07H0o`0`07H0o`D0oooo
00<000000?ooo`3oool0403oool007l0oooo00<000000?ooo`3oool00P3o
oolb07Ko000300000000oal00?lO02D00?lO00<00000003o]000ok@07`00
ok@00`0000000;Co002do`0N002do`03000000007ol001oo02D001oo00<0
000007H0o`1f0?l0;`1f0?l50?ooo`030000003oool0oooo0100oooo001o
0?ooo`8000000`3ooolb07Ko000300000000oal00?lO02D00?lO00<00000
003o]000ok@07`00ok@00`0000000;Co002do`0N002do`03000000007ol0
01oo02D001oo0P00000`07H0o`@0oooo0P00000B0?ooo`00O`3oool00`00
0000oooo0?ooo`020?oooc40M_l000<00000003o7`00oal09P00oal00`00
00000?nd003o]00O003o]00300000000]?l00;Co01h00;Co00<00000000O
o`007ol09P007ol00`000000MP3o07H0o`0^07H0o`D0oooo00<000000?oo
o`3oool0403oool007l0oooo00<000000?ooo`3oool00P3oool`07Ko0003
00000000oal00?lO02H00?lO00<00000003o]000ok@08000ok@00`000000
0;Co002do`0O002do`03000000007ol001oo02H001oo00<0000007H0o`1f
0?l0;@1f0?l50?ooo`030000003oool0oooo0100oooo001o0?ooo`030000
003oool0oooo0080oooo;`1fo`000`0000000?lO003o7`0W003o7`030000
0000ok@00?nd02000?nd00<00000002do`00]?l07`00]?l00`00000001oo
000Oo`0W000Oo`030000001f0?l0MP3o02`0MP3o1@3oool00`000000oooo
0?ooo`0@0?ooo`00O`3oool00`000000oooo0?ooo`020?ooobl0M_l000<0
0000003o7`00oal09`00oal00`0000000?nd003o]00P003o]00300000000
]?l00;Co01l00;Co00<00000000Oo`007ol09`007ol00`000000MP3o07H0
o`0/07H0o`D0oooo00<000000?ooo`3oool0403oool007l0oooo00<00000
0?ooo`3oool00P3oool^07Ko000300000000oal00?lO02L00?lO00<00000
003o]000ok@08@00ok@00`0000000;Co002do`0P002do`03000000007ol0
01oo02L001oo00<0000007H0o`1f0?l0:`1f0?l50?ooo`030000003oool0
oooo0100oooo001o0?ooo`8000000`3oool]07Ko000300000000oal00?lO
02P00?lO00<00000003o]000ok@08@00ok@00`0000000;Co002do`0P002d
o`03000000007ol001oo02P001oo00<0000007H0o`1f0?l0:P1f0?l40?oo
o`8000004P3oool007l0oooo00<000000?ooo`3oool00P3oool/07Ko0080
0000:P00oal00`0000000?nd003o]00Q003o]00300000000]?l00;Co0200
0;Co00<00000000Oo`007ol0:0007ol2000002/0MP3o1@3oool00`000000
oooo0?ooo`0@0?ooo`00O`3oool00`000000oooo0?ooo`020?ooob/0M_l0
00<00000003o7`00oal0:@00oal00`0000000?nd003o]00R003o]0030000
0000]?l00;Co02000;Co00<00000000Oo`007ol0:@007ol00`000000MP3o
07H0o`0Y07H0o`D0oooo00<000000?ooo`3oool0403oool007l0oooo00<0
00000?ooo`3oool00P3oool[07Ko000300000000oal00?lO02T00?lO00<0
0000003o]000ok@08P00ok@00`0000000;Co002do`0Q002do`0300000000
7ol001oo02T001oo00<0000007H0o`1f0?l0:01f0?l50?ooo`030000003o
ool0oooo0100oooo001o0?ooo`030000003oool0oooo0080oooo:P1fo`00
0`0000000?lO003o7`0Z003o7`0300000000ok@00?nd02800?nd00<00000
002do`00]?l08@00]?l00`00000001oo000Oo`0Z000Oo`030000001f0?l0
MP3o02L0MP3o1@3oool00`000000oooo0?ooo`0@0?ooo`00O`3oool00`00
0000oooo0?ooo`020?ooobX0M_l000<00000003o7`00oal0:P00oal00`00
00000?nd003o]00R003o]00300000000]?l00;Co02800;Co00<00000000O
o`007ol0:P007ol00`000000MP3o07H0o`0V07H0o`D0oooo00<000000?oo
o`3oool0403oool007l0oooo00<000000?ooo`3oool00P3ooolY07Ko0003
00000000oal00?lO02X00?lO00<00000003o]000ok@08`00ok@00`000000
0;Co002do`0R002do`03000000007ol001oo02X001oo00<0000007H0o`1f
0?l09P1f0?l50?ooo`030000003oool0oooo0100oooo001o0?ooo`800000
0`3ooolX07Ko000300000000oal00?lO02/00?lO00<00000003o]000ok@0
8`00ok@00`0000000;Co002do`0R002do`03000000007ol001oo02X001oo
00<0000007H0o`1f0?l09P1f0?l40?ooo`8000004P3oool007l0oooo00<0
00000?ooo`3oool00P3ooolX07Ko000300000000oal00?lO02/00?lO00<0
0000003o]000ok@08`00ok@00`0000000;Co002do`0R002do`0300000000
7ol001oo02/001oo00<0000007H0o`1f0?l09@1f0?l50?ooo`030000003o
ool0oooo0100oooo001o0?ooo`030000003oool0oooo0080oooo9`1fo`00
0`0000000?lO003o7`0[003o7`0300000000ok@00?nd02@00?nd00<00000
002do`00]?l08`00]?l00`00000001oo000Oo`0[000Oo`030000001f0?l0
MP3o02@0MP3o1@3oool00`000000oooo0?ooo`0@0?ooo`00O`3oool00`00
0000oooo0?ooo`020?ooobH0M_l000<00000003o7`00oal0;000oal00`00
00000?nd003o]00T003o]00300000000]?l00;Co02<00;Co00<00000000O
o`007ol0;0007ol00`000000MP3o07H0o`0S07H0o`D0oooo00<000000?oo
o`3oool0403oool007l0oooo00<000000?ooo`3oool00P3ooolU07Ko0003
00000000oal00?lO02d00?lO00<00000003o]000ok@09000ok@00`000000
0;Co002do`0S002do`800000;P007ol00`000000MP3o07H0o`0R07H0o`D0
oooo00<000000?ooo`3oool0403oool007l0oooo00<000000?ooo`3oool0
0P3ooolT07Ko000300000000oal00?lO02d00?lO00<00000003o]000ok@0
9@00ok@00`0000000;Co002do`0T002do`03000000007ol001oo02`001oo
00<0000007H0o`1f0?l08P1f0?l50?ooo`030000003oool0oooo0100oooo
001o0?ooo`8000000`3ooolT07Ko000300000000oal00?lO02d00?lO00<0
0000003o]000ok@09@00ok@00`0000000;Co002do`0T002do`0300000000
7ol001oo02d001oo00<0000007H0o`1f0?l08@1f0?l40?ooo`8000004P3o
ool007l0oooo00<000000?ooo`3oool00P3ooolS07Ko000300000000oal0
0?lO02h00?lO00<00000003o]000ok@09@00ok@00`0000000;Co002do`0T
002do`03000000007ol001oo02h001oo00<0000007H0o`1f0?l0801f0?l5
0?ooo`030000003oool0oooo0100oooo001o0?ooo`030000003oool0oooo
0080oooo8P1fo`02000002l00?lO00<00000003o]000ok@09P00ok@00`00
00000;Co002do`0U002do`03000000007ol001oo02d001oo0P00000Q07H0
o`D0oooo00<000000?ooo`3oool0403oool007l0oooo00<000000?ooo`3o
ool00P3ooolR07Ko000300000000oal00?lO02h00?lO00<00000003o]000
ok@09P00ok@00`0000000;Co002do`0U002do`03000000007ol001oo02l0
01oo00<0000007H0o`1f0?l07P1f0?l50?ooo`030000003oool0oooo0100
oooo001i0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooob40M_l0
00<00000003o7`00oal0;`00oal00`0000000?nd003o]00V003o]0030000
0000]?l00;Co02D00;Co00<00000000Oo`007ol0;`007ol00`000000MP3o
07H0o`0N07H0o`D0oooo00<000000?ooo`3oool0403oool007X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooob00M_l00P00
000a003o7`0300000000ok@00?nd02H00?nd00<00000002do`00]?l09P00
]?l00`00000001oo000Oo`0^000Oo`8000007`1f0?l50?ooo`030000003o
ool0oooo0100oooo001g0?ooo`D000000`3oool2000000<0oooo801fo`00
0`0000000?lO003o7`0_003o7`0300000000ok@00?nd02L00?nd00<00000
002do`00]?l09P00]?l00`00000001oo000Oo`0_000Oo`030000001f0?l0
MP3o01d0MP3o103oool200000180oooo001g0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool007P0oooo00<000000?ooo`000000103ooooo0000
00<000004P3oool007T0oooo0P00003o0?oooaT0oooo003o0?oooi@0oooo
0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The mapping  ",
  Cell[BoxData[
      \(w = Arcsin\ z\)]],
  "  conformally maps D onto the semi-infinite strip  ",
  Cell[BoxData[
      \(v > 0, \(-\(\[Pi]\/2\)\) < u < \[Pi]\/2\)]],
  ",  where the new problem is to find the steady state temperature  ",
  Cell[BoxData[
      RowBox[{\(T\^*\), 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  " that has the boundary conditions  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{" ", 
        RowBox[{
          RowBox[{
            RowBox[{\(T\^*\), 
              RowBox[{"(", 
                RowBox[{\(\[Pi]\/2\), 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "v"}], ")"}]}], " ", "=", "  ", 
            "1"}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "   ", "v"}], " ", ">", " ", 
              "0"}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[";",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}], "\n"}], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{\(T\^*\), 
              RowBox[{"(", 
                RowBox[{\(\(-\[Pi]\)\/2\), 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "v"}], ")"}]}], "=", \(-1\)}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "   ", "v"}], ">", " ", "0"}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[";",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{\(\[PartialD]\(T\^*\)\/\[PartialD]n\), "  ", "=", "  ", 
          RowBox[{
            RowBox[{\(T\_v\%*\), 
              RowBox[{"(", 
                RowBox[{"u", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "0"}], ")"}]}], "  ", "=", "  ",
             "0"}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "   ", "-", \(\[Pi]\/2\)}], "<", "u", 
          "<", 
          RowBox[{\(\[Pi]\/2\), 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "  \n\nUsing the result of Example 11.1, we can easily obtain the solution: \
 \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(T\^*\), 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], "  ", "=", 
        " ", \(2\/\[Pi]\ u\)}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "Therefore the solution in D is  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
        " ", \(2\/\[Pi]\ Re \((Arcsin\ z)\)\)}]]],
  ".  \n\nIf an explicit solution is required, then we can use Formula ",
  StyleBox["(10-26)",
    FontColor->RGBColor[0, 0, 1]],
  " to obtain  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
        "  ", \(\(2\/\[Pi]\) 
          Arcsin \((\(\@\(\((x + 1)\)\^2 + y\^2\)\  - \ \@\(\((x - 1)\)\^2 + \
y\^2\)\)\/2)\)\)}]]],
  "\n\nwhere the function  ",
  Cell[BoxData[
      \(Arcsin\ t\)]],
  "  has range values satisfying  ",
  Cell[BoxData[
      \(\(-\(\[Pi]\/2\)\) < Arcsin\ t < \[Pi]\/2\)]],
  ";  see Figure 11.21."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.21",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/temperature/\
TemperaturesFigures/mat1121.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The temperature ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " with ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(T\_y\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "0"}], ")"}]}], "=", 
        RowBox[{
          RowBox[{
            RowBox[{"0", "  ", 
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}], " ", "-", "1"}], "<", "x", "<", 
          "1"}]}]]],
  ", \n\t\t\tand boundary values ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "0"}], ")"}]}], "=", 
        RowBox[{
          RowBox[{\(-1\), "  ", 
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "x"}], "<", \(-1\)}]}]]],
  ", and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "0"}], ")"}]}], "=", 
        RowBox[{
          RowBox[{"1", "  ", 
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "x"}], ">", "1"}]}]]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.17.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
This is similar to Example 11.13, but the method of solution is different.

Construct the solution via a known conformal mapping. \
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[T, Ty, x, y];\)\ \), "\[IndentingNewLine]", 
    \(\(T[x_, 
          y_]\  = \(\(\ \)\(2\)\)\/\[Pi]\ Re[
            ArcSin[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", 
        ComplexExpand[T[x, y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(T[x_, y_]\  = \ 
        2\/\[Pi]\ ArcSin[\(\@\(\((x + 1)\)\^2\  + \ y\^2\)\  - \@\(\((x - \
1)\)\^2\  + \ y\^2\)\)\/2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "For computational purposes we use the formula  ",
  Cell[BoxData[
      \(Re[ArcSin[x\  + \ \[ImaginaryI]\ y]] = 
        ArcSin[\(\@\(\((x + 1)\)\^2\  + \ y\^2\)\  - \@\(\((x - 1)\)\^2\  + \ \
y\^2\)\)\/2]\)]],
  "  \nThen we can check out the temperature and the normal derivative at \
several boundary points."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(T[x_, y_]\  = \ 
        2\/\[Pi]\ ArcSin[\(\@\(\((x + 1)\)\^2\  + \ y\^2\)\  - \@\(\((x - \
1)\)\^2\  + \ y\^2\)\)\/2];\)\ \), "\n", 
    \(\(Ty[x_, y_]\  = \ \[PartialD]\_y\ T[x, y];\)\ \), "\n", 
    \(\(Print["\<  T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Some boundary values are\>"];\)\ \), "\n", 
    \(\(Print["\< T[-3,0] = \>", 
        T[\(-3\), 0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< T[-2,0] = \>", T[\(-2\), 0]];\)\ \), "\n", 
    \(\(Print["\< T[-1,0] = \>", T[\(-1\), 0]];\)\ \), "\n", 
    \(\(Print["\<  T[1,0] = \>", T[1, 0]];\)\ \), "\n", 
    \(\(Print["\<  T[2,0] = \>", T[2, 0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  T[3,0] = \>", T[3, 0]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(T\_y\)[x,y] = \>\"", 
        Ty[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Some values of the normal derivative are\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(T\_y\)[\!\(\(-1\)\/2\),0] = \>\"", 
        Ty[\(-1\)\/2, 0]];\)\ \), "\n", 
    \(\(Print[\*"\"\<  \!\(T\_y\)[0,0] = \>\"", Ty[0, 0]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(T\_y\)[\!\(1\/2\),0] = \>\"", 
        Ty[1\/2, 0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the temperature."
}], "Text"],

Cell[BoxData[{
    \(\(T[x_, 
          y_]\  = \(\(\ \)\(2\)\)\/\[Pi]\ Re[
            ArcSin[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\[IndentingNewLine]", 
    \(\(cont\  = \ Table[\(-1\)\  + \ 0.2  k, {k, 0, 10}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[T[x, y], {x, \(-4\), 4}, {y, 0.000001, 4}, 
        Contours\  \[Rule] \ cont, PlotPoints \[Rule] 25, 
        AspectRatio \[Rule] 1\/2, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\n", 
    \(\(Print["\<The contours are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[T[x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Hence the temperature function  ",
  Cell[BoxData[
      \(T[x, 
          y] = \(\(\ \)\(2\)\)\/\[Pi]\ Re[
            ArcSin[x\  + \ \[ImaginaryI]\ y]]\)]],
  "  is harmonic in the upper half plane  ",
  Cell[BoxData[
      \(\(\(\ \)\(Im[z] > 0\)\(\ \)\)\)]],
  ",  and has the desired boundary values.  "
}], "Text"],

Cell[TextData[{
  "Then use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[T[x, y], {x, \(-2\), 2}, {y, 0.00001, 1.5}, 
        PlotPoints \[Rule] {41, 16}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\[Phi]\>"}, 
        ColorFunction \[Rule] Hue, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 1.5, 0.5], 
            Range[\(-1\), 1, 1]}, ViewPoint \[Rule] {\(-2.5\), \(-3\), 2}, 
        AxesEdge \[Rule] {{\(-1\), \(-1\)}, {\(-1\), \(-1\)}, {1, \
\(-1\)}}];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Hence the temperature function  ",
  Cell[BoxData[
      \(T[x, 
          y] = \(\(\ \)\(2\)\)\/\[Pi]\ Re[
            ArcSin[x\  + \ \[ImaginaryI]\ y]]\)]],
  "  is harmonic in the upper half plane  ",
  Cell[BoxData[
      \(\(\(\ \)\(Im[z] > 0\)\(\ \)\)\)]],
  ",  and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Using Previous Techniques",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe techniques of the N-value Dirichlet problem in Sections 11.2 and \
Poisson's integral formula in 11.3 can be used to find steady state \
temperatures.  We recast two previous examples in the context of steady state \
temperatures. "
}], "Text"],

Cell[TextData[{
  StyleBox["Revisited Example 11.6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the temperature  ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  in the upper half-plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  where the temperature at points on the boundary satisfies Figure 11.5.  \
That is \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", "4"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "      ", "x"}], "<", \(-1\)}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", "1"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "-", "1"}], "<", "x", "<", 
          "0"}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", "3"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "      ", "0"}], "<", "x", "<", "1"}],
         
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", "2"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "      ", "1"}], "<", 
          RowBox[{"x", 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000UB000`400?l0
0000o`00003oo`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00R`3oool40000
03X0oooo1@00000g0?ooo`800000>P3oool5000003T0oooo1000000=0?oo
o`00R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03H0
oooo00@000000?ooo`3oool00000>`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00h0oooo002<0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool0=P3oool010000000oooo0?ooo`00000k0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool03@3oool008D0
oooo100000040?ooo`030000003oool0oooo03<0oooo100000040?ooo`03
0000003oool0oooo03H0oooo00@000000?ooo`3oool00000>`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo002;0?ooo`04
0000003oool0oooo000003`0oooo00<000000?ooo`3oool0=P3oool01000
0000oooo0?ooo`00000k0?ooo`030000003oool0oooo03T0oooo00@00000
0?ooo`3oool000003@3oool008`0oooo0P00000l0?ooo`800000>@3oool2
000003/0oooo0P00000l0?ooo`8000003P3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool007h0oooo0P0000050?ooool000000`0000090?ooo`00
O@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool007d0oooo
00@000000?ooo`3oool00000103oool200000400oooo0P00000l0?ooo`80
0000?03oool200000400oooo0P0000090?ooo`00O@3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0080oooo>@3o054:000003D0
oe401`00000i0014o`@00000>`00od@50?ooo`030000003oool0oooo00L0
oooo001m0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3ooolf0?l0D@<0000000<0o`3>0000000000003000000^0?mA0080
00000P3ocP04000000030031o`000000000003L004Co0P0000000`00ol40
00000000000j003oA0D0oooo00<000000?ooo`3oool01`3oool007h0oooo
0P0000050?ooo`030000003oool0oooo0080oooo<`3o0543000000<0o`3>
2`0000040?o>00D000009@3oD@0400000080olh01`0000020031o`800000
<`00A?l2000000050031o`0000000?o1003o`@000000>P00od@50?ooo`03
0000003oool0oooo00L0oooo00250?ooo`030000003oool0oooo0080oooo
;`3o0544000000D0o`3>00<000000;@0o`0000001P0000000`0ho`000000
0;Co0002000000L0olh01P00000J0?mA00D000001@3ocP000`000000]?l0
0;Co000200000004003oA00000000?o1000000<00<7o0P00000`0014o`05
00000000`Ol00<7o0031o`0000000`00ol400`0000000?m4003oA00g003o
A0D0oooo00<000000?ooo`3oool01`3oool008D0oooo00<000000?ooo`3o
ool00P3oool]0?l0D@<000001@3o0<h3000000050;@0o`00000000000000
0000A?l01`0000020;Co00<000002P3ocP0;000000D0oe402`0000080?o>
00090000002do`00]?l00000000ho`000000003oA00000000?o100800000
1000`Ol2000002d004Co0P0000030031o`0300000000ol400?o100800?o1
00<00000003oA000od@0=P00od@50?ooo`030000003oool0oooo00L0oooo
00250?ooo`8000000`3ooolY0?l0D@@000001`3o0<h200000080]03o00<0
000003P0o`0000000P0000000`00`Ol00000000000030000000303So0000
0000000000<0]?l00P00000C0?o>00D00000403ocP0300000080]?l00P00
0000100ho`000000003oA0000002003o`@8000001@00`Ol2000002T004Co
0P0000050031o`0300000000ol400?o100<00?o100<00000003oA000od@0
=@00od@40?ooo`8000002@3oool008D0oooo00<000000?ooo`3oool00P3o
oolV0?l0D@@000002@3o0<h010000000]03o0;@0o`2d0?l20000000:03P0
o`00000004Co00000000`Ol00000003o`@0000000?m400000080>?l00P00
00040;Co00<00000903ocP000`000000]?l00;Co00030;Co00040000000h
o`00>?l0000000800?m400@00000003o`@00ol4000001`00`Ol2000002H0
04Co0P0000060031o`0300000000ol400?o100<00?o10P00000f003oA0D0
oooo00<000000?ooo`3oool01`3oool008D0oooo00<000000?ooo`3oool0
0P3ooolT0?l0D@<000002P3o0<h2000000<0]03o0P00000203P0o`070000
0000A?l000000031o`0000000?o100000002003oA0030000000ho`00>?l0
008000001P2do`0200000200olh00P0000050;Co00030000000ho`00>?l0
008000000P00od@01@0000000?o1003o`@00ol40000000P00<7o0P00000S
0014o`8000001`00`Ol00`0000000?o1003o`@04003o`@800000=@00od@5
0?ooo`030000003oool0oooo00L0oooo00250?ooo`030000003oool0oooo
0080oooo8@3o0543000000`0o`3>00<000000;@0o`2d0?l00`2d0?l01000
0000>03o03P0o`0000020014o`0300000000`Ol0000000800?o100@00000
003oA000od@000000`0ho`000`000000]?l00;Co00050;Co00@000006@3o
cP03000000H0]?l000D0000003So000ho`00>?l000000003003oA0040000
0000ol400?o1003o`@8000002000`Ol3000001l004Co0P0000090031o`03
00000000ol400?o100D00?o10P00000d003oA0D0oooo00<000000?ooo`3o
ool01`3oool008D0oooo00<000000?ooo`3oool00P3ooolO0?l0D@800000
3P3o0<h00`000000]03o0;@0o`030;@0o`050000000h0?l0>03o03P0o`00
00000P00A?l00`0000000<7o00000002003o`@0300000000od@00?m40080
00000`0ho`02000000T0]?l01@00000A0?o>00<00000202do`02000000<0
>?l000D00000003oA000od@00?m400000004003o`@0300000000`Ol00<7o
00P00<7o0`00000K0014o`<000002P00`Ol00`0000000?o1003o`@06003o
`@0300000000od@00?m403800?m41@3oool00`000000oooo0?ooo`070?oo
o`00Q@3oool00`000000oooo0?ooo`020?oooa/0o`1A1000000>0?l0cP80
00001@2d0?l010000000>03o03P0o`0h0?l20000008004Co00@000000031
o`00`Ol000000P00ol400`0000000?m4003oA002000000@0>?l00P00000<
0;Co014000002@2do`02000000@0>?l00P000003003oA00300000000ol40
0?o100<00?o100<000000031o`00`Ol02P00`Ol3000001H004Co0P00000<
0031o`8000002@00ol400`0000000?m4003oA00a003oA0D0oooo00<00000
0?ooo`3oool01`3oool008D0oooo00<000000?ooo`3oool00P3ooolI0?l0
D@8000004@3o0<h2000000H0]03o00D0000003P0o`0h0?l0>03o00000003
0014o`0400000000`Ol00<7o000000800?o100@00000003oA000od@00?m4
0P00000503So00030000002do`00]?l00280]?l00P00000503So00030000
0000od@00?m400800?m400<00000003o`@00ol400`00ol400`0000000<7o
0031o`0=0031o`8000004P00A?l2000000h00<7o00<00000003o`@00ol40
2@00ol400`0000000?m4003oA00`003oA0D0oooo00<000000?ooo`3oool0
1`3oool008D0oooo0P0000030?oooaH0o`1A0`00000B0?l0cP030000002d
0?l0]03o00D0]03o00<0000003P0o`0h0?l00P0h0?l01@00000004Co0014
o`00A?l0000000800<7o00<00000003o`@00ol400P000003003oA0800000
1@0ho`0200000240]?l00P00000503So008000001000od@00`0000000?o1
003o`@04003o`@0300000000`Ol00<7o00h00<7o1P0000070014o`D00000
4000`Ol00`0000000?o1003o`@09003o`@800000<@00od@40?ooo`800000
2@3oool008D0oooo00<000000?ooo`3oool00P3ooolD0?l0D@800000503o
0<h00`000000]03o0;@0o`050;@0o`030000000h0?l0>03o0080>03o00@0
00000014o`00A?l004Co0P0000020031o`0500000000ol400?o1003o`@00
00001000od@00`000000>?l003So000503So00<000007@2do`000`000000
>?l003So000503So000300000000od@00?m400<00?m400<00000003o`@00
ol401@00ol400`0000000<7o0031o`0C0031o`L000005@00`Ol00`000000
0?o1003o`@0:003o`@800000<000od@50?ooo`030000003oool0oooo00L0
oooo00250?ooo`030000003oool0oooo0080oooo4@3o0543000001@0o`3>
0P0000070;@0o`800000100h0?l01@00000004Co0014o`00A?l0000000<0
0<7o00@00000003o`@00ol400?o10P000004003oA08000001`0ho`030000
01P0]?l00`00000703So008000001@00od@00`0000000?o1003o`@05003o
`@0300000000`Ol00<7o02l00<7o00<00000003o`@00ol402`00ol400`00
00000?m4003oA00^003oA0D0oooo00<000000?ooo`3oool01`3oool008D0
oooo00<000000?ooo`3oool00P3oool>0?l0D@<000005P3o0<h2000000L0
]03o0P00000503P0o`0500000000A?l004Co0014o`0000001000`Ol01000
00000?o1003o`@00ol42000000@00?m40P00000903So00@000004P2do`02
000000X0>?l000<00000003oA000od@01000od@00`0000000?o1003o`@06
003o`@0300000000`Ol00<7o02d00<7o00<00000003o`@00ol403@00ol42
000002h00?m41@3oool00`000000oooo0?ooo`070?ooo`00Q@3oool00`00
0000oooo0?ooo`020?ooo`/0o`1A0`00000H0?l0cP030000002d0?l0]03o
00L0]03o00<0000003P0o`0h0?l00`0h0?l00`00000004Co0014o`020014
o`0300000000`Ol00<7o00800<7o00<00000003o`@00ol400P00ol420000
00D00?m400<0000003So000ho`002@0ho`06000000030;Co00000000]?l0
00D0]?l01@00000;03So000300000000od@00?m400D00?m400<00000003o
`@00ol401P00ol400`0000000<7o0031o`0]0031o`0300000000ol400?o1
00h00?o100<00000003oA000od@0;000od@50?ooo`030000003oool0oooo
00L0oooo00250?ooo`030000003oool0oooo0080oooo2@3o0543000001P0
o`3>0P0000090;@0o`8000001@0h0?l00`00000004Co0014o`020014o`03
00000000`Ol00<7o00800<7o00<00000003o`@00ol400P00ol42000000H0
0?m400<0000003So000ho`003P0ho`08000000l0>?l00P000007003oA003
00000000ol400?o100L00?o100<000000031o`00`Ol0;000`Ol00`000000
0?o1003o`@0?003o`@0300000000od@00?m402/00?m41@3oool00`000000
oooo0?ooo`070?ooo`00Q@3oool2000000<0oooo1P3o0543000001X0o`3>
0P0000090;@0o`8000001P0h0?l00`00000004Co0014o`020014o`030000
0000`Ol00<7o00800<7o0P000004003o`@8000001P00od@2000002@0>?l0
0P000008003oA00300000000ol400?o100L00?o10P00000/0031o`800000
4@00ol42000002`00?m4103oool2000000T0oooo00250?ooo`030000003o
ool0oooo0080oooo1@3o0542000001/0o`3>0P00000:0;@0o`030000000h
0?l0>03o00@0>03o00<000000014o`00A?l00`00A?l00`0000000<7o0031
o`030031o`0300000000ol400?o100<00?o100<00000003oA000od@01@00
od@300000240>?l000<00000003oA000od@02000od@00`0000000?o1003o
`@08003o`@0300000000`Ol00<7o02X00<7o00<00000003o`@00ol404P00
ol400`0000000?m4003oA00Y003oA0D0oooo00<000000?ooo`3oool01`3o
ool008D0oooo00<000000?ooo`3oool00P3oool00`3o0540000000000002
000001`0o`3>00<000000;@0o`2d0?l02@2d0?l2000000H0>03o00<00000
0014o`00A?l00`00A?l00`0000000<7o0031o`030031o`0300000000ol40
0?o100@00?o100<00000003oA000od@01P00od@2000001l0>?l00P000009
003oA00300000000ol400?o100T00?o10P00000[0031o`0300000000ol40
0?o101800?o10P00000Z003oA0D0oooo00<000000?ooo`3oool01`3oool0
08D0oooo00<000000?ooo`3oool00P3oool2000001h0o`3>00<000000;@0
o`2d0?l02P2d0?l00`000000>03o03P0o`0503P0o`0300000000A?l004Co
00<004Co00<000000031o`00`Ol01000`Ol00`0000000?o1003o`@04003o
`@0300000000od@00?m400L00?m40P00000L03So000300000000od@00?m4
00T00?m400<00000003o`@00ol402P00ol400`0000000<7o0031o`0X0031
o`0300000000ol400?o101@00?o100<00000003oA000od@0:000od@50?oo
o`030000003oool0oooo00L0oooo00250?ooo`030000003oool0oooo0080
oooo7P3o0<h2000000`0]03o00<0000003P0o`0h0?l01P0h0?l00`000000
04Co0014o`030014o`8000001@00`Ol00`0000000?o1003o`@04003o`@80
00002P00od@2000001L0>?l00`00000<003oA00300000000ol400?o100X0
0?o10P00000Y0031o`0300000000ol400?o101D00?o100<00000003oA000
od@09`00od@50?ooo`030000003oool0oooo00L0oooo00250?ooo`030000
003oool0oooo0080oooo7@3o0<h2000000`0]03o0P00000703P0o`800000
1P00A?l00`0000000<7o0031o`030031o`8000001P00ol42000000/00?m4
0`00000B03So008000003P00od@00`0000000?o1003o`@0<003o`@030000
0000`Ol00<7o02H00<7o0P00000H003o`@0300000000od@00?m402H00?m4
1@3oool00`000000oooo0?ooo`070?ooo`00Q@3oool2000000<0oooo703o
0<h00`000000]03o0;@0o`0<0;@0o`030000000h0?l0>03o00H0>03o00<0
00000014o`00A?l01@00A?l00`0000000<7o0031o`040031o`0300000000
ol400?o100D00?o10P00000=003oA0@000002P0ho`04000001000?m400<0
0000003o`@00ol403000ol400`0000000<7o0031o`0V0031o`0300000000
ol400?o101P00?o100<00000003oA000od@09@00od@40?ooo`8000002@3o
ool008D0oooo00<000000?ooo`3oool00P3ooolK0?l0cP8000003@2d0?l2
000000P0>03o00<000000014o`00A?l01@00A?l00`0000000<7o0031o`04
0031o`0300000000ol400?o100H00?o10P00000@003oA0X000004`00od@2
000000l00?o100<000000031o`00`Ol09@00`Ol00`0000000?o1003o`@0I
003o`@0300000000od@00?m402@00?m41@3oool00`000000oooo0?ooo`07
0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooaX0o`3>00<000000;@0
o`2d0?l03@2d0?l00`000000>03o03P0o`0703P0o`0300000000A?l004Co
00D004Co00<000000031o`00`Ol01@00`Ol00`0000000?o1003o`@06003o
`@0300000000od@00?m402/00?m400<00000003o`@00ol403P00ol400`00
00000<7o0031o`0T0031o`0300000000ol400?o101/00?o100<00000003o
A000od@08`00od@50?ooo`030000003oool0oooo00L0oooo00250?ooo`03
0000003oool0oooo0080oooo6@3o0<h2000000h0]03o0P00000903P0o`03
00000000A?l004Co00D004Co00<000000031o`00`Ol01@00`Ol00`000000
0?o1003o`@07003o`@800000:P00od@2000001400?o100<000000031o`00
`Ol08`00`Ol00`0000000?o1003o`@0K003o`@8000009000od@50?ooo`03
0000003oool0oooo00L0oooo001b0?ooo`800000103oool2000000@0oooo
0P0000050?ooo`030000003oool0oooo0080oooo5`3o0<h200000100]03o
00<0000003P0o`0h0?l01`0h0?l00`00000004Co0014o`060014o`030000
0000`Ol00<7o00H00<7o00<00000003o`@00ol401`00ol42000002P00?m4
0P00000B003o`@8000008`00`Ol00`0000000?o1003o`@0N003o`@030000
0000od@00?m402400?m41@3oool00`000000oooo0?ooo`070?ooo`00L@3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P3ooolG0?l0cP030000002d0?l0]03o00h0
]03o00<0000003P0o`0h0?l0200h0?l00`00000004Co0014o`060014o`03
00000000`Ol00<7o00H00<7o00<00000003o`@00ol402@00ol400`000000
0?m4003oA00T003oA08000005000ol400`0000000<7o0031o`0Q0031o`03
00000000ol400?o101h00?o10P00000R003oA0D0oooo00<000000?ooo`3o
ool01`3oool00740oooo00@000000?ooo`3oool000002`3oool00`000000
oooo0?ooo`020?ooo`8000000`3ooolE0?l0cP800000402d0?l2000000X0
>03o00<000000014o`00A?l01P00A?l00`0000000<7o0031o`070031o`03
00000000ol400?o100T00?o10P00000T003oA00300000000ol400?o101<0
0?o10P00000Q0031o`0300000000ol400?o102000?o10P00000Q003oA0@0
oooo0P0000090?ooo`00L@3oool010000000oooo0?ooo`0000090?ooo`80
00001@3oool00`000000oooo0?ooo`020?oooaD0o`3>00<000000;@0o`2d
0?l03`2d0?l00`000000>03o03P0o`0903P0o`0300000000A?l004Co00L0
04Co00<000000031o`00`Ol01P00`Ol2000000`00?o100<00000003oA000
od@08000od@00`0000000?o1003o`@0E003o`@0300000000`Ol00<7o01h0
0<7o0P00000T003o`@0300000000od@00?m401h00?m41@3oool00`000000
oooo0?ooo`070?ooo`00L@3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3ooolC0?l0cP80
00004@2d0?l2000000/0>03o00<000000014o`00A?l01`00A?l00`000000
0<7o0031o`070031o`0300000000ol400?o100/00?o10P00000O003oA003
00000000ol400?o101H00?o100<000000031o`00`Ol07P00`Ol00`000000
0?o1003o`@0S003o`@8000007`00od@50?ooo`030000003oool0oooo00L0
oooo001b0?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3oool0
0P3ooolB0?l0cP8000004P2d0?l00`000000>03o03P0o`0:03P0o`030000
0000A?l004Co00L004Co00<000000031o`00`Ol02000`Ol00`0000000?o1
003o`@0<003o`@8000006`00od@2000001X00?o100<000000031o`00`Ol0
7000`Ol2000002L00?o100<00000003oA000od@07000od@50?ooo`030000
003oool0oooo00L0oooo00250?ooo`030000003oool0oooo0080oooo4@3o
0<h00`000000]03o0;@0o`0B0;@0o`030000000h0?l0>03o00T0>03o00<0
00000014o`00A?l02000A?l00`0000000<7o0031o`080031o`0300000000
ol400?o100h00?o10`00000F003oA08000007000ol400`0000000<7o0031
o`0L0031o`0300000000ol400?o102L00?o10P00000L003oA0D0oooo00<0
00000?ooo`3oool01`3oool008D0oooo00<000000?ooo`3oool00P3oool@
0?l0cP8000004`2d0?l00`000000>03o03P0o`0:03P0o`0300000000A?l0
04Co00P004Co00<000000031o`00`Ol02@00`Ol00`0000000?o1003o`@0?
003o`@<000004P00od@2000001l00?o100<000000031o`00`Ol06P00`Ol0
0`0000000?o1003o`@0X003o`@8000007000od@50?ooo`030000003oool0
oooo00L0oooo00250?ooo`8000000`3oool?0?l0cP030000002d0?l0]03o
01<0]03o00<0000003P0o`0h0?l02P0h0?l00`00000004Co0014o`090014
o`0300000000`Ol00<7o00T00<7o00<00000003o`@00ol404@00ol450000
00T00?m41000000Q003o`@0300000000`Ol00<7o01T00<7o00<00000003o
`@00ol40:`00ol400`0000000?m4003oA00I003oA0@0oooo0P0000090?oo
o`00Q@3oool00`000000oooo0?ooo`020?ooo`h0o`3>0P00000D0;@0o`03
0000000h0?l0>03o00/0>03o00<000000014o`00A?l02@00A?l00`000000
0<7o0031o`090031o`8000005`00ol49000002H00?o100<000000031o`00
`Ol05`00`Ol2000002h00?o100<00000003oA000od@06000od@50?ooo`03
0000003oool0oooo00L0oooo00250?ooo`030000003oool0oooo0080oooo
3@3o0<h2000001@0]03o0P00000=03P0o`0300000000A?l004Co00T004Co
00<000000031o`00`Ol02P00`Ol2000004D00?o10P00000G0031o`800000
<000ol42000001P00?m41@3oool00`000000oooo0?ooo`070?ooo`00Q@3o
ool00`000000oooo0?ooo`020?ooo``0o`3>00<000000;@0o`2d0?l0502d
0?l00`000000>03o03P0o`0<03P0o`0300000000A?l004Co00T004Co00<0
00000031o`00`Ol02`00`Ol00`0000000?o1003o`@14003o`@0300000000
`Ol00<7o01D00<7o00<00000003o`@00ol40<000ol400`0000000?m4003o
A00F003oA0D0oooo00<000000?ooo`3oool01`3oool008D0oooo00<00000
0?ooo`3oool00P3oool;0?l0cP030000002d0?l0]03o01@0]03o0P00000>
03P0o`0300000000A?l004Co00X004Co00<000000031o`00`Ol02`00`Ol0
0`0000000?o1003o`@13003o`@8000005@00`Ol00`0000000?o1003o`@0b
003o`@8000005P00od@50?ooo`030000003oool0oooo00L0oooo00250?oo
o`030000003oool0oooo0080oooo2P3o0<h00`000000]03o0;@0o`0E0;@0
o`030000000h0?l0>03o00d0>03o00<000000014o`00A?l02P00A?l00`00
00000<7o0031o`0<0031o`0300000000ol400?o104<00?o100<000000031
o`00`Ol04P00`Ol00`0000000?o1003o`@0e003o`@0300000000od@00?m4
01<00?m41@3oool00`000000oooo0?ooo`070?ooo`00Q@3oool00`000000
oooo0?ooo`020?ooo`T0o`3>00<000000;@0o`2d0?l05@2d0?l00`000000
>03o03P0o`0>03P0o`0300000000A?l004Co00X004Co00<000000031o`00
`Ol03@00`Ol00`0000000?o1003o`@13003o`@0300000000`Ol00<7o0100
0<7o00<00000003o`@00ol40=`00ol400`0000000?m4003oA00B003oA0D0
oooo00<000000?ooo`3oool01`3oool008D0oooo0P0000030?ooo`P0o`3>
00<000000;@0o`2d0?l05P2d0?l00`000000>03o03P0o`0=03P0o`030000
0000A?l004Co00/004Co0P00000>0031o`800000A000ol400`0000000<7o
0031o`0?0031o`800000>P00ol42000001800?m4103oool2000000T0oooo
00250?ooo`030000003oool0oooo0080oooo1`3o0<h00`000000]03o0;@0
o`0G0;@0o`030000000h0?l0>03o00d0>03o00<000000014o`00A?l03000
A?l00`0000000<7o0031o`0>0031o`0300000000ol400?o104800?o100<0
00000031o`00`Ol03@00`Ol00`0000000?o1003o`@0k003o`@8000004@00
od@50?ooo`030000003oool0oooo00L0oooo00250?ooo`030000003oool0
oooo0080oooo1P3o0<h00`000000]03o0;@0o`0G0;@0o`030000000h0?l0
>03o00h0>03o00<000000014o`00A?l03000A?l00`0000000<7o0031o`0>
0031o`800000@`00ol400`0000000<7o0031o`0<0031o`800000?P00ol42
000001000?m41@3oool00`000000oooo0?ooo`070?ooo`00Q@3oool00`00
0000oooo0?ooo`020?ooo`@0o`3>0P00000I0;@0o`800000400h0?l00`00
000004Co0014o`0<0014o`8000004@00`Ol2000004800?o100<000000031
o`00`Ol02P00`Ol00`0000000?o1003o`@10003o`@8000003P00od@50?oo
o`030000003oool0oooo00L0oooo00250?ooo`030000003oool0oooo0080
oooo0`3o0<h2000001X0]03o00<0000003P0o`0h0?l03`0h0?l00`000000
04Co0014o`0=0014o`0300000000`Ol00<7o01000<7o0P000011003o`@03
00000000`Ol00<7o00T00<7o00<00000003o`@00ol40@P00ol42000000d0
0?m41@3oool00`000000oooo0?ooo`070?ooo`00Q@3oool00`000000oooo
0?ooo`020?ooo`80o`3>0P00000K0;@0o`030000000h0?l0>03o00l0>03o
00<000000014o`00A?l03@00A?l00`0000000<7o0031o`0A0031o`800000
@@00ol400`0000000<7o0031o`060031o`800000AP00ol42000000`00?m4
1@3oool00`000000oooo0?ooo`070?ooo`00Q@3oool2000000<0oooo0P3o
0<h00`000000]03o0;@0o`0I0;@0o`030000000h0?l0>03o0100>03o00<0
00000014o`00A?l03P00A?l00`0000000<7o0031o`0B0031o`0300000000
ol400?o103h00?o100<000000031o`00`Ol01@00`Ol00`0000000?o1003o
`@18003o`@0300000000od@00?m400T00?m4103oool2000000T0oooo0025
0?ooo`030000003oool0oooo0080oooo00<0o`3>0000002d0?l06`2d0?l0
0`000000>03o03P0o`0@03P0o`0300000000A?l004Co00h004Co00<00000
0031o`00`Ol04`00`Ol00`0000000?o1003o`@0n003o`@0300000000`Ol0
0<7o00<00<7o0P00001;003o`@8000002@00od@50?ooo`030000003oool0
oooo00L0oooo00250?ooo`030000003oool0oooo0080oooo00<000000;@0
o`2d0?l06P2d0?l200000180>03o00<000000014o`00A?l03P00A?l20000
01D00<7o0P00000n003o`@8000000P00`Ol2000004h00?o10`000007003o
A0D0oooo00<000000?ooo`3oool01`3oool008D0oooo00<000000?ooo`3o
ool00P3ooolM0;@0o`030000000h0?l0>03o0140>03o00<000000014o`00
A?l03`00A?l00`0000000<7o0031o`0E0031o`800000?@00ol4400000580
0?o100<00000003oA000od@01000od@50?ooo`030000003oool0oooo00L0
oooo00250?ooo`030000003oool0oooo0080oooo702d0?l2000001<0>03o
00<000000014o`00A?l03`00A?l00`0000000<7o0031o`0F0031o`<00000
>`00ol42000005@00?o10P000005003oA0D0oooo00<000000?ooo`3oool0
1`3oool008D0oooo00<000000?ooo`3oool00P3ooolL0;@0o`030000000h
0?l0>03o0180>03o00<000000014o`00A?l04000A?l00`0000000<7o0031
o`0G0031o`<00000=`00ol42000000030031o`0000000?o105D00?o100<0
0000003oA000od@00P00od@50?ooo`030000003oool0oooo00L0oooo0025
0?ooo`8000000`3ooolL0;@0o`030000000h0?l0>03o0180>03o00<00000
0014o`00A?l04000A?l00`0000000<7o0031o`0I0031o`800000=000ol42
000000@00<7o00<00000003o`@00ol40E000ol42000000800?m4103oool2
000000T0oooo00250?ooo`030000003oool0oooo0080oooo6`2d0?l00`00
0000>03o03P0o`0C03P0o`0300000000A?l004Co014004Co00<000000031
o`00`Ol06P00`Ol3000002h00?o10`0000060031o`800000E`00ol420000
00D0oooo00<000000?ooo`3oool01`3oool008D0oooo00<000000?ooo`3o
ool00P3ooolK0;@0o`030000000h0?l0>03o01<0>03o00<000000014o`00
A?l04@00A?l00`0000000<7o0031o`0M0031o`800000:P00ol43000000T0
0<7o00<00000003o`@00ol40E`00ol400`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00L0oooo00250?ooo`030000003oool0oooo0080oooo
6P2d0?l00`000000>03o03P0o`0D03P0o`0300000000A?l004Co014004Co
0P00000P0031o`@000008`00ol43000000`00<7o0P00001H003o`@D0oooo
00<000000?ooo`3oool01`3oool007d0oooo1@0000030?ooo`030000003o
ool0oooo0080oooo6P2d0?l00`000000>03o03P0o`0D03P0o`0300000000
A?l004Co018004Co00<000000031o`00`Ol08P00`Ol3000001`00?o11000
000@0031o`0300000000ol400?o105H00?o11@3oool00`000000oooo0?oo
o`070?ooo`00O`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0080oooo6@2d0?l2000001H0>03o00<000000014o`00A?l04P00A?l2
000002H00<7o1@00000B003o`@D000005@00`Ol00`0000000?o1003o`@1E
003o`@D0oooo00<000000?ooo`3oool01`3oool007l0oooo00<000000?oo
o`3oool00`3oool2000000<0oooo6@2d0?l00`000000>03o03P0o`0E03P0
o`0300000000A?l004Co01<004Co00<000000031o`00`Ol0:@00`OlB0000
01X00<7o0P00001F003o`@@0oooo0P0000090?ooo`00O`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo6@2d0?l00`000000
>03o03P0o`0E03P0o`0300000000A?l004Co01@004Co00<000000031o`00
`Ol0E@00`Ol00`0000000?o1003o`@1D003o`@D0oooo00<000000?ooo`3o
ool01`3oool007l0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?oooaP0]03o00<0000003P0o`0h0?l05P0h0?l00`00000004Co
0014o`0D0014o`0300000000`Ol00<7o05D00<7o0P00001E003o`@D0oooo
00<000000?ooo`3oool01`3oool007h0oooo0P0000050?ooo`030000003o
ool0oooo0080oooo602d0?l00`000000>03o03P0o`0F03P0o`0300000000
A?l004Co01D004Co00<000000031o`00`Ol0E@00`Ol00`0000000?o1003o
`@1C003o`@D0oooo00<000000?ooo`3oool01`3oool008D0oooo00<00000
0?ooo`3oool00P3ooolG0;@0o`800000600h0?l00`00000004Co0014o`0E
0014o`0300000000`Ol00<7o05H00<7o00<00000003o`@00ol40DP00ol45
0?ooo`030000003oool0oooo00L0oooo00250?ooo`030000003oool0oooo
0080oooo5`2d0?l00`000000>03o03P0o`0G03P0o`0300000000A?l004Co
01H004Co00<000000031o`00`Ol0E@00`Ol2000005<00?o11@3oool00`00
0000oooo0?ooo`070?ooo`00Q@3oool2000000<0oooo5`2d0?l00`000000
>03o03P0o`0G03P0o`0300000000A?l004Co01H004Co00<000000031o`00
`Ol0EP00`Ol00`0000000?o1003o`@1A003o`@@0oooo0P0000090?ooo`00
Q@3oool00`000000oooo0?ooo`020?oooaH0]03o00<0000003P0o`0h0?l0
600h0?l00`00000004Co0014o`0G0014o`0300000000`Ol00<7o05H00<7o
00<00000003o`@00ol40D000ol450?ooo`030000003oool0oooo00L0oooo
00250?ooo`030000003oool0oooo0080oooo5P2d0?l00`000000>03o03P0
o`0H03P0o`0300000000A?l004Co01L004Co0P00001G0031o`800000D@00
ol450?ooo`030000003oool0oooo00L0oooo00250?ooo`030000003oool0
oooo0080oooo5@2d0?l00`000000>03o03P0o`0I03P0o`0300000000A?l0
04Co01P004Co00<000000031o`00`Ol0EP00`Ol00`0000000?o1003o`@1?
003o`@D0oooo00<000000?ooo`3oool01`3oool008D0oooo00<000000?oo
o`3oool00P3ooolE0;@0o`030000000h0?l0>03o01T0>03o00<000000014
o`00A?l06000A?l2000005P00<7o00<00000003o`@00ol40CP00ol450?oo
o`030000003oool0oooo00L0oooo00250?ooo`030000003oool0oooo0080
oooo5@2d0?l00`000000>03o03P0o`0I03P0o`0300000000A?l004Co01T0
04Co00<000000031o`00`Ol0EP00`Ol00`0000000?o1003o`@1>003o`@D0
oooo00<000000?ooo`3oool01`3oool008D0oooo0P0000030?oooa@0]03o
00<0000003P0o`0h0?l06P0h0?l00`00000004Co0014o`0J0014o`030000
0000`Ol00<7o05H00<7o00<00000003o`@00ol40C@00ol440?ooo`800000
2@3oool008D0oooo00<000000?ooo`3oool00P3ooolD0;@0o`030000000h
0?l0>03o01X0>03o00<000000014o`00A?l06P00A?l2000005P00<7o00<0
0000003o`@00ol40C000ol450?ooo`030000003oool0oooo00L0oooo0025
0?ooo`030000003oool0oooo0080oooo4`2d0?l00`000000>03o03P0o`0K
03P0o`0300000000A?l004Co01/004Co00<000000031o`00`Ol0E`00`Ol0
0`0000000?o1003o`@1;003o`@D0oooo00<000000?ooo`3oool01`3oool0
08D0oooo00<000000?ooo`3oool00P3ooolC0;@0o`030000000h0?l0>03o
01/0>03o00<000000014o`00A?l06`00A?l2000005P00<7o00<00000003o
`@00ol40B`00ol450?ooo`030000003oool0oooo00L0oooo00250?ooo`03
0000003oool0oooo0080oooo4P2d0?l2000001d0>03o00<000000014o`00
A?l07000A?l2000005P00<7o00<00000003o`@00ol40BP00ol450?ooo`03
0000003oool0oooo00L0oooo00250?ooo`030000003oool0oooo0080oooo
4P2d0?l00`000000>03o03P0o`0L03P0o`0300000000A?l004Co01d004Co
00<000000031o`00`Ol0EP00`Ol2000004/00?o11@3oool00`000000oooo
0?ooo`070?ooo`00Q@3oool00`000000oooo0?ooo`020?oooa80]03o00<0
000003P0o`0h0?l0700h0?l00`00000004Co0014o`0M0014o`800000F000
`Ol2000004X00?o11@3oool00`000000oooo0?ooo`070?ooo`00Q@3oool2
000000<0oooo4@2d0?l00`000000>03o03P0o`0M03P0o`0300000000A?l0
04Co01h004Co00<000000031o`00`Ol0E`00`Ol00`0000000?o1003o`@18
003o`@@0oooo0P0000090?ooo`00Q@3oool00`000000oooo0?ooo`020?oo
oa40]03o00<0000003P0o`0h0?l07@0h0?l20000020004Co00<000000031
o`00`Ol0EP00`Ol2000004T00?o11@3oool00`000000oooo0?ooo`070?oo
o`00Q@3oool00`000000oooo0?ooo`020?oooa40]03o00<0000003P0o`0h
0?l07P0h0?l00`00000004Co0014o`0N0014o`0300000000`Ol00<7o05L0
0<7o00<00000003o`@00ol40A`00ol450?ooo`030000003oool0oooo00L0
oooo00250?ooo`030000003oool0oooo0080oooo402d0?l00`000000>03o
03P0o`0O03P0o`0300000000A?l004Co01l004Co00<000000031o`00`Ol0
E`00`Ol00`0000000?o1003o`@16003o`@D0oooo00<000000?ooo`3oool0
1`3oool008D0oooo00<000000?ooo`3oool00P3oool@0;@0o`030000000h
0?l0>03o01l0>03o00<000000014o`00A?l08000A?l00`0000000<7o0031
o`1G0031o`0300000000ol400?o104D00?o11@3oool00`000000oooo0?oo
o`070?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`l0]03o00<00000
03P0o`0h0?l0800h0?l00`00000004Co0014o`0P0014o`800000F000`Ol2
000004H00?o11@3oool00`000000oooo0?ooo`070?ooo`00Q@3oool20000
00<0oooo3`2d0?l00`000000>03o03P0o`0P03P0o`0300000000A?l004Co
024004Co00<000000031o`00`Ol0E`00`Ol00`0000000?o1003o`@14003o
`@@0oooo0P0000090?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`l0
]03o00<0000003P0o`0h0?l0800h0?l00`00000004Co0014o`0R0014o`03
00000000`Ol00<7o05L00<7o00<00000003o`@00ol40@`00ol450?ooo`03
0000003oool0oooo00L0oooo00250?ooo`030000003oool0oooo0080oooo
3P2d0?l00`000000>03o03P0o`0Q03P0o`0300000000A?l004Co028004Co
0P00001H0031o`800000A000ol450?ooo`030000003oool0oooo00L0oooo
00250?ooo`030000003oool0oooo0080oooo3P2d0?l00`000000>03o03P0
o`0Q03P0o`0300000000A?l004Co02<004Co00<000000031o`00`Ol0E`00
`Ol2000004<00?o11@3oool00`000000oooo0?ooo`070?ooo`00L@3oool5
00000080oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`02
0?ooo`d0]03o0P00000S03P0o`0300000000A?l004Co02@004Co00<00000
0031o`00`Ol0E`00`Ol00`0000000?o1003o`@11003o`@D0oooo00<00000
0?ooo`3oool01`3oool007<0oooo00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo3@2d0?l0
0`000000>03o03P0o`0R03P0o`0300000000A?l004Co02@004Co0P00001I
0031o`0300000000ol400?o104000?o11@3oool00`000000oooo0?ooo`07
0?ooo`00L`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo0P0000030?ooo`d0]03o00<0000003P0o`0h0?l08P0h0?l00`00
000004Co0014o`0U0014o`0300000000`Ol00<7o05P00<7o00<00000003o
`@00ol40?`00ol440?ooo`8000002@3oool007<0oooo00<000000?ooo`3o
ool0203oool2000000D0oooo00<000000?ooo`3oool00P3oool<0;@0o`80
0000900h0?l00`00000004Co0014o`0U0014o`800000F@00`Ol200000400
0?o11@3oool00`000000oooo0?ooo`070?ooo`00L`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool<0;@0o`030000000h0?l0>03o02<0>03o00<000000014o`00A?l0
9P00A?l2000005T00<7o00<00000003o`@00ol40?P00ol450?ooo`030000
003oool0oooo00L0oooo001b0?ooo`8000002P3oool3000000@0oooo00<0
00000?ooo`3oool00P3oool<0;@0o`030000000h0?l0>03o02<0>03o00<0
00000014o`00A?l09`00A?l00`0000000<7o0031o`1H0031o`0300000000
ol400?o103d00?o11@3oool00`000000oooo0?ooo`070?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooo`/0]03o00<0000003P0o`0h0?l0900h0?l0
0`00000004Co0014o`0X0014o`0300000000`Ol00<7o05L00<7o0P00000n
003o`@D0oooo00<000000?ooo`3oool01`3oool008D0oooo00<000000?oo
o`3oool00P3oool;0;@0o`030000000h0?l0>03o02D0>03o00<000000014
o`00A?l09`00A?l2000005T00<7o0P00000m003o`@D0oooo00<000000?oo
o`3oool01`3oool008D0oooo0P0000030?ooo`X0]03o00<0000003P0o`0h
0?l09P0h0?l00`00000004Co0014o`0X0014o`0300000000`Ol00<7o05P0
0<7o00<00000003o`@00ol40>`00ol440?ooo`8000002@3oool008D0oooo
00<000000?ooo`3oool00P3oool:0;@0o`030000000h0?l0>03o02H0>03o
00<000000014o`00A?l0:@00A?l00`0000000<7o0031o`1H0031o`030000
0000ol400?o103X00?o11@3oool00`000000oooo0?ooo`070?ooo`00Q@3o
ool00`000000oooo0?ooo`020?ooo`X0]03o00<0000003P0o`0h0?l09P0h
0?l00`00000004Co0014o`0Y0014o`800000FP00`Ol00`0000000?o1003o
`@0i003o`@D0oooo00<000000?ooo`3oool01`3oool008D0oooo00<00000
0?ooo`3oool00P3oool90;@0o`030000000h0?l0>03o02L0>03o00<00000
0014o`00A?l0:P00A?l00`0000000<7o0031o`1H0031o`800000>P00ol45
0?ooo`030000003oool0oooo00L0oooo00250?ooo`030000003oool0oooo
0080oooo2@2d0?l00`000000>03o03P0o`0W03P0o`0300000000A?l004Co
02/004Co00<000000031o`00`Ol0F000`Ol2000003T00?o11@3oool00`00
0000oooo0?ooo`070?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`P0
]03o0P00000Y03P0o`0300000000A?l004Co02/004Co00<000000031o`00
`Ol0F@00`Ol00`0000000?o1003o`@0g003o`@D0oooo00<000000?ooo`3o
ool01`3oool008D0oooo0P0000030?ooo`P0]03o00<0000003P0o`0h0?l0
:00h0?l00`00000004Co0014o`0/0014o`0300000000`Ol00<7o05T00<7o
00<00000003o`@00ol40=P00ol440?ooo`8000002@3oool008D0oooo00<0
00000?ooo`3oool00P3oool80;@0o`030000000h0?l0>03o02P0>03o00<0
00000014o`00A?l0;@00A?l00`0000000<7o0031o`1I0031o`0300000000
ol400?o103D00?o11@3oool00`000000oooo0?ooo`070?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooo`L0]03o0P00000Z03P0o`0300000000A?l0
04Co02d004Co00<000000031o`00`Ol0F@00`Ol2000003H00?o11@3oool0
0`000000oooo0?ooo`070?ooo`00Q@3oool00`000000oooo0?ooo`020?oo
o`L0]03o00<0000003P0o`0h0?l0:@0h0?l00`00000004Co0014o`0^0014
o`0300000000`Ol00<7o05T00<7o0P00000e003o`@D0oooo00<000000?oo
o`3oool01`3oool008D0oooo00<000000?ooo`3oool00P3oool70;@0o`03
0000000h0?l0>03o02T0>03o00<000000014o`00A?l0;`00A?l00`000000
0<7o0031o`1I0031o`0300000000ol400?o103<00?o11@3oool00`000000
oooo0?ooo`070?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`H0]03o
00<0000003P0o`0h0?l0:P0h0?l00`00000004Co0014o`0_0014o`030000
0000`Ol00<7o05X00<7o00<00000003o`@00ol40<P00ol450?ooo`030000
003oool0oooo00L0oooo00250?ooo`030000003oool0oooo0080oooo1P2d
0?l00`000000>03o03P0o`0[03P0o`0300000000A?l004Co02l004Co00<0
00000031o`00`Ol0FP00`Ol00`0000000?o1003o`@0a003o`@D0oooo00<0
00000?ooo`3oool01`3oool008D0oooo0P0000030?ooo`D0]03o0P00000]
03P0o`0300000000A?l004Co02l004Co0P00001K0031o`800000<P00ol44
0?ooo`8000002@3oool008D0oooo00<000000?ooo`3oool00P3oool50;@0
o`030000000h0?l0>03o02`0>03o00<000000014o`00A?l0<000A?l00`00
00000<7o0031o`1J0031o`800000<@00ol450?ooo`030000003oool0oooo
00L0oooo00250?ooo`030000003oool0oooo0080oooo1@2d0?l00`000000
>03o03P0o`0/03P0o`0300000000A?l004Co034004Co00<000000031o`00
`Ol0FP00`Ol00`0000000?o1003o`@0_003o`@D0oooo00<000000?ooo`3o
ool01`3oool008D0oooo00<000000?ooo`3oool00P3oool40;@0o`800000
;P0h0?l00`00000004Co0014o`0a0014o`800000G000`Ol00`0000000?o1
003o`@0^003o`@D0oooo00<000000?ooo`3oool01`3oool008D0oooo00<0
00000?ooo`3oool00P3oool40;@0o`030000000h0?l0>03o02d0>03o00<0
00000014o`00A?l0<P00A?l00`0000000<7o0031o`1K0031o`0300000000
ol400?o102d00?o11@3oool00`000000oooo0?ooo`070?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooo`<0]03o0P00000_03P0o`0300000000A?l0
04Co038004Co0P00001L0031o`800000;P00ol450?ooo`030000003oool0
oooo00L0oooo00250?ooo`8000000`3oool30;@0o`030000000h0?l0>03o
02h0>03o00<000000014o`00A?l0<`00A?l00`0000000<7o0031o`1K0031
o`800000;@00ol440?ooo`8000002@3oool008D0oooo00<000000?ooo`3o
ool00P3oool30;@0o`030000000h0?l0>03o02h0>03o00<000000014o`00
A?l0=000A?l00`0000000<7o0031o`1K0031o`0300000000ol400?o102/0
0?o11@3oool00`000000oooo0?ooo`070?ooo`00Q@3oool00`000000oooo
0?ooo`020?ooo`80]03o0P00000`03P0o`0300000000A?l004Co03@004Co
0P00001M0031o`0300000000ol400?o102X00?o11@3oool00`000000oooo
0?ooo`070?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`80]03o00<0
000003P0o`0h0?l0;`0h0?l00`00000004Co0014o`0e0014o`0300000000
`Ol00<7o05`00<7o00<00000003o`@00ol40:@00ol450?ooo`030000003o
ool0oooo00L0oooo001m0?ooo`@00000103oool00`000000oooo0?ooo`02
0?ooo`80]03o00<0000003P0o`0h0?l0;`0h0?l00`00000004Co0014o`0e
0014o`800000G@00`Ol2000002X00?o11@3oool00`000000oooo0?ooo`07
0?ooo`00O@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo00<0]03o0000000h0?l0<@0h0?l00`00000004Co0014o`0f0014
o`0300000000`Ol00<7o05`00<7o0P00000Y003o`@D0oooo00<000000?oo
o`3oool01`3oool007h0oooo00<000000?ooo`3oool0103oool2000000<0
oooo00<0]03o0000000h0?l0<P0h0?l00`00000004Co0014o`0f0014o`03
00000000`Ol00<7o05`00<7o00<00000003o`@00ol409`00ol440?ooo`80
00002@3oool007l0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`00O@3o
ool010000000oooo0?ooo`0000040?ooool000000`0000090?ooo`00OP3o
ool200000?l0oooo4@3oool00?l0ooooT@3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{400, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution. This is a four-value Dirichlet problem in the upper half-plane \
defined by  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  ".  For the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane, the solution in Equation ",
  StyleBox["(11-5)",
    FontColor->RGBColor[0, 0, 1]],
  " becomes  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
          "  ", \(a\_3\ \  + \ \ \(1\/\[Pi]\) \(\[Sum]\+\(k = 1\)\%3\((a\_\(k \
- 1\) - a\_k)\)\ Arg\ \((z - x\_k)\)\)\)}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
        "  ", \(a\_3\ \  + \ \ \(a\_0 - a\_1\)\/\[Pi]\ Arg\ \((z - 
                x\_1)\)\  + \ \ \(a\_1 - a\_2\)\/\[Pi]\ Arg\ \((z - 
                x\_2)\)\  + \ \ \(a\_2 - a\_3\)\/\[Pi]\ Arg\ \((z - 
                x\_3)\)\)}]}]],
  "\n\nHere we have  ",
  Cell[BoxData[
      RowBox[{\(a\_0 = 4\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(a\_1 = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(a\_2 = 3\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(and\ \ a\_3 = 2\)}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(and\ \ x\_3 = 1\)}]]],
  ",  which we substitute into equation for  ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  to obtain  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
          "  ", \(2\  + \ \(\(4 - 1\)\/\[Pi]\) 
              Arg \((z - \((\(-1\))\))\)\  + \ \(\(1 - 3\)\/\[Pi]\) 
              Arg \((z - 0)\)\  + \ \(\(3 - 2\)\/\[Pi]\) Arg \((z - 1)\)\)}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "                 ", \(\(=\)\(\ \ \)\(2\ \  + \ \ \(3\/\[Pi]\) 
              Arg \((z + 1)\)\ \  - \ \ \(2\/\[Pi]\) 
              Arg \((z)\)\ \  + \ \(\(\(\ \)\(1\)\)\/\[Pi]\) 
              Arg \((z - 1)\)\)\), "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        "                 ", \(\(=\)\(\ \ \)\(2\  + \ \(3\/\[Pi]\) 
              Arg \((x + 1 + \[ImaginaryI]\ y)\)\  - \ \(2\/\[Pi]\) 
              Arg \((x + \[ImaginaryI]\ y)\)\  + \(\(\(\ \)\(1\)\)\/\[Pi]\) 
              Arg \((x - 1 + \[ImaginaryI]\ y)\)\)\), "\[IndentingNewLine]"}],
     "\[IndentingNewLine]", 
      RowBox[{
        "                 ", \(\(=\)\(\ \ \)\(2\ \  + \ \ \(3\/\[Pi]\) 
              Arctan \((y\/\(x + 1\))\)\ \  - \ \ \(2\/\[Pi]\) 
              Arctan \((y\/x)\)\ \  + \ \(\(\(\ \)\(1\)\)\/\[Pi]\) 
              Arctan \((y\/\(x - 1\))\)\)\)}]}]],
  "  "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.5",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/dirichletproblemplane/\
DirichletProblemFigures/mat1105.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The  Dirichlet solution for the steady state temperatures. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Revisited Solution 11.6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the boundary values and construct the  Dirichlet sum.", "Text"],

Cell[BoxData[{
    \(\(Clear[a, t, x, y, z, T];\)\ \), "\n", 
    \(\(x\_1\  = \ \(-1\);\)\ \), "\n", 
    \(\(x\_2\  = \ \ 0;\)\ \), "\n", 
    \(\(x\_3\  = \ \ 1;\)\ \), "\n", 
    \(\(a\_0\  = \ \ 4;\)\ \), "\n", 
    \(\(a\_1\  = \ \ 1;\)\ \), "\n", 
    \(\(a\_2\  = \ \ 3;\)\ \), "\n", 
    \(\(a\_3\  = \ \ 2;\)\ \), "\n", 
    \(\(z\  = \ x\  + \ \[ImaginaryI]\ y;\)\ \), "\n", 
    \(\(T[x_, y_] = 
        a\_3 + \(\(a\_0 - a\_1\)\/\[Pi]\) 
            Arg[z - x\_1] + \(\(a\_1 - a\_2\)\/\[Pi]\) 
            Arg[z - x\_2] + \(\(a\_2 - a\_3\)\/\[Pi]\) 
            Arg[z - x\_3];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nFirst use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(cont = Table[k, {k, 1, 4, 1\/4}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ContourPlot[T[x, y], {x, \(-2\), 2}, {y, 0.00001, 2}, 
        Contours \[Rule] cont, PlotPoints \[Rule] 55, 
        AspectRatio \[Rule] 1\/2, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The contours are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[T[x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nThen use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ParametricPlot3D`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot3D[T[x, y], {x, \(-2\), 2}, {y, 0.00001, 1}, 
        PlotPoints \[Rule] {41, 11}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\[Phi][x,y] \>"}, 
        ColorFunction \[Rule] Hue];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nThe function  ",
  Cell[BoxData[
      \(T[x, y] = 
        2 + Arg[\(-1\) + x + \[ImaginaryI]\ y]\/\[Pi] - \(2\ Arg[x + \
\[ImaginaryI]\ y]\)\/\[Pi] + \(3\ Arg[1 + x + \[ImaginaryI]\ y]\)\/\[Pi]\)]],
  "  is harmonic in the upper half-plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  ",  and takes on the desired boundary values."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Revisited Example 11.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the temperature ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " in the upper half-plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  ", where the temperature at points on the boundary satisfies  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", "1"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "    ", "-", "1"}], " ", 
            "\[LessEqual]", " ", "x", " ", "\[LessEqual]", " ", "1"}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{"T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", "0"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          StyleBox["for",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "    ", "|", "x", "|", 
          RowBox[{">", 
            RowBox[{"1", 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00R`3oool40000
03X0oooo1@00000g0?ooo`800000>P3oool5000003T0oooo1000000@0?oo
o`00R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03H0
oooo00@000000?ooo`3oool00000>`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo0140oooo002<0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool0=P3oool010000000oooo0?ooo`00000k0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0403oool008D0
oooo100000040?ooo`030000003oool0oooo03<0oooo100000040?ooo`03
0000003oool0oooo03H0oooo00@000000?ooo`3oool00000>`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00l0oooo002;0?ooo`04
0000003oool0oooo000003`0oooo00<000000?ooo`3oool0=P3oool01000
0000oooo0?ooo`00000k0?ooo`030000003oool0oooo03T0oooo00@00000
0?ooo`3oool00000403oool008`0oooo0P00000l0?ooo`800000>@3oool2
000003/0oooo0P00000l0?ooo`8000004@3oool00?l0ooooU03oool00?l0
ooooU03oool00?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03oool0
0?l0ooooU03oool007h0oooo0P0000050?ooool000000`00000<0?ooo`00
O@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool007d0oooo
00@000000?ooo`3oool00000103oool200000400oooo0P00001j0?ooo`80
0000@03oool2000000`0oooo001m0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P3ooolj0?mM00T00000LP3o05d9000003T0
oed01@3oool00`000000oooo0?ooo`0:0?ooo`00O@3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0080oooo=`3oG@0300000003
0?oc00000000000000@000000P3o0?<2000006h0o`1M0P0000020?l0l`H0
000000<0oo<0000000000000=`3oG@050?ooo`030000003oool0oooo00X0
oooo001n0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooocD0oed0
0`0000020?oc00T000000P3o0?<4000006H0o`1M100000020?l0l`X00000
00@0oo<00000000000000000=03oG@050?ooo`030000003oool0oooo00X0
oooo00250?ooo`030000003oool0oooo0080oooo<`3oG@02000000@0oo<0
00@0000007Ko000000000?lO1@0000000`1f0?l000000?l0l`040?l0l`D0
0000G03o05d5000000D0o`3c00<0000007H0o`1f0?l00`0000001@00ok@0
00000000001fo`00000000@0oo<00P00000b0?mM00D0oooo00<000000?oo
o`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3oool`0?mM00<0
0000103ol`020000000507Ko00000000000000000000ok@00P0000001000
7ol000000000001f0?l2000000L0o`3c1@00001D0?l0G@D000001`3o0?<2
0000000407H0o`0000000000000Oo`80000000D00?nd0000000000000000
07Ko0002000000@0oo<00`00000_0?mM00D0oooo00<000000?ooo`3oool0
2P3oool008D0oooo0P0000030?ooobd0oed00`0000060?oc008000000P1f
o`00200000000?lO00000000ok@00000002do`00000001oo0P00000207H0
o`8000002P3o0?<5000004X0o`1M1@00000:0?l0l`8000000P1f0?l20000
0007000Oo`0000000;Co00000000ok@00000003o7`0200000080M_l000<0
00000?oc003ol`00103ol`03000002`0oed0103oool2000000`0oooo0025
0?ooo`030000003oool0oooo0080oooo:`3oG@03000000L0oo<000D00000
07Ko001fo`00M_l000000002003o7`0500000000ok@00000002do`000000
0P007ol00`000000MP3o07H0o`0207H0o`8000003@3o0?<6000003h0o`1M
1P00000=0?l0l`800000101f0?l02000000001oo000Oo`0000000;Co0000
0000ok@000000P00oal01@000000M_l007Ko001fo`00000000P0oo<00P00
000Z0?mM00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<00000
0?ooo`3oool00P3ooolY0?mM008000002@3ol`000`000000M_l007Ko0002
07Ko000600000000oal00?lO00000000ok@000000P00]?l01000000001oo
000Oo`00000507H0o`8000004@3o0?<600000380o`1M1P00000A0?l0l`<0
0000101f0?l00`00000001oo000Oo`0200000003002do`0000000?nd0080
000000<00?lO0000000000000`1fo`000`000000oo<00?oc00070?oc00<0
00009`3oG@050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000
003oool0oooo0080oooo9P3oG@03000000X0oo<000<0000007Ko001fo`00
0P1fo`000`0000000?lO003o7`0200000005003o]00000000;Co002do`00
00000`007ol00`000000MP3o07H0o`0407H0o`8000005@3o0?<;000001`0
o`1M2`00000E0?l0l`8000001P1f0?l01@00000001oo000Oo`007ol00000
00800;Co00@00000003o]000ok@000000P00oal00`000000M_l007Ko0002
07Ko00030000003ol`00oo<000P0oo<00`00000U0?mM00D0oooo00<00000
0?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3ooolU0?mM
008000002`3ol`02000000@0M_l000@00000003o7`00oal000000P00ok@0
1@0000000;Co002do`00]?l0000000<001oo00<0000007H0o`1f0?l0101f
0?l2000001l0o`3c7000000O0?l0l`8000001P1f0?l01000000001oo000O
o`007ol2000000800;Co00@00000003o]000ok@000000P00oal2000000@0
M_l00P00000:0?oc00800000903oG@050?ooo`030000003oool0oooo00X0
oooo00250?ooo`030000003oool0oooo0080oooo8P3oG@03000000`0oo<0
00<0000007Ko001fo`000`1fo`001@0000000?lO003o7`00oal0000000<0
0?nd00@00000002do`00]?l0000010007ol2000000H0MP3o0`00001D0?l0
l`<000001`1f0?l00`00000001oo000Oo`02000Oo`0300000000]?l00;Co
008000000P00ok@01@0000000?lO003o7`00oal0000000D0M_l000<00000
0?oc003ol`002P3ol`0300000240oed01@3oool00`000000oooo0?ooo`0:
0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooob00oed00P00000>0?oc
00030000001fo`00M_l000<0M_l00P000003003o7`0500000000ok@00?nd
003o]00000000`00]?l00`00000001oo000Oo`02000Oo`030000001f0?l0
MP3o00L0MP3o0P00001@0?l0l`8000002@1f0?l00`00000001oo000Oo`02
000Oo`0500000000]?l00;Co002do`0000000`00ok@00`0000000?lO003o
7`02003o7`030000001fo`00M_l000<0M_l000<000000?oc003ol`00303o
l`02000001l0oed01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool2
000000<0oooo7`3oG@02000000h0oo<000<0000007Ko001fo`00101fo`00
0`0000000?lO003o7`02003o7`0500000000ok@00?nd003o]00000000`00
]?l2000000@001oo0P00000907H0o`<00000BP3o0?<3000000T0MP3o0P00
0005000Oo`0500000000]?l00;Co002do`0000000`00ok@00`0000000?lO
003o7`02003o7`030000001fo`00M_l000@0M_l000<000000?oc003ol`00
303ol`02000001h0oed0103oool2000000`0oooo00250?ooo`030000003o
ool0oooo0080oooo703oG@03000000l0oo<000<0000007Ko001fo`001@1f
o`000`0000000?lO003o7`02003o7`0500000000ok@00?nd003o]0000000
1000]?l00`00000001oo000Oo`03000Oo`030000001f0?l0MP3o00X0MP3o
0P0000160?l0l`800000301f0?l00`00000001oo000Oo`03000Oo`030000
0000]?l00;Co00800;Co00D00000003o]000ok@00?nd00000004003o7`03
0000001fo`00M_l000D0M_l000<000000?oc003ol`003@3ol`03000001/0
oed01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo
0?ooo`020?oooa/0oed00P00000@0?oc008000001P1fo`000`0000000?lO
003o7`03003o7`0500000000ok@00?nd003o]00000001000]?l2000000D0
01oo0P00000<07H0o`@00000?P3o0?<4000000`0MP3o0P000005000Oo`80
00001000]?l01@0000000?nd003o]000ok@0000000D00?lO00<0000007Ko
001fo`00101fo`0200000100oo<00P00000J0?mM00D0oooo00<000000?oo
o`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3ooolI0?mM0080
00004@3ol`02000000L0M_l000<00000003o7`00oal00`00oal00`000000
0?nd003o]002003o]00300000000]?l00;Co00800;Co0P000006000Oo`80
00003P1f0?l3000003P0o`3c0`00000?07H0o`03000000007ol001oo00D0
01oo00<00000002do`00]?l00P00]?l00`0000000?nd003o]002003o]080
00001000oal00`000000M_l007Ko000607Ko00030000003ol`00oo<000l0
oo<00P00000H0?mM00D0oooo00<000000?ooo`3oool02P3oool008D0oooo
00<000000?ooo`3oool00P3ooolG0?mM00<000004@3ol`000`000000M_l0
07Ko000607Ko000300000000oal00?lO00@00?lO00<00000003o]000ok@0
0P00ok@00`0000000;Co002do`03002do`03000000007ol001oo00D001oo
00<0000007H0o`1f0?l03`1f0?l400000300o`3c1@00000@07H0o`030000
00007ol001oo00D001oo00<00000002do`00]?l00`00]?l00`0000000?nd
003o]003003o]00300000000oal00?lO00<00?lO00<0000007Ko001fo`00
1P1fo`000`000000oo<00?oc000?0?oc00<000005P3oG@050?ooo`030000
003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo5P3o
G@0200000180oo<00P00000807Ko000300000000oal00?lO00<00?lO0P00
0004003o]00300000000]?l00;Co00<00;Co0P000007000Oo`8000004`1f
0?l4000002P0o`3c1000000C07H0o`8000001`007ol2000000D00;Co00<0
0000003o]000ok@00`00ok@00`0000000?lO003o7`03003o7`030000001f
o`00M_l000H0M_l00P00000B0?oc008000005@3oG@050?ooo`030000003o
ool0oooo00X0oooo00250?ooo`8000000`3ooolD0?mM008000004`3ol`02
000000P0M_l00P000005003o7`0300000000ok@00?nd00<00?nd0P000005
002do`80000020007ol2000001D0MP3o1`00000J0?l0l`L000005@1f0?l2
000000P001oo0P000005002do`8000001@00ok@00`0000000?lO003o7`03
003o7`800000201fo`02000001<0oo<00`00000B0?mM00@0oooo0P00000<
0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooa80oed00P00000E0?oc
00030000001fo`00M_l000L0M_l000<00000003o7`00oal01000oal00`00
00000?nd003o]004003o]00300000000]?l00;Co00@00;Co00<00000000O
o`007ol020007ol00`000000MP3o07H0o`0I07H0oaX000006`1f0?l00`00
000001oo000Oo`08000Oo`0300000000]?l00;Co00@00;Co00<00000003o
]000ok@01000ok@00`0000000?lO003o7`04003o7`030000001fo`00M_l0
00L0M_l000<000000?oc003ol`00503ol`000`000000oed00?mM000?0?mM
00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3o
ool00P3ooolA0?mM008000005@3ol`000`000000M_l007Ko000807Ko0003
00000000oal00?lO00@00?lO00<00000003o]000ok@01000ok@00`000000
0;Co002do`05002do`03000000007ol001oo00P001oo0P00001<07H0o`80
00002P007ol00`0000000;Co002do`05002do`0300000000ok@00?nd00@0
0?nd00<00000003o7`00oal01000oal00`000000M_l007Ko000807Ko0003
0000003ol`00oo<001@0oo<00P00000?0?mM00D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo00<000000?ooo`3oool00P3oool@0?mM00030000
003ol`00oo<001@0oo<00P00000:07Ko000300000000oal00?lO00@00?lO
00<00000003o]000ok@01@00ok@00`0000000;Co002do`05002do`030000
00007ol001oo00T001oo0P00001807H0o`8000002`007ol00`0000000;Co
002do`05002do`0300000000ok@00?nd00D00?nd00<00000003o7`00oal0
1000oal00`000000M_l007Ko000907Ko00030000003ol`00oo<001@0oo<0
0P00000>0?mM00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<0
00000?ooo`3oool00P3oool=0?mM00<000005`3ol`000`000000M_l007Ko
000807Ko000300000000oal00?lO00H00?lO00<00000003o]000ok@01000
ok@00`0000000;Co002do`05002do`8000002`007ol2000004H0MP3o0P00
000;000Oo`8000001`00]?l00`0000000?nd003o]005003o]00300000000
oal00?lO00D00?lO00<0000007Ko001fo`00201fo`02000001H0oo<00`00
000<0?mM00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<00000
0?ooo`3oool00P3oool<0?mM00800000603ol`000`000000M_l007Ko0009
07Ko000300000000oal00?lO00H00?lO00<00000003o]000ok@01000ok@2
000000L00;Co0P00000<000Oo`<00000@01f0?l3000000`001oo0P000007
002do`8000001`00ok@00`0000000?lO003o7`05003o7`030000001fo`00
M_l000T0M_l000<000000?oc003ol`005P3ol`02000000/0oed01@3oool0
0`000000oooo0?ooo`0:0?ooo`00Q@3oool2000000<0oooo2`3oG@000`00
0000oo<00?oc000G0?oc00030000001fo`00M_l000X0M_l000<00000003o
7`00oal01P00oal00`0000000?nd003o]005003o]00300000000]?l00;Co
00L00;Co00<00000000Oo`007ol030007ol2000003`0MP3o0P00000>000O
o`8000002000]?l00`0000000?nd003o]005003o]00300000000oal00?lO
00H00?lO00<0000007Ko001fo`002P1fo`000`000000oo<00?oc000G0?oc
00030000003oG@00oed000P0oed0103oool2000000`0oooo00250?ooo`03
0000003oool0oooo0080oooo2@3oG@02000001T0oo<00P00000;07Ko0080
00002000oal00`0000000?nd003o]005003o]00300000000]?l00;Co00L0
0;Co0P00000?000Oo`<00000=`1f0?l2000000l001oo0P000009002do`03
00000000ok@00?nd00D00?nd00<00000003o7`00oal01`00oal00`000000
M_l007Ko000907Ko008000006@3ol`02000000P0oed01@3oool00`000000
oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooo`P0oed0
00<000000?oc003ol`006@3ol`000`000000M_l007Ko000:07Ko00030000
0000oal00?lO00L00?lO00<00000003o]000ok@01P00ok@00`0000000;Co
002do`07002do`03000000007ol001oo010001oo0P00000b07H0o`<00000
4@007ol00`0000000;Co002do`07002do`0300000000ok@00?nd00H00?nd
00<00000003o7`00oal01`00oal00`000000M_l007Ko000:07Ko00030000
003ol`00oo<001T0oo<000<000000?mM003oG@001@3oG@050?ooo`030000
003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo1P3o
G@02000001/0oo<00P00000<07Ko000300000000oal00?lO00L00?lO00<0
0000003o]000ok@01P00ok@00`0000000;Co002do`08002do`8000004P00
7ol3000002d0MP3o0P00000B000Oo`8000002P00]?l00`0000000?nd003o
]006003o]00300000000oal00?lO00L00?lO00<0000007Ko001fo`002`1f
o`000`000000oo<00?oc000I0?oc008000001@3oG@050?ooo`030000003o
ool0oooo00X0oooo001b0?ooo`800000103oool2000000@0oooo0P000005
0?ooo`030000003oool0oooo0080oooo1@3oG@02000001/0oo<00P00000=
07Ko000300000000oal00?lO00L00?lO00<00000003o]000ok@01`00ok@0
0`0000000;Co002do`08002do`80000050007ol4000002@0MP3o1@00000C
000Oo`8000002P00]?l00`0000000?nd003o]007003o]00300000000oal0
0?lO00L00?lO00<0000007Ko001fo`002`1fo`02000001/0oo<00P000004
0?mM00D0oooo00<000000?ooo`3oool02P3oool00740oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo0080oooo0`3oG@02000001d0oo<000<0000007Ko001fo`00301f
o`000`0000000?lO003o7`07003o7`0300000000ok@00?nd00L00?nd00<0
0000002do`00]?l02P00]?l00`00000001oo000Oo`0E000Oo`@00000701f
0?l5000001H001oo00<00000002do`00]?l02P00]?l00`0000000?nd003o
]007003o]00300000000oal00?lO00P00?lO00<0000007Ko001fo`002`1f
o`000`000000oo<00?oc000K0?oc008000000P3oG@050?ooo`030000003o
ool0oooo00X0oooo001a0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool00P3oool2000000<0oooo0P3oG@02000001d0oo<00P00
000=07Ko000300000000oal00?lO00P00?lO00<00000003o]000ok@02000
ok@00`0000000;Co002do`0:002do`03000000007ol001oo01P001oo2000
000<07H0o`P000006P007ol00`0000000;Co002do`0:002do`0300000000
ok@00?nd00P00?nd00<00000003o7`00oal02000oal00`000000M_l007Ko
000<07Ko00030000003ol`00oo<001/0oo<00P0000000`3oG@00oooo0?oo
o`020?ooo`800000303oool00740oooo00@000000?ooo`3oool000002@3o
ool2000000D0oooo00<000000?ooo`3oool00P3oool00`3oG@0000000?oc
000N0?oc00030000001fo`00M_l000`0M_l000<00000003o7`00oal02000
oal2000000T00?nd0P00000<002do`03000000007ol001oo01l001oo3000
000Q000Oo`0300000000]?l00;Co00X00;Co0P00000:003o]00300000000
oal00?lO00P00?lO00<0000007Ko001fo`00301fo`000`000000oo<00?oc
000M0?oc00030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3o
ool00740oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo0P00000N0?oc00030000001f
o`00M_l000d0M_l000<00000003o7`00oal02@00oal00`0000000?nd003o
]008003o]00300000000]?l00;Co00/00;Co0P00001:000Oo`8000003@00
]?l00`0000000?nd003o]008003o]00300000000oal00?lO00T00?lO00<0
000007Ko001fo`003@1fo`000`000000oo<00?oc000L0?oc00800000103o
ool00`000000oooo0?ooo`0:0?ooo`00LP3oool2000000X0oooo0`000004
0?ooo`030000003oool0oooo0080oooo7`3ol`02000000l0M_l000<00000
003o7`00oal02@00oal00`0000000?nd003o]009003o]00300000000]?l0
0;Co00`00;Co0P000016000Oo`8000003P00]?l2000000X00?nd00<00000
003o7`00oal02@00oal00`000000M_l007Ko000=07Ko008000007P3ol`05
0?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo
0080oooo7`3ol`000`000000M_l007Ko000>07Ko000300000000oal00?lO
00T00?lO00<00000003o]000ok@02@00ok@00`0000000;Co002do`0=002d
o`800000A0007ol2000000l00;Co00<00000003o]000ok@02@00ok@00`00
00000?lO003o7`09003o7`030000001fo`00M_l000h0M_l000<000000?oc
003ol`00703ol`050?ooo`030000003oool0oooo00X0oooo00250?ooo`03
0000003oool0oooo0080oooo7P3ol`0200000100M_l000<00000003o7`00
oal02@00oal00`0000000?nd003o]00:003o]00300000000]?l00;Co00h0
0;Co0P000010000Oo`8000004000]?l00`0000000?nd003o]00:003o]003
00000000oal00?lO00T00?lO0P00000?07Ko008000007@3ol`050?ooo`03
0000003oool0oooo00X0oooo00250?ooo`8000000`3ooolN0?oc00030000
001fo`00M_l000h0M_l000<00000003o7`00oal02`00oal00`0000000?nd
003o]00:003o]00300000000]?l00;Co00l00;Co00<00000000Oo`007ol0
?0007ol2000001000;Co00<00000003o]000ok@02P00ok@00`0000000?lO
003o7`0;003o7`030000001fo`00M_l000h0M_l000<000000?oc003ol`00
6`3ol`040?ooo`800000303oool008D0oooo00<000000?ooo`3oool00P3o
oolM0?oc00800000401fo`000`0000000?lO003o7`0;003o7`0300000000
ok@00?nd00X00?nd0P00000A002do`800000>P007ol2000001400;Co0P00
000<003o]00300000000oal00?lO00/00?lO00<0000007Ko001fo`003P1f
o`02000001`0oo<01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?oooad0oo<000<0000007Ko001fo`003`1fo`00
0`0000000?lO003o7`0;003o7`0300000000ok@00?nd00/00?nd0P00000B
002do`<00000=0007ol3000001800;Co0P00000=003o]00300000000oal0
0?lO00/00?lO00<0000007Ko001fo`003`1fo`000`000000oo<00?oc000J
0?oc00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?oo
o`3oool00P3ooolL0?oc008000004@1fo`000`0000000?lO003o7`0<003o
7`0300000000ok@00?nd00/00?nd00<00000002do`00]?l04`00]?l20000
030001oo0P00000E002do`0300000000ok@00?nd00`00?nd00<00000003o
7`00oal02`00oal00`000000M_l007Ko000@07Ko00030000003ol`00oo<0
01T0oo<01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000
oooo0?ooo`020?oooa`0oo<000<0000007Ko001fo`00401fo`000`000000
0?lO003o7`0<003o7`0300000000ok@00?nd00`00?nd00<00000002do`00
]?l05000]?l3000002X001oo0`00000F002do`0300000000ok@00?nd00`0
0?nd00<00000003o7`00oal03000oal00`000000M_l007Ko000@07Ko0003
0000003ol`00oo<001T0oo<01@3oool00`000000oooo0?ooo`0:0?ooo`00
Q@3oool00`000000oooo0?ooo`020?oooa/0oo<00P00000B07Ko00030000
0000oal00?lO00`00?lO00<00000003o]000ok@03@00ok@00`0000000;Co
002do`0F002do`<0000090007ol3000001P00;Co00<00000003o]000ok@0
3@00ok@00`0000000?lO003o7`0<003o7`030000001fo`00M_l00100M_l0
0P00000J0?oc00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<0
00000?ooo`3oool00P3ooolK0?oc00030000001fo`00M_l00140M_l000<0
0000003o7`00oal03@00oal00`0000000?nd003o]00=003o]00300000000
]?l00;Co01P00;Co0`00000N000Oo`@000006@00]?l00`0000000?nd003o
]00>003o]00300000000oal00?lO00`00?lO00<0000007Ko001fo`004@1f
o`000`000000oo<00?oc000H0?oc00D0oooo00<000000?ooo`3oool02P3o
ool008D0oooo0P0000030?oooa/0oo<000<0000007Ko001fo`004@1fo`00
0`0000000?lO003o7`0=003o7`0300000000ok@00?nd00d00?nd0P00000L
002do`H000004P007ol6000001`00;Co0P00000?003o]00300000000oal0
0?lO00d00?lO00<0000007Ko001fo`004@1fo`02000001T0oo<0103oool2
000000`0oooo00250?ooo`030000003oool0oooo0080oooo6P3ol`000`00
0000M_l007Ko000B07Ko000300000000oal00?lO00d00?lO00<00000003o
]000ok@03`00ok@00`0000000;Co002do`0O002doa8000008@00]?l00`00
00000?nd003o]00?003o]00300000000oal00?lO00d00?lO00<0000007Ko
001fo`004P1fo`000`000000oo<00?oc000G0?oc00D0oooo00<000000?oo
o`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3ooolJ0?oc0003
0000001fo`00M_l00180M_l000<00000003o7`00oal03P00oal00`000000
0?nd003o]00>003o]0800000DP00]?l2000001000?nd0P00000?003o7`03
0000001fo`00M_l00180M_l000<000000?oc003ol`005`3ol`050?ooo`03
0000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo
6@3ol`02000001@0M_l000<00000003o7`00oal03P00oal00`0000000?nd
003o]00@003o]0800000C`00]?l00`0000000?nd003o]00@003o]0030000
0000oal00?lO00h00?lO00<0000007Ko001fo`004`1fo`000`000000oo<0
0?oc000F0?oc00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<0
00000?ooo`3oool00P3ooolI0?oc00030000001fo`00M_l001<0M_l000<0
0000003o7`00oal03P00oal2000001800?nd0P00001=002do`0300000000
ok@00?nd01000?nd0P00000@003o7`030000001fo`00M_l001<0M_l000<0
00000?oc003ol`005P3ol`050?ooo`030000003oool0oooo00X0oooo0025
0?ooo`030000003oool0oooo0080oooo6@3ol`000`000000M_l007Ko000C
07Ko000300000000oal00?lO00l00?lO00<00000003o]000ok@04@00ok@2
000004X00;Co0P00000C003o]00300000000oal00?lO00l00?lO00<00000
07Ko001fo`004`1fo`02000001L0oo<01@3oool00`000000oooo0?ooo`0:
0?ooo`00Q@3oool2000000<0oooo603ol`000`000000M_l007Ko000D07Ko
000300000000oal00?lO01000?lO00<00000003o]000ok@04P00ok@00`00
00000;Co002do`16002do`0300000000ok@00?nd01800?nd00<00000003o
7`00oal04000oal00`000000M_l007Ko000D07Ko00030000003ol`00oo<0
01D0oo<0103oool2000000`0oooo00250?ooo`030000003oool0oooo0080
oooo603ol`000`000000M_l007Ko000D07Ko000300000000oal00?lO0100
0?lO00<00000003o]000ok@04`00ok@00`0000000;Co002do`14002do`80
00005000ok@00`0000000?lO003o7`0@003o7`030000001fo`00M_l001@0
M_l000<000000?oc003ol`005@3ol`050?ooo`030000003oool0oooo00X0
oooo00250?ooo`030000003oool0oooo0080oooo603ol`000`000000M_l0
07Ko000D07Ko000300000000oal00?lO01400?lO00<00000003o]000ok@0
4`00ok@2000004800;Co0P00000E003o]00300000000oal00?lO01400?lO
00<0000007Ko001fo`00501fo`02000001H0oo<01@3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooaL0oo<000<0
000007Ko001fo`005@1fo`000`0000000?lO003o7`0A003o7`0300000000
ok@00?nd01D00?nd0P00000n002do`<000005P00ok@00`0000000?lO003o
7`0A003o7`030000001fo`00M_l001D0M_l000<000000?oc003ol`00503o
l`050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0
oooo0080oooo5`3ol`000`000000M_l007Ko000F07Ko000300000000oal0
0?lO01400?lO00<00000003o]000ok@05@00ok@3000003/00;Co0P00000G
003o]00300000000oal00?lO01800?lO00<0000007Ko001fo`005@1fo`00
0`000000oo<00?oc000D0?oc00D0oooo00<000000?ooo`3oool02P3oool0
08D0oooo00<000000?ooo`3oool00P3ooolG0?oc00030000001fo`00M_l0
01H0M_l000<00000003o7`00oal04@00oal00`0000000?nd003o]00G003o
]0<00000=`00]?l2000001T00?nd00<00000003o7`00oal04@00oal00`00
0000M_l007Ko000F07Ko00030000003ol`00oo<001@0oo<01@3oool00`00
0000oooo0?ooo`0:0?ooo`00Q@3oool2000000<0oooo5P3ol`02000001P0
M_l000<00000003o7`00oal04P00oal00`0000000?nd003o]00H003o]080
0000=000]?l2000001X00?nd00<00000003o7`00oal04P00oal00`000000
M_l007Ko000G07Ko00030000003ol`00oo<001<0oo<0103oool2000000`0
oooo00250?ooo`030000003oool0oooo0080oooo5P3ol`000`000000M_l0
07Ko000G07Ko000300000000oal00?lO01<00?lO00<00000003o]000ok@0
6@00ok@3000002h00;Co0`00000K003o]00300000000oal00?lO01<00?lO
00<0000007Ko001fo`005`1fo`000`000000oo<00?oc000C0?oc00D0oooo
00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3o
oolF0?oc00030000001fo`00M_l001L0M_l000<00000003o7`00oal05000
oal00`0000000?nd003o]00K003o]0800000:P00]?l3000001`00?nd0P00
000E003o7`030000001fo`00M_l001L0M_l000<000000?oc003ol`004`3o
l`050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0
oooo0080oooo5P3ol`000`000000M_l007Ko000G07Ko000300000000oal0
0?lO01@00?lO00<00000003o]000ok@07@00ok@4000002<00;Co0`00000O
003o]00300000000oal00?lO01@00?lO00<0000007Ko001fo`005`1fo`02
000001@0oo<01@3oool00`000000oooo0?ooo`0:0?ooo`00O@3oool50000
00<0oooo00<000000?ooo`3oool00P3ooolE0?oc00030000001fo`00M_l0
01P0M_l000<00000003o7`00oal05@00oal00`0000000?nd003o]00P003o
]0<000007000]?l4000002400?nd00<00000003o7`00oal05@00oal00`00
0000M_l007Ko000H07Ko00030000003ol`00oo<00180oo<01@3oool00`00
0000oooo0?ooo`0:0?ooo`00O`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo5@3ol`000`000000M_l007Ko000I07Ko0003
00000000oal00?lO01@00?lO0P00000T003o]0D000004P00]?l5000002@0
0?nd0P00000F003o7`8000006P1fo`000`000000oo<00?oc000B0?oc00D0
oooo00<000000?ooo`3oool02P3oool007l0oooo00<000000?ooo`3oool0
0`3oool2000000<0oooo5@3ol`000`000000M_l007Ko000I07Ko00030000
0000oal00?lO01D00?lO0P00000X003o]1800000:000ok@2000001L00?lO
00<0000007Ko001fo`006@1fo`000`000000oo<00?oc000B0?oc00@0oooo
0P00000<0?ooo`00O`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo5@3ol`000`000000M_l007Ko000I07Ko000300000000
oal00?lO01H00?lO00<00000003o]000ok@0H000ok@00`0000000?lO003o
7`0F003o7`030000001fo`00M_l001T0M_l000<000000?oc003ol`004P3o
l`050?ooo`030000003oool0oooo00X0oooo001o0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3ooolD0?oc008000006`1fo`02
000001P00?lO0P00001N003o]08000006@00oal00`000000M_l007Ko000J
07Ko00030000003ol`00oo<00140oo<01@3oool00`000000oooo0?ooo`0:
0?ooo`00OP3oool2000000D0oooo00<000000?ooo`3oool00P3ooolD0?oc
00030000001fo`00M_l001/0M_l000<00000003o7`00oal05`00oal00`00
00000?nd003o]01L003o]00300000000oal00?lO01L00?lO00<0000007Ko
001fo`006`1fo`000`000000oo<00?oc000A0?oc00D0oooo00<000000?oo
o`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3ooolD0?oc0003
0000001fo`00M_l001/0M_l000<00000003o7`00oal06000oal00`000000
0?nd003o]01J003o]00300000000oal00?lO01P00?lO00<0000007Ko001f
o`006`1fo`000`000000oo<00?oc000A0?oc00D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo00<000000?ooo`3oool00P3ooolD0?oc00030000
001fo`00M_l001/0M_l000<00000003o7`00oal06@00oal2000005P00?nd
0P00000K003o7`030000001fo`00M_l001/0M_l000<000000?oc003ol`00
4@3ol`050?ooo`030000003oool0oooo00X0oooo00250?ooo`8000000`3o
oolD0?oc00030000001fo`00M_l001`0M_l000<00000003o7`00oal06@00
oal00`0000000?nd003o]01F003o]00300000000oal00?lO01X00?lO00<0
000007Ko001fo`006`1fo`000`000000oo<00?oc000A0?oc00@0oooo0P00
000<0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooa<0oo<00P00000N
07Ko000300000000oal00?lO01X00?lO0P00001D003o]08000007000oal0
0`000000M_l007Ko000M07Ko00030000003ol`00oo<00100oo<01@3oool0
0`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oo
oa<0oo<000<0000007Ko001fo`007@1fo`000`0000000?lO003o7`0K003o
7`800000DP00ok@2000001d00?lO00<0000007Ko001fo`007@1fo`000`00
0000oo<00?oc000@0?oc00D0oooo00<000000?ooo`3oool02P3oool008D0
oooo00<000000?ooo`3oool00P3ooolC0?oc00030000001fo`00M_l001h0
M_l000<00000003o7`00oal07000oal00`0000000?nd003o]01>003o]003
00000000oal00?lO01d00?lO00<0000007Ko001fo`007@1fo`000`000000
oo<00?oc000@0?oc00D0oooo00<000000?ooo`3oool02P3oool008D0oooo
00<000000?ooo`3oool00P3ooolC0?oc00030000001fo`00M_l001h0M_l0
00<00000003o7`00oal07@00oal00`0000000?nd003o]01<003o]0030000
0000oal00?lO01d00?lO00<0000007Ko001fo`007P1fo`000`000000oo<0
0?oc000@0?oc00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<0
00000?ooo`3oool00P3ooolC0?oc00030000001fo`00M_l001h0M_l000<0
0000003o7`00oal07P00oal2000004X00?nd0P00000P003o7`030000001f
o`00M_l001h0M_l000<000000?oc003ol`00403ol`050?ooo`030000003o
ool0oooo00X0oooo00250?ooo`8000000`3ooolC0?oc00030000001fo`00
M_l001l0M_l000<00000003o7`00oal07P00oal2000004P00?nd0P00000P
003o7`800000801fo`000`000000oo<00?oc000@0?oc00@0oooo0P00000<
0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooa<0oo<000<0000007Ko
001fo`007`1fo`000`0000000?lO003o7`0P003o7`800000A000ok@20000
02800?lO00<0000007Ko001fo`007`1fo`000`000000oo<00?oc000@0?oc
00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3o
ool00P3ooolC0?oc00030000001fo`00M_l00200M_l000<00000003o7`00
oal08000oal3000004400?nd0P00000S003o7`030000001fo`00M_l001l0
M_l000<000000?oc003ol`00403ol`050?ooo`030000003oool0oooo00X0
oooo00250?ooo`030000003oool0oooo0080oooo4`3ol`000`000000M_l0
07Ko000P07Ko000300000000oal00?lO02800?lO0P00000n003o]0800000
9000oal00`000000M_l007Ko000Q07Ko00030000003ol`00oo<000l0oo<0
1@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?oo
o`020?oooa80oo<000<0000007Ko001fo`008@1fo`000`0000000?lO003o
7`0T003o7`800000>P00ok@2000002H00?lO00<0000007Ko001fo`008@1f
o`000`000000oo<00?oc000?0?oc00D0oooo00<000000?ooo`3oool02P3o
ool008D0oooo00<000000?ooo`3oool00P3ooolB0?oc00030000001fo`00
M_l00280M_l000<00000003o7`00oal09@00oal2000003H00?nd0`00000V
003o7`030000001fo`00M_l00280M_l000<000000?oc003ol`003`3ol`05
0?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo
0080oooo4P3ol`000`000000M_l007Ko000R07Ko00800000:000oal30000
03000?nd0`00000X003o7`800000901fo`000`000000oo<00?oc000?0?oc
00D0oooo00<000000?ooo`3oool02P3oool008D0oooo0P0000030?oooa80
oo<000<0000007Ko001fo`008`1fo`000`0000000?lO003o7`0X003o7`<0
0000;@00ok@2000002X00?lO00<0000007Ko001fo`008`1fo`000`000000
oo<00?oc000?0?oc00@0oooo0P00000<0?ooo`00Q@3oool00`000000oooo
0?ooo`020?oooa80oo<000<0000007Ko001fo`008`1fo`02000002`00?lO
0`00000V003o]0@00000:`00oal2000002D0M_l000<000000?oc003ol`00
3`3ol`050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003o
ool0oooo0080oooo4P3ol`000`000000M_l007Ko000T07Ko000300000000
oal00?lO02d00?lO0`00000P003o]0<00000;`00oal00`000000M_l007Ko
000T07Ko00030000003ol`00oo<000l0oo<01@3oool00`000000oooo0?oo
o`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooa80oo<000<00000
07Ko001fo`00901fo`02000003400?lO1@00000F003o]0D00000<@00oal2
000002H0M_l000<000000?oc003ol`003`3ol`050?ooo`030000003oool0
oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo4P3ol`000`00
0000M_l007Ko000U07Ko000300000000oal00?lO03@00?lO5P00000f003o
7`030000001fo`00M_l002D0M_l000<000000?oc003ol`003`3ol`050?oo
o`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080
oooo4P3ol`000`000000M_l007Ko000V07Ko000300000000oal00?lO07h0
0?lO00<0000007Ko001fo`009P1fo`000`000000oo<00?oc000?0?oc00D0
oooo00<000000?ooo`3oool02P3oool008D0oooo0P0000030?oooa80oo<0
00<0000007Ko001fo`009P1fo`02000007h00?lO0P00000X07Ko00030000
003ol`00oo<000l0oo<0103oool2000000`0oooo00250?ooo`030000003o
ool0oooo0080oooo4P3ol`000`000000M_l007Ko000W07Ko000300000000
oal00?lO07`00?lO00<0000007Ko001fo`009`1fo`000`000000oo<00?oc
000?0?oc00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<00000
0?ooo`3oool00P3ooolB0?oc00030000001fo`00M_l002P0M_l000<00000
003o7`00oal0NP00oal2000002T0M_l000<000000?oc003ol`003`3ol`05
0?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo
0080oooo4P3ol`000`000000M_l007Ko000X07Ko00800000NP00oal20000
02X0M_l000<000000?oc003ol`003`3ol`050?ooo`030000003oool0oooo
00X0oooo001a0?ooo`D000000P3oool2000000@0oooo0P0000050?ooo`03
0000003oool0oooo0080oooo4P3ol`000`000000M_l007Ko000Y07Ko0003
00000000oal00?lO07P00?lO00<0000007Ko001fo`00:@1fo`000`000000
oo<00?oc000?0?oc00D0oooo00<000000?ooo`3oool02P3oool007<0oooo
00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0080oooo4P3ol`000`000000M_l007Ko000Z07Ko0003
00000000oal00?lO07H00?lO00<0000007Ko001fo`00:P1fo`000`000000
oo<00?oc000?0?oc00D0oooo00<000000?ooo`3oool02P3oool007<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`800000
0`3ooolC0?oc00030000001fo`00M_l002X0M_l000<00000003o7`00oal0
M000oal00`000000M_l007Ko000[07Ko00030000003ol`00oo<000l0oo<0
103oool2000000`0oooo001c0?ooo`030000003oool0oooo00P0oooo0P00
00050?ooo`030000003oool0oooo0080oooo4`3ol`000`000000M_l007Ko
000Z07Ko00800000M000oal2000002d0M_l000<000000?oc003ol`003`3o
l`050?ooo`030000003oool0oooo00X0oooo001c0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?oooa<0oo<000<0000007Ko001fo`00:`1fo`02000007800?lO0P00000]
07Ko00030000003ol`00oo<00100oo<01@3oool00`000000oooo0?ooo`0:
0?ooo`00LP3oool2000000X0oooo0`0000040?ooo`030000003oool0oooo
0080oooo4`3ol`000`000000M_l007Ko000/07Ko000300000000oal00?lO
07000?lO00<0000007Ko001fo`00;01fo`000`000000oo<00?oc000@0?oc
00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3o
ool00P3ooolC0?oc00030000001fo`00M_l002d0M_l000<00000003o7`00
oal0KP00oal00`000000M_l007Ko000]07Ko00030000003ol`00oo<00100
oo<01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo
0?ooo`020?oooa<0oo<000<0000007Ko001fo`00;P1fo`02000006`00?lO
0P00000`07Ko00030000003ol`00oo<00100oo<01@3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool2000000<0oooo4`3ol`000`000000M_l007Ko
000_07Ko000300000000oal00?lO06X00?lO00<0000007Ko001fo`00;`1f
o`000`000000oo<00?oc000@0?oc00@0oooo0P00000<0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?oooa<0oo<000<0000007Ko001fo`00<01fo`02
000006P00?lO0P00000b07Ko00030000003ol`00oo<00100oo<01@3oool0
0`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oo
oa<0oo<000<0000007Ko001fo`00<@1fo`000`0000000?lO003o7`1V003o
7`030000001fo`00M_l00340M_l000<000000?oc003ol`00403ol`050?oo
o`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080
oooo4`3ol`02000003<0M_l00P00001U003o7`030000001fo`00M_l00380
M_l000<000000?oc003ol`00403ol`050?ooo`030000003oool0oooo00X0
oooo00250?ooo`030000003oool0oooo0080oooo503ol`000`000000M_l0
07Ko000b07Ko00800000HP00oal2000003@0M_l000<000000?oc003ol`00
4@3ol`050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003o
ool0oooo0080oooo503ol`000`000000M_l007Ko000c07Ko00800000H000
oal2000003D0M_l000<000000?oc003ol`004@3ol`050?ooo`030000003o
ool0oooo00X0oooo00250?ooo`8000000`3ooolD0?oc00030000001fo`00
M_l003@0M_l00P00001N003o7`800000=P1fo`000`000000oo<00?oc000A
0?oc00@0oooo0P00000<0?ooo`00Q@3oool00`000000oooo0?ooo`020?oo
oa@0oo<000<0000007Ko001fo`00=P1fo`000`0000000?lO003o7`1J003o
7`030000001fo`00M_l003H0M_l000<000000?oc003ol`004@3ol`050?oo
o`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080
oooo503ol`02000003P0M_l00P00001H003o7`800000>@1fo`000`000000
oo<00?oc000A0?oc00D0oooo00<000000?ooo`3oool02P3oool008D0oooo
00<000000?ooo`3oool00P3ooolE0?oc00030000001fo`00M_l003L0M_l0
0`00001E003o7`800000>@1fo`000`000000oo<00?oc000B0?oc00D0oooo
00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3o
oolE0?oc00030000001fo`00M_l003T0M_l00P00001B003o7`800000>`1f
o`000`000000oo<00?oc000B0?oc00D0oooo00<000000?ooo`3oool02P3o
ool008D0oooo00<000000?ooo`3oool00P3ooolE0?oc00030000001fo`00
M_l003X0M_l00P00001@003o7`800000?01fo`000`000000oo<00?oc000B
0?oc00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?oo
o`3oool00P3ooolE0?oc00030000001fo`00M_l003`0M_l000<00000003o
7`00oal0C000oal00`000000M_l007Ko000l07Ko00030000003ol`00oo<0
0180oo<01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool2000000<0
oooo5P3ol`000`000000M_l007Ko000l07Ko00<00000B000oal3000003h0
M_l00P00000D0?oc00@0oooo0P00000<0?ooo`00Q@3oool00`000000oooo
0?ooo`020?oooaH0oo<000<0000007Ko001fo`00?`1fo`02000004@00?lO
0P00001107Ko00030000003ol`00oo<001<0oo<01@3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooaH0oo<000<0
000007Ko001fo`00@01fo`03000004400?lO0P00001207Ko00030000003o
l`00oo<001<0oo<01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?oooaH0oo<00P00001407Ko00800000?000oal3
000004@0M_l000<000000?oc003ol`004`3ol`050?ooo`030000003oool0
oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo5`3ol`000`00
0000M_l007Ko001407Ko00<00000=`00oal2000004H0M_l000<000000?oc
003ol`00503ol`050?ooo`030000003oool0oooo00X0oooo00250?ooo`03
0000003oool0oooo0080oooo5`3ol`000`000000M_l007Ko001607Ko00<0
0000<P00oal3000004P0M_l000<000000?oc003ol`00503ol`050?ooo`03
0000003oool0oooo00X0oooo00250?ooo`8000000`3ooolG0?oc00800000
BP1fo`03000002`00?lO0`00001;07Ko00030000003ol`00oo<001@0oo<0
103oool2000000`0oooo00250?ooo`030000003oool0oooo0080oooo603o
l`000`000000M_l007Ko001;07Ko00<000009P00oal3000004d0M_l000<0
00000?oc003ol`005@3ol`050?ooo`030000003oool0oooo00X0oooo0025
0?ooo`030000003oool0oooo0080oooo603ol`000`000000M_l007Ko001>
07Ko00D000007000oal500000500M_l000<000000?oc003ol`005@3ol`05
0?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo
0080oooo603ol`000`000000M_l007Ko001C07Ko00T000002P00oal90000
05D0M_l000<000000?oc003ol`005@3ol`050?ooo`030000003oool0oooo
00X0oooo001m0?ooo`@00000103oool00`000000oooo0?ooo`020?oooaT0
oo<000<0000007Ko001fo`00FP1fo`0<000005`0M_l000<000000?oc003o
l`005P3ol`050?ooo`030000003oool0oooo00X0oooo001m0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3ooolI0?oc00030000
001fo`00M_l00<80M_l000<000000?oc003ol`005P3ol`050?ooo`030000
003oool0oooo00X0oooo001n0?ooo`030000003oool0oooo00@0oooo0P00
00030?oooaX0oo<000<0000007Ko001fo`00`@1fo`000`000000oo<00?oc
000F0?oc00@0oooo0P00000<0?ooo`00O`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00X0oooo001m0?ooo`040000003oool0oooo000000@0ooooo`000003
000000`0oooo001n0?ooo`800000o`3ooolD0?ooo`00o`3ooonD0?ooo`00
\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution. Using Equation ",
  StyleBox["(11-12)",
    FontColor->RGBColor[0, 0, 1]],
  ", we obtain  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
        "  ", \(y\/\[Pi]\ \(\[Integral]\_\(-1\)\%1\( 
                  1\/\(\((x - t)\)\^2 + y\^2\)\) \[DifferentialD]t\)\)}]]],
  "\n\nUsing techniques from calculus we have the integration formula  ",
  Cell[BoxData[
      \(\[Integral]\(y\/\(\((x - t)\)\^2 + 
                  y\^2\)\) \[DifferentialD]t\ \  = \ \ Arctan \((y\/\(x - \
t\))\)\)]],
  ".  We obtain the solution as follows \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"T", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
        "  ", \(\(\(\(1\/\[Pi]\) \((Arctan 
                 y\/\(x - t\))\)\)\( | \+\(t = \(\(-1\)\(\ \)\)\)\%\(t - 
                1\)\)\)\ \ \[IndentingNewLine]\[IndentingNewLine]
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \ \)\(\(1\/\[Pi]\) 
              Arctan \((y\/\(x - 1\))\)\ \  - \ \ \(1\/\[Pi]\) 
              Arctan \((y\/\(x + 1\))\)\)\)\)}]]],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Revisited Solution 11.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "The solution is similar to Example 11.7, but the method of solution is \
different.\n\nEnter the function U[t] and use the Poisson integral to \
construct  ",
  Cell[BoxData[
      \(T \((x, y)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[a, t, v, x, y, z, T, U];\)\ \), "\n", 
    \(\(U[t_]\  = \ 1;\)\ \), "\n", 
    \(\(G[t_] = 
        y\/\[Pi]\ \(\[Integral]\(U[t]\/\(\((x - t)\)\^2 + 
                    y\^2\)\) \[DifferentialD]t\);\)\), "\[IndentingNewLine]", \

    \(\(T[x_, y_]\  = \ Apart[Together[G[1] - G[\(-1\)]]];\)\ \), "\n", 
    \(\(v[x_, y_]\  = \ 
        ReplaceAll[T[x, y], 
          ArcTan[z_] \[Rule] \(-ArcTan[1\/z]\)];\)\ \), "\n", 
    \(\(Print["\<  U[t]  =  \>", U[t]];\)\ \ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<T[x,y]  =  \!\(y\/\[Pi]\) \!\(\[Integral]\_\(-1\)\%1\)\!\
\(U[t]\/\(\((x - t)\)\^2 + y\^2\)\)\[DifferentialD]t\>\""];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<T[x,y]  =  \>", T[x, y]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<T[x,y]  =  \>", v[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(cont = Table[k, {k, 0, 1, 1\/10}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[T[x, y], {x, \(-2\), 2}, {y, 0.000001, 2}, 
        Contours \[Rule] cont, PlotPoints \[Rule] 35, 
        AspectRatio \[Rule] 1\/2, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The contours are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[T[x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Then use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[T[x, y], {x, \(-2\), 2}, {y, 0.00001, 1.5}, 
        PlotPoints \[Rule] {41, 16}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\[Phi]\>"}, 
        ColorFunction \[Rule] Hue, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 1.5, 0.5], 
            Range[\(-1\), 3, 0.5]}, ViewPoint \[Rule] {\(-2.5\), \(-3\), 2}, 
        AxesEdge \[Rule] {{\(-1\), \(-1\)}, {\(-1\), \(-1\)}, {1, \
\(-1\)}}];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Therefore, the function  ",
  Cell[BoxData[
      \(T[x, 
          y] = \(1\/\[Pi]\) ArcTan[\(1 - x\)\/y] + \(1\/\[Pi]\) 
            ArcTan[\(1 + x\)\/y]\)]],
  "  is harmonic in the upper half-plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  ",  and takes on the desired boundary values."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the temperature ",
  Cell[BoxData[
      RowBox[{"T", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " in the upper half-plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  ", where the temperature at points on the boundary satisfies  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], 
          "=", \(1 - x\^2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "    ", "-", "1"}], " ", 
            "\[LessEqual]", " ", "x", " ", "\[LessEqual]", " ", "1"}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{"T", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", "0"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "           ", 
        RowBox[{
          StyleBox["for",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "    ", "|", "x", "|", 
          RowBox[{">", 
            RowBox[{"1", 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00R`3oool40000
03X0oooo1@00000g0?ooo`800000>P3oool5000003T0oooo1000000@0?oo
o`00R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03H0
oooo00@000000?ooo`3oool00000>`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo0140oooo002<0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool0=P3oool010000000oooo0?ooo`00000k0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0403oool008D0
oooo100000040?ooo`030000003oool0oooo03<0oooo100000040?ooo`03
0000003oool0oooo03H0oooo00@000000?ooo`3oool00000>`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00l0oooo002;0?ooo`04
0000003oool0oooo000003`0oooo00<000000?ooo`3oool0=P3oool01000
0000oooo0?ooo`00000k0?ooo`030000003oool0oooo03T0oooo00@00000
0?ooo`3oool00000403oool008`0oooo0P00000l0?ooo`800000>@3oool2
000003/0oooo0P00000l0?ooo`8000004@3oool00?l0ooooU03oool00?l0
ooooU03oool00?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03oool0
0?l0ooooU03oool007h0oooo0P0000050?ooool000000`00000<0?ooo`00
O@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool007d0oooo
00@000000?ooo`3oool00000103oool2000004@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000
103oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?oo
o`000000A03oool2000000`0oooo001m0?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00P3ooom00?mn00050000002Yo`00ZOl0
0:Wo000000000`00obh01@0000000?Wo003io`00nOl0000000<002;o00D0
00000;D0o`2e0?l0]@3o000000060?l0LP030000003o0000o`0003h0o`00
00<000000?l0LP3o07800`3o07800`000000]@3o0;D0o`020;D0o`030000
00008_l002;o008002;o00@00000003io`00nOl000000P00obh00`000000
ZOl00:Wo00020:Wo00030000003oOP00ogh003d0ogh01@3oool00`000000
oooo0?ooo`0:0?ooo`00O@3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0080oooo?`3oOP000`000000ZOl00:Wo00020:Wo0005
00000000obh00?l^003o;P0000000`00nOl01@00000002;o000Ro`008_l0
000000@0]@3o00<000000?l0LP3o07800`3o07800`000000o`000?l0000m
0?l000030000003o0780o`1b00@0o`1b00D000000;D0o`2e0?l0]@3o0000
0004000Ro`0500000000nOl00?Wo003io`0000000`00obh00`000000ZOl0
0:Wo00020:Wo00030000003oOP00ogh003`0ogh01@3oool00`000000oooo
0?ooo`0:0?ooo`00OP3oool2000000D0oooo00<000000?ooo`3oool00P3o
ooln0?mn00030000002Yo`00ZOl00080ZOl000<00000003o;P00obh00P00
obh01@0000000?Wo003io`00nOl0000000@002;o00D000000;D0o`2e0?l0
]@3o000000060?l0LP030000003o0000o`0003`0o`0000<000000?l0LP3o
07800`3o07800`000000]@3o0;D0o`020;D0o`03000000008_l002;o0080
02;o00D00000003io`00nOl00?Wo00000003003o;P030000002Yo`00ZOl0
00<0ZOl000<000000?mn003oOP00>`3oOP050?ooo`030000003oool0oooo
00X0oooo00250?ooo`030000003oool0oooo0080oooo?@3oOP000`000000
ZOl00:Wo00030:Wo000300000000obh00?l^00800?l^00D00000003io`00
nOl00?Wo00000004000Ro`030000002e0?l0]@3o0080]@3o00<000000?l0
LP3o0780103o07800`000000o`000?l0000j0?l000030000003o0780o`1b
00@0o`1b00<000000;D0o`2e0?l00P2e0?l00`00000002;o000Ro`02000R
o`0500000000nOl00?Wo003io`0000001000obh00`000000ZOl00:Wo0003
0:Wo00030000003oOP00ogh003X0ogh01@3oool00`000000oooo0?ooo`0:
0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooc`0ogh000<000000:Wo
002Yo`00102Yo`000`0000000?l^003o;P02003o;P0500000000nOl00?Wo
003io`00000010008_l00`000000]@3o0;D0o`030;D0o`030000003o0780
o`1b00<0o`1b00<000000?l0003o0000>@3o00000`000000o`1b0?l0LP04
0?l0LP030000002e0?l0]@3o00<0]@3o00<00000000Ro`008_l00P008_l0
1@0000000?Wo003io`00nOl0000000@00?l^00<000000:Wo002Yo`00102Y
o`000`000000ogh00?mn000i0?mn00D0oooo00<000000?ooo`3oool02P3o
ool008D0oooo0P0000030?oooc/0ogh000<000000:Wo002Yo`00102Yo`00
0`0000000?l^003o;P02003o;P0300000000nOl00?Wo00<00?Wo00<00000
000Ro`008_l00P008_l00`000000]@3o0;D0o`030;D0o`030000003o0780
o`1b00<0o`1b00<000000?l0003o0000>03o00000`000000o`1b0?l0LP03
0?l0LP030000002e0?l0]@3o00<0]@3o00<00000000Ro`008_l00P008_l0
0`0000000?Wo003io`03003io`0300000000obh00?l^00800?l^00<00000
0:Wo002Yo`00102Yo`000`000000ogh00?mn000h0?mn00@0oooo0P00000<
0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooocT0ogh00P0000070:Wo
000300000000obh00?l^00800?l^00<00000003io`00nOl00`00nOl00`00
000002;o000Ro`02000Ro`030000002e0?l0]@3o00@0]@3o00<000000?l0
LP3o07800`3o0782000003H0o`000P0000050?l0LP030000002e0?l0]@3o
00@0]@3o00<00000000Ro`008_l00P008_l00`0000000?Wo003io`03003i
o`0300000000obh00?l^00800?l^00<000000:Wo002Yo`001@2Yo`020000
03P0ogh01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000
oooo0?ooo`020?ooocP0ogh000<000000:Wo002Yo`001P2Yo`000`000000
0?l^003o;P03003o;P0300000000nOl00?Wo00<00?Wo00<00000000Ro`00
8_l00P008_l00`000000]@3o0;D0o`040;D0o`030000003o0780o`1b00D0
o`1b00<000000?l0003o0000<P3o00000`000000o`1b0?l0LP040?l0LP03
0000002e0?l0]@3o00@0]@3o00<00000000Ro`008_l00`008_l00`000000
0?Wo003io`03003io`0300000000obh00?l^00<00?l^00<000000:Wo002Y
o`001P2Yo`000`000000ogh00?mn000e0?mn00D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo00<000000?ooo`3oool00P3ooolf0?mn00800000
2@2Yo`000`0000000?l^003o;P03003o;P0300000000nOl00?Wo00<00?Wo
00<00000000Ro`008_l00`008_l00`000000]@3o0;D0o`040;D0o`030000
003o0780o`1b00D0o`1b0P00000`0?l0008000001`3o07800`000000]@3o
0;D0o`040;D0o`03000000008_l002;o00<002;o00<00000003io`00nOl0
0`00nOl00`0000000?l^003o;P03003o;P030000002Yo`00ZOl000L0ZOl0
0P00000e0?mn00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<0
00000?ooo`3oool00P3ooole0?mn00030000002Yo`00ZOl000P0ZOl000<0
0000003o;P00obh01000obh00`0000000?Wo003io`03003io`0300000000
8_l002;o00<002;o00<000000;D0o`2e0?l0102e0?l00`000000o`1b0?l0
LP070?l0LP030000003o0000o`0002`0o`0000<000000?l0LP3o07801P3o
07800`000000]@3o0;D0o`040;D0o`03000000008_l002;o00@002;o00<0
0000003io`00nOl00`00nOl00`0000000?l^003o;P04003o;P030000002Y
o`00ZOl000P0ZOl000<000000?mn003oOP00<P3oOP050?ooo`030000003o
ool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo=03oOP00
0`000000ZOl00:Wo00090:Wo000300000000obh00?l^00@00?l^00<00000
003io`00nOl00`00nOl00`00000002;o000Ro`04000Ro`030000002e0?l0
]@3o00@0]@3o00<000000?l0LP3o07801`3o07800`000000o`000?l0000Z
0?l000030000003o0780o`1b00L0o`1b00<000000;D0o`2e0?l0102e0?l0
0`00000002;o000Ro`04000Ro`0300000000nOl00?Wo00<00?Wo00<00000
003o;P00obh01000obh00`000000ZOl00:Wo00090:Wo00030000003oOP00
ogh00340ogh01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?oooc<0ogh000<000000:Wo002Yo`002@2Yo`000`00
00000?l^003o;P05003o;P0300000000nOl00?Wo00<00?Wo00<00000000R
o`008_l010008_l00`000000]@3o0;D0o`050;D0o`030000003o0780o`1b
00L0o`1b00<000000?l0003o0000:03o00000`000000o`1b0?l0LP070?l0
LP030000002e0?l0]@3o00@0]@3o00<00000000Ro`008_l01@008_l00`00
00000?Wo003io`03003io`0300000000obh00?l^00@00?l^00<000000:Wo
002Yo`002P2Yo`000`000000ogh00?mn000`0?mn00D0oooo00<000000?oo
o`3oool02P3oool008D0oooo0P0000030?oooc80ogh000<000000:Wo002Y
o`002P2Yo`000`0000000?l^003o;P05003o;P0300000000nOl00?Wo00<0
0?Wo00<00000000Ro`008_l01@008_l00`000000]@3o0;D0o`040;D0o`03
0000003o0780o`1b00P0o`1b0P00000V0?l0008000002@3o07800`000000
]@3o0;D0o`050;D0o`03000000008_l002;o00@002;o00<00000003io`00
nOl01000nOl00`0000000?l^003o;P05003o;P030000002Yo`00ZOl000X0
ZOl000<000000?mn003oOP00;`3oOP040?ooo`800000303oool008D0oooo
00<000000?ooo`3oool00P3oool`0?mn00800000302Yo`000`0000000?l^
003o;P06003o;P0300000000nOl00?Wo00@00?Wo00<00000000Ro`008_l0
10008_l00`000000]@3o0;D0o`050;D0o`030000003o0780o`1b00T0o`1b
0P00000R0?l0008000002`3o07800`000000]@3o0;D0o`040;D0o`030000
00008_l002;o00D002;o00<00000003io`00nOl01@00nOl00`0000000?l^
003o;P04003o;P030000002Yo`00ZOl000/0ZOl00P00000_0?mn00D0oooo
00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3o
ool_0?mn00030000002Yo`00ZOl000`0ZOl000<00000003o;P00obh01P00
obh00`0000000?Wo003io`04003io`03000000008_l002;o00D002;o00<0
00000;D0o`2e0?l01@2e0?l2000000/0o`1b00<000000?l0003o00007P3o
00000`000000o`1b0?l0LP090?l0LP8000001`2e0?l00`00000002;o000R
o`05000Ro`0300000000nOl00?Wo00D00?Wo00<00000003o;P00obh01@00
obh00`000000ZOl00:Wo000<0:Wo00030000003oOP00ogh002`0ogh01@3o
ool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`02
0?ooobd0ogh00P00000>0:Wo000300000000obh00?l^00L00?l^00<00000
003io`00nOl01000nOl00`00000002;o000Ro`05000Ro`030000002e0?l0
]@3o00L0]@3o00<000000?l0LP3o07802@3o0783000001X0o`000`00000;
0?l0LP030000002e0?l0]@3o00H0]@3o00<00000000Ro`008_l01P008_l0
0`0000000?Wo003io`05003io`0300000000obh00?l^00H00?l^00<00000
0:Wo002Yo`00302Yo`02000002`0ogh01@3oool00`000000oooo0?ooo`0:
0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooob/0ogh00P00000@0:Wo
000300000000obh00?l^00H00?l^00<00000003io`00nOl01P00nOl00`00
000002;o000Ro`05000Ro`030000002e0?l0]@3o00L0]@3o0P00000<0?l0
LP@000004P3o0004000000`0o`1b0P0000090;D0o`03000000008_l002;o
00D002;o00<00000003io`00nOl01P00nOl00`0000000?l^003o;P06003o
;P030000002Yo`00ZOl000h0ZOl00P00000Z0?mn00D0oooo00<000000?oo
o`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3ooolZ0?mn0003
0000002Yo`00ZOl000l0ZOl000<00000003o;P00obh01`00obh00`000000
0?Wo003io`06003io`03000000008_l002;o00H002;o00<000000;D0o`2e
0?l0202e0?l00`000000o`1b0?l0LP0=0?l0LPP000000`3o0007000000l0
o`1b00<000000;D0o`2e0?l0202e0?l00`00000002;o000Ro`06000Ro`03
00000000nOl00?Wo00H00?Wo00<00000003o;P00obh01`00obh00`000000
ZOl00:Wo000?0:Wo00030000003oOP00ogh002L0ogh01@3oool00`000000
oooo0?ooo`0:0?ooo`00Q@3oool2000000<0oooo:@3oOP000`000000ZOl0
0:Wo000@0:Wo000300000000obh00?l^00L00?l^00<00000003io`00nOl0
1P00nOl00`00000002;o000Ro`06000Ro`030000002e0?l0]@3o00T0]@3o
00<000000?l0LP3o0780503o0783000001D0o`1b00<000000;D0o`2e0?l0
202e0?l00`00000002;o000Ro`07000Ro`0300000000nOl00?Wo00H00?Wo
00<00000003o;P00obh01`00obh00`000000ZOl00:Wo000@0:Wo00030000
003oOP00ogh002H0ogh0103oool2000000`0oooo00250?ooo`030000003o
ool0oooo0080oooo9`3oOP0200000180ZOl000<00000003o;P00obh02000
obh00`0000000?Wo003io`07003io`03000000008_l002;o00H002;o00<0
00000;D0o`2e0?l02@2e0?l00`000000o`1b0?l0LP0Z0?l0LP030000002e
0?l0]@3o00T0]@3o00<00000000Ro`008_l01P008_l00`0000000?Wo003i
o`07003io`0300000000obh00?l^00P00?l^00<000000:Wo002Yo`00402Y
o`02000002H0ogh01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooobH0ogh000<000000:Wo002Yo`004P2Yo`00
0`0000000?l^003o;P08003o;P0300000000nOl00?Wo00L00?Wo00<00000
000Ro`008_l01P008_l00`000000]@3o0;D0o`0:0;D0o`030000003o0780
o`1b02P0o`1b00<000000;D0o`2e0?l02@2e0?l00`00000002;o000Ro`07
000Ro`0300000000nOl00?Wo00L00?Wo00<00000003o;P00obh02000obh0
0`000000ZOl00:Wo000B0:Wo00030000003oOP00ogh002<0ogh01@3oool0
0`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oo
obD0ogh000<000000:Wo002Yo`004`2Yo`000`0000000?l^003o;P08003o
;P0300000000nOl00?Wo00L00?Wo00<00000000Ro`008_l01`008_l00`00
0000]@3o0;D0o`0:0;D0o`<00000903o0783000000`0]@3o00<00000000R
o`008_l01`008_l00`0000000?Wo003io`07003io`0300000000obh00?l^
00T00?l^00<000000:Wo002Yo`004P2Yo`000`000000ogh00?mn000R0?mn
00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3o
ool00P3ooolT0?mn00030000002Yo`00ZOl001<0ZOl000<00000003o;P00
obh02@00obh00`0000000?Wo003io`07003io`03000000008_l002;o00P0
02;o00<000000;D0o`2e0?l0302e0?l200000200o`1b0P00000>0;D0o`03
000000008_l002;o00P002;o00<00000003io`00nOl01`00nOl00`000000
0?l^003o;P09003o;P030000002Yo`00ZOl001<0ZOl000<000000?mn003o
OP008@3oOP050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000
003oool0oooo0080oooo8`3oOP000`000000ZOl00:Wo000D0:Wo00030000
0000obh00?l^00T00?l^00<00000003io`00nOl01`00nOl00`00000002;o
000Ro`09000Ro`030000002e0?l0]@3o00d0]@3o0P00000L0?l0LP800000
3`2e0?l00`00000002;o000Ro`08000Ro`0300000000nOl00?Wo00P00?Wo
00<00000003o;P00obh02@00obh00`000000ZOl00:Wo000D0:Wo00030000
003oOP00ogh00200ogh01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3o
ool2000000<0oooo8P3oOP000`000000ZOl00:Wo000D0:Wo000300000000
obh00?l^00X00?l^00<00000003io`00nOl02000nOl00`00000002;o000R
o`09000Ro`030000002e0?l0]@3o00h0]@3o0P00000H0?l0LP800000402e
0?l00`00000002;o000Ro`09000Ro`0300000000nOl00?Wo00P00?Wo00<0
0000003o;P00obh02P00obh00`000000ZOl00:Wo000D0:Wo00030000003o
OP00ogh001l0ogh0103oool2000000`0oooo00250?ooo`030000003oool0
oooo0080oooo8@3oOP000`000000ZOl00:Wo000E0:Wo000300000000obh0
0?l^00X00?l^00<00000003io`00nOl02000nOl00`00000002;o000Ro`0:
000Ro`030000002e0?l0]@3o00l0]@3o0`00000C0?l0LP8000004@2e0?l0
0`00000002;o000Ro`0:000Ro`0300000000nOl00?Wo00P00?Wo00<00000
003o;P00obh02P00obh00`000000ZOl00:Wo000E0:Wo00030000003oOP00
ogh001h0ogh01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?ooob00ogh000<000000:Wo002Yo`005P2Yo`000`00
00000?l^003o;P0:003o;P0300000000nOl00?Wo00T00?Wo00<00000000R
o`008_l02P008_l00`000000]@3o0;D0o`0A0;D0oa<000004P2e0?l00`00
000002;o000Ro`0:000Ro`0300000000nOl00?Wo00T00?Wo00<00000003o
;P00obh02P00obh00`000000ZOl00:Wo000F0:Wo00030000003oOP00ogh0
01d0ogh01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000
oooo0?ooo`020?oooal0ogh000<000000:Wo002Yo`005P2Yo`000`000000
0?l^003o;P0;003o;P0300000000nOl00?Wo00T00?Wo00<00000000Ro`00
8_l02`008_l2000003D0]@3o00<00000000Ro`008_l02`008_l00`000000
0?Wo003io`09003io`0300000000obh00?l^00/00?l^00<000000:Wo002Y
o`005P2Yo`02000001d0ogh01@3oool00`000000oooo0?ooo`0:0?ooo`00
LP3oool2000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo
0?ooo`020?oooah0ogh000<000000:Wo002Yo`005`2Yo`000`0000000?l^
003o;P0;003o;P0300000000nOl00?Wo00X00?Wo00<00000000Ro`008_l0
30008_l00`000000]@3o0;D0o`0a0;D0o`03000000008_l002;o00/002;o
00<00000003io`00nOl02P00nOl00`0000000?l^003o;P0;003o;P030000
002Yo`00ZOl001P0ZOl000<000000?mn003oOP006P3oOP050?ooo`030000
003oool0oooo00X0oooo001a0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oooad0
ogh000<000000:Wo002Yo`00602Yo`000`0000000?l^003o;P0;003o;P03
00000000nOl00?Wo00X00?Wo00<00000000Ro`008_l03@008_l00`000000
]@3o0;D0o`0^0;D0o`8000003@008_l00`0000000?Wo003io`0;003io`03
00000000obh00?l^00/00?l^00<000000:Wo002Yo`00602Yo`000`000000
ogh00?mn000J0?mn00D0oooo00<000000?ooo`3oool02P3oool00740oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`80
00000`3ooolL0?mn00030000002Yo`00ZOl001P0ZOl000<00000003o;P00
obh03000obh00`0000000?Wo003io`0;003io`03000000008_l002;o00d0
02;o0P00000/0;D0o`8000003`008_l00`0000000?Wo003io`0:003io`03
00000000obh00?l^00`00?l^00<000000:Wo002Yo`006@2Yo`000`000000
ogh00?mn000I0?mn00@0oooo0P00000<0?ooo`00L@3oool010000000oooo
0?ooo`0000090?ooo`8000001@3oool00`000000oooo0?ooo`020?oooa/0
ogh000<000000:Wo002Yo`006@2Yo`000`0000000?l^003o;P0=003o;P03
00000000nOl00?Wo00X00?Wo00<00000000Ro`008_l03`008_l00`000000
]@3o0;D0o`0X0;D0o`03000000008_l002;o00h002;o00<00000003io`00
nOl02`00nOl00`0000000?l^003o;P0=003o;P030000002Yo`00ZOl001T0
ZOl000<000000?mn003oOP00603oOP050?ooo`030000003oool0oooo00X0
oooo001a0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?oooaX0ogh000<000000:Wo002Y
o`006P2Yo`000`0000000?l^003o;P0=003o;P0300000000nOl00?Wo00/0
0?Wo00<00000000Ro`008_l03`008_l00`000000]@3o0;D0o`0V0;D0o`03
000000008_l002;o00l002;o00<00000003io`00nOl02`00nOl00`000000
0?l^003o;P0=003o;P030000002Yo`00ZOl001X0ZOl000<000000?mn003o
OP005`3oOP050?ooo`030000003oool0oooo00X0oooo001b0?ooo`800000
2P3oool3000000@0oooo00<000000?ooo`3oool00P3ooolI0?mn00030000
002Yo`00ZOl001/0ZOl000<00000003o;P00obh03@00obh00`0000000?Wo
003io`0<003io`03000000008_l002;o00l002;o0P00000T0;D0o`800000
4@008_l00`0000000?Wo003io`0<003io`0300000000obh00?l^00d00?l^
00<000000:Wo002Yo`006`2Yo`000`000000ogh00?mn000F0?mn00D0oooo
00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3o
oolH0?mn00030000002Yo`00ZOl001/0ZOl000<00000003o;P00obh03P00
obh00`0000000?Wo003io`0<003io`03000000008_l002;o014002;o0P00
000P0;D0o`8000004`008_l00`0000000?Wo003io`0;003io`0300000000
obh00?l^00h00?l^00<000000:Wo002Yo`006`2Yo`000`000000ogh00?mn
000F0?mn00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<00000
0?ooo`3oool00P3ooolH0?mn00030000002Yo`00ZOl001/0ZOl000<00000
003o;P00obh03`00obh00`0000000?Wo003io`0<003io`03000000008_l0
02;o018002;o0P00000L0;D0o`80000050008_l00`0000000?Wo003io`0<
003io`0300000000obh00?l^00l00?l^00<000000:Wo002Yo`006`2Yo`00
0`000000ogh00?mn000E0?mn00D0oooo00<000000?ooo`3oool02P3oool0
08D0oooo0P0000030?oooaL0ogh000<000000:Wo002Yo`00702Yo`000`00
00000?l^003o;P0?003o;P0300000000nOl00?Wo00d00?Wo00<00000000R
o`008_l04`008_l3000001H0]@3o0`00000E000Ro`0300000000nOl00?Wo
00d00?Wo00<00000003o;P00obh03`00obh00`000000ZOl00:Wo000L0:Wo
00030000003oOP00ogh001@0ogh0103oool2000000`0oooo00250?ooo`03
0000003oool0oooo0080oooo5P3oOP000`000000ZOl00:Wo000M0:Wo0003
00000000obh00?l^00l00?l^00<00000003io`00nOl03P00nOl00`000000
02;o000Ro`0E000Ro`L00000202e0?l7000001L002;o00<00000003io`00
nOl03P00nOl00`0000000?l^003o;P0?003o;P030000002Yo`00ZOl001d0
ZOl00P00000D0?mn00D0oooo00<000000?ooo`3oool02P3oool008D0oooo
00<000000?ooo`3oool00P3ooolE0?mn00030000002Yo`00ZOl001d0ZOl0
00<00000003o;P00obh04@00obh00`0000000?Wo003io`0>003io`030000
00008_l002;o01/002;o2000000M000Ro`0300000000nOl00?Wo00l00?Wo
00<00000003o;P00obh04000obh00`000000ZOl00:Wo000M0:Wo00030000
003oOP00ogh00180ogh01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?oooa@0ogh000<000000:Wo002Yo`007P2Y
o`000`0000000?l^003o;P0A003o;P0300000000nOl00?Wo00l00?Wo00<0
0000000Ro`008_l0?P008_l00`0000000?Wo003io`0@003io`0300000000
obh00?l^01000?l^00<000000:Wo002Yo`007P2Yo`000`000000ogh00?mn
000A0?mn00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<00000
0?ooo`3oool00P3ooolC0?mn00030000002Yo`00ZOl001l0ZOl000<00000
003o;P00obh04@00obh00`0000000?Wo003io`0@003io`03000000008_l0
02;o03`002;o00<00000003io`00nOl04000nOl00`0000000?l^003o;P0A
003o;P030000002Yo`00ZOl001l0ZOl000<000000?mn003oOP00403oOP05
0?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo
0080oooo4P3oOP000`000000ZOl00:Wo000O0:Wo000300000000obh00?l^
01800?l^00<00000003io`00nOl04000nOl00`00000002;o000Ro`0k000R
o`0300000000nOl00?Wo01400?Wo00<00000003o;P00obh04@00obh00`00
0000ZOl00:Wo000O0:Wo00030000003oOP00ogh00100ogh01@3oool00`00
0000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooa80
ogh000<000000:Wo002Yo`007`2Yo`000`0000000?l^003o;P0C003o;P03
00000000nOl00?Wo01000?Wo00<00000000Ro`008_l0>P008_l00`000000
0?Wo003io`0@003io`0300000000obh00?l^01<00?l^00<000000:Wo002Y
o`007`2Yo`000`000000ogh00?mn000?0?mn00D0oooo00<000000?ooo`3o
ool02P3oool008D0oooo0P0000030?oooa40ogh000<000000:Wo002Yo`00
802Yo`000`0000000?l^003o;P0C003o;P0300000000nOl00?Wo01400?Wo
0P00000h000Ro`8000004`00nOl00`0000000?l^003o;P0C003o;P030000
002Yo`00ZOl00200ZOl000<000000?mn003oOP003P3oOP040?ooo`800000
303oool008D0oooo00<000000?ooo`3oool00P3oool@0?mn00030000002Y
o`00ZOl00240ZOl000<00000003o;P00obh04`00obh00`0000000?Wo003i
o`0C003io`03000000008_l002;o03@002;o00<00000003io`00nOl04`00
nOl00`0000000?l^003o;P0C003o;P030000002Yo`00ZOl00240ZOl000<0
00000?mn003oOP003@3oOP050?ooo`030000003oool0oooo00X0oooo0025
0?ooo`030000003oool0oooo0080oooo3`3oOP000`000000ZOl00:Wo000R
0:Wo000300000000obh00?l^01<00?l^00<00000003io`00nOl05000nOl2
0000038002;o0P00000E003io`0300000000obh00?l^01@00?l^00<00000
0:Wo002Yo`008P2Yo`000`000000ogh00?mn000<0?mn00D0oooo00<00000
0?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3oool>0?mn
00030000002Yo`00ZOl002<0ZOl000<00000003o;P00obh05000obh00`00
00000?Wo003io`0E003io`03000000008_l002;o02h002;o00<00000003i
o`00nOl05@00nOl00`0000000?l^003o;P0D003o;P030000002Yo`00ZOl0
02<0ZOl000<000000?mn003oOP002`3oOP050?ooo`030000003oool0oooo
00X0oooo00250?ooo`030000003oool0oooo0080oooo3P3oOP000`000000
ZOl00:Wo000S0:Wo000300000000obh00?l^01@00?l^00<00000003io`00
nOl05P00nOl00`00000002;o000Ro`0/000Ro`0300000000nOl00?Wo01H0
0?Wo00<00000003o;P00obh05000obh00`000000ZOl00:Wo000S0:Wo0003
0000003oOP00ogh000/0ogh01@3oool00`000000oooo0?ooo`0:0?ooo`00
Q@3oool00`000000oooo0?ooo`020?ooo`d0ogh000<000000:Wo002Yo`00
902Yo`000`0000000?l^003o;P0E003o;P0300000000nOl00?Wo01H00?Wo
0`00000X000Ro`<000006000nOl00`0000000?l^003o;P0E003o;P030000
002Yo`00ZOl002@0ZOl000<000000?mn003oOP002P3oOP050?ooo`030000
003oool0oooo00X0oooo00250?ooo`8000000`3oool=0?mn00030000002Y
o`00ZOl002@0ZOl000<00000003o;P00obh05@00obh00`0000000?Wo003i
o`0I003io`80000090008_l2000001/00?Wo00<00000003o;P00obh05@00
obh00`000000ZOl00:Wo000T0:Wo00030000003oOP00ogh000X0ogh0103o
ool2000000`0oooo00250?ooo`030000003oool0oooo0080oooo303oOP00
0`000000ZOl00:Wo000U0:Wo000300000000obh00?l^01H00?l^00<00000
003io`00nOl06P00nOl20000020002;o0P00000L003io`0300000000obh0
0?l^01H00?l^00<000000:Wo002Yo`009@2Yo`000`000000ogh00?mn0009
0?mn00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?oo
o`3oool00P3oool;0?mn00030000002Yo`00ZOl002H0ZOl000<00000003o
;P00obh05P00obh00`0000000?Wo003io`0L003io`<000006P008_l30000
01d00?Wo00<00000003o;P00obh05`00obh00`000000ZOl00:Wo000V0:Wo
00030000003oOP00ogh000P0ogh01@3oool00`000000oooo0?ooo`0:0?oo
o`00Q@3oool00`000000oooo0?ooo`020?ooo`X0ogh000<000000:Wo002Y
o`009`2Yo`000`0000000?l^003o;P0G003o;P0300000000nOl00?Wo01h0
0?Wo1000000B000Ro`@000008000nOl00`0000000?l^003o;P0G003o;P03
0000002Yo`00ZOl002H0ZOl000<000000?mn003oOP00203oOP050?ooo`03
0000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo
2P3oOP000`000000ZOl00:Wo000W0:Wo000300000000obh00?l^01L00?l^
00<00000003io`00nOl08P00nOlB000002<00?Wo00<00000003o;P00obh0
6000obh00`000000ZOl00:Wo000W0:Wo00030000003oOP00ogh000L0ogh0
1@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?oo
o`020?ooo`T0ogh000<000000:Wo002Yo`00:02Yo`000`0000000?l^003o
;P0H003o;P0300000000nOl00?Wo05H00?Wo00<00000003o;P00obh06000
obh00`000000ZOl00:Wo000X0:Wo00030000003oOP00ogh000H0ogh01@3o
ool00`000000oooo0?ooo`0:0?ooo`00Q@3oool2000000<0oooo203oOP00
0`000000ZOl00:Wo000Y0:Wo000300000000obh00?l^01T00?l^00<00000
003io`00nOl0E000nOl00`0000000?l^003o;P0I003o;P030000002Yo`00
ZOl002T0ZOl000<000000?mn003oOP001@3oOP040?ooo`800000303oool0
08D0oooo00<000000?ooo`3oool00P3oool80?mn00030000002Yo`00ZOl0
02T0ZOl000<00000003o;P00obh06P00obh00`0000000?Wo003io`1B003i
o`0300000000obh00?l^01X00?l^00<000000:Wo002Yo`00:@2Yo`000`00
0000ogh00?mn00050?mn00D0oooo00<000000?ooo`3oool02P3oool008D0
oooo00<000000?ooo`3oool00P3oool70?mn00030000002Yo`00ZOl002X0
ZOl000<00000003o;P00obh06`00obh00`0000000?Wo003io`1@003io`03
00000000obh00?l^01/00?l^00<000000:Wo002Yo`00:P2Yo`000`000000
ogh00?mn00040?mn00D0oooo00<000000?ooo`3oool02P3oool008D0oooo
00<000000?ooo`3oool00P3oool70?mn00030000002Yo`00ZOl002X0ZOl0
00<00000003o;P00obh07000obh00`0000000?Wo003io`1>003io`030000
0000obh00?l^01`00?l^00<000000:Wo002Yo`00:P2Yo`000`000000ogh0
0?mn00040?mn00D0oooo00<000000?ooo`3oool02P3oool007d0oooo1@00
00030?ooo`030000003oool0oooo0080oooo1P3oOP000`000000ZOl00:Wo
000[0:Wo000300000000obh00?l^01`00?l^00<00000003io`00nOl0C@00
nOl00`0000000?l^003o;P0M003o;P030000002Yo`00ZOl002/0ZOl000<0
00000?mn003oOP000`3oOP050?ooo`030000003oool0oooo00X0oooo001o
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool6
0?mn00030000002Yo`00ZOl002/0ZOl000<00000003o;P00obh07@00obh0
0`0000000?Wo003io`1<003io`0300000000obh00?l^01d00?l^00<00000
0:Wo002Yo`00:`2Yo`000`000000ogh00?mn00030?mn00D0oooo00<00000
0?ooo`3oool02P3oool007l0oooo00<000000?ooo`3oool00`3oool20000
00<0oooo1@3oOP000`000000ZOl00:Wo000/0:Wo000300000000obh00?l^
01h00?l^00<00000003io`00nOl0BP00nOl00`0000000?l^003o;P0N003o
;P030000002Yo`00ZOl002`0ZOl000<000000?mn003oOP000P3oOP040?oo
o`800000303oool007l0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`@0ogh000<000000:Wo002Yo`00;@2Yo`000`000000
0?l^003o;P0O003o;P0300000000nOl00?Wo04P00?Wo00<00000003o;P00
obh07`00obh00`000000ZOl00:Wo000/0:Wo00030000003oOP00ogh00080
ogh01@3oool00`000000oooo0?ooo`0:0?ooo`00O`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo103oOP000`000000ZOl0
0:Wo000]0:Wo000300000000obh00?l^02000?l^00<00000003io`00nOl0
AP00nOl00`0000000?l^003o;P0O003o;P030000002Yo`00ZOl002h0ZOl0
00@000000?mn003oOP00ogh01@3oool00`000000oooo0?ooo`0:0?ooo`00
OP3oool2000000D0oooo00<000000?ooo`3oool00P3oool30?mn00030000
002Yo`00ZOl002l0ZOl000<00000003o;P00obh07`00obh00`0000000?Wo
003io`15003io`0300000000obh00?l^02000?l^00<000000:Wo002Yo`00
;P2Yo`0010000000ogh00?mn003oOP050?ooo`030000003oool0oooo00X0
oooo00250?ooo`030000003oool0oooo0080oooo0`3oOP000`000000ZOl0
0:Wo000_0:Wo000300000000obh00?l^02000?l^00<00000003io`00nOl0
A000nOl00`0000000?l^003o;P0P003o;P030000002Yo`00ZOl002l0ZOl0
00<000000?mn003oOP001@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?ooo`<0ogh000<000000:Wo002Yo`00;`2Y
o`000`0000000?l^003o;P0Q003o;P800000@P00nOl2000002<00?l^00<0
00000:Wo002Yo`00<02Yo`000`000000ogh00?ooo`040?ooo`030000003o
ool0oooo00X0oooo00250?ooo`8000000`3oool20?mn00030000002Yo`00
ZOl00340ZOl000<00000003o;P00obh08P00obh2000003h00?Wo0P00000U
003o;P030000002Yo`00ZOl00300ZOl000<000000?mn003oool00`3oool2
000000`0oooo00250?ooo`030000003oool0oooo0080oooo0P3oOP000`00
0000ZOl00:Wo000a0:Wo000300000000obh00?l^02@00?l^00<00000003i
o`00nOl0>P00nOl00`0000000?l^003o;P0U003o;P030000002Yo`00ZOl0
0340ZOl000<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?oo
o`00Q@3oool00`000000oooo0?ooo`020?ooo`030?mn00000000ZOl003<0
ZOl000<00000003o;P00obh09@00obh00`0000000?Wo003io`0h003io`03
00000000obh00?l^02H00?l^00<000000:Wo002Yo`00<@2Yo`000`000000
oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00250?ooo`030000
003oool0oooo0080oooo00<0ogh00000002Yo`00<`2Yo`000`0000000?l^
003o;P0V003o;P800000=P00nOl2000002P00?l^00<000000:Wo002Yo`00
<P2Yo`000`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo
00250?ooo`030000003oool0oooo0080oooo00<000000:Wo002Yo`00<`2Y
o`000`0000000?l^003o;P0X003o;P800000<P00nOl2000002X00?l^00<0
00000:Wo002Yo`00<`2Yo`000`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo00<00000
0:Wo002Yo`00<`2Yo`000`0000000?l^003o;P0Z003o;P800000;P00nOl2
000002`00?l^00<000000:Wo002Yo`00<`2Yo`000`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00X0oooo00250?ooo`8000000`3oool00`00
0000ZOl00:Wo000c0:Wo000300000000obh00?l^02`00?l^0P00000Z003i
o`800000;P00obh00`000000ZOl00:Wo000c0:Wo00040000003oool0oooo
0?ooo`800000303oool008D0oooo00<000000?ooo`3oool00P3ooolg0:Wo
000300000000obh00?l^02d00?l^0P00000V003io`800000;`00obh00`00
0000ZOl00:Wo000d0:Wo00D0oooo00<000000?ooo`3oool02P3oool008D0
oooo00<000000?ooo`3oool00P3ooolg0:Wo000300000000obh00?l^02l0
0?l^0P00000R003io`800000<@00obh00`000000ZOl00:Wo000d0:Wo00D0
oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool0
0P3ooolh0:Wo000300000000obh00?l^03000?l^1000000J003io`@00000
<`00obh00`000000ZOl00:Wo000d0:Wo00D0oooo00<000000?ooo`3oool0
2P3oool008D0oooo00<000000?ooo`3oool00P3ooolh0:Wo000300000000
obh00?l^03@00?l^1000000B003io`@00000=P00obh00`000000ZOl00:Wo
000e0:Wo00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<00000
0?ooo`3oool00P3oooli0:Wo000300000000obh00?l^03L00?l^4P00000j
003o;P030000002Yo`00ZOl003D0ZOl01@3oool00`000000oooo0?ooo`0:
0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooocT0ZOl000<00000003o
;P00obh0PP00obh00`000000ZOl00:Wo000f0:Wo00D0oooo00<000000?oo
o`3oool02P3oool008D0oooo0P0000030?ooocT0ZOl000<00000003o;P00
obh0PP00obh00`000000ZOl00:Wo000f0:Wo00@0oooo0P00000<0?ooo`00
Q@3oool00`000000oooo0?ooo`020?ooocX0ZOl000<00000003o;P00obh0
P000obh00`000000ZOl00:Wo000g0:Wo00D0oooo00<000000?ooo`3oool0
2P3oool008D0oooo00<000000?ooo`3oool00P3ooolj0:Wo000300000000
obh00?l^08000?l^00<000000:Wo002Yo`00=`2Yo`050?ooo`030000003o
ool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo>P2Yo`00
0`0000000?l^003o;P20003o;P030000002Yo`00ZOl003L0ZOl01@3oool0
0`000000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oo
ocX0ZOl000<00000003o;P00obh0O`00obh00`000000ZOl00:Wo000h0:Wo
00D0oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3o
ool00P3ooolk0:Wo000300000000obh00?l^07h00?l^00<000000:Wo002Y
o`00>02Yo`050?ooo`030000003oool0oooo00X0oooo00250?ooo`800000
0`3ooolk0:Wo000300000000obh00?l^07d00?l^00<000000:Wo002Yo`00
>@2Yo`040?ooo`800000303oool008D0oooo00<000000?ooo`3oool00P3o
ooll0:Wo000300000000obh00?l^07`00?l^00<000000:Wo002Yo`00>@2Y
o`050?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0
oooo0080oooo?@2Yo`000`0000000?l^003o;P1j003o;P030000002Yo`00
ZOl003X0ZOl01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?ooocd0ZOl000<00000003o;P00obh0NP00obh00`00
0000ZOl00:Wo000j0:Wo00D0oooo00<000000?ooo`3oool02P3oool00740
oooo1@0000020?ooo`800000103oool2000000D0oooo00<000000?ooo`3o
ool00P3oooln0:Wo000300000000obh00?l^07P00?l^00<000000:Wo002Y
o`00>`2Yo`050?ooo`030000003oool0oooo00X0oooo001c0?ooo`030000
003oool0oooo00L0oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`020?ooocl0ZOl000<00000003o;P00obh0MP00obh00`000000
ZOl00:Wo000l0:Wo00D0oooo00<000000?ooo`3oool02P3oool007<0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`800000
0`3ooolo0:Wo000300000000obh00?l^07D00?l^00<000000:Wo002Yo`00
?@2Yo`040?ooo`800000303oool007<0oooo00<000000?ooo`3oool0203o
ool2000000D0oooo00<000000?ooo`3oool00P3ooom00:Wo000300000000
obh00?l^07@00?l^00<000000:Wo002Yo`00?@2Yo`050?ooo`030000003o
ool0oooo00X0oooo001c0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?oood40ZOl000<00000
003o;P00obh0LP00obh00`000000ZOl00:Wo000n0:Wo00D0oooo00<00000
0?ooo`3oool02P3oool00780oooo0P00000:0?ooo`<00000103oool00`00
0000oooo0?ooo`020?oood40ZOl000<00000003o;P00obh0LP00obh00`00
0000ZOl00:Wo000n0:Wo00D0oooo00<000000?ooo`3oool02P3oool008D0
oooo00<000000?ooo`3oool00P3ooom20:Wo000300000000obh00?l^0700
0?l^00<000000:Wo002Yo`00?`2Yo`050?ooo`030000003oool0oooo00X0
oooo00250?ooo`030000003oool0oooo0080oooo@P2Yo`000`0000000?l^
003o;P1`003o;P030000002Yo`00ZOl003l0ZOl01@3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool2000000<0oooo@`2Yo`000`0000000?l^003o
;P1^003o;P030000002Yo`00ZOl00400ZOl0103oool2000000`0oooo0025
0?ooo`030000003oool0oooo0080ooooA02Yo`000`0000000?l^003o;P1/
003o;P030000002Yo`00ZOl00440ZOl01@3oool00`000000oooo0?ooo`0:
0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooodD0ZOl000<00000003o
;P00obh0JP00obh00`000000ZOl00:Wo00120:Wo00D0oooo00<000000?oo
o`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3ooom60:Wo0003
00000000obh00?l^06P00?l^00<000000:Wo002Yo`00@`2Yo`050?ooo`03
0000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080oooo
A`2Yo`02000006L00?l^00<000000:Wo002Yo`00A02Yo`050?ooo`030000
003oool0oooo00X0oooo00250?ooo`030000003oool0oooo0080ooooB@2Y
o`000`0000000?l^003o;P1S003o;P030000002Yo`00ZOl004D0ZOl01@3o
ool00`000000oooo0?ooo`0:0?ooo`00Q@3oool2000000<0ooooB@2Yo`00
0`0000000?l^003o;P1R003o;P030000002Yo`00ZOl004H0ZOl0103oool2
000000`0oooo00250?ooo`030000003oool0oooo0080ooooBP2Yo`000`00
00000?l^003o;P1P003o;P030000002Yo`00ZOl004L0ZOl01@3oool00`00
0000oooo0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?oood/0
ZOl000<00000003o;P00obh0GP00obh00`000000ZOl00:Wo00180:Wo00D0
oooo00<000000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool0
0P3ooom<0:Wo00800000G000obh2000004/0ZOl01@3oool00`000000oooo
0?ooo`0:0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooodh0ZOl000<0
0000003o;P00obh0F000obh00`000000ZOl00:Wo001;0:Wo00D0oooo00<0
00000?ooo`3oool02P3oool008D0oooo00<000000?ooo`3oool00P3ooom?
0:Wo000300000000obh00?l^05H00?l^00<000000:Wo002Yo`00C02Yo`05
0?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo
0080ooooD02Yo`000`0000000?l^003o;P1D003o;P030000002Yo`00ZOl0
04d0ZOl01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool2000000<0
ooooD@2Yo`02000005800?l^0P00001@0:Wo00@0oooo0P00000<0?ooo`00
Q@3oool00`000000oooo0?ooo`020?oooe<0ZOl000<00000003o;P00obh0
CP00obh00`000000ZOl00:Wo001@0:Wo00D0oooo00<000000?ooo`3oool0
2P3oool008D0oooo00<000000?ooo`3oool00P3ooomD0:Wo000300000000
obh00?l^04`00?l^00<000000:Wo002Yo`00D@2Yo`050?ooo`030000003o
ool0oooo00X0oooo00250?ooo`030000003oool0oooo0080ooooE@2Yo`02
000004X00?l^0P00001D0:Wo00D0oooo00<000000?ooo`3oool02P3oool0
08D0oooo00<000000?ooo`3oool00P3ooomG0:Wo000300000000obh00?l^
04H00?l^00<000000:Wo002Yo`00E02Yo`050?ooo`030000003oool0oooo
00X0oooo00250?ooo`030000003oool0oooo0080ooooF02Yo`02000004@0
0?l^0P00001G0:Wo00D0oooo00<000000?ooo`3oool02P3oool008D0oooo
0P0000030?oooeX0ZOl00P000010003o;P800000F@2Yo`040?ooo`800000
303oool008D0oooo00<000000?ooo`3oool00P3ooomL0:Wo00800000?000
obh2000005/0ZOl01@3oool00`000000oooo0?ooo`0:0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?oooeh0ZOl01000000d003o;P@00000G@2Yo`05
0?ooo`030000003oool0oooo00X0oooo00250?ooo`030000003oool0oooo
0080ooooHP2Yo`03000002h00?l^0`00001Q0:Wo00D0oooo00<000000?oo
o`3oool02P3oool007d0oooo100000040?ooo`030000003oool0oooo0080
ooooI@2Yo`03000002P00?l^0`00001T0:Wo00D0oooo00<000000?ooo`3o
ool02P3oool007d0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooofP0ZOl00`00000R003o;P<00000I`2Yo`050?ooo`030000
003oool0oooo00X0oooo001n0?ooo`030000003oool0oooo00@0oooo0P00
00030?ooof/0ZOl00P00000N003o;P800000JP2Yo`040?ooo`800000303o
ool007l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`00O@3oool01000
0000oooo0?ooo`0000040?ooool000000`00000<0?ooo`00OP3oool20000
0?l0oooo503oool00?l0ooooU03oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the function U[t] and use the Poisson integral to construct  ",
  Cell[BoxData[
      \(T \((x, y)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[x, y, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[t, \[Phi]];\)\ \), "\n", 
    \(\(U[t_]\  = \ 1 - t\^2;\)\ \), "\n", 
    \(\(G[t_] = 
        y\/\[Pi]\ \(\[Integral]\(U[t]\/\(\((x - t)\)\^2 + 
                    y\^2\)\) \[DifferentialD]t\);\)\), "\[IndentingNewLine]", \

    \(\(T[x_, y_]\  = \ Apart[Together[G[1] - G[\(-1\)]]];\)\ \), "\n", 
    \(\(v[x_, y_]\  = \ 
        ReplaceAll[T[x, y], 
          ArcTan[z_] \[Rule] \(-ArcTan[1\/z]\)];\)\ \), "\n", 
    \(\(Print["\<  U[t]  =  \>", U[t]];\)\ \ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<T[x,y]  =  \!\(y\/\[Pi]\) \!\(\[Integral]\_\(-1\)\%1\)\!\
\(U[t]\/\(\((x - t)\)\^2 + y\^2\)\)\[DifferentialD]t\>\""];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<T[x,y]  =  \>", T[x, y]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(T[x_, y_] = FullSimplify[T[x, y]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<T[x,y]  =  \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(cont = Table[k, {k, 0, 1, 1\/10}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[T[x, y], {x, \(-2\), 2}, {y, 0.000001, 2}, 
        Contours \[Rule] cont, PlotPoints \[Rule] 35, 
        AspectRatio \[Rule] 1\/2, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The contours are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[T[x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Then use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot3D[T[x, y], {x, \(-2\), 2}, {y, 0.00001, 1.5}, 
        PlotPoints \[Rule] {41, 16}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>", "\<\[Phi]\>"}, 
        ColorFunction \[Rule] Hue, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[0, 1.5, 0.5], 
            Range[\(-1\), 3, 0.5]}, ViewPoint \[Rule] {\(-2.5\), \(-3\), 2}, 
        AxesEdge \[Rule] {{\(-1\), \(-1\)}, {\(-1\), \(-1\)}, {1, \
\(-1\)}}];\)\ \), "\n", 
    \(\(Print["\<T[x,y] = \>", T[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Therefore, the function ",
  Cell[BoxData[
      \(T[x, y]\)]],
  " is harmonic in the upper half-plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  ",  and takes on the desired boundary values."
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Dirichlet Problem",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/DirichletProblemBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Electrostatics",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ElectrostaticsBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Steady State Temperature",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/TemperaturesBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{982, 627},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 345860, 7434}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 121, 2, 33, "Text"],
Cell[2226, 66, 4633, 124, 242, "Text",
  Evaluatable->False],
Cell[6862, 192, 6424, 162, 257, "Text"],
Cell[13289, 356, 995, 28, 74, "Text"],
Cell[14287, 386, 339, 11, 33, "Text"],
Cell[14629, 399, 3930, 103, 266, "Text"],
Cell[18562, 504, 3282, 90, 128, "Text",
  Evaluatable->False],
Cell[21847, 596, 988, 28, 52, "Text"],
Cell[22838, 626, 2455, 74, 93, "Text",
  Evaluatable->False],
Cell[25296, 702, 12988, 216, 163, 12874, 212, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[38287, 920, 1593, 48, 71, "Text"],
Cell[39883, 970, 1921, 56, 131, "Text"],
Cell[41807, 1028, 413, 14, 33, "Text"],

Cell[CellGroupData[{
Cell[42245, 1046, 113, 2, 33, "Text"],
Cell[42361, 1050, 169, 8, 33, "Text"],
Cell[42533, 1060, 126, 3, 33, "Text"],
Cell[42662, 1065, 1638, 32, 378, "Input"],
Cell[44303, 1099, 225, 7, 36, "Text"],
Cell[44531, 1108, 541, 11, 123, "Input"],
Cell[45075, 1121, 189, 6, 36, "Text"],
Cell[45267, 1129, 506, 10, 123, "Input"],
Cell[45776, 1141, 202, 7, 33, "Text",
  Evaluatable->False],
Cell[45981, 1150, 438, 10, 190, "Input"],
Cell[46422, 1162, 137, 5, 33, "Text"],
Cell[46562, 1169, 740, 13, 225, "Input"],
Cell[47305, 1184, 220, 6, 52, "Text"]
}, Closed]],
Cell[47540, 1193, 4404, 124, 104, "Text",
  Evaluatable->False],
Cell[51947, 1319, 29576, 488, 163, 29462, 484, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[81526, 1809, 3097, 88, 191, "Text"],
Cell[84626, 1899, 842, 28, 33, "Text"],

Cell[CellGroupData[{
Cell[85493, 1931, 113, 2, 33, "Text"],
Cell[85609, 1935, 944, 30, 33, "Text"],
Cell[86556, 1967, 1057, 18, 144, "Input"],
Cell[87616, 1987, 107, 3, 33, "Text"],
Cell[87726, 1992, 308, 7, 104, "Input"],
Cell[88037, 2001, 342, 10, 55, "Text",
  Evaluatable->False],
Cell[88382, 2013, 526, 12, 186, "Input"],
Cell[88911, 2027, 137, 5, 33, "Text"],
Cell[89051, 2034, 730, 13, 225, "Input"],
Cell[89784, 2049, 283, 8, 36, "Text"],
Cell[90070, 2059, 134, 5, 33, "Text"],
Cell[90207, 2066, 629, 12, 130, "Input"],
Cell[90839, 2080, 283, 8, 36, "Text"]
}, Closed]],
Cell[91137, 2091, 8705, 226, 104, "Text",
  Evaluatable->False],
Cell[99845, 2319, 24997, 413, 163, 24883, 409, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[124845, 2734, 1537, 36, 256, "Text"],
Cell[126385, 2772, 6883, 191, 289, "Text"],
Cell[133271, 2965, 884, 27, 40, "Text"],

Cell[CellGroupData[{
Cell[134180, 2996, 113, 2, 33, "Text"],
Cell[134296, 3000, 112, 3, 33, "Text"],
Cell[134411, 3005, 1158, 26, 353, "Input"],
Cell[135572, 3033, 86, 2, 33, "Text"],
Cell[135661, 3037, 852, 15, 271, "Input"],
Cell[136516, 3054, 137, 5, 33, "Text"],
Cell[136656, 3061, 732, 13, 225, "Input"],
Cell[137391, 3076, 343, 9, 68, "Text"]
}, Closed]],
Cell[137749, 3088, 6209, 191, 182, "Text"],
Cell[143961, 3281, 1864, 56, 128, "Text"],
Cell[145828, 3339, 4300, 119, 107, "Text"],
Cell[150131, 3460, 3211, 89, 226, "Text"],
Cell[153345, 3551, 632, 20, 33, "Text"],
Cell[153980, 3573, 375, 11, 33, "Text"],
Cell[154358, 3586, 6429, 176, 150, "Text",
  Evaluatable->False],
Cell[160790, 3764, 33777, 557, 163, 33663, 553, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[194570, 4323, 7087, 191, 262, "Text"],
Cell[201660, 4516, 1507, 43, 208, "Text"],
Cell[203170, 4561, 3315, 98, 52, "Text"],

Cell[CellGroupData[{
Cell[206510, 4663, 113, 2, 33, "Text"],
Cell[206626, 4667, 154, 4, 71, "Text"],
Cell[206783, 4673, 625, 13, 186, "Input"],
Cell[207411, 4688, 392, 10, 61, "Text",
  Evaluatable->False],
Cell[207806, 4700, 1408, 26, 438, "Input"],
Cell[209217, 4728, 137, 5, 33, "Text"],
Cell[209357, 4735, 887, 16, 258, "Input"],
Cell[210247, 4753, 339, 10, 36, "Text"],
Cell[210589, 4765, 134, 5, 33, "Text"],
Cell[210726, 4772, 632, 12, 130, "Input"],
Cell[211361, 4786, 339, 10, 36, "Text"]
}, Closed]],
Cell[211715, 4799, 372, 8, 87, "Text"],
Cell[212090, 4809, 7325, 209, 183, "Text",
  Evaluatable->False],
Cell[219418, 5020, 31743, 523, 163, 31629, 519, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[251164, 5545, 5355, 141, 326, "Text"],
Cell[256522, 5688, 385, 11, 33, "Text"],

Cell[CellGroupData[{
Cell[256932, 5703, 122, 2, 33, "Text"],
Cell[257057, 5707, 75, 0, 33, "Text"],
Cell[257135, 5709, 722, 17, 262, "Input"],
Cell[257860, 5728, 142, 5, 52, "Text"],
Cell[258005, 5735, 711, 12, 217, "Input"],
Cell[258719, 5749, 136, 5, 52, "Text"],
Cell[258858, 5756, 492, 9, 110, "Input"],
Cell[259353, 5767, 366, 10, 55, "Text"]
}, Closed]],
Cell[259734, 5780, 4341, 122, 85, "Text",
  Evaluatable->False],
Cell[264078, 5904, 33590, 554, 163, 33476, 550, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[297671, 6460, 1815, 46, 225, "Text"],

Cell[CellGroupData[{
Cell[299511, 6510, 123, 2, 33, "Text"],
Cell[299637, 6514, 239, 7, 71, "Text"],
Cell[299879, 6523, 956, 20, 316, "Input"],
Cell[300838, 6545, 134, 5, 33, "Text"],
Cell[300975, 6552, 698, 12, 217, "Input"],
Cell[301676, 6566, 134, 5, 33, "Text"],
Cell[301813, 6573, 634, 12, 130, "Input"],
Cell[302450, 6587, 324, 10, 38, "Text"]
}, Closed]],
Cell[302789, 6600, 4361, 123, 85, "Text",
  Evaluatable->False],
Cell[307153, 6725, 32955, 543, 163, 32841, 539, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[340133, 7272, 115, 2, 33, "Text"],
Cell[340251, 7276, 150, 5, 33, "Text"],
Cell[340404, 7283, 1077, 22, 356, "Input"],
Cell[341484, 7307, 134, 5, 33, "Text"],
Cell[341621, 7314, 698, 12, 217, "Input"],
Cell[342322, 7328, 134, 5, 33, "Text"],
Cell[342459, 7335, 634, 12, 130, "Input"],
Cell[343096, 7349, 226, 8, 33, "Text"]
}, Closed]],
Cell[343337, 7360, 290, 7, 30, "Text"],
Cell[343630, 7369, 291, 7, 33, "Text"],
Cell[343924, 7378, 286, 7, 33, "Text"],
Cell[344213, 7387, 294, 7, 33, "Text"],
Cell[344510, 7396, 257, 5, 33, "Text"],
Cell[344770, 7403, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

