(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    458092,       9023]*)
(*NotebookOutlinePosition[    459096,       9059]*)
(*  CellTagsIndexPosition[    459019,       9053]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["11.6 Two-Dimensional Electrostatics",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tA two-dimensional electrostatic field is produced by a system of charged \
wires, plates, and cylindrical conductors that are perpendicular to the z \
plane. The wires, plates, and cylinders are assumed to be so long that the \
effects at the ends can be neglected, as mentioned in Section 11.4.  This \
assumption results in an electric field  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["E",
          FontSize->14,
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontSize->14], 
          RowBox[{
            StyleBox["x",
              FontSize->14], 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["y",
              FontSize->14]}], 
          StyleBox[")",
            FontSize->14]}]}]]],
  "  that can be interpreted as the force acting on a unit positive charge \
placed at the point ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"x", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->14,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "y"}], ")"}]]],
  ".  In the study of electrostatics the vector field  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["E",
          FontSize->14,
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontSize->14], 
          RowBox[{
            StyleBox["x",
              FontSize->14], 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["y",
              FontSize->14]}], 
          StyleBox[")",
            FontSize->14]}]}]]],
  "  is shown to be conservative and is derivable from a function  ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]],
    AspectRatioFixed->True],
  ",  called the electrostatic potential, expressed as  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["E",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", " ", 
        RowBox[{
          RowBox[{\(-\ grad\), " ", "\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", " ", 
          RowBox[{
            RowBox[{\(-\ \ \[Phi]\_x\), 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->14,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], " ", "-", " ", 
            RowBox[{"\[ImaginaryI]", "  ", \(\[Phi]\_y\), 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->14,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}]}]}]}]]],
  ".\n\n\tIf we make the additional assumption that there are no charges \
within the domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ",  then Gauss' Law for electrostatic fields implies that the line integral \
of the outward normal component of   ",
  Cell[BoxData[
      RowBox[{
        StyleBox["E",
          FontSize->14,
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontSize->14], 
          RowBox[{
            StyleBox["x",
              FontSize->14], 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["y",
              FontSize->14]}], 
          StyleBox[")",
            FontSize->14]}]}]]],
  "  taken around any small rectangle lying inside ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " is identically zero.  A heuristic argument similar to the one for steady \
state temperatures with  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["T",
          FontSize->14], 
        RowBox[{
          StyleBox["(",
            FontSize->14], 
          RowBox[{
            StyleBox["x",
              FontSize->14], 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["y",
              FontSize->14]}], 
          StyleBox[")",
            FontSize->14]}]}]]],
  "  replaced by   ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{
          StyleBox["(",
            FontSize->14], 
          RowBox[{
            StyleBox["x",
              FontSize->14], 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["y",
              FontSize->14]}], 
          StyleBox[")",
            FontSize->14]}]}]]],
  "  will show that the value of the line integral is  \n\t\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"-", 
          RowBox[{"[", 
            RowBox[{
              RowBox[{\(\[Phi]\_xx\), 
                RowBox[{"(", 
                  RowBox[{"x", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->14,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "y"}], ")"}]}], " ", "+", 
              "  ", 
              RowBox[{\(\[Phi]\_yy\), 
                RowBox[{"(", 
                  RowBox[{"x", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->14,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "y"}], ")"}]}]}], "]"}]}], 
        "\[CapitalDelta]x", " ", "\[CapitalDelta]y"}]]],
  ".  \n\nThis quantity is zero, so we conclude that  ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{
          StyleBox["(",
            FontSize->14], 
          RowBox[{
            StyleBox["x",
              FontSize->14], 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["y",
              FontSize->14]}], 
          StyleBox[")",
            FontSize->14]}]}]]],
  "  is a harmonic function.  If we let  ",
  Cell[BoxData[
      RowBox[{"\[Psi]", 
        RowBox[{
          StyleBox["(",
            FontSize->14], 
          RowBox[{
            StyleBox["x",
              FontSize->14], 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["y",
              FontSize->14]}], 
          StyleBox[")",
            FontSize->14]}]}]]],
  "  be the harmonic conjugate, then  \n\n\t\t\t  ",
  Cell[BoxData[
      RowBox[{\(F \((z)\)\), "  ", "=", "  ", 
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "+", "  ", 
          RowBox[{"\[ImaginaryI]", " ", "\[Psi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  " \n\nis the complex potential (not to be confused with the electrostatic \
potential).\n\nThe curves  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Phi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", \(K\_1\)}]]],
  "  are called the equipotential curves, and the curves  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", \(K\_2\)}]]],
  "  are called the lines of flux.  If a small test charge is allowed to move \
under the influence of the field   ",
  Cell[BoxData[
      RowBox[{
        StyleBox["E",
          FontSize->14,
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox["(",
            FontSize->14], 
          RowBox[{
            StyleBox["x",
              FontSize->14], 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["y",
              FontSize->14]}], 
          StyleBox[")",
            FontSize->14]}]}]]],
  ",  then it will travel along a line of flux.  Boundary value problems for \
the potential function ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " are mathematically the same as those for steady state heat flow, and they \
are realizations of the Dirichlet problem where the harmonic function is ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 11.18.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider two parallel conducting planes that pass perpendicular to the \
",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane through the lines  ",
  Cell[BoxData[
      \(x = \(a\ \ and\ \ x = b\)\)]],
  ",  which are kept at the potentials  ",
  Cell[BoxData[
      StyleBox[\(U\_1\),
        FontSize->14]]],
  " and ",
  Cell[BoxData[
      \(U\_2\)]],
  ", respectively.  Then according to the result of Example 11.1, the \
electrical potential is \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Phi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
        "  ", \(U\_1\ \  + \ \ \(\(U\_2\  - \ 
                  U\_1\)\/\(b\ \  - \ \ a\)\) \((x - a)\)\)}]],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000490000Vb000`400?l0
0000o`00003oo`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00
o`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?oo
o`00o`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00P`3oool5
000001D0oooo0P0000040?ooo`800000103oool2000001@0oooo0P00000G
0?ooo`800000103oool2000000@0oooo0P00000F0?ooo`D00000203oool0
08D0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000180oooo00@000000?ooo`3oool00000
5@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
01L0oooo00<000000?ooo`3oool0203oool008D0oooo00<000000?ooo`3o
ool0503oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo
0100oooo00@000000?ooo`3oool000005@3oool010000000oooo0?ooo`00
000;0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0203o
ool007d0oooo100000040?ooo`030000003oool0oooo00h0oooo10000002
0?ooo`040000003oool0oooo000000T0oooo0P00000C0?ooo`040000003o
ool0oooo000001D0oooo00@000000?ooo`3oool000002@3oool2000001P0
oooo00<000000?ooo`3oool0203oool008D0oooo00<000000?ooo`3oool0
503oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0180
oooo00@000000?ooo`3oool000005@3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0203oool0
08@0oooo0P00000G0?ooo`8000002P3oool3000001<0oooo0P00000G0?oo
o`8000002P3oool3000001H0oooo0P00000:0?ooo`00o`3oool:0?ooo`00
o`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00NP3oool20000
00<0ooooPP0000080?ooo`00N@3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000001h0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`000000203oool007T0oooo00@000000?ooo`3oool000000P3oool2
000000030?ooo`000000oooo00X0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00X0oooo0`0000080?ooo`00N@3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000/0o`1M00<0
00000?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`0300000000
7ol001oo00T001oo00<00000002do`00]?l02P00]?l00`0000000?nd003o
]009003o]00300000000oal00?lO00T00?lO00<0000007Ko001fo`002P1f
o`000`000000oo<00?oc00090?oc00030000003oG@00oed000X0oed000<0
00000?ooo`000000203oool007T0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000;0?l0G@030000003o0?<0o`3c00T0o`3c
00<0000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`09000Oo`030000
0000]?l00;Co00X00;Co00<00000003o]000ok@02@00ok@00`0000000?lO
003o7`09003o7`030000001fo`00M_l000X0M_l000<000000?oc003ol`00
2@3ol`000`000000oed00?mM000:0?mM00030000003oool0000000P0oooo
001j0?ooo`8000000`3oool010000000oooo0?ooo`00000;0?l0G@030000
003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l00`00000001oo
000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<00000003o]000ok@0
2@00ok@00`0000000?lO003o7`09003o7`030000001fo`00M_l000X0M_l0
00<000000?oc003ol`002@3ol`000`000000oed00?mM000:0?mM00030000
003oool0000000P0oooo001o0?ooo`040000003oool0oooo000000/0o`1M
00<000000?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`030000
00007ol001oo00T001oo00<00000002do`00]?l02P00]?l00`0000000?nd
003o]009003o]00300000000oal00?lO00T00?lO00<0000007Ko001fo`00
2P1fo`000`000000oo<00?oc00090?oc00030000003oG@00oed000X0oed0
00<000000?ooo`000000203oool007l0oooo00@000000?ooo`3oool00000
2`3o05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0MP3o
00<00000000Oo`007ol02@007ol00`0000000;Co002do`0:002do`030000
0000ok@00?nd00T00?nd00<00000003o7`00oal02@00oal00`000000M_l0
07Ko000:07Ko00030000003ol`00oo<000T0oo<000<000000?mM003oG@00
2P3oG@000`000000oooo000000080?ooo`00O`3oool010000000oooo0?oo
o`00000;0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l0
2P1f0?l00`00000001oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co
00<00000003o]000ok@02@00ok@00`0000000?lO003o7`09003o7`030000
001fo`00M_l000X0M_l000<000000?oc003ol`002@3ol`000`000000oed0
0?mM000:0?mM00030000003oool0000000P0oooo001o0?ooo`80000000<0
oooo0000003o05d02P3o05d00`000000o`3c0?l0l`090?l0l`030000001f
0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol00`0000000;Co002d
o`0:002do`0300000000ok@00?nd00T00?nd00<00000003o7`00oal02@00
oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<000T0oo<000<0
00000?mM003oG@002P3oG@03000000P0oooo001o0?ooo`040000003oool0
oooo000000/0o`1M00<000000?l0l`3o0?<02@3o0?<00`000000MP3o07H0
o`0:07H0o`03000000007ol001oo00T001oo00<00000002do`00]?l02P00
]?l00`0000000?nd003o]009003o]00300000000oal00?lO00T00?lO00<0
000007Ko001fo`002P1fo`000`000000oo<00?oc00090?oc00030000003o
G@00oed000X0oed000<000000?ooo`000000203oool007l0oooo00@00000
0?ooo`3oool000002`3o05d00`000000o`3c0?l0l`090?l0l`030000001f
0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol00`0000000;Co002d
o`0:002do`0300000000ok@00?nd00T00?nd00<00000003o7`00oal02@00
oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<000T0oo<000<0
00000?mM003oG@002P3oG@000`000000oooo000000080?ooo`00O`3oool0
10000000oooo0?ooo`00000;0?l0G@030000003o0?<0o`3c00T0o`3c00<0
000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`09000Oo`0300000000
]?l00;Co00X00;Co00<00000003o]000ok@02@00ok@00`0000000?lO003o
7`09003o7`030000001fo`00M_l000X0M_l000<000000?oc003ol`002@3o
l`000`000000oed00?mM000:0?mM00030000003oool0000000P0oooo001o
0?ooo`040000003oool0oooo000000/0o`1M00<000000?l0l`3o0?<02@3o
0?<00`000000MP3o07H0o`0:07H0o`03000000007ol001oo00T001oo00<0
0000002do`00]?l02P00]?l00`0000000?nd003o]009003o]00300000000
oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`000`000000oo<00?oc
00090?oc00030000003oG@00oed000X0oed000<000000?ooo`000000203o
ool007l0oooo00@000000?ooo`3oool000002`3o05d00`000000o`3c0?l0
l`090?l0l`030000001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@00
7ol00`0000000;Co002do`0:002do`0300000000ok@00?nd00T00?nd00<0
0000003o7`00oal02@00oal00`000000M_l007Ko000:07Ko00030000003o
l`00oo<000T0oo<000<000000?mM003oG@002P3oG@000`000000oooo0000
00080?ooo`00O`3oool2000000030?ooo`000000o`1M00X0o`1M00<00000
0?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`03000000007ol0
01oo00T001oo00<00000002do`00]?l02P00]?l00`0000000?nd003o]009
003o]00300000000oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`00
0`000000oo<00?oc00090?oc00030000003oG@00oed000X0oed00`000008
0?ooo`00O`3oool010000000oooo0?ooo`00000;0?l0G@030000003o0?<0
o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`09
000Oo`0300000000]?l00;Co00X00;Co00<00000003o]000ok@02@00ok@0
0`0000000?lO003o7`09003o7`030000001fo`00M_l000X0M_l000<00000
0?oc003ol`002@3ol`000`000000oed00?mM000:0?mM00030000003oool0
000000P0oooo001o0?ooo`040000003oool0oooo000000/0o`1M00<00000
0?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`03000000007ol0
01oo00T001oo00<00000002do`00]?l02P00]?l00`0000000?nd003o]009
003o]00300000000oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`00
0`000000oo<00?oc00090?oc00030000003oG@00oed000X0oed000<00000
0?ooo`000000203oool007l0oooo00@000000?ooo`3oool000002`3o05d0
0`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0MP3o00<00000
000Oo`007ol02@007ol00`0000000;Co002do`0:002do`0300000000ok@0
0?nd00T00?nd00<00000003o7`00oal02@00oal00`000000M_l007Ko000:
07Ko00030000003ol`00oo<000T0oo<000<000000?mM003oG@002P3oG@00
0`000000oooo000000080?ooo`00O`3oool010000000oooo0?ooo`00000;
0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l0
0`00000001oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<00000
003o]000ok@02@00ok@00`0000000?lO003o7`09003o7`030000001fo`00
M_l000X0M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM000:
0?mM00030000003oool0000000P0oooo001o0?ooo`040000003oool0oooo
000000/0o`1M00<000000?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:
07H0o`03000000007ol001oo00T001oo00<00000002do`00]?l02P00]?l0
0`0000000?nd003o]009003o]00300000000oal00?lO00T00?lO00<00000
07Ko001fo`002P1fo`000`000000oo<00?oc00090?oc00030000003oG@00
oed000X0oed000<000000?ooo`000000203oool007l0oooo0P0000000`3o
ool000000?l0G@0:0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0
o`1f0?l02P1f0?l00`00000001oo000Oo`09000Oo`0300000000]?l00;Co
00X00;Co00<00000003o]000ok@02@00ok@00`0000000?lO003o7`09003o
7`030000001fo`00M_l000X0M_l000<000000?oc003ol`002@3ol`000`00
0000oed00?mM000:0?mM00<00000203oool007l0oooo00@000000?ooo`3o
ool000002`3o05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o
00X0MP3o00<00000000Oo`007ol02@007ol00`0000000;Co002do`0:002d
o`0300000000ok@00?nd00T00?nd00<00000003o7`00oal02@00oal00`00
0000M_l007Ko000:07Ko00030000003ol`00oo<000T0oo<000<000000?mM
003oG@002P3oG@000`000000oooo000000080?ooo`00O`3oool010000000
oooo0?ooo`00000;0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0
o`1f0?l02P1f0?l00`00000001oo000Oo`09000Oo`0300000000]?l00;Co
00X00;Co00<00000003o]000ok@02@00ok@00`0000000?lO003o7`09003o
7`030000001fo`00M_l000X0M_l000<000000?oc003ol`002@3ol`000`00
0000oed00?mM000:0?mM00030000003oool0000000P0oooo001o0?ooo`04
0000003oool0oooo000000/0o`1M00<000000?l0l`3o0?<02@3o0?<00`00
0000MP3o07H0o`0:07H0o`03000000007ol001oo00T001oo00<00000002d
o`00]?l02P00]?l00`0000000?nd003o]009003o]00300000000oal00?lO
00T00?lO00<0000007Ko001fo`002P1fo`000`000000oo<00?oc00090?oc
00030000003oG@00oed000X0oed000<000000?ooo`000000203oool007l0
oooo00@000000?ooo`3oool000002`3o05d00`000000o`3c0?l0l`090?l0
l`030000001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol00`00
00000;Co002do`0:002do`0300000000ok@00?nd00T00?nd00<00000003o
7`00oal02@00oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<0
00T0oo<000<000000?mM003oG@002P3oG@000`000000oooo000000080?oo
o`00O`3oool010000000oooo0?ooo`00000;0?l0G@030000003o0?<0o`3c
00T0o`3c00<0000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`09000O
o`0300000000]?l00;Co00X00;Co00<00000003o]000ok@02@00ok@00`00
00000?lO003o7`09003o7`030000001fo`00M_l000X0M_l000<000000?oc
003ol`002@3ol`000`000000oed00?mM000:0?mM00030000003oool00000
00P0oooo001o0?ooo`80000000<0oooo0000003o05d02P3o05d00`000000
o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0MP3o00<00000000Oo`00
7ol02@007ol00`0000000;Co002do`0:002do`0300000000ok@00?nd00T0
0?nd00<00000003o7`00oal02@00oal00`000000M_l007Ko000:07Ko0003
0000003ol`00oo<000T0oo<000<000000?mM003oG@002P3oG@03000000P0
oooo001o0?ooo`040000003oool0oooo000000/0o`1M00<000000?l0l`3o
0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`03000000007ol001oo00T0
01oo00<00000002do`00]?l02P00]?l00`0000000?nd003o]009003o]003
00000000oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`000`000000
oo<00?oc00090?oc00030000003oG@00oed000X0oed000<000000?ooo`00
0000203oool007l0oooo00@000000?ooo`3oool000002`3o05d00`000000
o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0MP3o00<00000000Oo`00
7ol02@007ol00`0000000;Co002do`0:002do`0300000000ok@00?nd00T0
0?nd00<00000003o7`00oal02@00oal00`000000M_l007Ko000:07Ko0003
0000003ol`00oo<000T0oo<000<000000?mM003oG@002P3oG@000`000000
oooo000000080?ooo`00O`3oool010000000oooo0?ooo`00000;0?l0G@03
0000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l00`000000
01oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<00000003o]000
ok@02@00ok@00`0000000?lO003o7`09003o7`030000001fo`00M_l000X0
M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM000:0?mM0003
0000003oool0000000P0oooo001^0?ooo`800000103oool2000000@0oooo
0P0000030?ooo`040000003oool0oooo000000/0o`1M00<000000?l0l`3o
0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`03000000007ol001oo00T0
01oo00<00000002do`00]?l02P00]?l00`0000000?nd003o]009003o]003
00000000oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`000`000000
oo<00?oc00090?oc00030000003oG@00oed000X0oed000<000000?ooo`00
0000203oool006d0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000/0o`1M00<00000
0?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`03000000007ol0
01oo00T001oo00<00000002do`00]?l02P00]?l00`0000000?nd003o]009
003o]00300000000oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`00
0`000000oo<00?oc00090?oc00030000003oG@00oed000X0oed000<00000
0?ooo`000000203oool006d0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`02000000030?ooo`000000o`1M00X0o`1M00<00000
0?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`03000000007ol0
01oo00T001oo00<00000002do`00]?l02P00]?l00`0000000?nd003o]009
003o]00300000000oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`00
0`000000oo<00?oc00090?oc00030000003oG@00oed000X0oed00`000008
0?ooo`00K@3oool010000000oooo0?ooo`0000090?ooo`8000000`3oool0
10000000oooo0?ooo`00000;0?l0G@030000003o0?<0o`3c00T0o`3c00<0
000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`09000Oo`0300000000
]?l00;Co00X00;Co00<00000003o]000ok@02@00ok@00`0000000?lO003o
7`09003o7`030000001fo`00M_l000X0M_l000<000000?oc003ol`002@3o
l`000`000000oed00?mM000:0?mM00030000003oool0000000P0oooo001]
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`00000;0?l0G@030000003o0?<0o`3c00T0o`3c
00<0000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`09000Oo`030000
0000]?l00;Co00X00;Co00<00000003o]000ok@02@00ok@00`0000000?lO
003o7`09003o7`030000001fo`00M_l000X0M_l000<000000?oc003ol`00
2@3ol`000`000000oed00?mM000:0?mM00030000003oool0000000P0oooo
001^0?ooo`8000002P3oool300000080oooo00@000000?ooo`3oool00000
2`3o05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0MP3o
00<00000000Oo`007ol02@007ol00`0000000;Co002do`0:002do`030000
0000ok@00?nd00T00?nd00<00000003o7`00oal02@00oal00`000000M_l0
07Ko000:07Ko00030000003ol`00oo<000T0oo<000<000000?mM003oG@00
2P3oG@000`000000oooo000000080?ooo`00O`3oool010000000oooo0?oo
o`00000;0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l0
2P1f0?l00`00000001oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co
00<00000003o]000ok@02@00ok@00`0000000?lO003o7`09003o7`030000
001fo`00M_l000X0M_l000<000000?oc003ol`002@3ol`000`000000oed0
0?mM000:0?mM00030000003oool0000000P0oooo001o0?ooo`040000003o
ool0oooo000000/0o`1M00<000000?l0l`3o0?<02@3o0?<00`000000MP3o
07H0o`0:07H0o`03000000007ol001oo00T001oo00<00000002do`00]?l0
2P00]?l00`0000000?nd003o]009003o]00300000000oal00?lO00T00?lO
00<0000007Ko001fo`002P1fo`000`000000oo<00?oc00090?oc00030000
003oG@00oed000X0oed000<000000?ooo`000000203oool007l0oooo00@0
00000?ooo`3oool000002`3o05d00`000000o`3c0?l0l`090?l0l`030000
001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol00`0000000;Co
002do`0:002do`0300000000ok@00?nd00T00?nd00<00000003o7`00oal0
2@00oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<000T0oo<0
00<000000?mM003oG@002P3oG@000`000000oooo000000080?ooo`00O`3o
ool2000000030?ooo`000000o`1M00X0o`1M00<000000?l0l`3o0?<02@3o
0?<00`000000MP3o07H0o`0:07H0o`03000000007ol001oo00T001oo00<0
0000002do`00]?l02P00]?l00`0000000?nd003o]009003o]00300000000
oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`000`000000oo<00?oc
00090?oc00030000003oG@00oed000X0oed00`0000080?ooo`00O`3oool0
10000000oooo0?ooo`00000;0?l0G@030000003o0?<0o`3c00T0o`3c00<0
000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`09000Oo`0300000000
]?l00;Co00X00;Co00<00000003o]000ok@02@00ok@00`0000000?lO003o
7`09003o7`030000001fo`00M_l000X0M_l000<000000?oc003ol`002@3o
l`000`000000oed00?mM000:0?mM00030000003oool0000000P0oooo001o
0?ooo`040000003oool0oooo000000/0o`1M00<000000?l0l`3o0?<02@3o
0?<00`000000MP3o07H0o`0:07H0o`03000000007ol001oo00T001oo00<0
0000002do`00]?l02P00]?l00`0000000?nd003o]009003o]00300000000
oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`000`000000oo<00?oc
00090?oc00030000003oG@00oed000X0oed000<000000?ooo`000000203o
ool007l0oooo00@000000?ooo`3oool000002`3o05d00`000000o`3c0?l0
l`090?l0l`030000001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@00
7ol00`0000000;Co002do`0:002do`0300000000ok@00?nd00T00?nd00<0
0000003o7`00oal02@00oal00`000000M_l007Ko000:07Ko00030000003o
l`00oo<000T0oo<000<000000?mM003oG@002P3oG@000`000000oooo0000
00080?ooo`00O`3oool010000000oooo0?ooo`00000;0?l0G@030000003o
0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l00`00000001oo000O
o`09000Oo`0300000000]?l00;Co00X00;Co00<00000003o]000ok@02@00
ok@00`0000000?lO003o7`09003o7`030000001fo`00M_l000X0M_l000<0
00000?oc003ol`002@3ol`000`000000oed00?mM000:0?mM00030000003o
ool0000000P0oooo001o0?ooo`040000003oool0oooo000000/0o`1M00<0
00000?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`0300000000
7ol001oo00T001oo00<00000002do`00]?l02P00]?l00`0000000?nd003o
]009003o]00300000000oal00?lO00T00?lO00<0000007Ko001fo`002P1f
o`000`000000oo<00?oc00090?oc00030000003oG@00oed000X0oed000<0
00000?ooo`000000203oool007l0oooo0P0000000`3oool000000?l0G@0:
0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l0
0`00000001oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<00000
003o]000ok@02@00ok@00`0000000?lO003o7`09003o7`030000001fo`00
M_l000X0M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM000:
0?mM00<00000203oool007l0oooo00@000000?ooo`3oool000002`3o05d0
0`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0MP3o00<00000
000Oo`007ol02@007ol00`0000000;Co002do`0:002do`0300000000ok@0
0?nd00T00?nd00<00000003o7`00oal02@00oal00`000000M_l007Ko000:
07Ko00030000003ol`00oo<000T0oo<000<000000?mM003oG@002P3oG@00
0`000000oooo000000080?ooo`00O`3oool010000000oooo0?ooo`00000;
0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l0
0`00000001oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<00000
003o]000ok@02@00ok@00`0000000?lO003o7`09003o7`030000001fo`00
M_l000X0M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM000:
0?mM00030000003oool0000000P0oooo001o0?ooo`040000003oool0oooo
000000/0o`1M00<000000?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:
07H0o`03000000007ol001oo00T001oo00<00000002do`00]?l02P00]?l0
0`0000000?nd003o]009003o]00300000000oal00?lO00T00?lO00<00000
07Ko001fo`002P1fo`000`000000oo<00?oc00090?oc00030000003oG@00
oed000X0oed000<000000?ooo`000000203oool007l0oooo00@000000?oo
o`3oool000002`3o05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0
MP3o00X0MP3o00<00000000Oo`007ol02@007ol00`0000000;Co002do`0:
002do`0300000000ok@00?nd00T00?nd00<00000003o7`00oal02@00oal0
0`000000M_l007Ko000:07Ko00030000003ol`00oo<000T0oo<000<00000
0?mM003oG@002P3oG@000`000000oooo000000080?ooo`00O`3oool01000
0000oooo0?ooo`00000;0?l0G@030000003o0?<0o`3c00T0o`3c00<00000
07H0o`1f0?l02P1f0?l00`00000001oo000Oo`09000Oo`0300000000]?l0
0;Co00X00;Co00<00000003o]000ok@02@00ok@00`0000000?lO003o7`09
003o7`030000001fo`00M_l000X0M_l000<000000?oc003ol`002@3ol`00
0`000000oed00?mM000:0?mM00030000003oool0000000P0oooo001o0?oo
o`80000000<0oooo0000003o05d02P3o05d00`000000o`3c0?l0l`090?l0
l`030000001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol00`00
00000;Co002do`0:002do`0300000000ok@00?nd00T00?nd00<00000003o
7`00oal02@00oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<0
00T0oo<000<000000?mM003oG@002P3oG@03000000P0oooo001o0?ooo`04
0000003oool0oooo000000/0o`1M00<000000?l0l`3o0?<02@3o0?<00`00
0000MP3o07H0o`0:07H0o`03000000007ol001oo00T001oo00<00000002d
o`00]?l02P00]?l00`0000000?nd003o]009003o]00300000000oal00?lO
00T00?lO00<0000007Ko001fo`002P1fo`000`000000oo<00?oc00090?oc
00030000003oG@00oed000X0oed000<000000?ooo`000000203oool007l0
oooo00@000000?ooo`3oool000002`3o05d00`000000o`3c0?l0l`090?l0
l`030000001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol00`00
00000;Co002do`0:002do`0300000000ok@00?nd00T00?nd00<00000003o
7`00oal02@00oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<0
00T0oo<000<000000?mM003oG@002P3oG@000`000000oooo000000080?oo
o`00O`3oool010000000oooo0?ooo`00000;0?l0G@030000003o0?<0o`3c
00T0o`3c00<0000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`09000O
o`0300000000]?l00;Co00X00;Co00<00000003o]000ok@02@00ok@00`00
00000?lO003o7`09003o7`030000001fo`00M_l000X0M_l000<000000?oc
003ol`002@3ol`000`000000oed00?mM000:0?mM00030000003oool00000
00P0oooo001o0?ooo`040000003oool0oooo000000/0o`1M00<000000?l0
l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`03000000007ol001oo
00T001oo00<00000002do`00]?l02P00]?l00`0000000?nd003o]009003o
]00300000000oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`000`00
0000oo<00?oc00090?oc00030000003oG@00oed000X0oed000<000000?oo
o`000000203oool007l0oooo00@000000?ooo`3oool000002`3o05d00`00
0000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0MP3o00<00000000O
o`007ol02@007ol00`0000000;Co002do`0:002do`0300000000ok@00?nd
00T00?nd00<00000003o7`00oal02@00oal00`000000M_l007Ko000:07Ko
00030000003ol`00oo<000T0oo<000<000000?mM003oG@002P3oG@000`00
0000oooo000000080?ooo`00O`3oool2000000030?ooo`000000o`1M00X0
o`1M00<000000?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`03
000000007ol001oo00T001oo00<00000002do`00]?l02P00]?l00`000000
0?nd003o]009003o]00300000000oal00?lO00T00?lO00<0000007Ko001f
o`002P1fo`000`000000oo<00?oc00090?oc00030000003oG@00oed000X0
oed00`0000080?ooo`00O`3oool010000000oooo0?ooo`00000;0?l0G@03
0000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l00`000000
01oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<00000003o]000
ok@02@00ok@00`0000000?lO003o7`09003o7`030000001fo`00M_l000X0
M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM000:0?mM0003
0000003oool0000000P0oooo001o0?ooo`040000003oool0oooo000000/0
o`1M00<000000?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`03
000000007ol001oo00T001oo00<00000002do`00]?l02P00]?l00`000000
0?nd003o]009003o]00300000000oal00?lO00T00?lO00<0000007Ko001f
o`002P1fo`000`000000oo<00?oc00090?oc00030000003oG@00oed000X0
oed000<000000?ooo`000000203oool007l0oooo00@000000?ooo`3oool0
00002`3o05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0
MP3o00<00000000Oo`007ol02@007ol00`0000000;Co002do`0:002do`03
00000000ok@00?nd00T00?nd00<00000003o7`00oal02@00oal00`000000
M_l007Ko000:07Ko00030000003ol`00oo<000T0oo<000<000000?mM003o
G@002P3oG@000`000000oooo000000080?ooo`00N@3oool5000000050?oo
o`000000oooo0?ooo`0000002`3o05d00`000000o`3c0?l0l`090?l0l`03
0000001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol00`000000
0;Co002do`0:002do`0300000000ok@00?nd00T00?nd00<00000003o7`00
oal02@00oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<000T0
oo<000<000000?mM003oG@002P3oG@000`000000oooo000000080?ooo`00
N`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?l0G@3o
05d02@3o05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0
MP3o00<00000000Oo`007ol02@007ol00`0000000;Co002do`0:002do`03
00000000ok@00?nd00T00?nd00<00000003o7`00oal02@00oal00`000000
M_l007Ko000:07Ko00030000003ol`00oo<000T0oo<000<000000?mM003o
G@002P3oG@000`000000oooo000000080?ooo`00N`3oool010000000oooo
0?ooo`3oool2000000030?ooo`000000o`1M00X0o`1M00<000000?l0l`3o
0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`03000000007ol001oo00T0
01oo00<00000002do`00]?l02P00]?l00`0000000?nd003o]009003o]003
00000000oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`000`000000
oo<00?oc00090?oc00030000003oG@00oed000X0oed00`0000080?ooo`00
N`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?l0G@3o
05d02@3o05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0
MP3o00<00000000Oo`007ol02@007ol00`0000000;Co002do`0:002do`03
00000000ok@00?nd00T00?nd00<00000003o7`00oal02@00oal00`000000
M_l007Ko000:07Ko00030000003ol`00oo<000T0oo<000<000000?mM003o
G@002P3oG@000`000000oooo000000080?ooo`00N`3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?l0G@3o05d02@3o05d00`000000
o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0MP3o00<00000000Oo`00
7ol02@007ol00`0000000;Co002do`0:002do`0300000000ok@00?nd00T0
0?nd00<00000003o7`00oal02@00oal00`000000M_l007Ko000:07Ko0003
0000003ol`00oo<000T0oo<000<000000?mM003oG@002P3oG@000`000000
oooo000000080?ooo`00NP3oool2000000<0oooo00@000000?ooo`3oool0
00002`3o05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0
MP3o00<00000000Oo`007ol02@007ol00`0000000;Co002do`0:002do`03
00000000ok@00?nd00T00?nd00<00000003o7`00oal02@00oal00`000000
M_l007Ko000:07Ko00030000003ol`00oo<000T0oo<000<000000?mM003o
G@002P3oG@000`000000oooo000000080?ooo`00O`3oool010000000oooo
0?ooo`00000;0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f
0?l02P1f0?l00`00000001oo000Oo`09000Oo`0300000000]?l00;Co00X0
0;Co00<00000003o]000ok@02@00ok@00`0000000?lO003o7`09003o7`03
0000001fo`00M_l000X0M_l000<000000?oc003ol`002@3ol`000`000000
oed00?mM000:0?mM00030000003oool0000000P0oooo001o0?ooo`040000
003oool0oooo000000/0o`1M00<000000?l0l`3o0?<02@3o0?<00`000000
MP3o07H0o`0:07H0o`03000000007ol001oo00T001oo00<00000002do`00
]?l02P00]?l00`0000000?nd003o]009003o]00300000000oal00?lO00T0
0?lO00<0000007Ko001fo`002P1fo`000`000000oo<00?oc00090?oc0003
0000003oG@00oed000X0oed000<000000?ooo`000000203oool007l0oooo
0P0000000`3oool000000?l0G@0:0?l0G@030000003o0?<0o`3c00T0o`3c
00<0000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`09000Oo`030000
0000]?l00;Co00X00;Co00<00000003o]000ok@02@00ok@00`0000000?lO
003o7`09003o7`030000001fo`00M_l000X0M_l000<000000?oc003ol`00
2@3ol`000`000000oed00?mM000:0?mM00<00000203oool007l0oooo00@0
00000?ooo`3oool000002`3o05d00`000000o`3c0?l0l`090?l0l`030000
001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol00`0000000;Co
002do`0:002do`0300000000ok@00?nd00T00?nd00<00000003o7`00oal0
2@00oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<000T0oo<0
00<000000?mM003oG@002P3oG@000`000000oooo000000080?ooo`00O`3o
ool010000000oooo0?ooo`00000;0?l0G@030000003o0?<0o`3c00T0o`3c
00<0000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`09000Oo`030000
0000]?l00;Co00X00;Co00<00000003o]000ok@02@00ok@00`0000000?lO
003o7`09003o7`030000001fo`00M_l000X0M_l000<000000?oc003ol`00
2@3ol`000`000000oed00?mM000:0?mM00030000003oool0000000P0oooo
001o0?ooo`040000003oool0oooo000000/0o`1M00<000000?l0l`3o0?<0
2@3o0?<00`000000MP3o07H0o`0:07H0o`03000000007ol001oo00T001oo
00<00000002do`00]?l02P00]?l00`0000000?nd003o]009003o]0030000
0000oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`000`000000oo<0
0?oc00090?oc00030000003oG@00oed000X0oed000<000000?ooo`000000
203oool007l0oooo00@000000?ooo`3oool000002`3o05d00`000000o`3c
0?l0l`090?l0l`030000001f0?l0MP3o00X0MP3o00<00000000Oo`007ol0
2@007ol00`0000000;Co002do`0:002do`0300000000ok@00?nd00T00?nd
00<00000003o7`00oal02@00oal00`000000M_l007Ko000:07Ko00030000
003ol`00oo<000T0oo<000<000000?mM003oG@002P3oG@000`000000oooo
000000080?ooo`00O`3oool010000000oooo0?ooo`00000;0?l0G@030000
003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l00`00000001oo
000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<00000003o]000ok@0
2@00ok@00`0000000?lO003o7`09003o7`030000001fo`00M_l000X0M_l0
00<000000?oc003ol`002@3ol`000`000000oed00?mM000:0?mM00030000
003oool0000000P0oooo001o0?ooo`040000003oool0oooo000000/0o`1M
00<000000?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`030000
00007ol001oo00T001oo00<00000002do`00]?l02P00]?l00`0000000?nd
003o]009003o]00300000000oal00?lO00T00?lO00<0000007Ko001fo`00
2P1fo`000`000000oo<00?oc00090?oc00030000003oG@00oed000X0oed0
00<000000?ooo`000000203oool007l0oooo0P0000000`3oool000000?l0
G@0:0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f
0?l00`00000001oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<0
0000003o]000ok@02@00ok@00`0000000?lO003o7`09003o7`030000001f
o`00M_l000X0M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM
000:0?mM00<00000203oool007l0oooo00@000000?ooo`3oool000002`3o
05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0MP3o00<0
0000000Oo`007ol02@007ol00`0000000;Co002do`0:002do`0300000000
ok@00?nd00T00?nd00<00000003o7`00oal02@00oal00`000000M_l007Ko
000:07Ko00030000003ol`00oo<000T0oo<000<000000?mM003oG@002P3o
G@000`000000oooo000000080?ooo`00O`3oool010000000oooo0?ooo`00
000;0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f
0?l00`00000001oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<0
0000003o]000ok@02@00ok@00`0000000?lO003o7`09003o7`030000001f
o`00M_l000X0M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM
000:0?mM00030000003oool0000000P0oooo001o0?ooo`040000003oool0
oooo000000/0o`1M00<000000?l0l`3o0?<02@3o0?<00`000000MP3o07H0
o`0:07H0o`03000000007ol001oo00T001oo00<00000002do`00]?l02P00
]?l00`0000000?nd003o]009003o]00300000000oal00?lO00T00?lO00<0
000007Ko001fo`002P1fo`000`000000oo<00?oc00090?oc00030000003o
G@00oed000X0oed000<000000?ooo`000000203oool007l0oooo00@00000
0?ooo`3oool000002`3o05d00`000000o`3c0?l0l`090?l0l`030000001f
0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol00`0000000;Co002d
o`0:002do`0300000000ok@00?nd00T00?nd00<00000003o7`00oal02@00
oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<000T0oo<000<0
00000?mM003oG@002P3oG@000`000000oooo000000080?ooo`00O`3oool0
10000000oooo0?ooo`00000;0?l0G@030000003o0?<0o`3c00T0o`3c00<0
000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`09000Oo`0300000000
]?l00;Co00X00;Co00<00000003o]000ok@02@00ok@00`0000000?lO003o
7`09003o7`030000001fo`00M_l000X0M_l000<000000?oc003ol`002@3o
l`000`000000oed00?mM000:0?mM00030000003oool0000000P0oooo001o
0?ooo`80000000<0oooo0000003o05d02P3o05d00`000000o`3c0?l0l`09
0?l0l`030000001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol0
0`0000000;Co002do`0:002do`0300000000ok@00?nd00T00?nd00<00000
003o7`00oal02@00oal00`000000M_l007Ko000:07Ko00030000003ol`00
oo<000T0oo<000<000000?mM003oG@002P3oG@03000000P0oooo001o0?oo
o`040000003oool0oooo000000/0o`1M00<000000?l0l`3o0?<02@3o0?<0
0`000000MP3o07H0o`0:07H0o`03000000007ol001oo00T001oo00<00000
002do`00]?l02P00]?l00`0000000?nd003o]009003o]00300000000oal0
0?lO00T00?lO00<0000007Ko001fo`002P1fo`000`000000oo<00?oc0009
0?oc00030000003oG@00oed000X0oed000<000000?ooo`000000203oool0
07l0oooo00@000000?ooo`3oool000002`3o05d00`000000o`3c0?l0l`09
0?l0l`030000001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol0
0`0000000;Co002do`0:002do`0300000000ok@00?nd00T00?nd00<00000
003o7`00oal02@00oal00`000000M_l007Ko000:07Ko00030000003ol`00
oo<000T0oo<000<000000?mM003oG@002P3oG@000`000000oooo00000008
0?ooo`00O`3oool010000000oooo0?ooo`00000;0?l0G@030000003o0?<0
o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`09
000Oo`0300000000]?l00;Co00X00;Co00<00000003o]000ok@02@00ok@0
0`0000000?lO003o7`09003o7`030000001fo`00M_l000X0M_l000<00000
0?oc003ol`002@3ol`000`000000oed00?mM000:0?mM00030000003oool0
000000P0oooo001o0?ooo`040000003oool0oooo000000/0o`1M00<00000
0?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`03000000007ol0
01oo00T001oo00<00000002do`00]?l02P00]?l00`0000000?nd003o]009
003o]00300000000oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`00
0`000000oo<00?oc00090?oc00030000003oG@00oed000X0oed000<00000
0?ooo`000000203oool007l0oooo00@000000?ooo`3oool000002`3o05d0
0`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0MP3o00<00000
000Oo`007ol02@007ol00`0000000;Co002do`0:002do`0300000000ok@0
0?nd00T00?nd00<00000003o7`00oal02@00oal00`000000M_l007Ko000:
07Ko00030000003ol`00oo<000T0oo<000<000000?mM003oG@002P3oG@00
0`000000oooo000000080?ooo`00O`3oool2000000030?ooo`000000o`1M
00X0o`1M00<000000?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0
o`03000000007ol001oo00T001oo00<00000002do`00]?l02P00]?l00`00
00000?nd003o]009003o]00300000000oal00?lO00T00?lO00<0000007Ko
001fo`002P1fo`000`000000oo<00?oc00090?oc00030000003oG@00oed0
00X0oed00`0000080?ooo`00O`3oool010000000oooo0?ooo`00000;0?l0
G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l00`00
000001oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<00000003o
]000ok@02@00ok@00`0000000?lO003o7`09003o7`030000001fo`00M_l0
00X0M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM000:0?mM
00030000003oool0000000P0oooo001o0?ooo`040000003oool0oooo0000
00/0o`1M00<000000?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0
o`03000000007ol001oo00T001oo00<00000002do`00]?l02P00]?l00`00
00000?nd003o]009003o]00300000000oal00?lO00T00?lO00<0000007Ko
001fo`002P1fo`000`000000oo<00?oc00090?oc00030000003oG@00oed0
00X0oed000<000000?ooo`000000203oool007l0oooo00@000000?ooo`3o
ool000002`3o05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o
00X0MP3o00<00000000Oo`007ol02@007ol00`0000000;Co002do`0:002d
o`0300000000ok@00?nd00T00?nd00<00000003o7`00oal02@00oal00`00
0000M_l007Ko000:07Ko00030000003ol`00oo<000T0oo<000<000000?mM
003oG@002P3oG@000`000000oooo000000080?ooo`00K@3oool500000080
oooo0P0000040?ooo`8000000`3oool010000000oooo0?ooo`00000;0?l0
G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l00`00
000001oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<00000003o
]000ok@02@00ok@00`0000000?lO003o7`09003o7`030000001fo`00M_l0
00X0M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM000:0?mM
00030000003oool0000000P0oooo001_0?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000;
0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l0
0`00000001oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<00000
003o]000ok@02@00ok@00`0000000?lO003o7`09003o7`030000001fo`00
M_l000X0M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM000:
0?mM00030000003oool0000000P0oooo001_0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00P0000000`3oool000000?l0G@0:0?l0
G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l00`00
000001oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<00000003o
]000ok@02@00ok@00`0000000?lO003o7`09003o7`030000001fo`00M_l0
00X0M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM000:0?mM
00<00000203oool006l0oooo00<000000?ooo`3oool0203oool2000000<0
oooo00@000000?ooo`3oool000002`3o05d00`000000o`3c0?l0l`090?l0
l`030000001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol00`00
00000;Co002do`0:002do`0300000000ok@00?nd00T00?nd00<00000003o
7`00oal02@00oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<0
00T0oo<000<000000?mM003oG@002P3oG@000`000000oooo000000080?oo
o`00K`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000002`3o05d00`000000o`3c0?l0l`090?l0
l`030000001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol00`00
00000;Co002do`0:002do`0300000000ok@00?nd00T00?nd00<00000003o
7`00oal02@00oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<0
00T0oo<000<000000?mM003oG@002P3oG@000`000000oooo000000080?oo
o`00KP3oool2000000X0oooo0`0000020?ooo`040000003oool0oooo0000
00/0o`1M00<000000?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0
o`03000000007ol001oo00T001oo00<00000002do`00]?l02P00]?l00`00
00000?nd003o]009003o]00300000000oal00?lO00T00?lO00<0000007Ko
001fo`002P1fo`000`000000oo<00?oc00090?oc00030000003oG@00oed0
00X0oed000<000000?ooo`000000203oool007l0oooo00@000000?ooo`3o
ool000002`3o05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o
00X0MP3o00<00000000Oo`007ol02@007ol00`0000000;Co002do`0:002d
o`0300000000ok@00?nd00T00?nd00<00000003o7`00oal02@00oal00`00
0000M_l007Ko000:07Ko00030000003ol`00oo<000T0oo<000<000000?mM
003oG@002P3oG@000`000000oooo000000080?ooo`00O`3oool010000000
oooo0?ooo`00000;0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0
o`1f0?l02P1f0?l00`00000001oo000Oo`09000Oo`0300000000]?l00;Co
00X00;Co00<00000003o]000ok@02@00ok@00`0000000?lO003o7`09003o
7`030000001fo`00M_l000X0M_l000<000000?oc003ol`002@3ol`000`00
0000oed00?mM000:0?mM00030000003oool0000000P0oooo001o0?ooo`80
000000<0oooo0000003o05d02P3o05d00`000000o`3c0?l0l`090?l0l`03
0000001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol00`000000
0;Co002do`0:002do`0300000000ok@00?nd00T00?nd00<00000003o7`00
oal02@00oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<000T0
oo<000<000000?mM003oG@002P3oG@03000000P0oooo001o0?ooo`040000
003oool0oooo000000/0o`1M00<000000?l0l`3o0?<02@3o0?<00`000000
MP3o07H0o`0:07H0o`03000000007ol001oo00T001oo00<00000002do`00
]?l02P00]?l00`0000000?nd003o]009003o]00300000000oal00?lO00T0
0?lO00<0000007Ko001fo`002P1fo`000`000000oo<00?oc00090?oc0003
0000003oG@00oed000X0oed000<000000?ooo`000000203oool007l0oooo
00@000000?ooo`3oool000002`3o05d00`000000o`3c0?l0l`090?l0l`03
0000001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol00`000000
0;Co002do`0:002do`0300000000ok@00?nd00T00?nd00<00000003o7`00
oal02@00oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<000T0
oo<000<000000?mM003oG@002P3oG@000`000000oooo000000080?ooo`00
O`3oool010000000oooo0?ooo`00000;0?l0G@030000003o0?<0o`3c00T0
o`3c00<0000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`09000Oo`03
00000000]?l00;Co00X00;Co00<00000003o]000ok@02@00ok@00`000000
0?lO003o7`09003o7`030000001fo`00M_l000X0M_l000<000000?oc003o
l`002@3ol`000`000000oed00?mM000:0?mM00030000003oool0000000P0
oooo001o0?ooo`040000003oool0oooo000000/0o`1M00<000000?l0l`3o
0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`03000000007ol001oo00T0
01oo00<00000002do`00]?l02P00]?l00`0000000?nd003o]009003o]003
00000000oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`000`000000
oo<00?oc00090?oc00030000003oG@00oed000X0oed000<000000?ooo`00
0000203oool007l0oooo00@000000?ooo`3oool000002`3o05d00`000000
o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0MP3o00<00000000Oo`00
7ol02@007ol00`0000000;Co002do`0:002do`0300000000ok@00?nd00T0
0?nd00<00000003o7`00oal02@00oal00`000000M_l007Ko000:07Ko0003
0000003ol`00oo<000T0oo<000<000000?mM003oG@002P3oG@000`000000
oooo000000080?ooo`00O`3oool010000000oooo0?ooo`00000;0?l0G@03
0000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l00`000000
01oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<00000003o]000
ok@02@00ok@00`0000000?lO003o7`09003o7`030000001fo`00M_l000X0
M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM000:0?mM0003
0000003oool0000000P0oooo001o0?ooo`80000000<0oooo0000003o05d0
2P3o05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0MP3o
00<00000000Oo`007ol02@007ol00`0000000;Co002do`0:002do`030000
0000ok@00?nd00T00?nd00<00000003o7`00oal02@00oal00`000000M_l0
07Ko000:07Ko00030000003ol`00oo<000T0oo<000<000000?mM003oG@00
2P3oG@03000000P0oooo001o0?ooo`040000003oool0oooo000000/0o`1M
00<000000?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`030000
00007ol001oo00T001oo00<00000002do`00]?l02P00]?l00`0000000?nd
003o]009003o]00300000000oal00?lO00T00?lO00<0000007Ko001fo`00
2P1fo`000`000000oo<00?oc00090?oc00030000003oG@00oed000X0oed0
00<000000?ooo`000000203oool007l0oooo00@000000?ooo`3oool00000
2`3o05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0MP3o
00<00000000Oo`007ol02@007ol00`0000000;Co002do`0:002do`030000
0000ok@00?nd00T00?nd00<00000003o7`00oal02@00oal00`000000M_l0
07Ko000:07Ko00030000003ol`00oo<000T0oo<000<000000?mM003oG@00
2P3oG@000`000000oooo000000080?ooo`00O`3oool010000000oooo0?oo
o`00000;0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l0
2P1f0?l00`00000001oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co
00<00000003o]000ok@02@00ok@00`0000000?lO003o7`09003o7`030000
001fo`00M_l000X0M_l000<000000?oc003ol`002@3ol`000`000000oed0
0?mM000:0?mM00030000003oool0000000P0oooo001o0?ooo`040000003o
ool0oooo000000/0o`1M00<000000?l0l`3o0?<02@3o0?<00`000000MP3o
07H0o`0:07H0o`03000000007ol001oo00T001oo00<00000002do`00]?l0
2P00]?l00`0000000?nd003o]009003o]00300000000oal00?lO00T00?lO
00<0000007Ko001fo`002P1fo`000`000000oo<00?oc00090?oc00030000
003oG@00oed000X0oed000<000000?ooo`000000203oool007l0oooo00@0
00000?ooo`3oool000002`3o05d00`000000o`3c0?l0l`090?l0l`030000
001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@007ol00`0000000;Co
002do`0:002do`0300000000ok@00?nd00T00?nd00<00000003o7`00oal0
2@00oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<000T0oo<0
00<000000?mM003oG@002P3oG@000`000000oooo000000080?ooo`00O`3o
ool2000000030?ooo`000000o`1M00X0o`1M00<000000?l0l`3o0?<02@3o
0?<00`000000MP3o07H0o`0:07H0o`03000000007ol001oo00T001oo00<0
0000002do`00]?l02P00]?l00`0000000?nd003o]009003o]00300000000
oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`000`000000oo<00?oc
00090?oc00030000003oG@00oed000X0oed00`0000080?ooo`00O`3oool0
10000000oooo0?ooo`00000;0?l0G@030000003o0?<0o`3c00T0o`3c00<0
000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`09000Oo`0300000000
]?l00;Co00X00;Co00<00000003o]000ok@02@00ok@00`0000000?lO003o
7`09003o7`030000001fo`00M_l000X0M_l000<000000?oc003ol`002@3o
l`000`000000oed00?mM000:0?mM00030000003oool0000000P0oooo001o
0?ooo`040000003oool0oooo000000/0o`1M00<000000?l0l`3o0?<02@3o
0?<00`000000MP3o07H0o`0:07H0o`03000000007ol001oo00T001oo00<0
0000002do`00]?l02P00]?l00`0000000?nd003o]009003o]00300000000
oal00?lO00T00?lO00<0000007Ko001fo`002P1fo`000`000000oo<00?oc
00090?oc00030000003oG@00oed000X0oed000<000000?ooo`000000203o
ool007l0oooo00@000000?ooo`3oool000002`3o05d00`000000o`3c0?l0
l`090?l0l`030000001f0?l0MP3o00X0MP3o00<00000000Oo`007ol02@00
7ol00`0000000;Co002do`0:002do`0300000000ok@00?nd00T00?nd00<0
0000003o7`00oal02@00oal00`000000M_l007Ko000:07Ko00030000003o
l`00oo<000T0oo<000<000000?mM003oG@002P3oG@000`000000oooo0000
00080?ooo`00O`3oool010000000oooo0?ooo`00000;0?l0G@030000003o
0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l00`00000001oo000O
o`09000Oo`0300000000]?l00;Co00X00;Co00<00000003o]000ok@02@00
ok@00`0000000?lO003o7`09003o7`030000001fo`00M_l000X0M_l000<0
00000?oc003ol`002@3ol`000`000000oed00?mM000:0?mM00030000003o
ool0000000P0oooo001o0?ooo`040000003oool0oooo000000/0o`1M00<0
00000?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:07H0o`0300000000
7ol001oo00T001oo00<00000002do`00]?l02P00]?l00`0000000?nd003o
]009003o]00300000000oal00?lO00T00?lO00<0000007Ko001fo`002P1f
o`000`000000oo<00?oc00090?oc00030000003oG@00oed000X0oed000<0
00000?ooo`000000203oool007l0oooo0P0000000`3oool000000?l0G@0:
0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l0
0`00000001oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<00000
003o]000ok@02@00ok@00`0000000?lO003o7`09003o7`030000001fo`00
M_l000X0M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM000:
0?mM00<00000203oool007l0oooo00@000000?ooo`3oool000002`3o05d0
0`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00X0MP3o00<00000
000Oo`007ol02@007ol00`0000000;Co002do`0:002do`0300000000ok@0
0?nd00T00?nd00<00000003o7`00oal02@00oal00`000000M_l007Ko000:
07Ko00030000003ol`00oo<000T0oo<000<000000?mM003oG@002P3oG@00
0`000000oooo000000080?ooo`00O`3oool010000000oooo0?ooo`00000;
0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l0
0`00000001oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<00000
003o]000ok@02@00ok@00`0000000?lO003o7`09003o7`030000001fo`00
M_l000X0M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM000:
0?mM00030000003oool0000000P0oooo001o0?ooo`040000003oool0oooo
000000/0o`1M00<000000?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0:
07H0o`03000000007ol001oo00T001oo00<00000002do`00]?l02P00]?l0
0`0000000?nd003o]009003o]00300000000oal00?lO00T00?lO00<00000
07Ko001fo`002P1fo`000`000000oo<00?oc00090?oc00030000003oG@00
oed000X0oed000<000000?ooo`000000203oool007T0oooo100000020?oo
o`040000003oool0oooo000000/0o`1M00<000000?l0l`3o0?<02@3o0?<0
0`000000MP3o07H0o`0:07H0o`03000000007ol001oo00T001oo00<00000
002do`00]?l02P00]?l00`0000000?nd003o]009003o]00300000000oal0
0?lO00T00?lO00<0000007Ko001fo`002P1fo`000`000000oo<00?oc0009
0?oc00030000003oG@00oed000X0oed000<000000?ooo`000000203oool0
07T0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000;
0?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02P1f0?l0
0`00000001oo000Oo`09000Oo`0300000000]?l00;Co00X00;Co00<00000
003o]000ok@02@00ok@00`0000000?lO003o7`09003o7`030000001fo`00
M_l000X0M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM000:
0?mM00030000003oool0000000P0oooo001j0?ooo`030000003oool0oooo
0080oooo0P0000000`3oool000000?l0G@0:0?l0G@030000003o0?<0o`3c
00T0o`3c00<0000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`09000O
o`0300000000]?l00;Co00X00;Co00<00000003o]000ok@02@00ok@00`00
00000?lO003o7`09003o7`030000001fo`00M_l000X0M_l000<000000?oc
003ol`002@3ol`000`000000oed00?mM000:0?mM00<00000203oool007/0
oooo00D000000?ooo`3oool0oooo000000200?ooo`030000003oool0oooo
00H0oooo001i0?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
000000P0oooo001j0?ooo`8000000`3ooon2000000P0oooo003o0?ooo`X0
oooo003o0?ooo`X0oooo003o0?ooo`X0oooo003o0?ooo`X0oooo003o0?oo
o`X0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{265, 155},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.18.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "This example is similar to Example 11.1 and  Example 11.14.  For \
illustration we use the boundary values  \n",
  Cell[BoxData[
      \(\[Phi] \((\(-1\), y)\) = 30, \n\[Phi] \((1, y)\) = \(-20. \)\)]],
  "\n\nEnter the formula for the electrical potential."
}], "Text"],

Cell[BoxData[{
    \(U = 0; \ Remove[U];\ \), "\[IndentingNewLine]", 
    \(\(Clear[a, b, c, x, y, cont, \[Phi]];\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ 
        U\_1\  + \ \(U\_2\  - \ U\_1\)\/\(b\  - \ a\)\ \((x\  - \ 
                a)\);\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Enter the boundary values  ",
  Cell[BoxData[
      \(a = \(-1\), \ \ b = 
        1, \ \ U\_1 = \(30\ \ and\ \ U\_2 = \(-20\)\)\)]],
  ",  and check out the formula."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(a\  = \(-1\);\)\ \), "\n", 
    \(\(b\  = \ 1;\)\ \), "\n", 
    \(\(U\_1\  = \ 30;\)\ \), "\n", 
    \(\(U\_2\  = \ \(-20\);\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, y]];\)\ \), "\n", 
    \(\(Print["\<\[Phi][-1,y] = \>", \[Phi][\(-1\), y]];\)\ \), "\n", 
    \(\(Print["\<\[Phi][0,y] = \>", \[Phi][0, y]];\)\ \), "\n", 
    \(\(Print["\<\[Phi][1,y] = \>", \[Phi][1, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the electrical potential."
}], "Text"],

Cell[BoxData[{
    \(\(cont\  = \ Table[c, {c, \(-20\), 30, 5}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Phi][x, y], {x, \(-1\), 1}, {y, 0, 2}, 
        Contours\  \[Rule] \ cont, PlotPoints \[Rule] 10, 
        AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[Phi][x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Hence the electrical potential  ",
  Cell[BoxData[
      \(\[Phi][x, y] = 30 - 25\ \((1 + x)\)\)]],
  "  is harmonic in the horizontal strip  ",
  Cell[BoxData[
      \(\(-1\) < Re[z] < 1\)]],
  "  and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.19.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the electrical potential  ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  in the region between two infinite coaxial cylinders  ",
  Cell[BoxData[
      RowBox[{"r", "=", 
        RowBox[{
          RowBox[{"a", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "r"}], "=", "b"}]}]]],
  ",  which are kept at potentials  ",
  Cell[BoxData[
      \(U\_1\ \ and\ \ U\_2\)]],
  ",  respectively.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000490000Vb000`400?l0
0000o`00003oo`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00
o`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?oo
o`00O@3oool4000001`0oooo1@00000J0?ooo`8000007@3oool5000001`0
oooo100000090?ooo`00O@3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo01T0oooo00@000000?ooo`3oool000007P3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00X0oooo001n0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool06@3oool010000000oooo
0?ooo`00000N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool02@3oool007L0oooo100000040?ooo`030000003oool0oooo01D0oooo
100000040?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool0
00007P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00P0
oooo001m0?ooo`040000003oool0oooo000001h0oooo00<000000?ooo`3o
ool06@3oool010000000oooo0?ooo`00000N0?ooo`030000003oool0oooo
01`0oooo00@000000?ooo`3oool000002@3oool007h0oooo0P00000N0?oo
o`800000703oool2000001h0oooo0P00000O0?ooo`8000002P3oool00?l0
oooo2P3oool00?l0oooo2P3oool00?l0oooo2P3oool00?l0oooo2P3oool0
07T0ooooR00000080?ooo`00L`3oool400000080oooo00@000000?ooo`3o
ool000007`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool07P3oool00`000000oooo000000080?oo
o`00L`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08@0
oooo00<000000?ooo`3oool01P3oool007@0oooo00<000000?ooo`3oool0
0P3oool2000003H0oooo6000000f0?ooo`800000203oool006d0oooo1000
00040?ooo`050000003oool0oooo0?ooo`0000000P3ooolb0?l000<00000
603G0?l300000380o`000P3oool00`000000oooo0?ooo`060?ooo`00L`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02h0o`00
1000000N0=L0o`@00000;P3o00020?ooo`030000003oool0oooo00H0oooo
001d0?ooo`8000000`3oool00`000000oooo0?ooo`0[0?l000<000009P3G
0?l4000002X0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool0
0`000000oooo0?ooo`0Y0?l000800000;@3G0?l2000002P0o`000P3oool0
0`000000oooo0?ooo`060?ooo`00N@3oool00`000000oooo0?ooo`0V0?l0
00<00000<@3G0?l3000002D0o`000P3oool00`000000oooo0?ooo`060?oo
o`00N@3oool2000000030?ooo`3o0000o`000280o`000P00000g0=L0o`80
00008`3o00020?ooo`030000003oool0oooo00H0oooo001i0?ooo`030000
003oool0oooo0280o`000P00000k0=L0o`8000008@3o00020?ooo`030000
003oool0oooo00H0oooo001i0?ooo`030000003oool0oooo0200o`000P00
000o0=L0o`030000003o0000o`0001h0o`000P3oool00`000000oooo0?oo
o`060?ooo`00N@3oool00`000000oooo0?ooo`0N0?l000800000@P3G0?l2
000001h0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool00`00
0000oooo0?ooo`0M0?l000030000003G0?l0e`3o01P0e`3o4P00000J0=L0
o`030000003o0000o`0001/0o`000P3oool00`000000oooo0?ooo`060?oo
o`00N@3oool00`000000oooo0?ooo`0L0?l000030000003G0?l0e`3o01D0
e`3o1000000B02D0o`@000005`3G0?l00`000000o`000?l0000J0?l00080
oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?ooo`3oool0
6`3o00000`000000e`3o0=L0o`0A0=L0o`D000006P0U0?l5000001<0e`3o
00<000000?l0003o00006@3o00020?ooo`030000003oool0oooo00H0oooo
001i0?ooo`80000000<0oooo0?l0003o0000603o00000`000000e`3o0=L0
o`0@0=L0o`800000900U0?l200000180e`3o0P00000I0?l00080oooo00<0
00000?ooo`3oool01P3oool007T0oooo00<000000?ooo`3oool0603o0002
00000140e`3o0P00000X02D0o`8000004P3G0?l00`000000o`000?l0000F
0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?oo
o`3oool05`3o00000`000000e`3o0=L0o`0?0=L0o`800000;00U0?l20000
0140e`3o0P00000F0?l00080oooo00<000000?ooo`3oool01P3oool007T0
oooo00<000000?ooo`3oool05@3o000200000140e`3o00<0000002D0o`0U
0?l0;P0U0?l200000140e`3o00<000000?l0003o00004`3o00020?ooo`03
0000003oool0oooo00H0oooo001i0?ooo`030000003oool0oooo01@0o`00
00<000000=L0o`3G0?l03`3G0?l2000003<09@3o0P00000@0=L0o`030000
003o0000o`000180o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3o
ool00`000000oooo0?ooo`0C0?l000030000003G0?l0e`3o00h0e`3o0P00
000g02D0o`030000003G0?l0e`3o00h0e`3o00<000000?l0003o00004@3o
00020?ooo`030000003oool0oooo00H0oooo001i0?ooo`80000000<0oooo
0?l0003o0000403o00000`000000e`3o0=L0o`0>0=L0o`030000000U0?l0
9@3o01<09@3o4000000E02D0o`8000003`3G0?l00`000000o`000?l0000@
0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?oo
o`3oool04@3o00000`000000e`3o0=L0o`0=0=L0o`8000004@0U0?l50000
010008go1@00000B02D0o`030000003G0?l0e`3o00d0e`3o00<000000?l0
003o00003`3o00020?ooo`030000003oool0oooo00H0oooo001i0?ooo`03
0000003oool0oooo0100o`0000<000000=L0o`3G0?l0303G0?l2000000l0
9@3o1000000J002=o`@000003`0U0?l2000000h0e`3o00<000000?l0003o
00003P3o00020?ooo`030000003oool0oooo00H0oooo001i0?ooo`030000
003oool0oooo00l0o`0000<000000=L0o`3G0?l0303G0?l00`0000009@3o
02D0o`0=02D0o`8000008P00SOl2000000l09@3o00<000000=L0o`3G0?l0
303G0?l00`000000o`000?l0000=0?l00080oooo00<000000?ooo`3oool0
1P3oool007T0oooo00<000000?ooo`3oool03`3o00000`000000e`3o0=L0
o`0;0=L0o`030000000U0?l09@3o00`09@3o0P00000V002=o`8000003P0U
0?l00`000000e`3o0=L0o`0;0=L0o`030000003o0000o`0000d0o`000P3o
ool00`000000oooo0?ooo`060?ooo`00N@3oool00`000000oooo0?ooo`0>
0?l000030000003G0?l0e`3o00/0e`3o00<0000002D0o`0U0?l0300U0?l0
0`00000008go002=o`0X002=o`030000000U0?l09@3o00`09@3o00<00000
0=L0o`3G0?l02`3G0?l00`000000o`000?l0000<0?l00080oooo00<00000
0?ooo`3oool01P3oool007T0oooo0P0000000`3oool0o`000?l0000;0?l0
00030000003G0?l0e`3o00/0e`3o00<0000002D0o`0U0?l0300U0?l00`00
000008go002=o`0Z002=o`8000003@0U0?l00`000000e`3o0=L0o`0;0=L0
o`030000003o0000o`0000/0o`000P3oool00`000000oooo0?ooo`060?oo
o`00N@3oool00`000000oooo0?ooo`0=0?l000030000003G0?l0e`3o00X0
e`3o00<0000002D0o`0U0?l02`0U0?l20000010008go3P00000A002=o`80
0000300U0?l00`000000e`3o0=L0o`0:0=L0o`030000003o0000o`0000/0
o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool00`000000oooo
0?ooo`0<0?l000030000003G0?l0e`3o00X0e`3o00<0000002D0o`0U0?l0
2P0U0?l2000000d008go1@00000>003o_`D000003P00SOl2000000/09@3o
00<000000=L0o`3G0?l02P3G0?l00`000000o`000?l0000:0?l00080oooo
00<000000?ooo`3oool01P3oool007T0oooo00<000000?ooo`3oool02`3o
00000`000000e`3o0=L0o`0:0=L0o`030000000U0?l09@3o00X09@3o00<0
0000002=o`00SOl02P00SOl3000001P00?no0`00000=002=o`030000000U
0?l09@3o00T09@3o00<000000=L0o`3G0?l02P3G0?l00`000000o`000?l0
00090?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<00000
0?ooo`3oool02`3o00000`000000e`3o0=L0o`090=L0o`030000000U0?l0
9@3o00X09@3o00<00000002=o`00SOl02@00SOl2000001h00?no0P00000<
002=o`030000000U0?l09@3o00T09@3o00<000000=L0o`3G0?l02P3G0?l0
0`000000o`000?l000080?l00080oooo00<000000?ooo`3oool01P3oool0
07<0oooo1@000000103oool000000?ooo`3oool:0?l000030000003G0?l0
e`3o00T0e`3o00<0000002D0o`0U0?l02@0U0?l2000000/008go00<00000
003o_`00okl08000okl2000000/008go00<0000002D0o`0U0?l02@0U0?l0
0`000000e`3o0=L0o`0:0=L0o`030000003o0000o`0000L0o`000P3oool0
0`000000oooo0?ooo`060?ooo`00M@3oool01@000000oooo0?ooo`3oool0
00000080oooo2@3o00000`000000e`3o0=L0o`090=L0o`030000000U0?l0
9@3o00T09@3o00<00000002=o`00SOl02@00SOl2000002D00?no0P00000:
002=o`030000000U0?l09@3o00T09@3o00<000000=L0o`3G0?l02@3G0?l0
0`000000o`000?l000070?l00080oooo00<000000?ooo`3oool01P3oool0
07D0oooo00@000000?ooo`3oool0oooo0P0000000`3oool0o`000?l00006
0?l000030000003G0?l0e`3o00X0e`3o00<0000002D0o`0U0?l0200U0?l0
0`00000008go002=o`08002=o`8000003@00okl>000000h00?no00<00000
002=o`00SOl02000SOl00`0000009@3o02D0o`0802D0o`030000003G0?l0
e`3o00X0e`3o00<000000?l0003o00001P3o00000`3oool0000000000008
0?ooo`00K@3oool4000000@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`P0o`0000<000000=L0o`3G0?l02@3G0?l00`0000009@3o02D0o`08
02D0o`0300000000SOl008go00P008go00<00000003o_`00okl02`00okl2
000000h0o`000P00000=003o_`0300000000SOl008go00P008go00<00000
02D0o`0U0?l0200U0?l00`000000e`3o0=L0o`0:0=L0o`030000003o0000
o`0000D0o`000P3oool00`000000oooo0?ooo`060?ooo`00M@3oool01@00
0000oooo0?ooo`3oool000000080oooo1`3o00000`000000e`3o0=L0o`09
0=L0o`030000000U0?l09@3o00P09@3o00<00000002=o`00SOl02000SOl0
0`0000000?no003o_`09003o_`<000004P3o0003000000/00?no00<00000
002=o`00SOl02000SOl00`0000009@3o02D0o`0802D0o`030000003G0?l0
e`3o00T0e`3o00<000000?l0003o00001@3o00020?ooo`030000003oool0
oooo00H0oooo001d0?ooo`8000000`3oool00`000000oooo0?ooo`070?l0
00030000003G0?l0e`3o00T0e`3o00<0000002D0o`0U0?l0200U0?l00`00
000008go002=o`07002=o`0300000000okl00?no00L00?no0`00000H0?l0
00<000002@00okl2000000T008go00<0000002D0o`0U0?l01`0U0?l00`00
0000e`3o0=L0o`0:0=L0o`030000003o0000o`0000@0o`000P3oool00`00
0000oooo0?ooo`060?ooo`00N@3oool00`000000oooo0?ooo`060?l00003
0000003G0?l0e`3o00T0e`3o00<0000002D0o`0U0?l0200U0?l00`000000
08go002=o`07002=o`0300000000okl00?no00H00?no0P00000N0?l00080
00002@00okl00`00000008go002=o`07002=o`030000000U0?l09@3o00L0
9@3o00<000000=L0o`3G0?l02@3G0?l00`000000o`000?l000040?l00080
oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?ooo`3oool0
1P3o00000`000000e`3o0=L0o`080=L0o`030000000U0?l09@3o00P09@3o
00<00000002=o`00SOl01P00SOl2000000P00?no00<000000?l0003o0000
803o0002000000P00?no00<00000002=o`00SOl01`00SOl00`0000009@3o
02D0o`0702D0o`030000003G0?l0e`3o00T0e`3o00<000000?l0003o0000
0`3o00020?ooo`030000003oool0oooo00H0oooo001i0?ooo`80000000<0
oooo0?l0003o00000`3o00000`000000e`3o0=L0o`090=L0o`030000000U
0?l09@3o00L09@3o00<00000002=o`00SOl01P00SOl00`0000000?no003o
_`07003o_`030000003o0000o`0002<0o`0000<00000003o_`00okl01P00
okl00`00000008go002=o`06002=o`030000000U0?l09@3o00L09@3o00<0
00000=L0o`3G0?l02@3G0?l00`000000o`000?l000030?l00080oooo00<0
00000?ooo`3oool01P3oool007T0oooo00<000000?ooo`3oool01@3o0000
0`000000e`3o0=L0o`080=L0o`030000000U0?l09@3o00L09@3o00<00000
002=o`00SOl01`00SOl00`0000000?no003o_`05003o_`8000009`3o0000
0`0000000?no003o_`06003o_`0300000000SOl008go00H008go00<00000
02D0o`0U0?l01`0U0?l00`000000e`3o0=L0o`080=L0o`030000003o0000
o`0000<0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool00`00
0000oooo0?ooo`040?l000030000003G0?l0e`3o00T0e`3o00<0000002D0
o`0U0?l01`0U0?l00`00000008go002=o`06002=o`0300000000okl00?no
00D00?no00<000000?l0003o0000:03o00000`0000000?no003o_`05003o
_`0300000000SOl008go00H008go00<0000002D0o`0U0?l01`0U0?l00`00
0000e`3o0=L0o`090=L0o`030000003o0000o`000080o`000P3oool00`00
0000oooo0?ooo`060?ooo`00N@3oool00`000000oooo0?ooo`040?l00003
0000003G0?l0e`3o00T0e`3o00<0000002D0o`0U0?l01P0U0?l00`000000
08go002=o`06002=o`0300000000okl00?no00D00?no00<000000?l0003o
0000:P3o00000`0000000?no003o_`05003o_`0300000000SOl008go00H0
08go00<0000002D0o`0U0?l01`0U0?l00`000000e`3o0=L0o`080=L0o`03
0000003o0000o`000080o`000P3oool00`000000oooo0?ooo`060?ooo`00
N@3oool00`000000oooo0?ooo`030?l000030000003G0?l0e`3o00T0e`3o
00<0000002D0o`0U0?l01`0U0?l00`00000008go002=o`06002=o`030000
0000okl00?no00@00?no00<000000?l0003o0000;03o00000`0000000?no
003o_`05003o_`0300000000SOl008go00D008go00<0000002D0o`0U0?l0
1`0U0?l00`000000e`3o0=L0o`090=L0o`040000003o0000o`000?l00080
oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?ooo`3oool0
0`3o00000`000000e`3o0=L0o`090=L0o`030000000U0?l09@3o00H09@3o
00<00000002=o`00SOl01P00SOl00`0000000?no003o_`04003o_`030000
003o0000o`0002h0o`0000<00000003o_`00okl01@00okl00`00000008go
002=o`05002=o`030000000U0?l09@3o00L09@3o00<000000=L0o`3G0?l0
203G0?l010000000o`000?l0003o00020?ooo`030000003oool0oooo00H0
oooo001i0?ooo`030000003oool0oooo00<0o`0000<000000=L0o`3G0?l0
2@3G0?l00`0000009@3o02D0o`0602D0o`0300000000SOl008go00D008go
00<00000003o_`00okl01000okl00`000000o`000?l0000`0?l000030000
0000okl00?no00@00?no00<00000002=o`00SOl01P00SOl00`0000009@3o
02D0o`0602D0o`030000003G0?l0e`3o00P0e`3o00@000000?l0003o0000
o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool2000000050?oo
o`3o0000o`000?l0000000002P3G0?l00`0000009@3o02D0o`0602D0o`03
00000000SOl008go00D008go00<00000003o_`00okl01@00okl00`000000
o`000?l0000a0?l0000300000000okl00?no00@00?no00<00000002=o`00
SOl01@00SOl00`0000009@3o02D0o`0702D0o`030000003G0?l0e`3o00L0
e`3o00@000000?l0003o0000o`000P3oool00`000000oooo0?ooo`060?oo
o`00N@3oool00`000000oooo0?ooo`020?l000030000003G0?l0e`3o00T0
e`3o00<0000002D0o`0U0?l01P0U0?l00`00000008go002=o`05002=o`03
00000000okl00?no00@00?no00<000000?l0003o0000<`3o00000`000000
0?no003o_`03003o_`0300000000SOl008go00H008go00<0000002D0o`0U
0?l01P0U0?l00`000000e`3o0=L0o`080=L0o`030000003o0000o`000080
oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?ooo`3oool0
0P3o00000`000000e`3o0=L0o`080=L0o`030000000U0?l09@3o00H09@3o
00<00000002=o`00SOl01@00SOl00`0000000?no003o_`04003o_`030000
003o0000o`0003@0o`0000<00000003o_`00okl01000okl00`00000008go
002=o`05002=o`030000000U0?l09@3o00L09@3o00<000000=L0o`3G0?l0
1`3G0?l00`000000o`000?l000020?ooo`030000003oool0oooo00H0oooo
001i0?ooo`030000003oool0oooo0080o`0000<000000=L0o`3G0?l0203G
0?l00`0000009@3o02D0o`0602D0o`0300000000SOl008go00D008go00<0
0000003o_`00okl01000okl00`000000o`000?l0000e0?l0000300000000
okl00?no00@00?no00<00000002=o`00SOl01@00SOl00`0000009@3o02D0
o`0602D0o`030000003G0?l0e`3o00L0e`3o00<000000?l0003o00000P3o
ool00`000000oooo0?ooo`060?ooo`00N@3oool00`000000oooo0?ooo`02
0?l000030000003G0?l0e`3o00P0e`3o00<0000002D0o`0U0?l01@0U0?l0
0`00000008go002=o`06002=o`0300000000okl00?no00<00?no00<00000
0?l0003o0000=P3o00000`0000000?no003o_`04003o_`0300000000SOl0
08go00D008go00<0000002D0o`0U0?l01P0U0?l00`000000e`3o0=L0o`07
0=L0o`030000003o0000o`000080oooo00<000000?ooo`3oool01P3oool0
07T0oooo00<000000?ooo`3oool00P3o00000`000000e`3o0=L0o`070=L0
o`030000000U0?l09@3o00H09@3o00<00000002=o`00SOl01@00SOl00`00
00000?no003o_`04003o_`030000003o0000o`0003L0o`0000<00000003o
_`00okl01000okl00`00000008go002=o`04002=o`030000000U0?l09@3o
00H09@3o00<000000=L0o`3G0?l0203G0?l01@000000o`000?ooo`3oool0
000000P0oooo001i0?ooo`80000000<0oooo0?l0000000002P3G0?l00`00
00009@3o02D0o`0602D0o`0300000000SOl008go00D008go00<00000003o
_`00okl00`00okl00`000000o`000?l0000h0?l0000300000000okl00?no
00@00?no00<00000002=o`00SOl01000SOl00`0000009@3o02D0o`0602D0
o`030000003G0?l0e`3o00P0e`3o00D000000?l0003oool0oooo00000008
0?ooo`00N@3oool01@000000oooo0?ooo`3o0000000000X0e`3o00<00000
02D0o`0U0?l01@0U0?l00`00000008go002=o`06002=o`0300000000okl0
0?no00<00?no00<000000?l0003o0000>03o00000`0000000?no003o_`04
003o_`0300000000SOl008go00D008go00<0000002D0o`0U0?l01P0U0?l0
0`000000e`3o0=L0o`070=L0o`050000003o0000oooo0?ooo`000000203o
ool007T0oooo00D000000?ooo`3oool0o`00000000090=L0o`030000000U
0?l09@3o00H09@3o00<00000002=o`00SOl01@00SOl00`0000000?no003o
_`03003o_`030000003o0000o`0003X0o`0000<00000003o_`00okl01000
okl00`00000008go002=o`04002=o`030000000U0?l09@3o00H09@3o00<0
00000=L0o`3G0?l0203G0?l010000000oooo0?ooo`0000080?ooo`00N@3o
ool01@000000oooo0?ooo`3o0000000000T0e`3o00<0000002D0o`0U0?l0
1P0U0?l00`00000008go002=o`05002=o`0300000000okl00?no00<00?no
00<000000?l0003o0000>P3o00000`0000000?no003o_`04003o_`030000
0000SOl008go00@008go00<0000002D0o`0U0?l01P0U0?l00`000000e`3o
0=L0o`080=L0o`040000003oool0oooo000000P0oooo001i0?ooo`050000
003oool0oooo0?l0000000002@3G0?l00`0000009@3o02D0o`0602D0o`03
00000000SOl008go00@008go00<00000003o_`00okl01000okl00`000000
o`000?l0000j0?l0000300000000okl00?no00@00?no00<00000002=o`00
SOl01000SOl00`0000009@3o02D0o`0602D0o`030000003G0?l0e`3o00P0
e`3o00@000000?ooo`3oool00000203oool007T0oooo00D000000?ooo`3o
ool0o`00000000090=L0o`030000000U0?l09@3o00H09@3o00<00000002=
o`00SOl01000SOl00`0000000?no003o_`04003o_`030000003o0000o`00
03/0o`0000<00000003o_`00okl00`00okl00`00000008go002=o`04002=
o`030000000U0?l09@3o00L09@3o00<000000=L0o`3G0?l01`3G0?l01000
0000oooo0?ooo`0000080?ooo`00N@3oool010000000oooo0?ooo`00000:
0=L0o`030000000U0?l09@3o00D09@3o00<00000002=o`00SOl01@00SOl0
0`0000000?no003o_`03003o_`030000003o0000o`0003`0o`0000<00000
003o_`00okl00`00okl00`00000008go002=o`05002=o`030000000U0?l0
9@3o00H09@3o00<000000=L0o`3G0?l01`3G0?l010000000oooo0?ooo`00
00080?ooo`00N@3oool2000000030?ooo`000000e`3o00P0e`3o00<00000
02D0o`0U0?l01P0U0?l00`00000008go002=o`04002=o`0300000000okl0
0?no00@00?no00<000000?l0003o0000?@3o00000`0000000?no003o_`03
003o_`0300000000SOl008go00@008go00<0000002D0o`0U0?l01P0U0?l0
0`000000e`3o0=L0o`070=L0o`040000003oool0oooo000000P0oooo001i
0?ooo`040000003oool0oooo000000T0e`3o00<0000002D0o`0U0?l01P0U
0?l00`00000008go002=o`04002=o`0300000000okl00?no00@00?no00<0
00000?l0003o0000?@3o00000`0000000?no003o_`03003o_`0300000000
SOl008go00@008go00<0000002D0o`0U0?l01P0U0?l00`000000e`3o0=L0
o`070=L0o`040000003oool0oooo000000P0oooo001i0?ooo`040000003o
ool0oooo000000T0e`3o00<0000002D0o`0U0?l01P0U0?l00`00000008go
002=o`04002=o`0300000000okl00?no00@00?no00<000000?l0003o0000
?@3o00000`0000000?no003o_`03003o_`0300000000SOl008go00@008go
00<0000002D0o`0U0?l01P0U0?l00`000000e`3o0=L0o`070=L0o`040000
003oool0oooo000000P0oooo001i0?ooo`040000003oool0oooo000000T0
e`3o00<0000002D0o`0U0?l01P0U0?l00`00000008go002=o`04002=o`03
00000000okl00?no00@00?no00<000000?l0003o0000?@3o00000`000000
0?no003o_`03003o_`0300000000SOl008go00@008go00<0000002D0o`0U
0?l01P0U0?l00`000000e`3o0=L0o`070=L0o`040000003oool0oooo0000
00P0oooo001d0?ooo`8000000`3oool010000000oooo0?ooo`0000090=L0
o`030000000U0?l09@3o00H09@3o00<00000002=o`00SOl01000SOl00`00
00000?no003o_`03003o_`030000003o0000o`0003h0o`0000<00000003o
_`00okl00`00okl00`00000008go002=o`05002=o`030000000U0?l09@3o
00D09@3o00<000000=L0o`3G0?l0203G0?l00`000000oooo000000080?oo
o`00L`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000T0e`3o00<0000002D0o`0U0?l01P0U0?l00`00000008go002=o`04
002=o`0300000000okl00?no00<00?no00<000000?l0003o0000?P3o0000
0`0000000?no003o_`03003o_`0300000000SOl008go00D008go00<00000
02D0o`0U0?l01@0U0?l00`000000e`3o0=L0o`080=L0o`030000003oool0
000000P0oooo001c0?ooo`040000003oool0oooo00000080oooo0P000000
0`3oool000000=L0o`080=L0o`030000000U0?l09@3o00H09@3o00<00000
002=o`00SOl01000SOl00`0000000?no003o_`03003o_`030000003o0000
o`0003h0o`0000<00000003o_`00okl00`00okl00`00000008go002=o`05
002=o`030000000U0?l09@3o00D09@3o00<000000=L0o`3G0?l0203G0?l3
000000P0oooo001c0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000002@3G0?l00`0000009@3o02D0o`0602D0o`0300000000
SOl008go00@008go00<00000003o_`00okl00`00okl00`000000o`000?l0
000n0?l0000300000000okl00?no00<00?no00<00000002=o`00SOl01@00
SOl00`0000009@3o02D0o`0502D0o`030000003G0?l0e`3o00P0e`3o00<0
00000?ooo`000000203oool007<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000090=L0o`030000000U0?l09@3o00H09@3o
00<00000002=o`00SOl01000SOl00`0000000?no003o_`03003o_`030000
003o0000o`0003h0o`0000<00000003o_`00okl00`00okl00`00000008go
002=o`05002=o`030000000U0?l09@3o00D09@3o00<000000=L0o`3G0?l0
203G0?l00`000000oooo000000080?ooo`00M03oool2000000<0oooo00@0
00000?ooo`3oool000002@3G0?l00`0000009@3o02D0o`0602D0o`030000
0000SOl008go00@008go00<00000003o_`00okl00`00okl00`000000o`00
0?l0000n0?l0000300000000okl00?no00<00?no00<00000002=o`00SOl0
1000SOl00`0000009@3o02D0o`0602D0o`030000003G0?l0e`3o00L0e`3o
00@000000?ooo`3oool00000203oool007T0oooo00@000000?ooo`3oool0
00002@3G0?l00`0000009@3o02D0o`0602D0o`0300000000SOl008go00@0
08go00<00000003o_`00okl01000okl00`000000o`000?l0000m0?l00003
00000000okl00?no00<00?no00<00000002=o`00SOl01000SOl00`000000
9@3o02D0o`0602D0o`030000003G0?l0e`3o00L0e`3o00@000000?ooo`3o
ool00000203oool007T0oooo00@000000?ooo`3oool000002@3G0?l00`00
00009@3o02D0o`0602D0o`0300000000SOl008go00@008go00<00000003o
_`00okl01000okl00`000000o`000?l0000m0?l0000300000000okl00?no
00<00?no00<00000002=o`00SOl01000SOl00`0000009@3o02D0o`0602D0
o`030000003G0?l0e`3o00L0e`3o00@000000?ooo`3oool00000203oool0
07T0oooo00@000000?ooo`3oool000002@3G0?l00`0000009@3o02D0o`06
02D0o`0300000000SOl008go00@008go00<00000003o_`00okl01000okl0
0`000000o`000?l0000m0?l0000300000000okl00?no00<00?no00<00000
002=o`00SOl01000SOl00`0000009@3o02D0o`0602D0o`030000003G0?l0
e`3o00L0e`3o00@000000?ooo`3oool00000203oool007T0oooo0P000000
0`3oool000000=L0o`080=L0o`030000000U0?l09@3o00H09@3o00<00000
002=o`00SOl01000SOl00`0000000?no003o_`04003o_`030000003o0000
o`0003d0o`0000<00000003o_`00okl00`00okl00`00000008go002=o`04
002=o`030000000U0?l09@3o00H09@3o00<000000=L0o`3G0?l01`3G0?l0
10000000oooo0?ooo`0000080?ooo`00N@3oool010000000oooo0?ooo`00
000:0=L0o`030000000U0?l09@3o00D09@3o00<00000002=o`00SOl01@00
SOl00`0000000?no003o_`03003o_`030000003o0000o`0003`0o`0000<0
0000003o_`00okl00`00okl00`00000008go002=o`05002=o`030000000U
0?l09@3o00H09@3o00<000000=L0o`3G0?l01`3G0?l010000000oooo0?oo
o`0000080?ooo`00N@3oool01@000000oooo0?ooo`3o0000000000T0e`3o
00<0000002D0o`0U0?l01P0U0?l00`00000008go002=o`04002=o`030000
0000okl00?no00@00?no00<000000?l0003o0000>`3o00000`0000000?no
003o_`03003o_`0300000000SOl008go00@008go00<0000002D0o`0U0?l0
1`0U0?l00`000000e`3o0=L0o`070=L0o`040000003oool0oooo000000P0
oooo001i0?ooo`050000003oool0oooo0?l0000000002@3G0?l00`000000
9@3o02D0o`0602D0o`0300000000SOl008go00@008go00<00000003o_`00
okl01000okl00`000000o`000?l0000j0?l0000300000000okl00?no00@0
0?no00<00000002=o`00SOl01000SOl00`0000009@3o02D0o`0602D0o`03
0000003G0?l0e`3o00P0e`3o00@000000?ooo`3oool00000203oool007T0
oooo00D000000?ooo`3oool0o`00000000090=L0o`030000000U0?l09@3o
00H09@3o00<00000002=o`00SOl01@00SOl00`0000000?no003o_`03003o
_`030000003o0000o`0003X0o`0000<00000003o_`00okl01000okl00`00
000008go002=o`04002=o`030000000U0?l09@3o00H09@3o00<000000=L0
o`3G0?l0203G0?l010000000oooo0?ooo`0000080?ooo`00N@3oool01@00
0000oooo0?ooo`3o0000000000T0e`3o00<0000002D0o`0U0?l01P0U0?l0
0`00000008go002=o`05002=o`0300000000okl00?no00<00?no00<00000
0?l0003o0000>P3o00000`0000000?no003o_`04003o_`0300000000SOl0
08go00@008go00<0000002D0o`0U0?l01P0U0?l00`000000e`3o0=L0o`08
0=L0o`040000003oool0oooo000000P0oooo001i0?ooo`80000000<0oooo
0?l0000000002P3G0?l00`0000009@3o02D0o`0502D0o`0300000000SOl0
08go00H008go00<00000003o_`00okl00`00okl00`000000o`000?l0000h
0?l0000300000000okl00?no00@00?no00<00000002=o`00SOl01@00SOl0
0`0000009@3o02D0o`0602D0o`030000003G0?l0e`3o00L0e`3o00D00000
0?l0003oool0oooo000000080?ooo`00N@3oool01@000000oooo0?ooo`3o
0000000000X0e`3o00<0000002D0o`0U0?l01P0U0?l00`00000008go002=
o`05002=o`0300000000okl00?no00<00?no00<000000?l0003o0000>03o
00000`0000000?no003o_`04003o_`0300000000SOl008go00@008go00<0
000002D0o`0U0?l01P0U0?l00`000000e`3o0=L0o`080=L0o`050000003o
0000oooo0?ooo`000000203oool007T0oooo00<000000?ooo`3oool00P3o
00000`000000e`3o0=L0o`070=L0o`030000000U0?l09@3o00H09@3o00<0
0000002=o`00SOl01@00SOl00`0000000?no003o_`04003o_`030000003o
0000o`0003L0o`0000<00000003o_`00okl01000okl00`00000008go002=
o`04002=o`030000000U0?l09@3o00H09@3o00<000000=L0o`3G0?l0203G
0?l01@000000o`000?ooo`3oool0000000P0oooo001i0?ooo`030000003o
ool0oooo0080o`0000<000000=L0o`3G0?l0203G0?l00`0000009@3o02D0
o`0502D0o`0300000000SOl008go00H008go00<00000003o_`00okl00`00
okl00`000000o`000?l0000f0?l0000300000000okl00?no00@00?no00<0
0000002=o`00SOl01@00SOl00`0000009@3o02D0o`0602D0o`030000003G
0?l0e`3o00L0e`3o00<000000?l0003o00000P3oool00`000000oooo0?oo
o`060?ooo`00N@3oool00`000000oooo0?ooo`020?l000030000003G0?l0
e`3o00P0e`3o00<0000002D0o`0U0?l01P0U0?l00`00000008go002=o`05
002=o`0300000000okl00?no00@00?no00<000000?l0003o0000=@3o0000
0`0000000?no003o_`04003o_`0300000000SOl008go00D008go00<00000
02D0o`0U0?l01P0U0?l00`000000e`3o0=L0o`070=L0o`030000003o0000
o`000080oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?oo
o`3oool00P3o00000`000000e`3o0=L0o`080=L0o`030000000U0?l09@3o
00H09@3o00<00000002=o`00SOl01@00SOl00`0000000?no003o_`05003o
_`030000003o0000o`0003<0o`0000<00000003o_`00okl01000okl00`00
000008go002=o`05002=o`030000000U0?l09@3o00L09@3o00<000000=L0
o`3G0?l01`3G0?l00`000000o`000?l000020?ooo`030000003oool0oooo
00H0oooo001i0?ooo`030000003oool0oooo0080o`0000<000000=L0o`3G
0?l02@3G0?l00`0000009@3o02D0o`0602D0o`0300000000SOl008go00D0
08go00<00000003o_`00okl01000okl00`000000o`000?l0000b0?l00003
00000000okl00?no00@00?no00<00000002=o`00SOl01P00SOl00`000000
9@3o02D0o`0602D0o`030000003G0?l0e`3o00P0e`3o00<000000?l0003o
00000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool2000000050?oo
o`3o0000o`000?l0000000002P3G0?l00`0000009@3o02D0o`0602D0o`03
00000000SOl008go00D008go00<00000003o_`00okl01@00okl00`000000
o`000?l0000`0?l0000300000000okl00?no00D00?no00<00000002=o`00
SOl01@00SOl00`0000009@3o02D0o`0702D0o`030000003G0?l0e`3o00L0
e`3o00@000000?l0003o0000o`000P3oool00`000000oooo0?ooo`060?oo
o`00N@3oool00`000000oooo0?ooo`030?l000030000003G0?l0e`3o00T0
e`3o00<0000002D0o`0U0?l01P0U0?l00`00000008go002=o`05002=o`03
00000000okl00?no00@00?no00<000000?l0003o0000<03o00000`000000
0?no003o_`04003o_`0300000000SOl008go00H008go00<0000002D0o`0U
0?l01P0U0?l00`000000e`3o0=L0o`080=L0o`040000003o0000o`000?l0
0080oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?ooo`3o
ool00`3o00000`000000e`3o0=L0o`090=L0o`030000000U0?l09@3o00H0
9@3o00<00000002=o`00SOl01P00SOl00`0000000?no003o_`04003o_`03
0000003o0000o`0002h0o`0000<00000003o_`00okl01@00okl00`000000
08go002=o`05002=o`030000000U0?l09@3o00L09@3o00<000000=L0o`3G
0?l0203G0?l010000000o`000?l0003o00020?ooo`030000003oool0oooo
00H0oooo001i0?ooo`030000003oool0oooo00<0o`0000<000000=L0o`3G
0?l02@3G0?l00`0000009@3o02D0o`0702D0o`0300000000SOl008go00H0
08go00<00000003o_`00okl01000okl00`000000o`000?l0000/0?l00003
00000000okl00?no00D00?no00<00000002=o`00SOl01@00SOl00`000000
9@3o02D0o`0702D0o`030000003G0?l0e`3o00P0e`3o00<000000?l0003o
00000P3o00020?ooo`030000003oool0oooo00H0oooo001i0?ooo`030000
003oool0oooo00@0o`0000<000000=L0o`3G0?l02@3G0?l00`0000009@3o
02D0o`0602D0o`0300000000SOl008go00L008go00<00000003o_`00okl0
1000okl00`000000o`000?l0000Z0?l0000300000000okl00?no00D00?no
00<00000002=o`00SOl01@00SOl00`0000009@3o02D0o`0802D0o`030000
003G0?l0e`3o00P0e`3o00<000000?l0003o00000P3o00020?ooo`030000
003oool0oooo00H0oooo001i0?ooo`030000003oool0oooo00@0o`0000<0
00000=L0o`3G0?l02@3G0?l00`0000009@3o02D0o`0702D0o`0300000000
SOl008go00H008go00<00000003o_`00okl01@00okl00`000000o`000?l0
000X0?l0000300000000okl00?no00D00?no00<00000002=o`00SOl01P00
SOl00`0000009@3o02D0o`0702D0o`030000003G0?l0e`3o00P0e`3o00<0
00000?l0003o00000`3o00020?ooo`030000003oool0oooo00H0oooo001i
0?ooo`80000000<0oooo0?l0003o00000`3o00000`000000e`3o0=L0o`08
0=L0o`030000000U0?l09@3o00P09@3o00<00000002=o`00SOl01P00SOl0
0`0000000?no003o_`05003o_`8000009P3o0002000000L00?no00<00000
002=o`00SOl01P00SOl00`0000009@3o02D0o`0702D0o`030000003G0?l0
e`3o00T0e`3o00<000000?l0003o00000`3o00020?ooo`030000003oool0
oooo00H0oooo001i0?ooo`030000003oool0oooo00H0o`0000<000000=L0
o`3G0?l0203G0?l00`0000009@3o02D0o`0802D0o`0300000000SOl008go
00H008go00<00000003o_`00okl01P00okl2000002<0o`0000<00000003o
_`00okl01P00okl00`00000008go002=o`07002=o`030000000U0?l09@3o
00L09@3o00<000000=L0o`3G0?l02@3G0?l00`000000o`000?l000030?l0
0080oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?ooo`3o
ool01P3o00000`000000e`3o0=L0o`090=L0o`030000000U0?l09@3o00P0
9@3o00<00000002=o`00SOl01P00SOl00`0000000?no003o_`07003o_`03
0000003o0000o`0001h0o`000P000009003o_`0300000000SOl008go00H0
08go00<0000002D0o`0U0?l01`0U0?l00`000000e`3o0=L0o`090=L0o`03
0000003o0000o`0000@0o`000P3oool00`000000oooo0?ooo`060?ooo`00
N@3oool00`000000oooo0?ooo`070?l000030000003G0?l0e`3o00P0e`3o
00<0000002D0o`0U0?l0200U0?l00`00000008go002=o`07002=o`030000
0000okl00?no00L00?no0P00000L0?l0008000002@00okl2000000P008go
00<0000002D0o`0U0?l0200U0?l00`000000e`3o0=L0o`090=L0o`030000
003o0000o`0000@0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3o
ool00`000000oooo0?ooo`070?l000030000003G0?l0e`3o00T0e`3o00<0
000002D0o`0U0?l0200U0?l00`00000008go002=o`07002=o`8000002@00
okl2000001P0o`000P00000:003o_`0300000000SOl008go00L008go00<0
000002D0o`0U0?l0200U0?l00`000000e`3o0=L0o`090=L0o`030000003o
0000o`0000D0o`000P3oool00`000000oooo0?ooo`060?ooo`00L`3oool5
000000040?ooo`000000oooo0?ooo`L0o`0000<000000=L0o`3G0?l02P3G
0?l00`0000009@3o02D0o`0802D0o`0300000000SOl008go00P008go00<0
0000003o_`00okl02000okl400000100o`001000000:003o_`8000002P00
SOl00`0000009@3o02D0o`0702D0o`030000003G0?l0e`3o00X0e`3o00<0
00000?l0003o00001@3o00020?ooo`030000003oool0oooo00H0oooo001e
0?ooo`050000003oool0oooo0?ooo`0000000P3oool80?l000030000003G
0?l0e`3o00T0e`3o00<0000002D0o`0U0?l0200U0?l00`00000008go002=
o`09002=o`0300000000okl00?no00/00?no1@0000060?l000D000003@00
okl00`00000008go002=o`09002=o`030000000U0?l09@3o00P09@3o00<0
00000=L0o`3G0?l02@3G0?l00`000000o`000?l000060?l00080oooo00<0
00000?ooo`3oool01P3oool007D0oooo00@000000?ooo`3oool0oooo0P00
00000`3oool0o`000?l000060?l000030000003G0?l0e`3o00X0e`3o00<0
000002D0o`0U0?l0200U0?l00`00000008go002=o`09002=o`0300000000
okl00?no00l00?no1P00000A003o_`8000002P00SOl00`0000009@3o02D0
o`0802D0o`030000003G0?l0e`3o00X0e`3o00<000000?l0003o00001P3o
00000`3oool00000000000080?ooo`00M@3oool01@000000oooo0?ooo`3o
ool000000080oooo2@3o00000`000000e`3o0=L0o`090=L0o`030000000U
0?l09@3o00T09@3o0P00000:002=o`8000009000okl2000000/008go00<0
000002D0o`0U0?l02@0U0?l00`000000e`3o0=L0o`090=L0o`030000003o
0000o`0000L0o`000P3oool00`000000oooo0?ooo`060?ooo`00M@3oool0
1@000000oooo0?ooo`3oool000000080oooo2P3o00000`000000e`3o0=L0
o`090=L0o`030000000U0?l09@3o00X09@3o00<00000002=o`00SOl02@00
SOl3000001h00?no0`00000;002=o`8000002`0U0?l00`000000e`3o0=L0
o`0:0=L0o`030000003o0000o`0000L0o`000P3oool00`000000oooo0?oo
o`060?ooo`00M03oool2000000<0oooo00<000000?ooo`3oool02`3o0000
0`000000e`3o0=L0o`090=L0o`030000000U0?l09@3o00X09@3o0P00000<
002=o`<000006000okl3000000d008go00<0000002D0o`0U0?l02P0U0?l0
0`000000e`3o0=L0o`0:0=L0o`030000003o0000o`0000P0o`000P3oool0
0`000000oooo0?ooo`060?ooo`00N@3oool00`000000oooo0?ooo`0;0?l0
00030000003G0?l0e`3o00X0e`3o00<0000002D0o`0U0?l02`0U0?l00`00
000008go002=o`0<002=o`8000005000okl2000000l008go00<0000002D0
o`0U0?l02P0U0?l00`000000e`3o0=L0o`0:0=L0o`030000003o0000o`00
00T0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool00`000000
oooo0?ooo`0<0?l000030000003G0?l0e`3o00X0e`3o00<0000002D0o`0U
0?l02`0U0?l00`00000008go002=o`0=002=o`<000003P00okl300000100
08go00<0000002D0o`0U0?l02P0U0?l00`000000e`3o0=L0o`0:0=L0o`03
0000003o0000o`0000X0o`000P3oool00`000000oooo0?ooo`060?ooo`00
N@3oool2000000030?ooo`3o0000o`0000/0o`0000<000000=L0o`3G0?l0
2P3G0?l00`0000009@3o02D0o`0;02D0o`0300000000SOl008go00l008go
3P00000A002=o`800000300U0?l00`000000e`3o0=L0o`0:0=L0o`030000
003o0000o`0000/0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3o
ool00`000000oooo0?ooo`0>0?l000030000003G0?l0e`3o00X0e`3o00<0
000002D0o`0U0?l02`0U0?l2000002`008go0P00000=02D0o`030000003G
0?l0e`3o00X0e`3o00<000000?l0003o0000303o00020?ooo`030000003o
ool0oooo00H0oooo001i0?ooo`030000003oool0oooo00h0o`0000<00000
0=L0o`3G0?l02`3G0?l00`0000009@3o02D0o`0<02D0o`800000:000SOl2
000000h09@3o00<000000=L0o`3G0?l02`3G0?l00`000000o`000?l0000<
0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?oo
o`3oool03`3o00000`000000e`3o0=L0o`0;0=L0o`030000000U0?l09@3o
00d09@3o0P00000T002=o`8000003`0U0?l00`000000e`3o0=L0o`0;0=L0
o`030000003o0000o`0000d0o`000P3oool00`000000oooo0?ooo`060?oo
o`00N@3oool00`000000oooo0?ooo`0@0?l000030000003G0?l0e`3o00/0
e`3o00<0000002D0o`0U0?l03P0U0?l20000020008go0P00000@02D0o`03
0000003G0?l0e`3o00/0e`3o00<000000?l0003o00003P3o00020?ooo`03
0000003oool0oooo00H0oooo001i0?ooo`030000003oool0oooo0100o`00
00<000000=L0o`3G0?l0303G0?l2000001009@3o0`00000J002=o`<00000
400U0?l2000000h0e`3o00<000000?l0003o00003P3o00020?ooo`030000
003oool0oooo00H0oooo001i0?ooo`030000003oool0oooo0140o`0000<0
00000=L0o`3G0?l03@3G0?l2000001409@3o1@00000@002=o`D000004P0U
0?l00`000000e`3o0=L0o`0=0=L0o`030000003o0000o`0000l0o`000P3o
ool00`000000oooo0?ooo`060?ooo`00N@3oool2000000030?ooo`3o0000
o`000100o`0000<000000=L0o`3G0?l03P3G0?l00`0000009@3o02D0o`0C
02D0oa0000005@0U0?l2000000l0e`3o00<000000?l0003o0000403o0002
0?ooo`030000003oool0oooo00H0oooo001i0?ooo`030000003oool0oooo
01<0o`0000<000000=L0o`3G0?l03P3G0?l2000003L09@3o00<000000=L0
o`3G0?l03P3G0?l00`000000o`000?l0000A0?l00080oooo00<000000?oo
o`3oool01P3oool007T0oooo00<000000?ooo`3oool0503o00000`000000
e`3o0=L0o`0?0=L0o`030000000U0?l09@3o03809@3o0P00000@0=L0o`03
0000003o0000o`000180o`000P3oool00`000000oooo0?ooo`060?ooo`00
N@3oool00`000000oooo0?ooo`0E0?l000800000403G0?l3000002h09@3o
0`00000A0=L0o`030000003o0000o`0001<0o`000P3oool00`000000oooo
0?ooo`060?ooo`00N@3oool00`000000oooo0?ooo`0G0?l000030000003G
0?l0e`3o0100e`3o0`00000X02D0o`<000004P3G0?l2000001H0o`000P3o
ool00`000000oooo0?ooo`060?ooo`00N@3oool00`000000oooo0?ooo`0H
0?l0008000004`3G0?l2000002@09@3o0P00000D0=L0o`030000003o0000
o`0001H0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool20000
00030?ooo`3o0000o`0001P0o`0000<000000=L0o`3G0?l04P3G0?l30000
01h09@3o0`00000D0=L0o`8000006@3o00020?ooo`030000003oool0oooo
00H0oooo001i0?ooo`030000003oool0oooo01/0o`0000<000000=L0o`3G
0?l0503G0?l3000001P09@3o0`00000F0=L0o`030000003o0000o`0001T0
o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool00`000000oooo
0?ooo`0L0?l0008000005`3G0?l5000000h09@3o1@00000G0=L0o`800000
703o00020?ooo`030000003oool0oooo00H0oooo001i0?ooo`030000003o
ool0oooo01h0o`0000<000000=L0o`3G0?l06@3G0?l>000001/0e`3o00<0
00000?l0003o0000703o00020?ooo`030000003oool0oooo00H0oooo001i
0?ooo`030000003oool0oooo01l0o`0000<000000=L0o`3G0?l0@03G0?l0
0`000000o`000?l0000M0?l00080oooo00<000000?ooo`3oool01P3oool0
07T0oooo00<000000?ooo`3oool0803o0002000003h0e`3o0P00000P0?l0
0080oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?ooo`3o
ool08P3o0003000003T0e`3o0P00000R0?l00080oooo00<000000?ooo`3o
ool01P3oool007T0oooo0P0000000`3oool0o`000?l0000S0?l000800000
=@3G0?l2000002@0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3o
ool00`000000oooo0?ooo`0W0?l000030000003G0?l0e`3o0300e`3o0P00
000V0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<00000
0?ooo`3oool0:03o0002000002h0e`3o0P00000X0?l00080oooo00<00000
0?ooo`3oool01P3oool007T0oooo00<000000?ooo`3oool0:P3o00040000
02H0e`3o1000000Z0?l00080oooo00<000000?ooo`3oool01P3oool007<0
oooo100000020?ooo`030000003oool0oooo02h0o`001@00000L0=L0o`D0
0000;P3o00020?ooo`030000003oool0oooo00H0oooo001c0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0<`3o000600000100e`3o
1P00000c0?l00080oooo00<000000?ooo`3oool01P3oool007@0oooo00<0
00000?ooo`3oool00P3oool2000000030?ooo`3o0000o`0003L0o`004000
000i0?l000030?ooo`000000000000P0oooo001e0?ooo`050000003oool0
oooo0?ooo`000000QP3oool00`000000oooo0?ooo`060?ooo`00L`3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo000000080?ooo`00M03o
ool2000000<0ooooR00000080?ooo`00o`3oool:0?ooo`00o`3oool:0?oo
o`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{265, 155},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The transformation  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(w\ \  = \ \ \(u + \ \[ImaginaryI]\ v\  = \ 
          log \((z)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \(\(\(=\)\(\ \)\(log \((x + \ \[ImaginaryI]\ y)\)\)\)\(\ \ \
\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \(\(=\)\(\ \ \)\(ln | 
          x + \ \[ImaginaryI]\ y | \ \(+\ \[ImaginaryI]\)\ arg \((x + \ \
\[ImaginaryI]\ y)\)\)\)\)}]],
  "  \n\nmaps the annular region between the circles  ",
  Cell[BoxData[
      RowBox[{"r", "=", 
        RowBox[{
          RowBox[{"a", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "r"}], "=", "b"}]}]]],
  "  onto the infinite strip  ",
  Cell[BoxData[
      \(ln\ \ a\  < \ u\  < \ ln\ b\)]],
  "  in the w plane, as shown in Figure 11.36.  The potential  ",
  Cell[BoxData[
      RowBox[{"\[CapitalPhi]", 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  "  in the infinite strip has the boundary values  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPhi]", 
          RowBox[{"(", 
            RowBox[{\(ln\ \ a\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], " ", "=", 
        " ", \(U\_1\)}]]],
  "   and   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPhi]", 
          RowBox[{"(", 
            RowBox[{\(ln\ b\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], " ", "=", 
        " ", \(U\_1\)}]]],
  "   for all  ",
  StyleBox["v",
    FontFamily->"Courier New"],
  ". \n\nIf we use the result of Example 11.18, the electrical potential  ",
  Cell[BoxData[
      RowBox[{"\[CapitalPhi]", 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  "  is  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPhi]", 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], "  ", "=", 
        "  ", \(U\_1\ \  + \ \ \(\(U\_2\  - \ 
                  U\_1\)\/\(ln\ b\ \  - \ \ ln\ \ a\)\) \((u - 
                ln\ \ a)\)\)}]],
    AspectRatioFixed->True],
  ".  \n\nBecause  ",
  Cell[BoxData[
      \(u\ \  = \ \ ln | x + \ \[ImaginaryI]\ y | \)]],
  ",  we can use this equation to conclude that the potential  ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  is  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Phi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
        "  ", \(U\_1\ \  + \ \ \(\(U\_2\  - \ 
                  U\_1\)\/\(ln\ b\ \  - \ \ ln\ \ a\)\) \((ln | 
                x + \ \[ImaginaryI]\ y | \ \(-\ ln\)\ \ a)\)\)}]],
    AspectRatioFixed->True],
  ".  \n\nThe equipotentials  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Phi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        "constant"}]]],
  "  are concentric circles centered on the origin, and the lines of flux are \
portions of rays emanating from the origin.  If  ",
  Cell[BoxData[
      \(U\_2 < U\_1\)]],
  ",  then the situation is as illustrated in Figure 11.36."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.36",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/electrostatics/\
ElectrostaticsFigures/mat1136.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The electrical field in a coaxial cylinder, where ",
  Cell[BoxData[
      \(U\_2 < U\_1\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.19.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "This example is similar to Example ",
  "11.",
  "3.  For illustration we use the boundary values  \n\n",
  Cell[BoxData[
      \(\[Phi] \((x, y)\) = \ \ \(0\ \ \ when\ \ \  | z |  = 
          1\), \n\[Phi] \((x, y)\) = \(40\ \ \ when\ \ \  | z |  = 2. \)\)]],
  "\n\nEnter the formula for the electrical potential."
}], "Text"],

Cell[BoxData[{
    \(R = \(U = 0\); \ Remove[R, U];\ \), "\[IndentingNewLine]", 
    \(\(Clear[a, b, c, x, y, cont, \[Phi]];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[cont, \[Phi]];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi][x_, y_] = 
        U\_1 + \(\(U\_2\  - \ U\_1\)\/\(Log[R\_2] - 
                  Log[R\_1]\)\) \((Log[\@\(x\^2 + y\^2\)] - 
                Log[R\_1])\);\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Enter the boundary values  ",
  Cell[BoxData[
      \(a = 1, \ \ b = 2, \ \ U\_1 = \(0\ \ and\ \ U\_2 = 40\)\)]],
  ",  and check out the formula."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(R\_1\ \  = \ 1;\)\ \), "\n", 
    \(\(R\_2\ \  = \ 2;\)\ \), "\n", 
    \(\(U\_1\  = \ 0;\)\ \), "\n", 
    \(\(U\_2\  = \ 40;\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][1,0] = \>", \[Phi][1, 0]];\)\ \), "\n", 
    \(\(Print["\<\[Phi][0,1] = \>", \[Phi][0, 1]];\)\ \), "\n", 
    \(\(Print["\<\[Phi][2,0] = \>", \[Phi][2, 0]];\)\ \), "\n", 
    \(\(Print["\<\[Phi][0,2] = \>", \[Phi][0, 
          2]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the electrical potential."
}], "Text"],

Cell[BoxData[{
    \(\(cont\  = \ Table[0 + 10  k, {k, 0, 4}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Phi][x, y], {x, \(-2\), 2}, {y, \(-2\), 2}, 
        Contours\  \[Rule] \ cont, PlotPoints \[Rule] 25, 
        AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[Phi][x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Hence the electrical potential  ",
  Cell[BoxData[
      \(\[Phi][x, y] = \(40\ Log[\@\(x\^2\  + \ y\^2\)]\)\/Log[2]\)]],
  "  is harmonic in the annulus  ",
  Cell[BoxData[
      \(\(\(1\)\(<\)\) | z | \(\(<\)\(2\)\)\)]],
  "  and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.20.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Find the electrical potential  ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  produced by two charged half-planes that are perpendicular to the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane and pass through the rays  ",
  Cell[BoxData[
      RowBox[{\(x < \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(y = 0\ \ and\ \ x > 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(y = 0\)}]]],
  "  where the planes are kept at the fixed potentials  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", \(-300\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "   ", "x"}], "<", \(-1\)}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->14,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->14,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}], "\n", 
      RowBox[{
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", "  ", 
          "300"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "   ", "x"}], ">", 
          RowBox[{"1", 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005N0000l2000`400?l0
0000o`00003oo`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00
o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?oo
o`00o`3ooomO0?ooo`00g03oool3000007l0oooo003M0?ooo`030000003o
ool0oooo07h0oooo002?0?ooo`030?l0003oool0oooo02X0oooo00<0003o
0?ooo`3oool06`3oool5000000<0oooo00<0o`000000003oool08`3oool0
0`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0oooo02H0oooo002@0?oo
o`030?l0003oool0oooo02T0oooo00<0003o0?ooo`3oool05@3oool40000
0080oooo00@000000?ooo`3oool00000103oool00`3o0000oooo0?ooo`0S
0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool09`3oool0
0900oooo00<0o`000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0K0?oo
o`030000003oool0000000@0oooo00<0o`000?ooo`3oool08P3oool00`00
0?l0oooo0?ooo`0Z0?ooo`030?l0003oool0oooo02L0oooo002A0?ooo`03
0?l0003oool0oooo02T0oooo00<0003o0?ooo`3oool0703oool2000000@0
oooo00<0o`000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0Y0?ooo`03
0?l0003oool0oooo02P0oooo002B0?ooo`030?l0003oool0oooo02P0oooo
00<0003o0?ooo`3oool08P3oool00`3o0000oooo0?ooo`0R0?ooo`030000
o`3oool0oooo02P0oooo00<0o`000?ooo`3oool0:@3oool00980oooo00<0
o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003o
ool0oooo0240oooo00<0003o0?ooo`3oool0:@3oool00`3o0000oooo0?oo
o`0Y0?ooo`00T`3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0
oooo0240oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`0X
0?ooo`030?l0003oool0oooo02X0oooo002C0?ooo`030?l0003oool0oooo
02P0oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?ooo`0Q0?oo
o`030000o`3oool0oooo02L0oooo00<0o`000?ooo`3oool0:`3oool009@0
oooo00<0o`000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0P0?ooo`03
0?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0:03oool00`3o0000
oooo0?ooo`0[0?ooo`00U@3oool00`3o0000oooo0?ooo`0W0?ooo`030000
o`3oool0oooo0200oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo
0?ooo`0W0?ooo`030?l0003oool0oooo02`0oooo002E0?ooo`030?l0003o
ool0oooo02L0oooo00<0003o0?ooo`3oool0803oool00`3o0000oooo0?oo
o`0O0?ooo`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3oool0;03o
ool009H0oooo00<0o`000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0O
0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool09`3oool0
0`3o0000oooo0?ooo`0]0?ooo`00U`3oool00`3o0000oooo0?ooo`0V0?oo
o`030000o`3oool0oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`00
0?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo02h0oooo002G0?ooo`03
0?l0003oool0oooo02L0oooo00<0003o0?ooo`3oool07P3oool00`3o0000
oooo0?ooo`0N0?ooo`030000o`3oool0oooo02L0oooo00<0o`000?ooo`3o
ool0;P3oool009P0oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo
0?ooo`0N0?ooo`030?l0003oool0oooo01h0oooo00<0003o0?ooo`3oool0
9P3oool00`3o0000oooo0?ooo`0_0?ooo`00V@3oool00`3o0000oooo0?oo
o`0U0?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool07P3o
ool00`000?l0oooo0?ooo`0U0?ooo`030?l0003oool0oooo0300oooo002I
0?ooo`030?l0003oool0oooo02H0oooo00<0003o0?ooo`3oool07@3oool0
0`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo02H0oooo00<0o`00
0?ooo`3oool0<03oool009X0oooo00<0o`000?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo01d0oooo00<0003o0?oo
o`3oool09@3oool00`3o0000oooo0?ooo`0a0?ooo`00V`3oool00`3o0000
oooo0?ooo`0T0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3o
ool07@3oool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo0380
oooo002K0?ooo`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool0
703oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo02@0oooo
00<0o`000?ooo`3oool0<`3oool009`0oooo00<0o`000?ooo`3oool0903o
ool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo01`0oooo00<0
003o0?ooo`3oool0903oool00`3o0000oooo0?ooo`0c0?ooo`00W@3oool0
0`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo01`0oooo00<0o`00
0?ooo`3oool0703oool00`000?l0oooo0?ooo`0S0?ooo`030?l0003oool0
oooo03@0oooo002N0?ooo`030?l0003oool0oooo02<0oooo00<0003o0?oo
o`3oool06`3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo
02<0oooo00<0o`000?ooo`3oool0=@3oool009h0oooo00<0o`000?ooo`3o
ool08`3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo01/0
oooo00<0003o0?ooo`3oool08`3oool00`3o0000oooo0?ooo`0e0?ooo`00
W`3oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo01/0oooo
00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0
003oool0oooo03H0oooo002P0?ooo`030?l0003oool0oooo0240oooo00<0
003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3o
ool0oooo0240oooo00<0o`000?ooo`3oool0=`3oool00:00oooo00<0o`00
0?ooo`3oool08P3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0
oooo01X0oooo00<0003o0?ooo`3oool08P3oool00`3o0000oooo0?ooo`0g
0?ooo`00X@3oool00`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo
01X0oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0Q0?oo
o`030?l0003oool0oooo03P0oooo002R0?ooo`030?l0003oool0oooo0200
oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0J0?ooo`03
0000o`3oool0oooo0200oooo00<0o`000?ooo`3oool0>@3oool00:80oooo
00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`0J0?ooo`030?l0
003oool0oooo01T0oooo00<0003o0?ooo`3oool0803oool00`3o0000oooo
0?ooo`0j0?ooo`00X`3oool00`3o0000oooo0?ooo`0P0?ooo`030000o`3o
ool0oooo01T0oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?oo
o`0P0?ooo`030?l0003oool0oooo03X0oooo002T0?ooo`030?l0003oool0
oooo01l0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0I
0?ooo`030000o`3oool0oooo01l0oooo00<0o`000?ooo`3oool0>`3oool0
0780oooo00<0003o0?ooo`3oool0<03oool00`3o0000oooo0?ooo`0N0?oo
o`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool06@3oool00`00
0?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo0340oooo00<0003o0?oo
o`3oool0203oool007<0oooo00<0003o0?ooo`3oool0;`3oool00`3o0000
oooo0?ooo`0O0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3o
ool0603oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo0300
oooo00<0003o0?ooo`3oool02@3oool007@0oooo0P000?l`0?ooo`030?l0
003oool0oooo01h0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo
0?ooo`0H0?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0
;`3oool20000o``0oooo001f0?ooo`030000o`3oool0oooo02h0oooo00<0
o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003o
ool0oooo01P0oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?oo
o`0_0?ooo`030000o`3oool0oooo00`0oooo001g0?ooo`030000o`3oool0
oooo02d0oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0H
0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool07@3oool0
0`3o0000oooo0?ooo`0^0?ooo`030000o`3oool0oooo00d0oooo001h0?oo
o`030000o`3oool0oooo02d0oooo00<0o`000?ooo`3oool07@3oool00`00
0?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?oo
o`3oool07@3oool00`3o0000oooo0?ooo`0]0?ooo`80003o403oool007T0
oooo00<0003o0?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0L0?ooo`03
0000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool05`3oool00`000?l0
oooo0?ooo`0L0?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3o
ool0403oool007X0oooo0P000?l^0?ooo`030?l0003oool0oooo01/0oooo
00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0G0?ooo`030000
o`3oool0oooo01/0oooo00<0o`000?ooo`3oool0;@3oool00`000?l0oooo
0?ooo`0A0?ooo`00O03oool00`000?l0oooo0?ooo`0[0?ooo`030?l0003o
ool0oooo01`0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?oo
o`0F0?ooo`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool0:`3o
ool20000oa@0oooo001m0?ooo`030000o`3oool0oooo02/0oooo00<0o`00
0?ooo`3oool06`3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0
oooo01H0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0[
0?ooo`030000o`3oool0oooo01@0oooo001n0?ooo`80003o;03oool00`3o
0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?oo
o`3oool05P3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo
02X0oooo0P000?lG0?ooo`00P03oool00`000?l0oooo0?ooo`0Z0?ooo`03
0?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool05@3oool00`3o0000
oooo0?ooo`0E0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3o
ool0:P3oool00`000?l0oooo0?ooo`0G0?ooo`00P@3oool00`000?l0oooo
0?ooo`0Y0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool0
5@3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01X0oooo
00<0o`000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0H0?ooo`00PP3o
ool20000obX0oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?oo
o`0E0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool06@3o
ool00`3o0000oooo0?ooo`0X0?ooo`80003o6`3oool008@0oooo00<0003o
0?ooo`3oool0:03oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0
oooo01D0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0I
0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool06`3oool0
08D0oooo00<0003o0?ooo`3oool0:03oool00`3o0000oooo0?ooo`0H0?oo
o`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0503oool00`00
0?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?oo
o`3oool0703oool008H0oooo0P000?lX0?ooo`030?l0003oool0oooo01P0
oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool09P3oool20000oal0
oooo00280?ooo`030000o`3oool0oooo02H0oooo00<0o`000?ooo`3oool0
5`3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo01@0oooo
00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0V0?ooo`030000
o`3oool0oooo01l0oooo00290?ooo`030000o`3oool0oooo02H0oooo00<0
o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003o
ool0oooo01<0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?oo
o`0V0?ooo`030000o`3oool0oooo0200oooo002:0?ooo`80003o9P3oool0
0`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo01<0oooo00<0o`00
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0
oooo02@0oooo0P000?lS0?ooo`00S03oool00`000?l0oooo0?ooo`0T0?oo
o`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool04`3oool00`3o
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?oo
o`3oool0903oool00`000?l0oooo0?ooo`0S0?ooo`00S@3oool00`000?l0
oooo0?ooo`0T0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo01H0
oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`0T0?ooo`00
SP3oool20000ob@0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo
0?ooo`0:0?ooo`@00000103oool00`3o0000oooo0?ooo`0B0?ooo`030000
o`3oool0oooo01H0oooo00<0o`000?ooo`3oool08P3oool20000obL0oooo
002@0?ooo`030000o`3oool0oooo0280oooo00<0o`000?ooo`3oool05@3o
ool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo00D0oooo00<0
o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003o
ool0oooo0280oooo00<0003o0?ooo`3oool09`3oool00940oooo00<0003o
0?ooo`3oool08@3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0
oooo00X0oooo00<000000?ooo`3oool0103oool00`3o000000000?ooo`0A
0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool08P3oool0
0`000?l0oooo0?ooo`0X0?ooo`00TP3oool20000ob80oooo00<0o`000?oo
o`3oool05@3oool00`000?l0oooo0?ooo`030?ooo`@00000103oool00`00
0000oooo0?ooo`030?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool05@3oool00`3o0000oooo0?ooo`0P0?ooo`80003o:`3oool009@0
oooo00<0003o0?ooo`3oool0803oool00`3o0000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo00T0oooo00@000000?ooo`3oool00000103oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?oo
o`3oool0803oool00`000?l0oooo0?ooo`0[0?ooo`00U@3oool00`000?l0
oooo0?ooo`0O0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3o
ool02@3oool2000000D0oooo00<0o`000?ooo`3oool0403oool00`000?l0
oooo0?ooo`0E0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3o
ool0;03oool009H0oooo00<0003o0?ooo`3oool07`3oool00`3o0000oooo
0?ooo`0D0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0
403oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo01l0oooo
00<0003o0?ooo`3oool0;@3oool009L0oooo0P000?lP0?ooo`030?l0003o
ool0oooo01<0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool07P3o
ool20000oc00oooo002I0?ooo`030000o`3oool0oooo01d0oooo00<0o`00
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0M
0?ooo`030000o`3oool0oooo0300oooo002J0?ooo`030000o`3oool0oooo
01d0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool04`3oool00`3o
0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo0340oooo002K0?ooo`03
0000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo0380
oooo002L0?ooo`80003o7@3oool00`3o0000oooo0?ooo`0B0?ooo`030000
o`3oool0oooo00l0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`0B0?ooo`030?l0003oool0oooo01/0oooo0P000?le0?ooo`00WP3o
ool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo0180oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo0180oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?oo
o`0e0?ooo`00W`3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool06`3oool0
0`000?l0oooo0?ooo`0f0?ooo`00X03oool00`000?l0oooo0?ooo`0J0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool06`3oool00`000?l0oooo0?ooo`0g0?ooo`00X@3oool20000oa/0
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0I0?ooo`80003o>P3oool00:<0oooo00<0003o0?ooo`3oool0
6@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0
003oool0oooo01T0oooo00<0003o0?ooo`3oool0>P3oool00:@0oooo00<0
003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool0>`3o
ool00:D0oooo0P000?lI0?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00l0oooo00<0o`000?ooo`3oool05`3oool20000och0oooo002W0?oo
o`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo
03h0oooo002X0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0G0?ooo`03
0000o`3oool0oooo03l0oooo002Y0?ooo`80003o5`3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo01D0oooo
0P000?m20?ooo`00Z`3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool05@3o
ool00`000?l0oooo0?ooo`120?ooo`00LP3oool20?l003P0oooo00<0003o
0?ooo`3oool0503oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0=`3oool2
0?l000X0oooo001d0?ooo`<0o`00=P3oool20000oaD0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0C0?oo
o`80003o=P3oool40?l000`0oooo001g0?ooo`<0o`00=@3oool00`000?l0
oooo0?ooo`0C0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0c0?ooo`<0
o`00403oool007X0oooo103o000b0?ooo`030000o`3oool0oooo0180oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0B0?ooo`030000o`3oool0oooo0340oooo0`3o000C0?ooo`00OP3o
ool30?l00300oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0180oooo00<0
003o0?ooo`3oool0;P3oool40?l001H0oooo00210?ooo`<0o`00;P3oool2
0000oa80oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0@0?ooo`80003o;P3oool30?l001X0oooo00240?oo
o`<0o`00;@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0[0?ooo`<0o`007@3oool008L0oooo0`3o000[0?ooo`03
0000o`3oool0oooo0100oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo02T0
oooo0`3o000P0?ooo`00RP3oool20?l002X0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00l0oooo00<0003o0?ooo`3oool0:03oool20?l002<0oooo
002<0?ooo`<0o`00:03oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0V0?ooo`<0o`009@3oool008l0oooo0`3o000V
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo02@0oooo0`3o000X0?ooo`00TP3oool30?l002@0oooo0P000?l?0?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool03@3oool20000ob@0oooo0`3o000[0?ooo`00U@3oool30?l002<0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool08@3oool30?l002h0oooo002H0?ooo`<0o`008@3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0O0?ooo`<0o`00
<@3oool009/0oooo0`3o000O0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo01d0oooo0`3o000d0?ooo`00WP3oool3
0?l001d0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool06`3oool30?l003L0oooo002Q0?ooo`<0o`006`3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0I0?oo
o`<0o`00>P3oool00:@0oooo0P3o000J0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo01P0oooo0P3o000m0?ooo`00
YP3oool20?l001T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool05`3oool20?l003l0oooo002X0?ooo`80o`00603o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0F0?ooo`80o`00@@3oool00:X0oooo0P3o000G0?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo01D0oooo0P3o0013
0?ooo`00[03oool30?l001D0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool04`3oool30?l004D0oooo002_0?ooo`<0
o`004P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`0@0?ooo`<0o`00B03oool00;80oooo0`3o000@0?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00h0oooo
0`3o001;0?ooo`00]@3oool30?l000h0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0303oool30?l004h0oooo001e
0?ooo`<00000<`3oool4000000T0oooo0P3o000=0?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00/0oooo0P3o000;
0?ooo`@00000=`3oool3000000P0oooo001f0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0303oool20?l000`0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool02P3oool20?l0
00d0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`070?oo
o`00L`3oool5000003@0oooo00<000000?ooo`3oool03@3oool20?l000X0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool02@3oool20?l00100oooo00<000000?ooo`3oool0=@3oool5000000P0
oooo001]0?ooo`@000000P3oool010000000oooo0?ooo`00000^0?ooo`@0
0000103oool00`000000oooo0?ooo`0>0?ooo`80o`002@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`80
o`004`3oool00`000000oooo0?ooo`0d0?ooo`040000003oool0oooo0000
00T0oooo001d0?ooo`030000003oool0000003@0oooo00@000000?ooo`3o
ool000004@3oool20?l000L0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01P3oool20?l001<0oooo00@000000?oo
o`3oool00000=P3oool00`000000oooo000000090?ooo`00M@3oool20000
03D0oooo0P00000D0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`0D0?ooo`800000>03oool2000000T0oooo00330?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`1J0?ooo`00
a03oool20?l000D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool20?l005d0oooo00360?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`1M0?ooo`00a`3oool0
1@3o0000oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`050000o`3o
ool0oooo0?ooo`3o0000H03oool00780ooooE@000?l20?l00080000000<0
003o0000000000000`0000000`3o0000000000000005000000030000o`00
0000000000H0000000<0o`000000000000001P0000000`000?l000000000
0005000000030?l000000000000000<0000000D0003o0000000000000000
0?l0001F0000o`X0oooo001b0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool06P3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o0000703oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo00P0oooo001b0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool06P3oool01@3o0000oooo
0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?oo
o`3o0000703oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
00P0oooo00360?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`1M0?ooo`00a@3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0G03oool00<@0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo05/0oooo00320?ooo`80o`001P3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`80o`00F`3oool00<00oooo0P3o00070?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo0P3o001I0?oo
o`00_P3oool20?l000T0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01`3oool20?l005L0oooo002l0?ooo`80o`00
2P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`080?ooo`80o`00E@3oool00;X0oooo0P3o000;0?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00X0oooo0P3o
001C0?ooo`00^03oool20?l000d0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool02`3oool20?l00540oooo002e0?oo
o`<0o`003P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0<0?ooo`<0o`00CP3oool00;80oooo0`3o000@0?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00h0
oooo0`3o001;0?ooo`00[`3oool30?l00180oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0403oool30?l004P0oooo
002/0?ooo`<0o`005@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0C0?ooo`<0o`00A@3oool00:X0oooo0P3o000G
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo01D0oooo0P3o00130?ooo`00Z03oool20?l001P0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool05P3oool20?l0
0440oooo002V0?ooo`80o`006@3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0G0?ooo`80o`00?`3oool00:@0oooo
0P3o000J0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo01P0oooo0P3o000m0?ooo`00X@3oool30?l001X0oooo0P00
0?l<0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool02`3oool20000oaX0oooo0`3o000j0?ooo`00WP3oool3
0?l001`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool06P3oool30?l003L0oooo002K0?ooo`<0o`007P3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0L0?oo
o`<0o`00=03oool009L0oooo103o000P0?ooo`030000o`3oool0oooo00d0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo01h0oooo103o000`0?ooo`00
U03oool30?l002<0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00h0oooo
00<0003o0?ooo`3oool08@3oool30?l002d0oooo002A0?ooo`<0o`009@3o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`0S0?ooo`<0o`00:P3oool008h0oooo0`3o000W0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo02D0oooo0`3o000W
0?ooo`00R`3oool30?l002T0oooo00<0003o0?ooo`3oool03`3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00l0oooo00<0003o0?ooo`3oool09`3oool30?l002@0oooo00280?ooo`<0
o`00:`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0403oool00`000?l0
oooo0?ooo`0Y0?ooo`<0o`008@3oool008D0oooo0`3o000]0?ooo`030000
o`3oool0oooo0100oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo02/0oooo
0`3o000N0?ooo`00PP3oool30?l002l0oooo00<0003o0?ooo`3oool0403o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool0;@3oool30?l001/0oooo001o
0?ooo`<0o`00<03oool20000oa<0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0A0?ooo`80003o<03oool3
0?l001P0oooo001l0?ooo`<0o`00<P3oool00`000?l0oooo0?ooo`0B0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0`0?ooo`<0o`005@3oool007X0
oooo0P3o000d0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0C0?ooo`03
0000o`3oool0oooo0380oooo0`3o000B0?ooo`00M`3oool30?l003D0oooo
00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0
=03oool30?l000l0oooo001d0?ooo`<0o`00=P3oool20000oaD0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`0C0?ooo`80003o=`3oool30?l000`0oooo001b0?ooo`80o`00>03oool0
0`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0g
0?ooo`80o`002P3oool00:/0oooo00<0003o0?ooo`3oool05@3oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
01D0oooo00<0003o0?ooo`3oool0@P3oool00:X0oooo00<0003o0?ooo`3o
ool05@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0@@3oool00:P0oooo
0P000?lH0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool05P3oool20000od40oooo002W0?ooo`030000o`3o
ool0oooo01L0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo03h0oooo002V
0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0
oooo03d0oooo002T0?ooo`80003o6P3oool00`3o0000oooo0?ooo`0?0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo01P0oooo0P000?lm0?oo
o`00X`3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo0100oooo00<0o`000?ooo`3oool06@3oool00`000?l0
oooo0?ooo`0j0?ooo`00XP3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
6@3oool00`000?l0oooo0?ooo`0i0?ooo`00X03oool20000oa/0oooo00<0
o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0J0?ooo`80003o>@3oool009l0oooo00<0003o0?ooo`3oool06`3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo01/0oooo00<0003o0?ooo`3oool0=P3oool009h0oooo00<0003o0?oo
o`3oool06`3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0B0?oo
o`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool0=@3oool009d0
oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0C0?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0C0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3o
ool0=03oool009/0oooo0P000?lN0?ooo`030?l0003oool0oooo0180oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo0180oooo00<0o`000?ooo`3oool0703oool20000oc@0oooo
002J0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00l0oooo00<0
003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3o
ool0oooo0340oooo002I0?ooo`030000o`3oool0oooo01d0oooo00<0o`00
0?ooo`3oool0503oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0M
0?ooo`030000o`3oool0oooo0300oooo002H0?ooo`030000o`3oool0oooo
01h0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0@0?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04`3oool00`3o
0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo02l0oooo002F0?ooo`80
003o803oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0100
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0D0?ooo`03
0?l0003oool0oooo01h0oooo0P000?l_0?ooo`00U@3oool00`000?l0oooo
0?ooo`0O0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0
403oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo01D0oooo
00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0/0?ooo`00U03o
ool00`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo01@0oooo00<0
003o0?ooo`3oool02@3oool4000000@0oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0200oooo00<0
003o0?ooo`3oool0:`3oool009<0oooo00<0003o0?ooo`3oool0803oool0
0`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00T0oooo00<00000
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo01D0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`0Z
0?ooo`00T@3oool20000ob80oooo00<0o`000?ooo`3oool05P3oool00`00
0?l0oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00<0o`000000
003oool04@3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo
0240oooo0P000?lZ0?ooo`00T03oool00`000?l0oooo0?ooo`0R0?ooo`03
0?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0303oool00`000000
oooo0?ooo`030?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o
ool05@3oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo02L0
oooo002?0?ooo`030000o`3oool0oooo0280oooo00<0o`000?ooo`3oool0
5P3oool00`000?l0oooo0?ooo`0:0?ooo`040000003oool0oooo000000@0
oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo0280oooo00<0003o0?ooo`3oool09P3oool008d0oooo
0P000?lU0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0
2`3oool2000000D0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo
0?ooo`0F0?ooo`030?l0003oool0oooo02<0oooo0P000?lV0?ooo`00S03o
ool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo01H0oooo00<0
003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3o
ool0oooo01H0oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?oo
o`0S0?ooo`00R`3oool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0
oooo01L0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0C
0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0903oool0
0`000?l0oooo0?ooo`0R0?ooo`00R@3oool20000obL0oooo00<0o`000?oo
o`3oool05`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo
01<0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0U0?oo
o`80003o8P3oool008P0oooo00<0003o0?ooo`3oool09P3oool00`3o0000
oooo0?ooo`0G0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3o
ool0503oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo02H0
oooo00<0003o0?ooo`3oool07`3oool008L0oooo00<0003o0?ooo`3oool0
9P3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo01@0oooo
00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0H0?ooo`030?l0
003oool0oooo02H0oooo00<0003o0?ooo`3oool07P3oool008D0oooo0P00
0?lY0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0503o
ool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo01P0oooo00<0
o`000?ooo`3oool09`3oool20000oah0oooo00240?ooo`030000o`3oool0
oooo02P0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0E
0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool06@3oool0
0`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo01/0oooo00230?oo
o`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3oool06@3oool00`00
0?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?oo
o`3oool06@3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo
01X0oooo00210?ooo`80003o:P3oool00`3o0000oooo0?ooo`0J0?ooo`03
0000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool05@3oool00`000?l0
oooo0?ooo`0J0?ooo`030?l0003oool0oooo02P0oooo0P000?lJ0?ooo`00
P03oool00`000?l0oooo0?ooo`0Z0?ooo`030?l0003oool0oooo01X0oooo
00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0E0?ooo`030000
o`3oool0oooo01X0oooo00<0o`000?ooo`3oool0:P3oool00`000?l0oooo
0?ooo`0G0?ooo`00O`3oool00`000?l0oooo0?ooo`0Z0?ooo`030?l0003o
ool0oooo01X0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?oo
o`0F0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3oool0:P3o
ool00`000?l0oooo0?ooo`0F0?ooo`00O@3oool20000ob`0oooo00<0o`00
0?ooo`3oool06`3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0
oooo01H0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0Z
0?ooo`80003o5P3oool007`0oooo00<0003o0?ooo`3oool0;03oool00`3o
0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?oo
o`3oool05P3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo
02`0oooo00<0003o0?ooo`3oool04`3oool007/0oooo00<0003o0?ooo`3o
ool0;03oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo01L0
oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0K0?ooo`03
0?l0003oool0oooo02`0oooo0P000?lC0?ooo`00N@3oool20000obh0oooo
00<0o`000?ooo`3oool0703oool00`000?l0oooo0?ooo`0G0?ooo`030?l0
003oool0oooo01L0oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo
0?ooo`0]0?ooo`030000o`3oool0oooo0100oooo001h0?ooo`030000o`3o
ool0oooo02h0oooo00<0o`000?ooo`3oool0703oool00`000?l0oooo0?oo
o`0G0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool0703o
ool00`3o0000oooo0?ooo`0^0?ooo`030000o`3oool0oooo00l0oooo001g
0?ooo`030000o`3oool0oooo02h0oooo00<0o`000?ooo`3oool0703oool0
0`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo01P0oooo00<0003o
0?ooo`3oool0703oool00`3o0000oooo0?ooo`0^0?ooo`80003o3`3oool0
07H0oooo00<0003o0?ooo`3oool0;P3oool00`3o0000oooo0?ooo`0M0?oo
o`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0603oool00`00
0?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo02l0oooo00<0003o0?oo
o`3oool0303oool007@0oooo0P000?l`0?ooo`030?l0003oool0oooo01h0
oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0H0?ooo`03
0000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0
oooo0?ooo`0;0?ooo`00L`3oool00`000?l0oooo0?ooo`0`0?ooo`030?l0
003oool0oooo01d0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo
0?ooo`0H0?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0
<03oool20000o`/0oooo001b0?ooo`030000o`3oool0oooo0300oooo00<0
o`000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003o
ool0oooo01T0oooo00<0003o0?ooo`3oool07P3oool00`3o0000oooo0?oo
o`0a0?ooo`030000o`3oool0oooo00P0oooo002T0?ooo`030?l0003oool0
oooo01l0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0I
0?ooo`030000o`3oool0oooo01l0oooo00<0o`000?ooo`3oool0>`3oool0
0:@0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0I0?oo
o`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool07`3oool00`3o
0000oooo0?ooo`0k0?ooo`00X`3oool00`3o0000oooo0?ooo`0O0?ooo`03
0000o`3oool0oooo01X0oooo00<0o`000?ooo`3oool06P3oool00`000?l0
oooo0?ooo`0O0?ooo`030?l0003oool0oooo03X0oooo002R0?ooo`030?l0
003oool0oooo0200oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo
0?ooo`0J0?ooo`030000o`3oool0oooo0200oooo00<0o`000?ooo`3oool0
>@3oool00:80oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?oo
o`0J0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool0803o
ool00`3o0000oooo0?ooo`0i0?ooo`00X@3oool00`3o0000oooo0?ooo`0P
0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool06`3oool0
0`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo03P0oooo002P0?oo
o`030?l0003oool0oooo0240oooo00<0003o0?ooo`3oool06`3oool00`3o
0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo0240oooo00<0o`000?oo
o`3oool0=`3oool00:00oooo00<0o`000?ooo`3oool08@3oool00`000?l0
oooo0?ooo`0K0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3o
ool08@3oool00`3o0000oooo0?ooo`0g0?ooo`00W`3oool00`3o0000oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool0
6`3oool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo03H0oooo
002N0?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool0703o
ool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo0280oooo00<0
o`000?ooo`3oool0=@3oool009d0oooo00<0o`000?ooo`3oool08`3oool0
0`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo01`0oooo00<0003o
0?ooo`3oool08`3oool00`3o0000oooo0?ooo`0d0?ooo`00W@3oool00`3o
0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo01`0oooo00<0o`000?oo
o`3oool0703oool00`000?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo
03@0oooo002L0?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3o
ool07@3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo02<0
oooo00<0o`000?ooo`3oool0<`3oool009/0oooo00<0o`000?ooo`3oool0
903oool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo01d0oooo
00<0003o0?ooo`3oool0903oool00`3o0000oooo0?ooo`0b0?ooo`00V`3o
ool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo01d0oooo00<0
o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0T0?ooo`030?l0003o
ool0oooo0380oooo002J0?ooo`030?l0003oool0oooo02@0oooo00<0003o
0?ooo`3oool07P3oool00`3o0000oooo0?ooo`0N0?ooo`030000o`3oool0
oooo02@0oooo00<0o`000?ooo`3oool0<@3oool009T0oooo00<0o`000?oo
o`3oool09@3oool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo
01h0oooo00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`0`0?oo
o`00V@3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo01h0
oooo00<0o`000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0U0?ooo`03
0?l0003oool0oooo0300oooo002H0?ooo`030?l0003oool0oooo02D0oooo
00<0003o0?ooo`3oool07`3oool00`3o0000oooo0?ooo`0O0?ooo`030000
o`3oool0oooo02D0oooo00<0o`000?ooo`3oool0;`3oool009L0oooo00<0
o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003o
ool0oooo01l0oooo00<0003o0?ooo`3oool09P3oool00`3o0000oooo0?oo
o`0^0?ooo`00U`3oool00`3o0000oooo0?ooo`0V0?ooo`030000o`3oool0
oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0V
0?ooo`030?l0003oool0oooo02h0oooo002F0?ooo`030?l0003oool0oooo
02H0oooo00<0003o0?ooo`3oool0803oool00`3o0000oooo0?ooo`0P0?oo
o`030000o`3oool0oooo02H0oooo00<0o`000?ooo`3oool0;@3oool009D0
oooo00<0o`000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0P0?ooo`03
0?l0003oool0oooo0200oooo00<0003o0?ooo`3oool09`3oool00`3o0000
oooo0?ooo`0/0?ooo`00U@3oool00`3o0000oooo0?ooo`0W0?ooo`030000
o`3oool0oooo0200oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo
0?ooo`0W0?ooo`030?l0003oool0oooo02`0oooo002D0?ooo`030?l0003o
ool0oooo02L0oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?oo
o`0Q0?ooo`030000o`3oool0oooo02L0oooo00<0o`000?ooo`3oool0:`3o
ool009<0oooo00<0o`000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0Q
0?ooo`030?l0003oool0oooo0240oooo00<0003o0?ooo`3oool0:03oool0
0`3o0000oooo0?ooo`0Z0?ooo`00TP3oool00`3o0000oooo0?ooo`0Y0?oo
o`030000o`3oool0oooo0240oooo00<0o`000?ooo`3oool08@3oool00`00
0?l0oooo0?ooo`0Y0?ooo`030?l0003oool0oooo02T0oooo002B0?ooo`03
0?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool08P3oool00`3o0000
oooo0?ooo`0R0?ooo`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3o
ool0:@3oool00940oooo00<0o`000?ooo`3oool0:@3oool00`000?l0oooo
0?ooo`0R0?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool0
:@3oool00`3o0000oooo0?ooo`0X0?ooo`00T03oool00`3o0000oooo0?oo
o`0Z0?ooo`030000o`3oool0oooo01`0oooo0`0000030?ooo`030?l0003o
ool0oooo0280oooo00<0003o0?ooo`3oool0:P3oool00`3o0000oooo0?oo
o`0W0?ooo`00T03oool00`3o0000oooo0?ooo`0Y0?ooo`030000o`3oool0
oooo01h0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0S
0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool09`3oool0
08l0oooo00<0o`000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0K0?oo
o`D000000`3oool00`3o000000000?ooo`0S0?ooo`030000o`3oool0oooo
02X0oooo00<0o`000?ooo`3oool09P3oool00=X0oooo00@000000?ooo`3o
ool00000P03oool00=/0oooo00<000000?ooo`000000P03oool00=`0oooo
0P0000200?ooo`00o`3ooomO0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{350, 240},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The result of Example 10.13 shows that the function  \n\n\t\t\t\
",
  Cell[BoxData[{
      \(\(\(w\ \  = \ \ u + \ \[ImaginaryI]\ v\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(\(=\)\(\ \ \)\(Arcsin \((z)\)\)\)\(\ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\ \)\(Arcsin \((x + \[ImaginaryI]\ y)\)\)\)\)}]],
  "  \n\nis a conformal mapping of the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane slit along the two rays  ",
  Cell[BoxData[
      RowBox[{\(x < \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(y = 0\ \ and\ \ x > 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(y = 0\)}]]],
  "  onto the vertical strip  ",
  Cell[BoxData[
      \(\(-\(\[Pi]\/2\)\)\  < \ u\  < \ \[Pi]\/2\)]],
  ". The new problem is to find the potential  ",
  Cell[BoxData[
      RowBox[{"\[CapitalPhi]", 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  "  that satisfies the boundary values  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalPhi]", 
            RowBox[{"(", 
              RowBox[{\(-\(\[Pi]\/2\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "v"}], ")"}]}], " ", "=", 
          " ", \(-300\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["all",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "v"}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->14,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->14,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}], "\n", 
      RowBox[{"   ", 
        RowBox[{
          RowBox[{
            RowBox[{"\[CapitalPhi]", 
              RowBox[{"(", 
                RowBox[{\(\[Pi]\/2\), 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->14,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "v"}], ")"}]}], " ", "=", "   ",
             "300"}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->14,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", 
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["all",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", 
            RowBox[{"v", 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]}]],
  "  \n\nFrom Example 11.1,\n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPhi]", 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], "  ", "=", 
        "  ", \(\(600\/\[Pi]\) u\)}]],
    AspectRatioFixed->True],
  ".  \n\nAs in the discussion of Example 11.17, the solution in the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane is \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
          "  ", \(\(600\/\[Pi]\) 
            Re \((Arcsin \((x + \[ImaginaryI]\ y)\))\)\)}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "                 ", \(\(=\)\(\ \ \)\(\(600\/\[Pi]\) 
            Arcsin \((\(\@\(\((x + 1)\)\^2 + y\^2\)\  - \ \@\(\((x - 1)\)\^2 \
+ y\^2\)\)\/2)\)\)\)}]}],
    AspectRatioFixed->True],
  ".  \n\n Several equipotential curves are shown in Figure 11.37."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.37",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/electrostatics/\
ElectrostaticsFigures/mat1137.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The electric field produced by two charged half-planes \n\t\t\t\t\tthat \
are perpendicular to the complex plane. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.20.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the formula for the electrical potential.", "Text"],

Cell[BoxData[{
    \(\(Clear[x, y, cont, \[Phi]];\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ 
        600\/\[Pi]\ Re[ArcSin[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, y]];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        ComplexExpand[\[Phi][x, y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi][x_, y_]\  = \ 
        600\/\[Pi]\ ArcSin[\(\@\(\((x + 1)\)\^2\  + \ y\^2\)\  - \@\(\((x - \
1)\)\^2\  + \ y\^2\)\)\/2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Check out the formula at some boundary values.", "Text"],

Cell[BoxData[{
    \(\(Print["\< \[Phi][x,y] = \>", \[Phi][x, y]];\)\ \), "\n", 
    \(\(Print["\<\[Phi][-1,0] = \>", \[Phi][\(-2\), 
          0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][-1,0] = \>", \[Phi][\(-1\), 0]];\)\ \), "\n", 
    \(\(Print["\< \[Phi][0,1] = \>", \[Phi][0, 1]];\)\ \), "\n", 
    \(\(Print["\< \[Phi][1,0] = \>", \[Phi][1, 
          0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \[Phi][1,0] = \>", \[Phi][2, 
          0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the electrical potential."
}], "Text"],

Cell[BoxData[{
    \(\(\[Phi][x_, y_]\  = \ 
        600\/\[Pi]\ Re[
            ArcSin[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(cont\  = \ Table[\(-300\)\  + \ 60  k, {k, 0, 10}];\)\ \), "\n", 
    \(\(ContourPlot[\[Phi][x, y], {x, \(-4\), 4}, {y, \(-4\), 4}, 
        Contours\  \[Rule] \ cont, PlotPoints \[Rule] 50, 
        AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[Phi][x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The following commands will graph the contours as parametric curves.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[X, Y, z, Z, w];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[F, solset];\)\ \), "\n", 
    \(\(F[z_]\  = \ 600\/\[Pi]\ ArcSin[z];\)\ \), "\n", 
    \(\(solset\  = \ Solve[w\  \[Equal] \ F[z], z];\)\ \), "\n", 
    \(\(Z[u_, v_]\  = \ 
        ReplaceAll[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), 
          w \[Rule] u\  + \ \[ImaginaryI]\ v];\)\ \), "\n", 
    \(\(X[u_, v_]\  = \ ComplexExpand[Re[Z[u, v]]];\)\ \), "\n", 
    \(\(Y[u_, v_]\  = \ ComplexExpand[Im[Z[u, v]]];\)\ \), "\n", 
    \(\(Print["\<w = \>", F[z]];\)\ \), "\n", 
    \(\(Print["\<Z = \>", Z[u, v]];\)\ \), "\n", 
    \(\(Print["\<Z = \>", 
        ComplexExpand[Z[u, v]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<X = \>", X[u, v]];\)\ \), "\n", 
    \(\(Print["\<Y = \>", Y[u, v]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[k];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns\  = \ 
        N[Table[{X[k\ 60, v], Y[k\ 60, v]}, {k, \(-5\), 5, 
              2}]];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns], {v, \(-500\), 500}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(eqns\  = \ 
        N[Table[{X[k\ 60, v], Y[k\ 60, v]}, {k, \(-4\), 4, 
              2}]];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns], {v, \(-500\), 500}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, PlotRange \[Rule] {{\(-4\), 4}, {\(-4\), 4}}, 
        AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-4\), 4, 1], Range[\(-4\), 4, 2]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[Phi][x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Hence the electrical potential  ",
  Cell[BoxData[
      \(\[Phi][x, y] = \(600\ Re[ArcSin[x + \[ImaginaryI]\ y]]\)\/\[Pi]\)]],
  "  is harmonic in plane slit along the rays  ",
  Cell[BoxData[
      \(x < \(-1\), y = 0\ \ and\ \ x > 1, y = 0\)]],
  "  and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.21.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the electrical potential  ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  in the disk  ",
  Cell[BoxData[
      \(D : \(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  "  that satisfies the boundary values\n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "=", "80"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "   ", "x"}], 
              "+", \(\[ImaginaryI]\ y\)}], "=", 
            RowBox[{
              RowBox[{"z", "  ", 
                StyleBox["on",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "  ", \(C\_1\)}], 
              "=", \({z = \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\  : \ 
                    0 < \[Theta] < \[Pi]\/2}\)}]}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->14,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->14,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "=", "  ", "0"}], 
        
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "   ", "x"}], 
            "+", \(\[ImaginaryI]\ y\)}], "=", 
          RowBox[{
            RowBox[{"z", "  ", 
              StyleBox["on",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(C\_2\)}], "=", 
            
            RowBox[{\({z = \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\  : \ \
\[Pi]\/2 < \[Theta] < 2  \[Pi]}\), 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005N0000l2000`400?l0
0000o`00003oo`3ooomO0?ooo`00o`3ooomO0?ooo`00o`3ooomO0?ooo`00
o`3ooomO0?ooo`00o`3ooomO0?ooo`00h@3oool00`000000oooo0?ooo`1j
0?ooo`00h@3oool00`000000oooo0?ooo`1j0?ooo`00h@3oool00`000000
oooo0?ooo`1j0?ooo`00h@3oool00`000000oooo0?ooo`1j0?ooo`00h@3o
ool00`000000oooo0?ooo`1j0?ooo`00h@3oool00`000000oooo0?ooo`1j
0?ooo`00h@3oool00`000000oooo0?ooo`1j0?ooo`00h@3oool00`000000
oooo0?ooo`1j0?ooo`00h@3oool00`000000oooo0?ooo`1j0?ooo`00f@3o
ool5000000<0oooo00<000000?ooo`3oool0NP3oool00=/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`1j0?ooo`00f03ooolC0000
og<0oooo003?0?ooo`T0003o0`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00L0oooo20000?m[0?ooo`00b`3oool40000o``0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?ooo`@0003o
I`3oool00<H0oooo1@000?l?0?ooo`8000001@3oool00`000000oooo0?oo
o`0C0?ooo`D0003oHP3oool00<80oooo10000?lK0?ooo`030000003oool0
oooo01P0oooo10000?mN0?ooo`00_P3oool40000oal0oooo00<000000?oo
o`3oool0703oool30000oe/0oooo002l0?ooo`80003o8`3oool00`000000
oooo0?ooo`0O0?ooo`<0003oF03oool00;T0oooo0`000?lU0?ooo`030000
003oool0oooo0280oooo0P000?mF0?ooo`00]`3oool20000obP0oooo00<0
00000?ooo`3oool0903oool20000oe@0oooo002e0?ooo`80003o:P3oool0
0`000000oooo0?ooo`0V0?ooo`80003oDP3oool00;<0oooo0P000?l/0?oo
o`030000003oool0oooo02P0oooo0P000?m@0?ooo`00/@3oool20000obh0
oooo00<000000?ooo`3oool0:P3oool20000odh0oooo002_0?ooo`80003o
<03oool00`000000oooo0?ooo`0/0?ooo`80003oC03oool00:h0oooo00<0
003o0?ooo`3oool0<03oool00`000000oooo0?ooo`0^0?ooo`80003oBP3o
ool00:`0oooo0P000?lc0?ooo`030000003oool0oooo0300oooo0P000?m8
0?ooo`00ZP3oool20000ocD0oooo00<000000?ooo`3oool0<P3oool00`00
0?l0oooo0?ooo`150?ooo`00Z03oool20000ocL0oooo00<000000?ooo`3o
ool0<`3oool20000odD0oooo002V0?ooo`80003o>@3oool00`000000oooo
0?ooo`0e0?ooo`030000o`3oool0oooo0480oooo002U0?ooo`030000o`3o
ool0oooo03T0oooo00<000000?ooo`3oool0=P3oool20000od80oooo002T
0?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0>03oool2
0000od00oooo002S0?ooo`030000o`3oool0oooo03/0oooo00<000000?oo
o`3oool0>P3oool00`000?l0oooo0?ooo`0m0?ooo`00XP3oool00`000?l0
oooo0?ooo`0l0?ooo`030000003oool0oooo03/0oooo00<0003o0?ooo`3o
ool0?03oool00:00oooo0P000?lo0?ooo`030000003oool0oooo03`0oooo
0P000?ll0?ooo`00W`3oool00`000?l0oooo0?ooo`0o0?ooo`030000003o
ool0oooo03h0oooo00<0003o0?ooo`3oool0>@3oool009h0oooo00<0003o
0?ooo`3oool0@03oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0
oooo03P0oooo002M0?ooo`030000o`3oool0oooo0440oooo00<000000?oo
o`3oool0@03oool20000ocP0oooo002L0?ooo`030000o`3oool0oooo0480
oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0e0?ooo`00
V`3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo04<0oooo
00<0003o0?ooo`3oool0=03oool009X0oooo00<0003o0?ooo`3oool0A03o
ool00`000000oooo0?ooo`140?ooo`030000o`3oool0oooo03<0oooo002H
0?ooo`80003oA`3oool00`000000oooo0?ooo`150?ooo`030000o`3oool0
oooo0380oooo002G0?ooo`030000o`3oool0oooo04L0oooo00<000000?oo
o`3oool0AP3oool00`000?l0oooo0?ooo`0a0?ooo`00UP3oool00`000?l0
oooo0?ooo`180?ooo`030000003oool0oooo04L0oooo00<0003o0?ooo`3o
ool0<03oool009D0oooo00<0003o0?ooo`3oool0B@3oool00`000000oooo
0?ooo`180?ooo`030000o`3oool0oooo02l0oooo002D0?ooo`030000o`3o
ool0oooo04X0oooo00<000000?ooo`3oool0B@3oool00`000?l0oooo0?oo
o`0^0?ooo`00T`3oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0
oooo04X0oooo00<0003o0?ooo`3oool0;@3oool00980oooo00<0003o0?oo
o`3oool0C03oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo
02`0oooo002A0?ooo`030000o`3oool0oooo04d0oooo00<000000?ooo`3o
ool0C03oool00`000?l0oooo0?ooo`0[0?ooo`00T03oool00`000?l0oooo
0?ooo`1>0?ooo`030000003oool0oooo04d0oooo00<0003o0?ooo`3oool0
:P3oool008l0oooo00<0003o0?ooo`3oool0C`3oool00`000000oooo0?oo
o`1>0?ooo`030000o`3oool0oooo02T0oooo002>0?ooo`030000o`3oool0
oooo0500oooo00<000000?ooo`3oool0C`3oool00`000?l0oooo0?ooo`0X
0?ooo`00S@3oool00`000?l0oooo0?ooo`1A0?ooo`030000003oool0oooo
0500oooo00<0003o0?ooo`3oool09`3oool008`0oooo00<0003o0?ooo`3o
ool0DP3oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo02L0
oooo002<0?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3oool0
D@3oool00`000?l0oooo0?ooo`0V0?ooo`00R`3oool00`000?l0oooo0?oo
o`1C0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool09@3o
ool008X0oooo00<0003o0?ooo`3oool0E03oool00`000000oooo0?ooo`1C
0?ooo`030000o`3oool0oooo02@0oooo002:0?ooo`030000o`3oool0oooo
05@0oooo00<000000?ooo`3oool0D`3oool00`000?l0oooo0?ooo`0T0?oo
o`00R@3oool00`000?l0oooo0?ooo`1E0?ooo`030000003oool0oooo05@0
oooo00<0003o0?ooo`3oool08`3oool008P0oooo00<0003o0?ooo`3oool0
EP3oool00`000000oooo0?ooo`1E0?ooo`030000o`3oool0oooo0280oooo
00280?ooo`030000o`3oool0oooo05H0oooo00<000000?ooo`3oool0EP3o
ool00`000?l0oooo0?ooo`0Q0?ooo`00Q`3oool00`000?l0oooo0?ooo`1G
0?ooo`030000003oool0oooo05H0oooo00<0003o0?ooo`3oool08@3oool0
08H0oooo00<0003o0?ooo`3oool0F03oool00`000000oooo0?ooo`1G0?oo
o`030000o`3oool0oooo0200oooo00260?ooo`030000o`3oool0oooo04D0
oooo0P0000040?ooo`800000103oool2000000D0oooo00<000000?ooo`3o
ool0E`3oool00`000?l0oooo0?ooo`0P0?ooo`00Q@3oool00`000?l0oooo
0?ooo`150?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`1H0?ooo`030000o`3oool0oooo
01l0oooo00250?ooo`030000o`3oool0oooo04D0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`020?ooo`800000F@3oool00`00
0?l0oooo0?ooo`0O0?ooo`00Q03oool00`000?l0oooo0?ooo`100?ooo`@0
00000P3oool010000000oooo0?ooo`0000090?ooo`8000001@3oool00`00
0000oooo0?ooo`1I0?ooo`030000o`3oool0oooo01h0oooo00230?ooo`03
0000o`3oool0oooo04L0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo05T0oooo00<0003o0?oo
o`3oool07P3oool008<0oooo00<0003o0?ooo`3oool0B03oool2000000X0
oooo0`0000040?ooo`030000003oool0oooo01H0oooo2`3o000i0?ooo`03
0000o`3oool0oooo01d0oooo00220?ooo`030000o`3oool0oooo05`0oooo
00<000000?ooo`3oool03P3oool80?l000/0oooo2@3o000`0?ooo`030000
o`3oool0oooo01d0oooo00220?ooo`030000o`3oool0oooo05`0oooo00<0
00000?ooo`3oool02`3oool30?l001`0oooo103o000]0?ooo`030000o`3o
ool0oooo01`0oooo00210?ooo`030000o`3oool0oooo05d0oooo00<00000
0?ooo`3oool01`3oool40?l002<0oooo0`3o000Z0?ooo`030000o`3oool0
oooo01`0oooo00210?ooo`030000o`3oool0oooo05d0oooo00<000000?oo
o`3oool00`3oool40?l002X0oooo103o000W0?ooo`030000o`3oool0oooo
01/0oooo00200?ooo`030000o`3oool0oooo05h0oooo00<000000?ooo`3o
ool00`3o000b0?ooo`<0o`00903oool00`000?l0oooo0?ooo`0K0?ooo`00
P03oool00`000?l0oooo0?ooo`1N0?ooo`030000003o0000o`0003P0oooo
0P3o000S0?ooo`030000o`3oool0oooo01X0oooo001o0?ooo`030000o`3o
ool0oooo05d0oooo0`3o000l0?ooo`<0o`00803oool00`000?l0oooo0?oo
o`0J0?ooo`00O`3oool00`000?l0oooo0?ooo`1K0?ooo`80o`000P3oool0
0`000000oooo0?ooo`0m0?ooo`80o`007`3oool00`000?l0oooo0?ooo`0I
0?ooo`00O`3oool00`000?l0oooo0?ooo`1I0?ooo`80o`00103oool00`00
0000oooo0?ooo`0o0?ooo`<0o`00703oool00`000?l0oooo0?ooo`0I0?oo
o`00OP3oool00`000?l0oooo0?ooo`1H0?ooo`80o`001P3oool00`000000
oooo0?ooo`120?ooo`80o`006`3oool00`000?l0oooo0?ooo`0H0?ooo`00
OP3oool00`000?l0oooo0?ooo`1F0?ooo`80o`00203oool00`000000oooo
0?ooo`140?ooo`80o`006@3oool00`000?l0oooo0?ooo`0H0?ooo`00OP3o
ool00`000?l0oooo0?ooo`1D0?ooo`80o`002P3oool00`000000oooo0?oo
o`160?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0603o
ool007d0oooo00<0003o0?ooo`3oool0E03oool00`3o0000oooo0?ooo`0:
0?ooo`030000003oool0oooo04L0oooo00<0o`000?ooo`3oool05P3oool0
0`000?l0oooo0?ooo`0G0?ooo`00O@3oool00`000?l0oooo0?ooo`1B0?oo
o`80o`003@3oool00`000000oooo0?ooo`180?ooo`80o`005P3oool00`00
0?l0oooo0?ooo`0G0?ooo`00O@3oool00`000?l0oooo0?ooo`1A0?ooo`03
0?l0003oool0oooo00d0oooo00<000000?ooo`3oool0BP3oool00`3o0000
oooo0?ooo`0C0?ooo`030000o`3oool0oooo01L0oooo001l0?ooo`030000
o`3oool0oooo0540oooo00<0o`000?ooo`3oool03P3oool00`000000oooo
0?ooo`1;0?ooo`80o`00503oool00`000?l0oooo0?ooo`0F0?ooo`00O03o
ool00`000?l0oooo0?ooo`1?0?ooo`80o`004@3oool00`000000oooo0?oo
o`1=0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool05P3o
ool007`0oooo00<0003o0?ooo`3oool0CP3oool00`3o0000oooo0?ooo`0A
0?ooo`030000003oool0oooo04h0oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0E0?ooo`00N`3oool00`000?l0oooo0?ooo`1>0?oo
o`030?l0003oool0oooo0180oooo00<000000?ooo`3oool0C`3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo01D0oooo001k0?ooo`03
0000o`3oool0oooo04d0oooo00<0o`000?ooo`3oool04`3oool00`000000
oooo0?ooo`1@0?ooo`80o`00403oool00`000?l0oooo0?ooo`0E0?ooo`00
N`3oool00`000?l0oooo0?ooo`1;0?ooo`80o`005P3oool00`000000oooo
0?ooo`1B0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
503oool007/0oooo00<0003o0?ooo`3oool0BP3oool00`3o0000oooo0?oo
o`0F0?ooo`030000003oool0oooo05<0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0D0?ooo`00NP3oool00`000?l0oooo0?ooo`1:
0?ooo`030?l0003oool0oooo01L0oooo00<000000?ooo`3oool0E03oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01@0oooo001j0?oo
o`030000o`3oool0oooo04T0oooo00<0o`000?ooo`3oool0603oool00`00
0000oooo0?ooo`1E0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool04`3oool007X0oooo00<0003o0?ooo`3oool0B03oool00`3o0000
oooo0?ooo`0I0?ooo`030000003oool0oooo05H0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0C0?ooo`00N@3oool00`000?l0oooo
0?ooo`180?ooo`030?l0003oool0oooo01X0oooo00<000000?ooo`3oool0
E`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo01<0oooo
001i0?ooo`030000o`3oool0oooo04L0oooo00<0o`000?ooo`3oool06`3o
ool00`000000oooo0?ooo`1H0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool04P3oool007T0oooo00<0003o0?ooo`3oool0AP3oool0
0`3o0000oooo0?ooo`0L0?ooo`030000003oool0oooo0340oooo0`000?lU
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool04P3oool0
07T0oooo00<0003o0?ooo`3oool0AP3oool00`3o0000oooo0?ooo`0L0?oo
o`030000003oool0oooo02D0oooo30000?l30?ooo`/0003o6`3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo0180oooo001h0?ooo`03
0000o`3oool0oooo04H0oooo00<0o`000?ooo`3oool07@3oool00`000000
oooo0?ooo`0R0?ooo`<0003o6P3oool40000oaL0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0B0?ooo`00N03oool00`000?l0oooo
0?ooo`150?ooo`030?l0003oool0oooo01h0oooo00<000000?ooo`3oool0
7P3oool40000ob40oooo10000?lD0?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool04P3oool007P0oooo00<0003o0?ooo`3oool0A03o
ool00`3o0000oooo0?ooo`0O0?ooo`030000003oool0oooo01X0oooo1000
0?lY0?ooo`<0003o4P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo0180oooo001h0?ooo`030000o`3oool0oooo04<0oooo00<0o`00
0?ooo`3oool0803oool00`000000oooo0?ooo`0H0?ooo`80003o<03oool3
0000oa00oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B
0?ooo`00N03oool00`000?l0oooo0?ooo`130?ooo`030?l0003oool0oooo
0200oooo00<000000?ooo`3oool05@3oool30000ocD0oooo0P000?l>0?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool007L0
oooo00<0003o0?ooo`3oool0@`3oool00`3o0000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo01<0oooo0P000?lj0?ooo`80003o3@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo001g0?ooo`030000
o`3oool0oooo0480oooo00<0o`000?ooo`3oool08P3oool00`000000oooo
0?ooo`0A0?ooo`80003o?P3oool30000o`/0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`0A0?ooo`00M`3oool00`000?l0oooo0?oo
o`120?ooo`030?l0003oool0oooo0280oooo00<000000?ooo`3oool03`3o
ool20000od<0oooo0P000?l:0?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool04@3oool007L0oooo00<0003o0?ooo`3oool0@@3oool0
0`3o0000oooo0?ooo`0S0?ooo`030000003oool0oooo00d0oooo0P000?m7
0?ooo`80003o203oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0140oooo001g0?ooo`030000o`3oool0oooo0440oooo00<0o`000?oo
o`3oool08`3oool00`000000oooo0?ooo`0;0?ooo`80003oB`3oool20000
o`L0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0A0?oo
o`00M`3oool00`000?l0000000000002000002/0oooo0P0000040?ooo`80
0000103oool2000000D0oooo00<0o`000?ooo`3oool0903oool00`000000
oooo0?ooo`090?ooo`80003o803oool2000000@0oooo0P0000040?ooo`80
00008@3oool00`000?l0oooo0?ooo`050?ooo`050?l0003oool0oooo0000
00000?l00`00000@0?ooo`00M`3oool00`000?l0oooo0000000/0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool0
0`3o0000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo00<0003o
0?ooo`3oool07`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo00000240oooo0P000?l50?ooo`060?l0003oool0oooo0?ooo`00
0?l000004P3oool007H0oooo00@0003o0?ooo`3oool00000;03oool01000
0000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`3o00009`3o
ool00`000000oooo0?ooo`060?ooo`80003o8P3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`020000oa80oooo001a0?ooo`@0000000D0
oooo0000o`3oool0oooo0000000V0?ooo`@000000P3oool010000000oooo
0?ooo`0000090?ooo`8000000`3oool00`3o0000oooo0?ooo`0V0?ooo`03
0000003oool0oooo00D0oooo00<0003o0?ooo`3oool08P3oool010000000
oooo0?ooo`0000090?ooo`8000009@3oool00`000?l0oooo0?ooo`020?oo
o`050?l0003oool0oooo0?ooo`000?l04P3oool007H0oooo00@0003o0?oo
o`3oool00000;03oool010000000oooo0?ooo`0000090?ooo`030000003o
ool0oooo0080oooo00<0o`000?ooo`3oool09P3oool00`000000oooo0?oo
o`030?ooo`80003o9@3oool010000000oooo0?ooo`0000090?ooo`030000
003oool0oooo00P0oooo3@3o000@0?ooo`80003o0`3oool0103o0000oooo
0?ooo`000?lB0?ooo`00MP3oool010000?l0oooo00000000000]0?ooo`80
00002P3oool3000000030?ooo`3o0000oooo02P0oooo00<000000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0V0?ooo`8000002P3oool3000000P0
o`003@3oool70?l000/0oooo00L0003o0?ooo`3oool0o`000?ooo`000000
003o0180oooo001f0?ooo`030000o`3oool0oooo03h0oooo00<0o`000?oo
o`3oool09`3oool01@000000oooo0?ooo`3oool0003o03D0oooo0`3o000L
0?ooo`D0o`001P3oool20000o`80oooo00<0o`000?ooo`000?l04P3oool0
07H0oooo00<0003o0?ooo`3oool0?@3oool00`3o0000oooo0?ooo`0X0?oo
o`040000003oool0oooo0000oc00oooo1P3o000T0?ooo`@0o`00103oool2
0000o`030?l0003oool0oooo0180oooo001f0?ooo`030000o`3oool0oooo
03d0oooo00<0o`000?ooo`3oool0:03oool00`000000oooo0000o`0_0?oo
o`80o`00;@3oool40?l00080oooo00<0003o0?ooo`3oool04`3oool007H0
oooo00<0003o0?ooo`3oool0?03oool00`3o0000oooo0?ooo`0Y0?ooo`03
000000000?l0oooo02`0oooo0`3o000c0?ooo`80o`005P3oool006`0oooo
2P0000000`000?l000000000000l000000030?l000000000000002T00000
00<0003o000000000000:@0000030?l004L000001`3oool007H0oooo00<0
003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`060?ooo`030?l0003o
ool0oooo02T0oooo00<0003o0000003oool0:03oool20?l000T0oooo00<0
00000?ooo`3oool0903oool;0000o`<0oooo00<000000?ooo`3oool0403o
ool007H0oooo00<0003o0?ooo`3oool0<P3oool00`000000oooo0?ooo`06
0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`0000009`3oool2
0?l000/0oooo00<000000?ooo`3oool07`3oool50000o`T0oooo0P3o0003
0?ooo`030000003oool0oooo0100oooo001f0?ooo`030000o`3oool0oooo
03X0oooo00<0o`000?ooo`3oool0:03oool010000?l0oooo0?ooo`00000V
0?ooo`030?l0003oool0oooo02P0oooo1@000?l<0?ooo`<0o`0000<0oooo
0000o`3oool0503oool007H0oooo00<0003o0?ooo`3oool0>P3oool00`3o
0000oooo0?ooo`0X0?ooo`040000o`3oool0oooo000002@0oooo0P3o000V
0?ooo`D0003o3`3oool20?l000<0oooo0P000?l00`3o0000oooo0?ooo`0B
0?ooo`00MP3oool00`000?l0oooo0?ooo`0i0?ooo`030?l0003oool0oooo
02P0oooo00D0003o0?ooo`3oool0oooo0000000R0?ooo`80o`009@3oool3
0000oa80oooo0P3o00040?ooo`80003o00@0oooo0?l0003oool0003o4P3o
ool007H0oooo00<0003o0?ooo`3oool0>@3oool00`3o0000oooo0?ooo`0W
0?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`3oool07P3oool2
0?l002D0oooo0P000?lD0?ooo`030?l0003oool0oooo00<0oooo0P000?l0
1@3oool0o`000?l0003oool0003o0180oooo001g0?ooo`030000o`3oool0
oooo03P0oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`03
0?ooo`030000003oool0oooo01d0oooo00<0o`000?ooo`3oool08P3oool3
0000oa@0oooo0P3o00050?ooo`80003o0P3oool0103o0000oooo0?ooo`00
0?lB0?ooo`00M`3oool00`000?l0oooo0?ooo`0g0?ooo`030?l0003oool0
oooo02H0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`0K
0?ooo`80o`008P3oool30000oaD0oooo0P3o00060?ooo`040000o`3oool0
oooo0?ooo`80o`000P3oool00`000?l0oooo0?ooo`0@0?ooo`00M`3oool0
0`000?l0oooo0?ooo`0g0?ooo`030?l0003oool0oooo02D0oooo00<0003o
0?ooo`3oool01@3oool00`000000oooo0?ooo`0J0?ooo`030?l0003oool0
oooo0200oooo0P000?lF0?ooo`80o`00203oool01@000?l0oooo0?ooo`3o
ool0o`0000<0oooo00<0003o0?ooo`3oool0403oool007L0oooo00<0003o
0?ooo`3oool0=`3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0
oooo00D0oooo00<000000?ooo`3oool06@3oool00`3o0000oooo0?ooo`0N
0?ooo`<0003o5P3oool20?l000T0oooo00<0003o0?ooo`3oool00P3oool0
103o0000oooo0?ooo`000?lC0?ooo`00M`3oool00`000?l0oooo0?ooo`0g
0?ooo`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool01P3oool0
0`000000oooo0?ooo`0G0?ooo`80o`007`3oool20000oaL0oooo0P3o0009
0?ooo`80003o103oool01@3o0000oooo0?ooo`3oool0003o01<0oooo001g
0?ooo`030000o`3oool0oooo03H0oooo00<0o`000?ooo`3oool0903oool0
0`000?l0oooo0?ooo`070?ooo`030000003oool0oooo01H0oooo00<0o`00
0?ooo`3oool07@3oool20000oaL0oooo0P3o000:0?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0A
0?ooo`00M`3oool00`000?l0oooo0?ooo`0f0?ooo`030?l0003oool0oooo
02<0oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`0E0?oo
o`030?l0003oool0oooo01`0oooo0P000?lH0?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo0140oooo001h0?ooo`030000o`3oool0oooo03D0
oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`080?ooo`03
0000003oool0oooo01<0oooo0P3o000N0?ooo`030000o`3oool0oooo01H0
oooo0P3o000;0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0A0?ooo`00N03oool00`000?l0oooo
0?ooo`0e0?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool0
2@3oool00`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo01`0oooo
0P000?lG0?ooo`80o`00303oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool04@3oool007P0oooo00<0
003o0?ooo`3oool0=@3oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3o
ool0oooo00T0oooo00<000000?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0L0?ooo`030000o`3oool0oooo01D0oooo0P3o000=0?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0A0?ooo`00N03oool00`000?l0oooo0?ooo`0d0?ooo`030?l0003oool0
oooo0280oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`0@
0?ooo`030?l0003oool0oooo01/0oooo0P000?lF0?ooo`80o`003P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool04@3oool007P0oooo00<0003o0?ooo`3oool0=03oool00`3o
0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00X0oooo00<000000?oo
o`3oool03`3oool00`3o0000oooo0?ooo`0J0?ooo`80003o5`3oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`0B0?ooo`00N03oool00`000?l0
oooo0?ooo`0d0?ooo`030?l0003oool0oooo0240oooo00<0003o0?ooo`3o
ool02`3oool00`000000oooo0?ooo`0=0?ooo`80o`00703oool00`000?l0
oooo0?ooo`0F0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0180
oooo001h0?ooo`030000o`3oool0oooo03@0oooo00<0o`000?ooo`3oool0
8@3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo
00<0o`000?ooo`3oool06P3oool20000oaL0oooo0P3o000?0?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0B0?ooo`00N@3oool00`000?l0oooo0?ooo`0c0?ooo`030?l0003o
ool0oooo0200oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?oo
o`0;0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool05P3o
ool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?ooo`00N@3oool0
0`000?l0oooo0?ooo`0c0?ooo`030?l0003oool0oooo0200oooo00<0003o
0?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030?l0003oool0
oooo01X0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0C0?ooo`00N@3oool00`000?l0oooo0?ooo`0c0?oo
o`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool03@3oool00`00
0000oooo0?ooo`090?ooo`030?l0003oool0oooo01T0oooo0P000?lH0?oo
o`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo01<0oooo001i0?ooo`03
0000o`3oool0oooo0380oooo00<0o`000?ooo`3oool0803oool00`000?l0
oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<0o`000?ooo`3o
ool0603oool00`000?l0oooo0?ooo`0F0?ooo`80o`00403oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool04`3oool007T0oooo00<0003o0?ooo`3oool0<P3oool00`3o0000oooo
0?ooo`0O0?ooo`030000o`3oool0oooo00h0oooo00<000000?ooo`3oool0
203oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo01H0oooo
00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool04`3oool007T0oooo00<0
003o0?ooo`3oool0<P3oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3o
ool0oooo00h0oooo00<000000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0H0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool0503oool007X0oooo00<0003o0?ooo`3oool0<@3oool0
0`3o0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00l0oooo00<00000
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0G0?ooo`80003o5`3oool2
0?l00140oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo01@0oooo001j0?ooo`030000o`3oool0oooo
0340oooo00<0o`000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0?0?oo
o`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool05P3oool00`00
0?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo0100oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
01@0oooo001j0?ooo`030000o`3oool0oooo0340oooo00<0o`000?ooo`3o
ool07P3oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo00D0
oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo01@0oooo001j0?ooo`030000
o`3oool0oooo0340oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo
0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<0o`000?ooo`3oool0
5P3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo01@0oooo001k0?ooo`030000o`3oool0oooo0300oooo00<0
o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0@0?ooo`030000003o
ool0oooo00@0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?oo
o`0E0?ooo`80o`004P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool05@3oool007/0oooo00<0003o
0?ooo`3oool0<03oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0
oooo0100oooo00<000000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0E
0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool05@3oool007/0oooo00<0003o0?ooo`3oool0<03oool00`3o
0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo0140oooo00<000000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo
01D0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool05P3oool007/0
oooo00<0003o0?ooo`3oool0<03oool00`3o0000oooo0?ooo`0L0?ooo`03
0000o`3oool0oooo0140oooo00<000000?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0D0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool05P3oool007`0oooo00<0003o0?ooo`3oool0
;`3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo0140oooo
00D000000?ooo`3oool0oooo0?l0000F0?ooo`030000o`3oool0oooo01D0
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool05P3oool007`0oooo
00<0003o0?ooo`3oool0;`3oool00`3o0000oooo0?ooo`0L0?ooo`030000
o`3oool0oooo0140oooo00D000000?ooo`3oool0oooo0?l0000F0?ooo`03
0000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool05`3oool007`0oooo00<0003o0?ooo`3oool0;`3oool00`3o0000oooo
0?ooo`0K0?ooo`030000o`3oool0oooo0180oooo00@000000?ooo`3oool0
o`005P3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0180
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo01L0oooo001m0?ooo`030000o`3oool0oooo02h0oooo
00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0B0?ooo`030000
003oool0o`0001H0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo
0?ooo`0B0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0H0?ooo`00O@3oool00`000?l0oooo0?oo
o`0^0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool04P3o
ool00`000000oooo0?l0000E0?ooo`030000o`3oool0oooo01@0oooo00<0
o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool0603oool007h0oooo00<0003o
0?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0
oooo0180oooo00<000000?l0003oool0503oool00`000?l0oooo0?ooo`0D
0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01P0oooo001n0?oo
o`030000o`3oool0oooo02h0oooo00<0o`000?ooo`3oool06P3oool00`00
0?l0oooo0?ooo`0B0?ooo`030000003o0000oooo01<0oooo00<0003o0?oo
o`3oool0503oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0I0?oo
o`00O`3oool00`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0oooo01T0
oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0B0?ooo`03
0000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool06@3oool007l0oooo00<0003o0?ooo`3oool0;@3oool00`3o0000oooo
0?ooo`0I0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0180oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo01X0oooo00200?ooo`030000o`3oool0oooo02`0oooo00<0
o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0B0?ooo`030?l00000
0000oooo0180oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?oo
o`0B0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0J0?ooo`00P03oool00`000?l0oooo0?ooo`0/
0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool04P3oool0
0`3o000000000?ooo`0A0?ooo`030000o`3oool0oooo01<0oooo00<0o`00
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool06P3oool00840oooo00<0003o0?oo
o`3oool0:`3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo
0180oooo00<0o`000000003oool04@3oool00`000?l0oooo0?ooo`0B0?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool03`3oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01/0oooo00210?ooo`03
0000o`3oool0oooo02`0oooo00<0o`000?ooo`3oool0603oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool000000140oooo00<0003o0?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0K0?ooo`00
PP3oool00`000?l0oooo0?ooo`0[0?ooo`030?l0003oool0oooo01P0oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0000000@0?ooo`030000
o`3oool0oooo0180oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
703oool00880oooo00<0003o0?ooo`3oool0:`3oool00`3o0000oooo0?oo
o`0H0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`000000403o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0180oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo01`0oooo00230?ooo`030000o`3oool0oooo02X0oooo00<0o`00
0?ooo`3oool0603oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
000000l0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0M0?ooo`00P`3oool00`000?l0oooo0?ooo`0[0?oo
o`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool0403oool0103o
0000oooo0?ooo`00000?0?ooo`030000o`3oool0oooo0100oooo00<0o`00
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool07@3oool008@0oooo00<0003o0?oo
o`3oool0:P3oool00`3o0000oooo0?ooo`0F0?ooo`040000o`3oool0oooo
0?ooo`800000103oool2000000@0oooo0P0000020?ooo`040?l0003oool0
oooo000000h0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0B0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0N0?ooo`00Q03oool00`000?l0oooo0?ooo`0Z
0?ooo`030?l0003oool0oooo01H0oooo00@0003o0?ooo`3oool000000P3o
ool00`000000oooo0?ooo`060?ooo`060000003oool0oooo0000003oool0
o`000P3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo0100
oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool07`3oool008D0oooo
00<0003o0?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0E0?ooo`040000
o`3oool0oooo00000080oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?l000020?ooo`800000303oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo0180oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0?0?ooo`030000o`3oool0oooo01l0oooo00260?ooo`030000
o`3oool0oooo02T0oooo00<0o`000?ooo`3oool05@3oool010000?l0oooo
0?ooo`0000020?ooo`030000003oool0oooo00L0oooo0P0000000`3oool0
o`000?ooo`020?ooo`030000003oool0oooo00X0oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0P0?ooo`00
QP3oool00`000?l0oooo0?ooo`0Y0?ooo`030?l0003oool0oooo01D0oooo
00@0003o0?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo0?l000<0oooo00<000000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
0240oooo00270?ooo`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3o
ool05@3oool010000?l0oooo0?ooo`3oool2000000X0oooo0`0000001@3o
0000oooo0?ooo`3oool0000000/0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool0403oool00`000?l0oooo0?ooo`0Q0?ooo`00Q`3oool00`00
0?l0oooo0?ooo`0Y0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?oo
o`3oool0403oool01@3o0000oooo0?ooo`3oool0000000/0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0R
0?ooo`00R03oool00`000?l0oooo0?ooo`0X0?ooo`030?l0003oool0oooo
01D0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`020?oo
o`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0R0?ooo`00R@3oool00`000?l0
oooo0?ooo`0W0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0S0?ooo`00R@3oool00`000?l0oooo0?ooo`0X0?ooo`030?l0
003oool0oooo01@0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`020?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0T0?ooo`00RP3o
ool00`000?l0oooo0?ooo`0W0?ooo`030?l0003oool0oooo01@0oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`020?ooo`030000003o
ool0oooo00L0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`0T0?ooo`00R`3oool00`000?l0oooo0?ooo`0W
0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0U
0?ooo`00S03oool00`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo
01<0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`030?oo
o`030000003oool0oooo00H0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0V0?ooo`00S03oool00`000?l0
oooo0?ooo`0W0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo00D0
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0W0?ooo`00S@3oool00`000?l0oooo0?ooo`0V0?ooo`030?l0
003oool0oooo0180oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0W0?ooo`00SP3o
ool00`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0?0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`0X0?ooo`00S`3oool00`000?l0oooo0?ooo`0U
0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0Y
0?ooo`00S`3oool00`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool04`3oool00`000?l0oooo0?ooo`0Z0?ooo`00T03oool00`000?l0
oooo0?ooo`0U0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04`3oool00`000?l0
oooo0?ooo`0[0?ooo`00T@3oool00`000?l0oooo0?ooo`0U0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0[0?ooo`00TP3o
ool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0503o
ool00`000?l0oooo0?ooo`0/0?ooo`00T`3oool00`000?l0oooo0?ooo`0T
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0]
0?ooo`00U03oool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0<0?ooo`80003o4`3oool00`3o0000oooo0?ooo`0D0?oo
o`030000o`3oool0oooo02h0oooo002E0?ooo`030000o`3oool0oooo02<0
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000o`0<0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool04@3oool20?l0
01H0oooo00<0003o0?ooo`3oool0;`3oool009H0oooo00<0003o0?ooo`3o
ool08`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0003o
00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0<03oool009L0
oooo00<0003o0?ooo`3oool08P3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool01@000000
oooo0?ooo`3oool0003o00/0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?oo
o`3oool0<@3oool009P0oooo00<0003o0?ooo`3oool08P3oool00`3o0000
oooo0?ooo`0?0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0103oool01@000000oooo0?ooo`3oool0003o00X0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
01D0oooo00<0003o0?ooo`3oool0<P3oool009T0oooo00<0003o0?ooo`3o
ool08P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0103oool010000000oooo0?ooo`000?l:0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0403oool20?l0
01H0oooo0P000?le0?ooo`00VP3oool00`000?l0oooo0?ooo`0Q0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`040?ooo`040000003oool0oooo0000o`X0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo
01D0oooo00<0003o0?ooo`3oool0=@3oool009/0oooo0P000?lR0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`040?ooo`040000003oool0oooo0000o`T0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo
01D0oooo00<0003o0?ooo`3oool0=P3oool009d0oooo00<0003o0?ooo`3o
ool0803oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0103oool010000000oooo0?ooo`000?l90?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool20?l0
01L0oooo00<0003o0?ooo`3oool0=`3oool009h0oooo00<0003o0?ooo`3o
ool07`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool00`3oool010000000oooo0?ooo`000?l80?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`3o
0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo03P0oooo002O0?ooo`03
0000o`3oool0oooo01l0oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`00
0?l02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0i0?ooo`00
X03oool20000ob00oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`000?l0
203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00l0oooo
00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0j0?ooo`00XP3o
ool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030000003o
ool0003o00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0>0?ooo`80o`005`3oool20000ocd0oooo002S0?ooo`80003o7`3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool00`3oool00`000000oooo0000o`070?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0F
0?ooo`030000o`3oool0oooo03d0oooo002U0?ooo`030000o`3oool0oooo
01d0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00<0oooo00<000000?ooo`000?l01P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool05@3oool20000od00oooo002V0?ooo`030000o`3oool0oooo01d0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo0080oooo00<000000000o`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00d0oooo0P3o000G0?ooo`03
0000o`3oool0oooo0400oooo002W0?ooo`80003o7P3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
0P3oool00`000000003o0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0303oool20?l001L0oooo0P000?m30?ooo`00Z@3o
ool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`0300000000
0?l0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`0;0?ooo`80o`00603oool00`000?l0oooo0?ooo`130?ooo`00ZP3oool2
0000oad0oooo0P3o000:0?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00P3oool00`000000003o0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool02P3oool20?l001P0oooo0P000?m6
0?ooo`00[03oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?oo
o`03000000000?l0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`090?ooo`80o`00603oool20000odP0oooo002]0?ooo`80
003o7@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0203oool20?l001P0
oooo0P000?m:0?ooo`00[`3oool20000oa`0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00L0
oooo0P3o000H0?ooo`80003oC03oool00;40oooo0P000?lK0?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo01H0oooo0P000?m>0?ooo`00
/`3oool30000oaT0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo0P3o000G0?ooo`80
003oD03oool00;H0oooo0`000?lG0?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0
oooo00D0o`000?ooo`3oool0oooo0000o`070?ooo`80o`005P3oool30000
oe80oooo002i0?ooo`80003o5P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0003o0P3oool01@3o
0000oooo0?ooo`3oool0003o00H0oooo0P3o000F0?ooo`80003oE@3oool0
0;/0oooo0P000?lE0?ooo`80o`001P3oool01@000?l0oooo0?ooo`3oool0
o`000080oooo00@0003o0?ooo`3oool0o`000P3oool00`000?l0oooo0?oo
o`030?ooo`80o`005@3oool30000oeL0oooo002m0?ooo`<0003o503oool2
0?l000D0oooo00@0003o0?ooo`3oool0o`000P3oool00`000?l0oooo0?l0
00020?ooo`030000o`3oool0oooo0080oooo0P3o000D0?ooo`<0003oFP3o
ool00<00oooo0P000?lD0?ooo`80o`00103oool02P000?l0oooo0?ooo`3o
0000oooo0000o`3oool0o`000?ooo`000?l30?ooo`80o`00503oool20000
oed0oooo00320?ooo`<0003o4`3oool20?l000<0oooo00P0003o0?ooo`3o
0000oooo0000o`3o0000oooo0000o`80oooo0P3o000D0?ooo`80003oG`3o
ool00<D0oooo1@000?l@0?ooo`80o`000P3oool01`000?l0oooo0?ooo`00
0000oooo0000o`3oool00P3o000B0?ooo`@0003oH@3oool00<X0oooo2000
0?l70?ooo`<000000P3o00030?ooo`040000003oool0oooo0?l000l0oooo
1@000?mU0?ooo`00dP3oool70000o`80oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`050?ooo`/0003oJP3oool00=T0oooo10000?l4
0?ooo`8000000P3oool40000ogD0oooo003K0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0NP3oool00=/0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1j0?ooo`00fP3oool2000000D0oooo
00<000000?ooo`3oool0NP3oool00>40oooo00<000000?ooo`3oool0NP3o
ool00>40oooo00<000000?ooo`3oool0NP3oool00>40oooo00<000000?oo
o`3oool0NP3oool00>40oooo00<000000?ooo`3oool0NP3oool00>40oooo
00<000000?ooo`3oool0NP3oool00>40oooo00<000000?ooo`3oool0NP3o
ool00>40oooo00<000000?ooo`3oool0NP3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{350, 240},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The mapping  ",
  Cell[BoxData[
      \(w\  = \ \(S \((z)\)\  = \ \(\((1 - \[ImaginaryI])\) \((z - \
\[ImaginaryI])\)\)\/\((z - 1)\)\)\)]],
  "  is a one-to-one conformal mapping of ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " onto the upper half-plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  "  with the property that ",
  Cell[BoxData[
      \(C\_1\)]],
  " is mapped onto the negative ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " axis and ",
  Cell[BoxData[
      \(C\_2\)]],
  " is mapped onto the positive ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " axis.  The potential ",
  Cell[BoxData[
      RowBox[{"\[CapitalPhi]", 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  " in the upper half-plane that satisfies the new boundary values \n\n\t\t\t\
",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalPhi]", 
            RowBox[{"(", 
              RowBox[{"u", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", "80"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", \(for\ \ \ u < 0\), ",", 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"\[CapitalPhi]", 
            RowBox[{"(", 
              RowBox[{"u", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], "=", "  ", "0"}], 
        
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", \(for\ \ \ u > 0\), ","}]]],
  "  \n\n is given by  \n \n",
  StyleBox[" (11-29)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPhi]", 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], "  ", "=", 
        "  ", \(\(80\/\[Pi]\) Arg \((w)\)\ \  = \ \ \(80\/\[Pi]\) 
            Arctan \((v\/u)\)\)}]],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[TextData[{
  "A straightforward calculation shows that  \n\n\t\t\t",
  Cell[BoxData[{
      \(w\ \  = \ \ \(u + \[ImaginaryI]\ v\ \  = \ \ \(S \((z)\)\ \  = \ \ \(\
\((1 - \[ImaginaryI])\) \((x + \[ImaginaryI]\ y - \[ImaginaryI])\)\)\/\((x + \
\[ImaginaryI]\ y - 1)\)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\ \ \)\(\(\((1 - \[ImaginaryI])\) \((x + \
\[ImaginaryI]\ \((y - 1)\))\)\)\/\((x - 
                1 + \[ImaginaryI]\ y)\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\ \ \)\(\(\((1 - \[ImaginaryI])\) \((x + \
\[ImaginaryI]\ \((y - 1)\))\) \((x - 1 - \[ImaginaryI]\ y)\)\)\/\(\((x - 
                  1 + \[ImaginaryI]\ y)\) \((x - 
                  1 - \[ImaginaryI]\ y)\)\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\ \ \)\(\(1 - 2\ x + x\^2 - 2\ y + 
              y\^2 + \[ImaginaryI]\ \((1 - x\^2 - y\^2)\)\)\/\(1 - 2\ x + 
              x\^2 + y\^2\)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\ \ \)\(\(\((x - 1)\)\^2 + \((y - 1)\)\^2 - 
              1 + \[ImaginaryI]\ \((1 - x\^2 - y\^2)\)\)\/\(1 - 2\ x + x\^2 + 
              y\^2\)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \(\(=\)\(\ \ \)\(\(\((x - 1)\)\^2 + \((y - 1)\)\^2 - \
1\)\/\(\((x - 1)\)\^2 + y\^2\)\  + \[ImaginaryI]\ \(\(\ \)\(1 - x\^2 - y\^2\)\
\)\/\(\((x - 1)\)\^2 + y\^2\)\)\)\)}]],
  " "
}], "Text"],

Cell[TextData[{
  "\n\nWe substitute the real and imaginary parts,  ",
  Cell[BoxData[
      RowBox[{"u", "=", 
        RowBox[{
          RowBox[{"u", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], 
          "=", \(\(\((x - 1)\)\^2 + \((y - 1)\)\^2 - 1\)\/\(\((x - 1)\)\^2 + 
                y\^2\)\)}]}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{"v", "=", 
        RowBox[{
          RowBox[{"v", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], 
          "=", \(\(\(\ \)\(1 - x\^2 - y\^2\)\)\/\(\((x - 1)\)\^2 + 
                y\^2\)\)}]}]]],
  "  from this equation, into Equation ",
  StyleBox[" (11-29)",
    FontColor->RGBColor[0, 0, 1]],
  " to obtain the desired solution:   \n\n \t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Phi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
        "  ", \(\(80\/\[Pi]\) 
          
          Arctan \((\(1 - x\^2 - y\^2\)\/\(\((x - 1)\)\^2 + \((y - 1)\)\^2 - \
1\))\)\)}]],
    AspectRatioFixed->True],
  ".  \n\nThe level curve  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPhi]", 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], "=", "\[Alpha]"}]],
    AspectRatioFixed->True],
  "  in the upper half-plane is a ray emanating from the origin, and the \
preimage  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Phi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "\[Alpha]"}]],
    AspectRatioFixed->True],
  "  in the unit disk is an arc of a circle that passes through the points  \
",
  Cell[BoxData[
      RowBox[{"z", "=", 
        RowBox[{
          RowBox[{"1", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "z"}], "=", 
          "\[ImaginaryI]"}]}]]],
  ".  Several level curves are illustrated in Figure 11.38."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.38",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/electrostatics/\
ElectrostaticsFigures/mat1138.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The potentials  ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{"\[CapitalPhi]", 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.21.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Construct the solution with a conformal mapping.  This example is similar to \
Example 11.8.\
\>", "Text"],

Cell[BoxData[{
    \(\(u = \(U = \(v = \(V = \(w = \(W = \(x = \(X = \(y = \(Y = \(z = \(Z = 
                              0\)\)\)\)\)\)\)\)\)\)\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(Remove[u, U, v, V, w, W, x, X, y, Y, z, 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, \[Phi]];\)\ \), "\n", 
    \(\(f[
          z_]\  = \ \(\((1\  - \ \[ImaginaryI])\) \((z\  - \ \[ImaginaryI])\)\
\)\/\(z\  - \ 1\);\)\ \), "\n", 
    \(\(W\  = \ \ ComplexExpand[f[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(U\  = \ 
        Together[
          ComplexExpand[Re[W], 
            TargetFunctions \[Rule] {Re, Im}]];\)\ \), "\n", 
    \(\(\(V\  = \ 
          Together[
            ComplexExpand[Im[W], 
              TargetFunctions \[Rule] {Re, Im}]];\)\ ;\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ 80\/\[Pi]\ ArcTan[V\/U];\)\ \), "\n", 
    \(\(Print["\<w = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<w = u + \[ImaginaryI] v = \>", 
        U\  + \ \[ImaginaryI]\ V];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\[Phi][x,y] = \!\(80\/\[Pi]\) \
ArcTan[\!\(v\/u\)]\>\""];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the temperature.  For computational purposes we \
use the following formula   ",
  Cell[BoxData[
      \(80\/\[Pi]\ ArcTan[\(1\  - \ x\^2\  - \ y\^2\)\/\(1\  - \ 2\ x\  + \ x\
\^2\  - \ 2\ y\  + \ y\^2\)] = \(-80\)\/\[Pi]\ \((\(-\[Pi]\)\/2 + 
              ArcTan[1 - x\^2 - y\^2, 1 - 2\ x + x\^2 - 2\ y + y\^2])\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(\[Phi][x_, 
          y_] = \(-80\)\/\[Pi]\ \((\(-\[Pi]\)\/2 + 
              ArcTan[1 - x\^2 - y\^2, 
                1 - 2\ x + x\^2 - 2\ y + 
                  y\^2])\);\)\ \), "\[IndentingNewLine]", 
    \(\(cont\  = \ Table[10  k, {k, 0, 8}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Phi][x, y], {x, \(-1\), 1}, {y, \(-1\), 1}, 
        Contours\  \[Rule] \ cont, PlotPoints \[Rule] 60, 
        AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, y]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[Phi][x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The following commands will graph the contours as parametric curves.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(u = \(v = \(w = \(X = \(Y = \(z = \(Z = 0\)\)\)\)\)\); \ 
    Remove[u, v, w, X, Y, z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[F];\)\ \), "\n", 
    \(\(F[
          z_]\  = \ \(\((1\  - \ \[ImaginaryI])\) \((z\  - \ \[ImaginaryI])\)\
\)\/\(z\  - \ 1\);\)\ \), "\n", 
    \(\(solset\  = \ Solve[w\  \[Equal] \ F[z], z];\)\ \), "\n", 
    \(\(Z[u_, v_]\  = \ 
        ReplaceAll[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), 
          w \[Rule] u\  + \ \[ImaginaryI]\ v];\)\ \), "\n", 
    \(\(X[u_, v_]\  = \ 
        Together[
          ComplexExpand[
            Re[Z[u, v]], \n\ \ \ \ \ \ \ \ \ \ \ TargetFunctions \[Rule] {Re, \
\ Im}]];\)\ \), "\n", 
    \(\(Y[u_, v_]\  = \ 
        Together[
          ComplexExpand[
            Im[Z[u, v]], \n\ \ \ \ \ \ \ \ \ \ \ TargetFunctions \[Rule] {Re, \
\ Im}]];\)\ \), "\n", 
    \(\(Print["\<w = \>", F[z]];\)\ \), "\n", 
    \(\(Print["\<z = \>", 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(Print["\<Z = \>", Z[u, v]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<X = \>", X[u, v]];\)\ \), "\n", 
    \(\(Print["\<Y = \>", Y[u, v]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(n\  = \ 8;\)\ \), "\n", 
    \(\(Clear[k];\)\ \), "\[IndentingNewLine]", 
    \(\(x[r_]\  = \ 
        Simplify[
          X[r\ Cos[\(k\ \[Pi]\)\/n], r\ Sin[\(k\ \[Pi]\)\/n]]];\)\ \), "\n", 
    \(\(y[r_]\  = \ 
        Simplify[
          Y[r\ Cos[\(k\ \[Pi]\)\/n], r\ Sin[\(k\ \[Pi]\)\/n]]];\)\ \), "\n", 
    \(\(eqns\  = \ N[Table[{x[r], y[r]}, {k, 0, n, 2}]];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns], {r, 0.05, 40}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(eqns\  = \ N[Table[{x[r], y[r]}, {k, 1, n - 1, 2}]];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns], {r, 0.05, 40}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, 
        PlotRange \[Rule] {{\(-1.1\), 1.1}, {\(-1.1\), 1.1}}, 
        AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Hence the electrical potential  ",
  Cell[BoxData[
      \(\[Phi][x, y] = 
        80\/\[Pi]\ ArcTan[\(1 - x\^2 - y\^2\)\/\(1 - 2\ x + x\^2 - 2\ y + \
y\^2\)]\)]],
  "  is harmonic in the disk |z| < 1 and has the desired boundary values.  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the electrical potential  ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  in the crescent-shaped region that lies inside the disk ",
  Cell[BoxData[
      \(D : \(\(|\)\(z - 2\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  "  and outside the circle ",
  Cell[BoxData[
      \(\(\(|\)\(z - 1\)\(|\)\) = \ 1\)]],
  "  that satisfies the following boundary values shown in Figure 11.41: \n\n\
\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "=", "100"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "   ", "|", \(z - 2\), "|"}], "=", 
          "2"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{\(z \[NotEqual] 0\), 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->14,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->14,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "=", "  ", "50"}],
         
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "   ", "|", \(z - 1\), "|"}], "=", 
          "1"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{"z", "\[NotEqual]", 
          RowBox[{"0", 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000490000Vb000`400?l0
0000o`00003oo`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00
o`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?ooo`00o`3oool:0?oo
o`00N`3oool2000001d0oooo1@00000L0?ooo`@000007@3oool200000200
oooo0`0000080?ooo`00NP3oool010000000oooo0?ooo`00000N0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool07@3oool010000000
oooo0?ooo`00000P0?ooo`030000003oool0oooo00L0oooo001j0?ooo`04
0000003oool0oooo000001h0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo01`0oooo1@0000080?oo
o`00NP3oool010000000oooo0?ooo`00000N0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0K0?oo
o`040000003oool0oooo000000T0oooo001j0?ooo`040000003oool0oooo
000001h0oooo00<000000?ooo`3oool0703oool010000000oooo0?ooo`00
000L0?ooo`040000003oool0oooo000001h0oooo00<000000?ooo`000000
2@3oool007/0oooo0P00000N0?ooo`8000007`3oool2000001h0oooo0P00
000P0?ooo`8000002@3oool00?l0oooo2P3oool00?l0oooo2P3oool00?l0
oooo2P3oool00?l0oooo2P3oool007T0ooooR00000080?ooo`00L`3oool4
00000080oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo000000080?ooo`00L`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool01P3oool0
07@0oooo00<000000?ooo`3oool00P3oool2000003L0oooo5P00000g0?oo
o`800000203oool006d0oooo100000040?ooo`050000003oool0oooo0?oo
o`0000000P3ooola0?l000D000005P2B0?l500000340o`000P3oool00`00
0000oooo0?ooo`060?ooo`00L`3oool010000000oooo0?ooo`0000020?oo
o`030000003oool0oooo02d0o`001@00000O0980o`@00000;@3o00020?oo
o`030000003oool0oooo00H0oooo001d0?ooo`8000000`3oool00`000000
oooo0?ooo`0Z0?l000@000009`2B0?l3000002X0o`000P3oool00`000000
oooo0?ooo`060?ooo`00N@3oool00`000000oooo0?ooo`0X0?l000<00000
;02B0?l3000002P0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3o
ool00`000000oooo0?ooo`0V0?l000<000003`2B0?l6000001`0TP3o0`00
000U0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo0P000000
0`3oool0o`000?l0000Q0?l000<000002P2B0?l8000000H0E03o2@00000E
0980o`@000008P3o00020?ooo`030000003oool0oooo00H0oooo001i0?oo
o`030000003oool0oooo0280o`000P0000070980o`D000005P1D0?l50000
01<0TP3o0`00000Q0?l00080oooo00<000000?ooo`3oool01P3oool007T0
oooo00<000000?ooo`3oool0803o0002000000H0TP3o1000000O05@0o`<0
00004P2B0?l200000200o`000P3oool00`000000oooo0?ooo`060?ooo`00
N@3oool00`000000oooo0?ooo`0N0?l000<000001@2B0?l3000002D0E03o
0`00000A0980o`8000007P3o00020?ooo`030000003oool0oooo00H0oooo
001i0?ooo`030000003oool0oooo01d0o`000P0000040980o`<00000301D
0?l9000001H0E03o0`00000@0980o`030000003o0000o`0001/0o`000P3o
ool00`000000oooo0?ooo`060?ooo`00N@3oool00`000000oooo0?ooo`0K
0?l000800000102B0?l3000000L0E03o1`00000801L0o`P000004@1D0?l3
000000l0TP3o0P00000K0?l00080oooo00<000000?ooo`3oool01P3oool0
07T0oooo00<000000?ooo`3oool06P3o0002000000<0TP3o0P00000605@0
o`@000005`0G0?l4000000l0E03o0P00000@0980o`030000003o0000o`00
01P0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool200000003
0?ooo`3o0000o`0001L0o`000P0000020980o`<00000101D0?l3000001h0
5`3o0`00000?05@0o`8000003`2B0?l2000001P0o`000P3oool00`000000
oooo0?ooo`060?ooo`00N@3oool00`000000oooo0?ooo`0G0?l000800000
0`2B0?l00`000000E03o05@0o`0305@0o`8000003@0G0?l20000000301L0
o`0000005`3o01805`3o0`00000>05@0o`8000003P2B0?l2000001L0o`00
0P3oool00`000000oooo0?ooo`060?ooo`00N@3oool00`000000oooo0?oo
o`0F0?l0008000000P2B0?l2000000<0E03o0`00000601L0o`X0000000<0
02Go0000000000001`00000?01L0o`<00000301D0?l3000000d0TP3o0P00
000F0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<00000
0?ooo`3oool05@3o0002000000030980o`000000000000<0E03o0P000005
01L0o`D000004`009Ol5000000`05`3o0`00000<05@0o`8000003@2B0?l2
000001D0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool00`00
0000oooo0?ooo`0D0?l00080000000<0TP3o0000000000000P1D0?l20000
00@05`3o1000000K000Uo`<00000300G0?l3000000`0E03o00<000000980
o`2B0?l0302B0?l00`000000o`000?l0000B0?l00080oooo00<000000?oo
o`3oool01P3oool007T0oooo00<000000?ooo`3oool04`3o000200000004
0980o`000000000005@0o`<000000P0G0?l3000000L002Go3@00000>000U
o`<000002`0G0?l2000000`0E03o0P00000=0980o`030000003o0000o`00
0140o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool200000003
0?ooo`3o0000o`000100o`000P000000102B0?l0000005@0o`1D0?l20000
00805`3o0`000004000Uo`H000003000H_l500000003000Uo`00000002Go
00T002Go0P00000;01L0o`8000002`1D0?l2000000d0TP3o00<000000?l0
003o0000403o00020?ooo`030000003oool0oooo00H0oooo001i0?ooo`03
0000003oool0oooo0140o`00100000000`1D0?l000000000000201L0o`<0
00000`009Ol3000001L006;o10000009000Uo`<000002P0G0?l2000000/0
E03o0P00000=0980o`030000003o0000o`0000l0o`000P3oool00`000000
oooo0?ooo`060?ooo`00N@3oool00`000000oooo0?ooo`0@0?l000800000
00<0TP3o0000001D0?l00P00000201L0o`8000000P009Ol3000000H006;o
2`00000<001Ro`<000002@009Ol3000000X05`3o00<0000005@0o`1D0?l0
2@1D0?l2000000d0TP3o00<000000?l0003o00003P3o00020?ooo`030000
003oool0oooo00H0oooo001i0?ooo`030000003oool0oooo00l0o`001000
0000101D0?l000000000000G0?l20000008002Go0P000003001Ro`H00000
2`00Wol5000000X006;o0`000008000Uo`<000002@0G0?l2000000X0E03o
0P00000<0980o`8000003`3o00020?ooo`030000003oool0oooo00H0oooo
001i0?ooo`030000003oool0oooo00l0o`0000H000000980o`000000E03o
0000000G0?l20000008002Go0P000002001Ro`@000005@00Wol3000000T0
06;o0`000008000Uo`8000002@0G0?l2000000/0E03o00<000000980o`2B
0?l02`2B0?l00`000000o`000?l0000<0?l00080oooo00<000000?ooo`3o
ool01P3oool007T0oooo00<000000?ooo`3oool03P3o00050000000401L0
o`0000000000000Uo`8000000P00H_l3000000@009oo3P000009002Oo`<0
00002000H_l3000000L002Go0P00000901L0o`8000002P1D0?l2000000`0
TP3o0P00000=0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo
0P0000000`3oool0o`000?l0000;0?l000080000002B0?l0000005@0o`00
00005`3o000000009Ol200000004001Ro`00000000000000008009oo1@00
000>003Lo`@000002000Wol3000000L006;o0P000008000Uo`800000200G
0?l2000000/0E03o00<000000980o`2B0?l02P2B0?l00`000000o`000?l0
000;0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<00000
0?ooo`3oool0303o000700000004000Uo`0000000000001Ro`8000000P00
Wol3000000@00=co2@000009003Lo`@000001P00Wol3000000H006;o0P00
0008000Uo`800000200G0?l2000000X0E03o0P00000<0980o`030000003o
0000o`0000X0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool0
0`000000oooo0?ooo`0<0?l00080000000<0E03o0000000G0?l00`000000
1000H_l0000000000000Wol300000003003Lo`000000000000@000002@00
onD5000000L00=co0P000007002Oo`8000001`00H_l2000000P002Go00<0
000001L0o`0G0?l01`0G0?l00`000000E03o05@0o`0805@0o`800000302B
0?l00`000000o`000?l000090?l00080oooo00<000000?ooo`3oool01P3o
ool007T0oooo00<000000?ooo`3oool02`3o000:00000004002Oo`000000
0000003Lo`@000001000onD7000000P00?oU10000005003Lo`<000001P00
Wol2000000H006;o0P000007000Uo`800000200G0?l2000000X0E03o00<0
00000980o`2B0?l02P2B0?l00`000000o`000?l000090?l00080oooo00<0
00000?ooo`3oool01P3oool007T0oooo00<000000?ooo`3oool02P3o0000
0`000000TP3o0000000900000005003Lo`000000000000000000onD01P00
0007003oZ0H000001@00onD3000000H00=co00<00000002Oo`00Wol01@00
Wol00`00000006;o001Ro`05001Ro`03000000009Ol002Go00H002Go00<0
000001L0o`0G0?l01P0G0?l2000000X0E03o00<000000980o`2B0?l02P2B
0?l00`000000o`000?l000080?l00080oooo00<000000?ooo`3oool01P3o
ool007<0oooo1@000000103oool000000?ooo`3oool:0?l000P0000000<0
09oo0000000000000P0000000`00onD0000000000002000000800?nX2@00
0006003oZ0@000001000onD3000000D00=co0P000006002Oo`8000001P00
H_l2000000H002Go0P00000801L0o`8000002@1D0?l2000000/0TP3o0P00
00090?l00080oooo00<000000?ooo`3oool01P3oool007D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`T0o`003`0000000`00ojP000000000
0004000000L00?m[1P000005003oZ08000001@00onD2000000D00=co0P00
0005002Oo`8000001P00H_l2000000H002Go0P00000801L0o`8000002@1D
0?l2000000/0TP3o0P0000080?l00080oooo00<000000?ooo`3oool01P3o
ool007D0oooo00@000000?ooo`3oool0oooo0P0000000`3oool0o`000?l0
00060?l00180000000<00?m[0000000000002P000004003oJ`@000001000
ojP3000000@00?oU00<00000003Lo`00g?l00`00g?l2000000D009oo0P00
0006001Ro`03000000009Ol002Go00H002Go00<0000001L0o`0G0?l01P0G
0?l00`000000E03o05@0o`0805@0o`030000002B0?l0TP3o00X0TP3o00<0
00000?l0003o00001P3o00000`3oool00000000000080?ooo`00K@3oool4
000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`P0o`003P00
00000`00of/0000000000002000000/0o`001@000004003oJ`8000001000
ojP2000000@00?oU0P000005003Lo`0300000000Wol009oo00@009oo00<0
0000001Ro`00H_l01000H_l2000000H002Go0P00000801L0o`030000001D
0?l0E03o00P0E03o00<000000980o`2B0?l02@2B0?l2000000L0o`000P3o
ool00`000000oooo0?ooo`060?ooo`00M@3oool01@000000oooo0?ooo`3o
ool000000080oooo1`3o000700000003003Lo`000000000000H000004`3o
0004000000<00?m[0P000004003oZ08000000`00onD2000000D00=co0P00
0004002Oo`8000001P00H_l00`00000002Go000Uo`05000Uo`030000000G
0?l05`3o00H05`3o0P00000905@0o`030000002B0?l0TP3o00X0TP3o0P00
00060?l00080oooo00<000000?ooo`3oool01P3oool007@0oooo0P000003
0?ooo`030000003oool0oooo00L0o`003@00000I0?l000<000000`00of/2
000000<00?nX0P000004003oi@8000001000g?l2000000@009oo0P000006
001Ro`03000000009Ol002Go00D002Go00<0000001L0o`0G0?l01P0G0?l0
0`000000E03o05@0o`0805@0o`030000002B0?l0TP3o00T0TP3o0P000006
0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?oo
o`3oool01P3o000<000001d0o`000`000003003oJ`0300000000ojP00?nX
00800?nX00<00000003oi@00onD00P00onD2000000@00=co0P000004002O
o`8000001P00H_l00`00000002Go000Uo`04000Uo`800000200G0?l00`00
0000E03o05@0o`0705@0o`8000002`2B0?l00`000000o`000?l000040?l0
0080oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?ooo`3o
ool01P3o000:00000240o`000P000003003oJ`8000000`00ojP2000000<0
0?oU0P000004003Lo`8000001000Wol2000000D006;o0P000006000Uo`80
00001`0G0?l2000000T0E03o00<000000980o`2B0?l02@2B0?l2000000D0
o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool2000000030?oo
o`3o0000o`0000<0o`002@00000U0?l0008000000P00of/2000000<00?nX
0P000003003oi@8000001000g?l00`00000009oo002Oo`03002Oo`030000
0000H_l006;o00@006;o0P000006000Uo`030000000G0?l05`3o00H05`3o
00<0000005@0o`1D0?l01`1D0?l00`000000TP3o0980o`0:0980o`030000
003o0000o`0000<0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3o
ool00`000000oooo0?ooo`050?l000P000009`3o0002000000800?m[0P00
0003003oZ08000000`00onD2000000@00=co00<00000002Oo`00Wol00`00
Wol00`00000006;o001Ro`04001Ro`03000000009Ol002Go00@002Go0P00
000701L0o`8000002@1D0?l00`000000TP3o0980o`090980o`030000003o
0000o`0000<0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool0
0`000000oooo0?ooo`040?l000P00000:@3o0002000000<00?m[00D00000
003oZ000ojP00?nX00000004003oi@8000001000g?l00`00000009oo002O
o`03002Oo`0300000000H_l006;o00<006;o00<00000000Uo`009Ol01@00
9Ol00`0000005`3o01L0o`0601L0o`030000001D0?l0E03o00L0E03o0P00
000;0980o`030000003o0000o`000080o`000P3oool00`000000oooo0?oo
o`060?ooo`00N@3oool00`000000oooo0?ooo`040?l000L00000:`3o0002
000000800?m[0P000003003oZ00300000000onD00?oU00800?oU00<00000
003Lo`00g?l00P00g?l2000000@009oo0P000005001Ro`03000000009Ol0
02Go00D002Go00<0000001L0o`0G0?l01@0G0?l2000000T0E03o00<00000
0980o`2B0?l02@2B0?l00`000000o`000?l000020?l00080oooo00<00000
0?ooo`3oool01P3oool007T0oooo00<000000?ooo`3oool0103o00060000
02d0o`000P000003003oJ`0500000000ojP00?nX003oZ00000001000onD0
0`0000000=co003Lo`02003Lo`0300000000Wol009oo00<009oo00<00000
001Ro`00H_l00`00H_l2000000H002Go00<0000001L0o`0G0?l01P0G0?l0
0`000000E03o05@0o`0705@0o`030000002B0?l0TP3o00T0TP3o0P000003
0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?oo
o`3oool00`3o0006000002l0o`000P000002003oJ`8000000P00ojP20000
00<00?oU0P000003003Lo`8000001000Wol2000000D006;o00<00000000U
o`009Ol01@009Ol00`0000005`3o01L0o`0501L0o`8000002@1D0?l00`00
0000TP3o0980o`090980o`040000003o0000o`000?l00080oooo00<00000
0?ooo`3oool01P3oool007T0oooo00<000000?ooo`3oool00`3o00050000
0340o`000P000002003oJ`0400000000ojP00?nX003oZ08000000`00onD0
0`0000000=co003Lo`02003Lo`0300000000Wol009oo00<009oo00<00000
001Ro`00H_l01000H_l00`00000002Go000Uo`04000Uo`030000000G0?l0
5`3o00H05`3o00<0000005@0o`1D0?l01`1D0?l00`000000TP3o0980o`09
0980o`040000003o0000o`000?l00080oooo00<000000?ooo`3oool01P3o
ool007T0oooo0P000000103oool0o`000?l0003o000500000380o`0000D0
0000003oJ`00of/00?m[00000003003oZ08000000P00onD2000000@00=co
00<00000002Oo`00Wol00P00Wol2000000D006;o00<00000000Uo`009Ol0
10009Ol2000000L05`3o00<0000005@0o`1D0?l01`1D0?l2000000X0TP3o
0P0000020?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<0
00000?ooo`3oool00P3o0005000003@0o`0000<00000003oJ`00of/00P00
0003003oZ00400000000onD00?oU003oi@8000000`00g?l2000000@009oo
00<00000001Ro`00H_l00`00H_l2000000H002Go00<0000001L0o`0G0?l0
1P0G0?l00`000000E03o05@0o`0705@0o`030000002B0?l0TP3o00T0TP3o
00<000000?l0003o00000P3oool00`000000oooo0?ooo`060?ooo`00N@3o
ool00`000000oooo0?ooo`020?l000@00000=P3o0000100000000?m[003o
J`000003003oZ08000000`00onD00`0000000=co003Lo`02003Lo`030000
0000Wol009oo00<009oo00<00000001Ro`00H_l00`00H_l00`00000002Go
000Uo`04000Uo`030000000G0?l05`3o00H05`3o00<0000005@0o`1D0?l0
1`1D0?l00`000000TP3o0980o`090980o`030000003o0000o`000080oooo
00<000000?ooo`3oool01P3oool007T0oooo00<000000?ooo`3oool00P3o
0004000003H0o`0000D00000003oJ`00of/00?m[00000003003oZ0040000
0000onD00?oU003oi@8000000`00g?l2000000@009oo00<00000001Ro`00
H_l00`00H_l2000000H002Go00<0000001L0o`0G0?l01@0G0?l00`000000
E03o05@0o`0705@0o`8000002P2B0?l2000000040?l0003oool0oooo0000
00P0oooo001i0?ooo`030000003oool0oooo0080o`000`00000h0?l00004
00000000of/00?m[000000<00?nX00<00000003oi@00onD00P00onD00`00
00000=co003Lo`02003Lo`0300000000Wol009oo008009oo00<00000001R
o`00H_l01000H_l00`00000002Go000Uo`04000Uo`030000000G0?l05`3o
00H05`3o00<0000005@0o`1D0?l01`1D0?l00`000000TP3o0980o`090980
o`050000003o0000oooo0?ooo`000000203oool007T0oooo00@000000?oo
o`3oool0o`000`00000i0?l0000500000000of/00?m[003oJ`0000000`00
ojP01@0000000?oU003oi@00onD0000000@00=co00<00000002Oo`00Wol0
0`00Wol00`00000006;o001Ro`03001Ro`03000000009Ol002Go00@002Go
0P00000701L0o`030000001D0?l0E03o00L0E03o00<000000980o`2B0?l0
2@2B0?l01@000000o`000?ooo`3oool0000000P0oooo001i0?ooo`800000
00<0oooo0?l0000000000P00000j0?l0000400000000of/00?m[000000<0
0?nX0P000003003oi@0300000000g?l00=co00800=co00<00000002Oo`00
Wol00P00Wol00`00000006;o001Ro`03001Ro`03000000009Ol002Go00D0
02Go00<0000001L0o`0G0?l01@0G0?l00`000000E03o05@0o`0705@0o`03
0000002B0?l0TP3o00T0TP3o00D000000?l0003oool0oooo000000080?oo
o`00N@3oool010000000oooo0?ooo`3o0002000003/0o`0000D00000003o
J`00of/00?m[00000003003oZ00500000000onD00?oU003oi@0000001000
g?l00`00000009oo002Oo`02002Oo`8000001@00H_l00`00000002Go000U
o`04000Uo`030000000G0?l05`3o00D05`3o0P00000805@0o`8000002P2B
0?l01@000000o`000?ooo`3oool0000000P0oooo001i0?ooo`040000003o
ool0oooo0?l000800000?03o0000100000000?m[003oJ`000003003oZ005
00000000onD00?oU003oi@0000001000g?l00`00000009oo002Oo`03002O
o`0300000000H_l006;o00<006;o00<00000000Uo`009Ol010009Ol00`00
00005`3o01L0o`0601L0o`030000001D0?l0E03o00L0E03o00<000000980
o`2B0?l0202B0?l01@000000o`000?ooo`3oool0000000P0oooo001i0?oo
o`040000003oool0oooo0?l000800000?03o00000`0000000?m[003oJ`02
000000800?nX00<00000003oi@00onD00P00onD0100000000=co003Lo`00
g?l2000000@009oo00<00000001Ro`00H_l00`00H_l00`00000002Go000U
o`04000Uo`8000001`0G0?l00`000000E03o05@0o`0705@0o`030000002B
0?l0TP3o00T0TP3o00@000000?ooo`3oool00000203oool007T0oooo00<0
00000?ooo`3oool00P00000m0?l0000500000000of/00?m[003oJ`000000
0`00ojP01@0000000?oU003oi@00onD0000000@00=co00<00000002Oo`00
Wol00P00Wol00`00000006;o001Ro`03001Ro`03000000009Ol002Go00D0
02Go00<0000001L0o`0G0?l01@0G0?l00`000000E03o05@0o`0705@0o`03
0000002B0?l0TP3o00T0TP3o00@000000?ooo`3oool00000203oool007T0
oooo00<000000?ooo`3oool00P00000m0?l0008000000P00of/01@000000
0?nX003oZ000ojP0000000<00?oU00<00000003Lo`00g?l00P00g?l00`00
000009oo002Oo`02002Oo`0300000000H_l006;o00@006;o00<00000000U
o`009Ol010009Ol00`0000005`3o01L0o`0501L0o`030000001D0?l0E03o
00L0E03o00<000000980o`2B0?l02@2B0?l010000000oooo0?ooo`000008
0?ooo`00N@3oool00`000000oooo0?ooo`02000003h0o`0000@00000003o
J`00of/000000`00ojP01@0000000?oU003oi@00onD0000000@00=co00<0
0000002Oo`00Wol00`00Wol00`00000006;o001Ro`03001Ro`0300000000
9Ol002Go00@002Go00<0000001L0o`0G0?l01@0G0?l00`000000E03o05@0
o`0705@0o`030000002B0?l0TP3o00T0TP3o00@000000?ooo`3oool00000
203oool007T0oooo0P0000000`3oool000000000000n0?l0000400000000
of/00?m[000000<00?nX00@00000003oi@00onD00?oU0P000003003Lo`03
00000000Wol009oo00<009oo00<00000001Ro`00H_l00`00H_l00`000000
02Go000Uo`04000Uo`030000000G0?l05`3o00D05`3o0P00000805@0o`03
0000002B0?l0TP3o00T0TP3o00@000000?ooo`3oool00000203oool007T0
oooo00@000000?ooo`3oool00000?`3o00001@0000000?m[003oJ`00of/0
000000800?nX0P000003003oi@0400000000g?l00=co003Lo`8000001000
Wol00`00000006;o001Ro`03001Ro`03000000009Ol002Go00@002Go00<0
000001L0o`0G0?l01P0G0?l00`000000E03o05@0o`0605@0o`8000002P2B
0?l010000000oooo0?ooo`0000080?ooo`00N@3oool010000000oooo0?oo
o`00000o0?l0000500000000of/00?m[003oJ`0000000`00ojP01@000000
0?oU003oi@00onD0000000@00=co00<00000002Oo`00Wol00P00Wol00`00
000006;o001Ro`03001Ro`03000000009Ol002Go00@002Go00<0000001L0
o`0G0?l01P0G0?l00`000000E03o05@0o`0705@0o`030000002B0?l0TP3o
00P0TP3o00@000000?ooo`3oool00000203oool007T0oooo00@000000?oo
o`3oool00000?`3o0002000000800?m[00D00000003oZ000ojP00?nX0000
0003003oi@0300000000g?l00=co00800=co00<00000002Oo`00Wol00P00
Wol00`00000006;o001Ro`03001Ro`8000001@009Ol00`0000005`3o01L0
o`0601L0o`030000001D0?l0E03o00L0E03o00<000000980o`2B0?l0202B
0?l010000000oooo0?ooo`0000080?ooo`00M03oool2000000<0oooo00@0
00000?ooo`3oool00000@03o0000100000000?m[003oJ`000003003oZ005
00000000onD00?oU003oi@0000001000g?l00`00000009oo002Oo`02002O
o`0300000000H_l006;o00<006;o00<00000000Uo`009Ol01@009Ol00`00
00005`3o01L0o`0501L0o`030000001D0?l0E03o00L0E03o00<000000980
o`2B0?l0202B0?l010000000oooo0?ooo`0000080?ooo`00L`3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000400o`0000@0
0000003oJ`00of/000000`00ojP01@0000000?oU003oi@00onD0000000@0
0=co00<00000002Oo`00Wol00P00Wol00`00000006;o001Ro`03001Ro`03
000000009Ol002Go00D002Go00<0000001L0o`0G0?l01@0G0?l00`000000
E03o05@0o`0705@0o`030000002B0?l0TP3o00P0TP3o00@000000?ooo`3o
ool00000203oool007<0oooo00@000000?ooo`3oool000000P3oool20000
00030?ooo`000000o`0003l0o`0000@00000003oJ`00of/000000`00ojP0
1@0000000?oU003oi@00onD0000000@00=co00<00000002Oo`00Wol00P00
Wol00`00000006;o001Ro`03001Ro`03000000009Ol002Go00D002Go00<0
000001L0o`0G0?l01@0G0?l00`000000E03o05@0o`0705@0o`030000002B
0?l0TP3o00P0TP3o00@000000?ooo`0000000000203oool007<0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000100?l00004
00000000of/00?m[000000<00?nX00D00000003oi@00onD00?oU00000004
003Lo`0300000000Wol009oo008009oo00<00000001Ro`00H_l00`00H_l0
0`00000002Go000Uo`05000Uo`030000000G0?l05`3o00D05`3o00<00000
05@0o`1D0?l01`1D0?l00`000000TP3o0980o`080980o`040000003oool0
oooo000000P0oooo001c0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000@03o0000100000000?m[003oJ`000003003oZ005
00000000onD00?oU003oi@0000001000g?l00`00000009oo002Oo`02002O
o`0300000000H_l006;o00<006;o00<00000000Uo`009Ol01@009Ol00`00
00005`3o01L0o`0501L0o`030000001D0?l0E03o00L0E03o00<000000980
o`2B0?l0202B0?l010000000oooo0?ooo`0000080?ooo`00M03oool20000
00<0oooo00@000000?ooo`3oool00000@03o0000100000000?m[003oJ`00
0003003oZ00500000000onD00?oU003oi@0000001000g?l00`00000009oo
002Oo`02002Oo`0300000000H_l006;o00<006;o0P000005000Uo`800000
1`0G0?l00`000000E03o05@0o`0705@0o`030000002B0?l0TP3o00P0TP3o
00@000000?ooo`3oool00000203oool007T0oooo00@000000?ooo`3oool0
0000?`3o00001@0000000?m[003oJ`00of/0000000<00?nX00D00000003o
i@00onD00?oU00000004003Lo`0300000000Wol009oo008009oo00<00000
001Ro`00H_l00`00H_l00`00000002Go000Uo`04000Uo`030000000G0?l0
5`3o00H05`3o00<0000005@0o`1D0?l01`1D0?l00`000000TP3o0980o`08
0980o`040000003oool0oooo000000P0oooo001i0?ooo`040000003oool0
oooo000003l0o`0000D00000003oJ`00of/00?m[00000002003oZ0800000
0`00onD00`0000000=co003Lo`02003Lo`0300000000Wol009oo008009oo
00<00000001Ro`00H_l00`00H_l00`00000002Go000Uo`04000Uo`030000
000G0?l05`3o00H05`3o00<0000005@0o`1D0?l01`1D0?l00`000000TP3o
0980o`080980o`040000003oool0oooo000000P0oooo001i0?ooo`040000
003oool0oooo000003l0o`0000D00000003oJ`00of/00?m[00000002003o
Z00300000000onD00?oU00800?oU00D00000003Lo`00g?l00=co00000005
002Oo`0300000000H_l006;o00<006;o00<00000000Uo`009Ol010009Ol0
0`0000005`3o01L0o`0601L0o`030000001D0?l0E03o00H0E03o00<00000
0980o`2B0?l02@2B0?l010000000oooo0?ooo`0000080?ooo`00N@3oool2
000000030?ooo`000000000003h0o`0000@00000003oJ`00of/000000`00
ojP0100000000?oU003oi@00onD2000000<00=co00<00000002Oo`00Wol0
0`00Wol00`00000006;o001Ro`03001Ro`03000000009Ol002Go00@002Go
00<0000001L0o`0G0?l01@0G0?l2000000P0E03o00<000000980o`2B0?l0
2@2B0?l010000000oooo0?ooo`0000080?ooo`00N@3oool00`000000oooo
0?ooo`02000003h0o`0000@00000003oJ`00of/000000`00ojP01@000000
0?oU003oi@00onD0000000@00=co00<00000002Oo`00Wol00`00Wol00`00
000006;o001Ro`03001Ro`03000000009Ol002Go00@002Go00<0000001L0
o`0G0?l01@0G0?l00`000000E03o05@0o`0705@0o`030000002B0?l0TP3o
00T0TP3o00@000000?ooo`3oool00000203oool007T0oooo00<000000?oo
o`3oool00P00000m0?l0008000000P00of/01@0000000?nX003oZ000ojP0
000000<00?oU00<00000003Lo`00g?l00P00g?l00`00000009oo002Oo`02
002Oo`0300000000H_l006;o00@006;o00<00000000Uo`009Ol010009Ol0
0`0000005`3o01L0o`0501L0o`030000001D0?l0E03o00L0E03o00<00000
0980o`2B0?l02@2B0?l010000000oooo0?ooo`0000080?ooo`00N@3oool0
0`000000oooo0?ooo`02000003d0o`0000D00000003oJ`00of/00?m[0000
0002003oZ08000000`00onD00`0000000=co003Lo`02003Lo`0300000000
Wol009oo008009oo00<00000001Ro`00H_l00`00H_l00`00000002Go000U
o`05000Uo`030000000G0?l05`3o00D05`3o00<0000005@0o`1D0?l01`1D
0?l00`000000TP3o0980o`090980o`040000003oool0oooo000000P0oooo
001i0?ooo`040000003oool0oooo0?l000800000?03o0000100000000?m[
003oJ`000003003oZ00300000000onD00?oU00800?oU00D00000003Lo`00
g?l00=co00000005002Oo`0300000000H_l006;o00<006;o00<00000000U
o`009Ol010009Ol00`0000005`3o01L0o`0601L0o`030000001D0?l0E03o
00L0E03o00<000000980o`2B0?l02@2B0?l010000000oooo0?ooo`000008
0?ooo`00N@3oool010000000oooo0?ooo`3o0002000003/0o`000P000002
003oJ`0500000000ojP00?nX003oZ00000000`00onD00`0000000=co003L
o`02003Lo`0300000000Wol009oo00<009oo00<00000001Ro`00H_l00`00
H_l00`00000002Go000Uo`04000Uo`030000000G0?l05`3o00H05`3o00<0
000005@0o`1D0?l01P1D0?l2000000X0TP3o00D000000?l0003oool0oooo
000000080?ooo`00N@3oool2000000040?ooo`3o00000000000003/0o`00
00D00000003oJ`00of/00?m[00000003003oZ00500000000onD00?oU003o
i@0000001000g?l00`00000009oo002Oo`02002Oo`8000001@00H_l00`00
000002Go000Uo`04000Uo`030000000G0?l05`3o00D05`3o00<0000005@0
o`1D0?l01`1D0?l00`000000TP3o0980o`090980o`050000003o0000oooo
0?ooo`000000203oool007T0oooo00@000000?ooo`3oool0o`000`00000i
0?l0008000000P00of/01@0000000?nX003oZ000ojP0000000<00?oU0P00
0003003Lo`8000001000Wol00`00000006;o001Ro`03001Ro`0300000000
9Ol002Go00D002Go00<0000001L0o`0G0?l01@0G0?l00`000000E03o05@0
o`0705@0o`030000002B0?l0TP3o00T0TP3o00D000000?l0003oool0oooo
000000080?ooo`00N@3oool010000000oooo0?ooo`3o0003000003T0o`00
00D00000003oJ`00of/00?m[00000003003oZ00500000000onD00?oU003o
i@0000001000g?l00`00000009oo002Oo`03002Oo`0300000000H_l006;o
00<006;o00<00000000Uo`009Ol010009Ol00`0000005`3o01L0o`0601L0
o`030000001D0?l0E03o00L0E03o00<000000980o`2B0?l02@2B0?l01@00
0000o`000?ooo`3oool0000000P0oooo001i0?ooo`030000003oool0oooo
0080o`000`00000g0?l0008000000P00of/01@0000000?nX003oZ000ojP0
000000@00?oU00<00000003Lo`00g?l00P00g?l00`00000009oo002Oo`02
002Oo`0300000000H_l006;o00@006;o00<00000000Uo`009Ol010009Ol0
0`0000005`3o01L0o`0501L0o`8000002@1D0?l00`000000TP3o0980o`09
0980o`050000003o0000oooo0?ooo`000000203oool007T0oooo00<00000
0?ooo`3oool00P3o0003000003L0o`0000D00000003oJ`00of/00?m[0000
0003003oZ00500000000onD00?oU003oi@0000001000g?l00`00000009oo
002Oo`03002Oo`0300000000H_l006;o00<006;o00<00000000Uo`009Ol0
1@009Ol00`0000005`3o01L0o`0501L0o`030000001D0?l0E03o00L0E03o
00<000000980o`2B0?l02@2B0?l00`000000o`000?l000020?ooo`030000
003oool0oooo00H0oooo001i0?ooo`030000003oool0oooo0080o`001000
000e0?l0008000000P00of/01@0000000?nX003oZ000ojP0000000@00?oU
00<00000003Lo`00g?l00P00g?l00`00000009oo002Oo`02002Oo`800000
1@00H_l00`00000002Go000Uo`04000Uo`030000000G0?l05`3o00H05`3o
00<0000005@0o`1D0?l01`1D0?l00`000000TP3o0980o`090980o`030000
003o0000o`000080oooo00<000000?ooo`3oool01P3oool007T0oooo00<0
00000?ooo`3oool00P3o0005000003<0o`000P000002003oJ`8000000`00
ojP01@0000000?oU003oi@00onD0000000@00=co00<00000002Oo`00Wol0
0`00Wol00`00000006;o001Ro`03001Ro`8000001P009Ol00`0000005`3o
01L0o`0601L0o`030000001D0?l0E03o00L0E03o00<000000980o`2B0?l0
2@2B0?l00`000000o`000?l000020?ooo`030000003oool0oooo00H0oooo
001i0?ooo`80000000@0oooo0?l0003o0000o`001@00000b0?l000050000
0000of/00?m[003oJ`0000000`00ojP0100000000?oU003oi@00onD20000
00@00=co00<00000002Oo`00Wol00P00Wol2000000D006;o00<00000000U
o`009Ol010009Ol2000000L05`3o00<0000005@0o`1D0?l01`1D0?l20000
00X0TP3o0P0000020?l00080oooo00<000000?ooo`3oool01P3oool007T0
oooo00<000000?ooo`3oool00`3o000500000340o`0000D00000003oJ`00
of/00?m[00000003003oZ08000000`00onD00`0000000=co003Lo`02003L
o`0300000000Wol009oo00<009oo00<00000001Ro`00H_l01000H_l00`00
000002Go000Uo`04000Uo`030000000G0?l05`3o00H05`3o00<0000005@0
o`1D0?l01`1D0?l00`000000TP3o0980o`090980o`040000003o0000o`00
0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?oo
o`3oool00`3o0006000002l0o`000P000002003oJ`8000000P00ojP20000
00<00?oU0P000003003Lo`8000001000Wol2000000D006;o00<00000000U
o`009Ol01@009Ol00`0000005`3o01L0o`0501L0o`8000002@1D0?l00`00
0000TP3o0980o`090980o`040000003o0000o`000?l00080oooo00<00000
0?ooo`3oool01P3oool007T0oooo00<000000?ooo`3oool0103o00060000
02d0o`000P000002003oJ`8000000`00ojP00`0000000?oU003oi@02003o
i@0300000000g?l00=co00800=co00<00000002Oo`00Wol00`00Wol00`00
000006;o001Ro`03001Ro`8000001P009Ol00`0000005`3o01L0o`0601L0
o`030000001D0?l0E03o00L0E03o00<000000980o`2B0?l02@2B0?l20000
00<0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool00`000000
oooo0?ooo`040?l000L00000:`3o0002000000800?m[0P000003003oZ003
00000000onD00?oU00800?oU00<00000003Lo`00g?l00P00g?l2000000@0
09oo0P000005001Ro`03000000009Ol002Go00D002Go00<0000001L0o`0G
0?l01@0G0?l2000000T0E03o00<000000980o`2B0?l02@2B0?l00`000000
o`000?l000020?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo
00<000000?ooo`3oool01@3o0008000002P0o`000P000002003oJ`800000
0`00ojP00`0000000?oU003oi@02003oi@0300000000g?l00=co00800=co
0P000004002Oo`8000001@00H_l00`00000002Go000Uo`05000Uo`030000
000G0?l05`3o00H05`3o00<0000005@0o`1D0?l01`1D0?l2000000X0TP3o
0P0000040?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo0P00
00000`3oool0o`000?l000030?l000T000009P3o0002000000800?m[00<0
0000003oZ000ojP00P00ojP00`0000000?oU003oi@02003oi@0300000000
g?l00=co00800=co0P000005002Oo`0300000000H_l006;o00@006;o00<0
0000000Uo`009Ol010009Ol00`0000005`3o01L0o`0601L0o`030000001D
0?l0E03o00P0E03o00<000000980o`2B0?l02@2B0?l00`000000o`000?l0
00030?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<00000
0?ooo`3oool01@3o000:000002<0o`000P000003003oJ`8000000`00ojP0
0`0000000?oU003oi@02003oi@8000001000g?l00`00000009oo002Oo`03
002Oo`0300000000H_l006;o00@006;o00<00000000Uo`009Ol01@009Ol0
0`0000005`3o01L0o`0601L0o`030000001D0?l0E03o00L0E03o00<00000
0980o`2B0?l02P2B0?l00`000000o`000?l000030?l00080oooo00<00000
0?ooo`3oool01P3oool007T0oooo00<000000?ooo`3oool01P3o000:0000
0240o`000P000003003oJ`8000000P00ojP2000000@00?oU00<00000003L
o`00g?l00`00g?l00`00000009oo002Oo`03002Oo`8000001@00H_l00`00
000002Go000Uo`05000Uo`030000000G0?l05`3o00H05`3o00<0000005@0
o`1D0?l0201D0?l00`000000TP3o0980o`090980o`030000003o0000o`00
00@0o`000P3oool00`000000oooo0?ooo`060?ooo`00N@3oool00`000000
oooo0?ooo`060?l000d00000703o0002000000<00?m[0P000003003oZ080
00001000onD2000000@00=co00<00000002Oo`00Wol00`00Wol2000000D0
06;o0P000006000Uo`8000001`0G0?l2000000T0E03o00<000000980o`2B
0?l02P2B0?l00`000000o`000?l000040?l00080oooo00<000000?ooo`3o
ool01P3oool007T0oooo00<000000?ooo`3oool01`3o000900000003003o
Z0000000000000800000603o0002000000@00?m[00<00000003oZ000ojP0
0P00ojP00`0000000?oU003oi@03003oi@0300000000g?l00=co00<00=co
00<00000002Oo`00Wol00`00Wol2000000H006;o00<00000000Uo`009Ol0
1@009Ol00`0000005`3o01L0o`0601L0o`030000001D0?l0E03o00P0E03o
00<000000980o`2B0?l02@2B0?l2000000H0o`000P3oool00`000000oooo
0?ooo`060?ooo`00L`3oool5000000040?ooo`000000oooo0?ooo`L0o`00
4@00000B0?l000<000000`00of/3000000<00?nX0P000004003oi@800000
1000g?l2000000D009oo0P000006001Ro`03000000009Ol002Go00D002Go
00<0000001L0o`0G0?l01P0G0?l2000000T0E03o00<000000980o`2B0?l0
2P2B0?l00`000000o`000?l000050?l00080oooo00<000000?ooo`3oool0
1P3oool007D0oooo00D000000?ooo`3oool0oooo000000020?ooo`P0o`00
500000090?l000D000001000of/2000000D00?nX0P000004003oi@800000
1@00g?l00`00000009oo002Oo`03002Oo`8000001P00H_l00`00000002Go
000Uo`05000Uo`030000000G0?l05`3o00L05`3o00<0000005@0o`1D0?l0
201D0?l00`000000TP3o0980o`090980o`030000003o0000o`0000H0o`00
0P3oool00`000000oooo0?ooo`060?ooo`00M@3oool010000000oooo0?oo
o`3oool2000000030?ooo`3o0000o`0000H0o`003P0000001000ojP00000
000000000002003oJ`T000001P00of/3000000@00?nX0`000004003oi@80
00001@00g?l2000000D009oo0P000006001Ro`03000000009Ol002Go00D0
02Go0P00000801L0o`030000001D0?l0E03o00P0E03o00<000000980o`2B
0?l02P2B0?l00`000000o`000?l000060?l000030?ooo`000000000000P0
oooo001e0?ooo`050000003oool0oooo0?ooo`0000000P3oool90?l001P0
00000`00of/7000000D00?nX0`000004003oi@8000001@00g?l3000000D0
09oo00<00000001Ro`00H_l01@00H_l00`00000002Go000Uo`05000Uo`80
0000200G0?l00`000000E03o05@0o`0805@0o`030000002B0?l0TP3o00X0
TP3o00<000000?l0003o00001`3o00020?ooo`030000003oool0oooo00H0
oooo001e0?ooo`050000003oool0oooo0?ooo`0000000P3oool:0?l000P0
000000<009oo0000000000000`0000001000onD00000000000000005003o
Z0<000002000ojP4000000D00?oU0`000005003Lo`8000001P00Wol20000
00H006;o00<00000000Uo`009Ol01@009Ol2000000P05`3o0P00000905@0
o`8000002`2B0?l2000000T0o`000P3oool00`000000oooo0?ooo`060?oo
o`00M03oool2000000<0oooo00<000000?ooo`3oool02P3o00001@000000
TP3o0000000000005`3o00L0000000<00=co0000000000000P0000000`00
onD000000000000>000000L00?oU0`000005003Lo`8000001P00Wol20000
00H006;o0P000008000Uo`030000000G0?l05`3o00H05`3o0P00000905@0
o`800000302B0?l00`000000o`000?l000080?l00080oooo00<000000?oo
o`3oool01P3oool007T0oooo00<000000?ooo`3oool02`3o000>00000004
003Lo`0000000000000001800?oU10000006003Lo`<000001P00Wol20000
00H006;o0P000007000Uo`800000200G0?l2000000X0E03o00<000000980
o`2B0?l02P2B0?l00`000000o`000?l000090?l00080oooo00<000000?oo
o`3oool01P3oool007T0oooo00<000000?ooo`3oool0303o000200000007
05@0o`0000005`3o000000009Ol00000001Ro`0300000005002Oo`000000
000000000000g?l020000003003oi@P000001`00g?l2000000L009oo0P00
0007001Ro`03000000009Ol002Go00H002Go0P00000801L0o`8000002P1D
0?l00`000000TP3o0980o`0:0980o`8000002`3o00020?ooo`030000003o
ool0oooo00H0oooo001i0?ooo`80000000<0oooo0?l0003o00002P3o0003
0000000305@0o`0000005`3o00@0000000D006;o0000000000000000002O
o`03000000H00=co1@00000:003Lo`@000001`00Wol2000000L006;o0P00
0008000Uo`800000200G0?l2000000X0E03o0P00000;0980o`800000303o
00020?ooo`030000003oool0oooo00H0oooo001i0?ooo`030000003oool0
oooo00d0o`002`0000001000H_l00000000000000002002Oo`D000002`00
g?l6000000L009oo0`000007001Ro`<000001`009Ol3000000P05`3o0P00
000:05@0o`800000302B0?l00`000000o`000?l0000;0?l00080oooo00<0
00000?ooo`3oool01P3oool007T0oooo00<000000?ooo`3oool03P3o0000
10000000TP3o0000001D0?l20000000301L0o`00000002Go00<0000000@0
06;o00000000000000001@00Wol<000000T009oo10000008001Ro`800000
20009Ol2000000T05`3o0P00000:05@0o`030000002B0?l0TP3o00/0TP3o
00<000000?l0003o0000303o00020?ooo`030000003oool0oooo00H0oooo
001i0?ooo`030000003oool0oooo00l0o`0000<000000980o`0000000`00
0000100G0?l00000000000009Ol30000008006;o1000000C002Oo`@00000
2@00H_l2000000T002Go0P00000901L0o`8000002P1D0?l2000000`0TP3o
0P00000>0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<0
00000?ooo`3oool03`3o0002000000030980o`000000E03o0080000000D0
5`3o0000000000000000000Uo`04000000<006;o1`000006002Oo`L00000
2P00H_l2000000T002Go0P00000901L0o`8000002`1D0?l2000000`0TP3o
0P00000?0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<0
00000?ooo`3oool0403o0002000000030980o`000000E03o00<0000000<0
5`3o0000000000000`009Ol3000000L006;o1`00000=001Ro`@000002@00
9Ol3000000T05`3o0P00000;05@0o`800000302B0?l200000100o`000P3o
ool00`000000oooo0?ooo`060?ooo`00N@3oool00`000000oooo0?ooo`0A
0?l00080000000@0TP3o000000000000E03o0P00000201L0o`8000000`00
9Ol4000001D006;o1000000:000Uo`<000002P0G0?l2000000/0E03o0P00
000<0980o`8000004@3o00020?ooo`030000003oool0oooo00H0oooo001i
0?ooo`80000000<0oooo0?l0003o0000403o0002000000040980o`000000
000005@0o`8000000P0G0?l3000000D002Go1`000008001Ro`H000003000
9Ol3000000X05`3o0P00000<05@0o`030000002B0?l0TP3o00/0TP3o0P00
000B0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<00000
0?ooo`3oool04`3o000200000080TP3o00<0000005@0o`1D0?l00P000003
01L0o`@000001`009Ol9000000l002Go0`00000<01L0o`8000002`1D0?l2
000000d0TP3o0P00000C0?l00080oooo00<000000?ooo`3oool01P3oool0
07T0oooo00<000000?ooo`3oool0503o0002000000040980o`0000000000
00000080E03o0P00000401L0o`<000006P009Ol4000000`05`3o0P00000<
05@0o`8000003@2B0?l2000001@0o`000P3oool00`000000oooo0?ooo`06
0?ooo`00N@3oool00`000000oooo0?ooo`0E0?l0008000000P2B0?l20000
00<0E03o0P00000501L0o`D000004@009Ol4000000h05`3o0P00000=05@0
o`030000002B0?l0TP3o00`0TP3o0P00000E0?l00080oooo00<000000?oo
o`3oool01P3oool007T0oooo00<000000?ooo`3oool05P3o000200000080
TP3o0P00000305@0o`<000001`0G0?lB000000l05`3o0`00000=05@0o`80
00003P2B0?l2000001H0o`000P3oool00`000000oooo0?ooo`060?ooo`00
N@3oool00`000000oooo0?ooo`0H0?l0008000000P2B0?l2000000@0E03o
0`00000R01L0o`<000003P1D0?l3000000h0TP3o00<000000?l0003o0000
5P3o00020?ooo`030000003oool0oooo00H0oooo001i0?ooo`80000000<0
oooo0?l0003o00005`3o000200000080TP3o0`00000405@0o`@00000700G
0?l4000000h0E03o0`00000>0980o`8000006@3o00020?ooo`030000003o
ool0oooo00H0oooo001i0?ooo`030000003oool0oooo01/0o`0000<00000
0980o`2B0?l00P2B0?l2000000H0E03o1000000D01L0o`D00000401D0?l2
000000l0TP3o0P00000J0?l00080oooo00<000000?ooo`3oool01P3oool0
07T0oooo00<000000?ooo`3oool06`3o0002000000@0TP3o0`00000805@0
oaD000004P1D0?l200000100TP3o0P00000K0?l00080oooo00<000000?oo
o`3oool01P3oool007T0oooo00<000000?ooo`3oool07@3o0003000000@0
TP3o0`00000Y05@0o`<00000402B0?l2000001d0o`000P3oool00`000000
oooo0?ooo`060?ooo`00N@3oool00`000000oooo0?ooo`0O0?l000800000
1@2B0?l3000002@0E03o0`00000B0980o`030000003o0000o`0001d0o`00
0P3oool00`000000oooo0?ooo`060?ooo`00N@3oool00`000000oooo0?oo
o`0P0?l000<000001P2B0?l4000001`0E03o1@00000B0980o`800000803o
00020?ooo`030000003oool0oooo00H0oooo001i0?ooo`030000003oool0
oooo0280o`00100000060980o`H000004`1D0?l5000001<0TP3o0`00000R
0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo0P0000000`3o
ool0o`000?l0000R0?l000<000002P2B0?lD000001L0TP3o0P00000T0?l0
0080oooo00<000000?ooo`3oool01P3oool007T0oooo00<000000?ooo`3o
ool09P3o000300000300TP3o0`00000V0?l00080oooo00<000000?ooo`3o
ool01P3oool007T0oooo00<000000?ooo`3oool0:@3o0003000002X0TP3o
1000000X0?l00080oooo00<000000?ooo`3oool01P3oool007T0oooo00<0
00000?ooo`3oool0:`3o0003000002H0TP3o0`00000[0?l00080oooo00<0
00000?ooo`3oool01P3oool007<0oooo100000020?ooo`030000003oool0
oooo02h0o`001000000N0980o`@00000;P3o00020?ooo`030000003oool0
oooo00H0oooo001c0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0<P3o0006000001<0TP3o1@00000b0?l00080oooo00<000000?oo
o`3oool01P3oool007@0oooo00<000000?ooo`3oool00P3oool200000003
0?ooo`3o0000o`0003D0o`005000000g0?l000030?ooo`000000000000P0
oooo001e0?ooo`050000003oool0oooo0?ooo`000000QP3oool00`000000
oooo0?ooo`060?ooo`00L`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo000000080?ooo`00M03oool2000000<0ooooR00000080?ooo`00
o`3oool:0?ooo`00o`3oool:0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{265, 155},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The result of Example 10.7 shows that the function  \n\n\t\t\t\
",
  Cell[BoxData[{
      \(\(\(w\ \  = \ \ \(u + \ \[ImaginaryI]\ v\ \  = \ \ \(\[ImaginaryI]\ \
\((4 - z)\)\)\/z\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\ \ \)\(\(\[ImaginaryI]\ \((4 - 
                  x - \[ImaginaryI]\ y)\)\)\/\((x + \[ImaginaryI]\ \
y)\)\)\)\)}]],
  "  \n\nis a conformal mapping of the crescent-shaped region that lies \
inside the disk ",
  Cell[BoxData[
      \(D : \(\(|\)\(z - 2\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  "  and outside the circle ",
  Cell[BoxData[
      \(\(\(|\)\(z - 1\)\(|\)\) = \ 1\)]],
  "  onto the horizontal strip  ",
  Cell[BoxData[
      \(0\  < \ v\  < \ 1\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.41",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/electrostatics/\
ElectrostaticsFigures/mat1141.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The electrical potential ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " inside ",
  Cell[BoxData[
      \(D : \(\(|\)\(z - 2\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  "  and outside ",
  Cell[BoxData[
      \(\(\(|\)\(z - 1\)\(|\)\) = \ 1\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Revisit and Explore Solution 10.7.",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Example 10.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the bilinear transformation ",
  Cell[BoxData[
      \(w = S \((z)\)\)]],
  " that maps the crescent-shaped region that lies inside the disk ",
  Cell[BoxData[
      \(D : \(\(|\)\(z - 2\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  "  and outside the circle ",
  Cell[BoxData[
      \(\(\(|\)\(z - 1\)\(|\)\) = \ 1\)]],
  "  onto a horizontal strip."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  For convenience we choose  ",
  Cell[BoxData[
      RowBox[{\(z\_1 = 4\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        " ", \(z\_2 = 2 + 2  \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(z\_3 = 0\)}]]],
  "  and the image values  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(w\_2 = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(w\_3 = \[Infinity]\)}]]],
  ",  respectively.  The ordered triple  ",
  Cell[BoxData[
      RowBox[{\(z\_1 = \(-4\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        " ", \(z\_2 = 2 + 2  \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(z\_3 = 0\)}]]],
  "  gives the circle  ",
  Cell[BoxData[
      \(C : \(\(|\)\(z - 2\)\(|\)\) = \ 2\)]],
  "  a positive orientation and the disk  ",
  Cell[BoxData[
      \(D : \(\(|\)\(z - 2\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  "  has a left orientation.  The image points  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(w\_2 = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(w\_3 = \[Infinity]\)}]]],
  "  all lie on the extended ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " axis, and they determine a left orientation for the upper half-plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  ".  Therefore we can use the second implicit formula (Equation ",
  StyleBox["(10-21)",
    FontColor->RGBColor[0, 0, 1]],
  ") to write  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\((z\  - \ 4)\)\ \((2\  + \ 2  \[ImaginaryI]\  - \ 0)\)\)\/\(\((z\  \
- \ 0)\) \((2\  + \ 2  \[ImaginaryI]\  - \ 4)\)\)\  = \ \(w\  - \ 0\)\/\(1\  \
- \ 0\)\)]],
  ",  \n\nwhich determines a mapping of the disk  ",
  Cell[BoxData[
      \(D : \(\(|\)\(z - 2\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  "  onto the upper half-plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  ".  Use the fact that ",
  Cell[BoxData[
      \(\(\(\ \)\(2\  + \ 2  \[ImaginaryI]\)\)\/\(\(-2\)\  + \ 2  \
\[ImaginaryI]\)\  = \(-\[ImaginaryI]\)\)]],
  "  to simplify the preceding equation and get \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(z\  - \ 
                4\)\/\(\(z\)\(\ \)\)\) \(\(\ \)\(2\  + \ 2  \[ImaginaryI]\)\)\
\/\(\(-2\)\  + \ 2  \[ImaginaryI]\)\  = \(\(\(z\  - \ 
                  4\)\/\(\(z\)\(\ \)\)\) \((\(-\[ImaginaryI]\))\)\  = \ \ \
w\/1\)\)]],
  " \n\nwhich can be written in the form  \n\n\t\t\t",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(\(-\[ImaginaryI]z\)\  + \ \[ImaginaryI]4\)\/\(\(z\
\)\(\ \)\)\)\)],
    AspectRatioFixed->True],
  ". "
}], "Text"],

Cell[TextData[{
  "A straightforward calculation shows that the points  ",
  Cell[BoxData[
      RowBox[{\(z\_4 = 1 - \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(z\_5 = 2\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        " ", \(z\_6 = 1 + \[ImaginaryI]\)}]]],
  "  are mapped onto the points  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(w\_4\ \  = \ \ \(S \((z\_4)\)\ \  = \ \ \(S \((1 - \
\[ImaginaryI])\)\ \  = \ \ \(-2\) + \[ImaginaryI]\)\)\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["  ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(w\_5\ \  = \ \ \(S \((z\_5)\)\ \  = \ \ \(S \
\((2)\)\ \  = \ \ \[ImaginaryI]\)\)\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[
          RowBox[{
            StyleBox["  ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  "}]], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", \(w\_6\ \  = \ \ \(S \((z\_6)\)\ \  = \ \ \(S \
\((1 + \[ImaginaryI])\)\ \  = \ \ 2 + \[ImaginaryI]\)\)\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox["  ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]]],
  "  \n\nrespectively.  The points  ",
  Cell[BoxData[
      RowBox[{\(w\_4 = \(-2\) + \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], " ", \(w\_5 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        " ", \(w\_6 = 2 + \[ImaginaryI]\)}]]],
  "  lie on the horizontal line  ",
  Cell[BoxData[
      \(Im \((w)\) > 1\)]],
  "  in the upper half-plane.  Therefore the crescent-shaped region is mapped \
onto the horizontal strip  ",
  Cell[BoxData[
      \(0 < Im \((w)\) < 1\)]],
  ",  as shown in Figure 10.7. "
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t\t",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Figure 10.7",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/mobiustranformation/\
MobiusTranformationFigures/mat1007.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The mapping  ",
  Cell[BoxData[
      \(w = \(S \((z)\) = \(\(-\[ImaginaryI]z\)\  + \ \[ImaginaryI]4\)\/\(\(z\
\)\(\ \)\)\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[TextData[{
  "Enter three points and their images and solve for  w = S(z).  For \
convenience we choose  ",
  Cell[BoxData[
      \(z\_1 = 4, \ z\_2 = 2 + 2  \[ImaginaryI], \ z\_3 = 0\)],
    AspectRatioFixed->True],
  "  which are mapped onto the points  ",
  Cell[BoxData[
      \(w\_1 = 0, \ w\_2 = 1, \ w\_3 = \[Infinity]\)],
    AspectRatioFixed->True],
  ",  respectively.  In this case we remove the terms involving  ",
  Cell[BoxData[
      \(w\_3\  = \ \[Infinity]\)],
    AspectRatioFixed->True],
  ",  in the implicit formula, because this implies that  ",
  Cell[BoxData[
      \(\(w\_2\  - \ w\_3\)\/\(w\  - \ w\_3\) = \(\(w\_2\  - \ \
\[Infinity]\)\/\(w\  - \ \[Infinity]\) = 1\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(S = \(T = \(w = \(W = \(z = \(Z = 0\)\)\)\)\); \ 
    Remove[S, T, w, W, z, Z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[formula, Iden, solset];\)\ \), "\n", 
    \(\(formula\  = \ \(\((z - z\_1)\) \((z\_2 - z\_3)\)\)\/\(\((z - z\_3)\) \
\((z\_2 - z\_1)\)\)\  \[Equal] \ \(w - w\_1\)\/\(w\_2 - w\_1\);\)\ \), "\n", 
    \(\(Print[formula];\)\ \), "\n", 
    \(\(z\_1\  = \ 4;\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(z\_2\  = \ 2 + 2  \[ImaginaryI];\)\ \ \), "\[IndentingNewLine]", 
    \(\(z\_3\  = \ 0;\)\ \ \), "\n", 
    \(\(w\_1\  = \ 0;\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\_2\  = \ 1;\)\ \ \), "\[IndentingNewLine]", 
    \(\(w\_3\  = \ \[Infinity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Substitute the values\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,    \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,   \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,    \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,       \!\(w\_3\) = \>\"", 
        w\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[formula];\)\ \), "\n", 
    \(\(solset\  = \ Solve[formula, w];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S(z) = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Check our work and look at the images of  ",
  Cell[BoxData[
      \(z\_1, \ z\_2, \ z\_3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Print[\*"\"\<   \!\(z\_1\) = \>\"", 
        z\_1, \*"\"\<,      \!\(z\_2\) = \>\"", 
        z\_2, \*"\"\<,    \!\(z\_3\) = \>\"", z\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_1\) = \>\"", 
        w\_1, \*"\"\<,      \!\(w\_2\) = \>\"", 
        w\_2, \*"\"\<,        \!\(w\_3\) = \>\"", w\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<S[\!\(z\_1\)] = \>\"", 
        S[z\_1], \*"\"\<,   S[\!\(z\_2\)] = \>\"", 
        S[z\_2], \*"\"\<,     S[\!\(z\_3\)] = \>\"", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "And we need to look at the images of three more points;   ",
  Cell[BoxData[
      \(z\_4 = 1 - \[ImaginaryI], \ z\_5 = 2, \ z\_6 = 1 + \[ImaginaryI]\)],
    AspectRatioFixed->True],
  "  and  ",
  Cell[BoxData[
      \(w\_4 = \(-2\) + \[ImaginaryI], \ w\_5 = \[ImaginaryI], \ 
      w\_6 = 2 + \[ImaginaryI]\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(z\_4\  = \ \ 1 - \[ImaginaryI]; \ \ \ \ \ z\_5\  = \ 
      2; \ \ \ \ z\_6\  = \ 1 + \[ImaginaryI];\ \), "\n", 
    \(w\_4\  = \ \(-2\) + \[ImaginaryI]; \ \ \ w\_5\  = \ \[ImaginaryI]; \ \ \
\ w\_6\  = \ 2 + \[ImaginaryI];\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<   \!\(z\_4\) = \>\"", 
        z\_4, \*"\"\<,       \!\(z\_5\) = \>\"", 
        z\_5, \*"\"\<,       \!\(z\_6\) = \>\"", z\_6];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(w\_4\) = \>\"", 
        w\_4, \*"\"\<,      \!\(w\_5\) = \>\"", 
        w\_5, \*"\"\<,       \!\(w\_6\) = \>\"", w\_6];\)\ \), "\n", 
    \(\(Print[\*"\"\<S[\!\(z\_4\)] = \>\"", 
        S[z\_4], \*"\"\<,   S[\!\(z\_5\)] = \>\"", 
        S[z\_5], \*"\"\<,    S[\!\(z\_6\)] = \>\"", 
        S[z\_6]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
To illustrate the mapping, consider the inverse image of the horizontal \
strip.  We will need to use the inverse function.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Iden[w_]\  = \ w;\)\ \), "\n", 
    \(\(solset\  = \ Solve[formula, z];\)\ \), "\n", 
    \(\(T[w_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<w = S[z] = \>", S[z]];\)\ \), "\n", 
    \(\(Print["\<z = T[w] = \>", T[w]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<T[S[z]] = \>", T[S[z]], "\< = \>", 
        Simplify[T[S[z]]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<S[T[w]] = \>", S[T[w]], "\< = \>", 
        Simplify[S[T[w]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Now plot the graphs using T[w] then the identity map.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(set\  = \ \ {{4, 0}, {2, 2}, {1, \(-1\)}, {2, 0}, {1, 
            1}};\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(zdots = 
        Graphics[{{Magenta, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Cyan, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}, {Green, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(4\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(5\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(set\  = \ \ {{0, 0}, {1, 0}, {\(-2\), 1}, {0, 1}, {2, 
            1}};\)\ \), "\[IndentingNewLine]", 
    \(\(wdots = 
        Graphics[{{Magenta, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(1\)\(\
\[RightDoubleBracket]\)\)]}, {Cyan, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(2\)\(\
\[RightDoubleBracket]\)\)]}, {Blue, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(3\)\(\
\[RightDoubleBracket]\)\)]}, {Green, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(4\)\(\
\[RightDoubleBracket]\)\)]}, {Red, PointSize[0.04], 
              Point[set\_\(\(\[LeftDoubleBracket]\)\(5\)\(\
\[RightDoubleBracket]\)\)]}}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(zplane = 
        CartesianMap[
          T\ \ \ , {\(-9\), 9, 0.3}, {0.005, 0.995, 
            0.09}, \[IndentingNewLine]PlotRange \[Rule] {{\(-0.05\), 
                4.05}, {\(-2.05\), 
                2.05}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 4, 1], 
              Range[2, 2, 
                1]}, \[IndentingNewLine]AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(wplane = 
        CartesianMap[
          Iden, {\(-9\), 9, 0.9}, {0.005, 0.995, 
            0.09}, \[IndentingNewLine]PlotRange \[Rule] {{\(-9\), 9}, {0, 
                1}}, AspectRatio \[Rule] 
            1\/3, \[IndentingNewLine]Ticks \[Rule] {Range[\(-9\), 9, 3], 
              Range[0, 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[zplane, zdots, 
        PlotRange \[Rule] {{\(-0.05\), 4.05}, {\(-2.05\), 2.05}}, 
        AspectRatio \[Rule] 
          1, \[IndentingNewLine]Ticks \[Rule] {Range[0, 4, 1], 
            Range[2, 2, 1]}, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The the crescent-shaped region that lies inside\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<the disk |z-2| < 2 and outside the circle |z-1| = 1.\>"];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Show[wplane, wdots, PlotRange \[Rule] {{\(-9\), 9}, {0, 1}}, 
        AspectRatio \[Rule] 
          1\/3, \[IndentingNewLine]Ticks \[Rule] {Range[\(-9\), 9, 3], 
            Range[0, 1, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image is the horizontal strip 0 < v < 1,\>"];\)\ \), "\n\
", 
    \(\(Print["\<under the mapping  w = \>", 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", z\_1, "\<] = \>", 
        S[z\_1], \[IndentingNewLine]"\<,      S[\>", z\_2, "\<] = \>", 
        S[z\_2], \[IndentingNewLine]"\<,   S[\>", z\_3, "\<] = \>", 
        S[z\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[\>", z\_4, "\<] = \>", 
        S[z\_4], \[IndentingNewLine]"\<,   S[\>", z\_5, "\<] = \>", 
        S[z\_5], \[IndentingNewLine]"\<,   S[\>", z\_6, "\<] = \>", 
        S[z\_6]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We have constructed the transformation ",
  Cell[BoxData[
      \(w = \(S[
            z] = \(-\(\(\[ImaginaryI]\ \((\(-4\)\  + \ z)\)\)\/z\)\)\)\)]],
  "  and see that the image of the crescent-shaped region that lies inside \
the disk ",
  Cell[BoxData[
      \(\(\(|\)\(z - 2\)\(|\)\(\(<\)\(\ \)\(2\)\)\)\)]],
  "  and outside the circle ",
  Cell[BoxData[
      \(\(\(|\)\(z - 1\)\(|\)\) = \ 1\)]],
  "  is the horizontal strip  ",
  Cell[BoxData[
      \(0 < v < 1\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\tThe new problem in the w plane is to find the potential  ",
  Cell[BoxData[
      RowBox[{"\[CapitalPhi]", 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  "  that satisfies the boundary values  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalPhi]", 
            RowBox[{"(", 
              RowBox[{"u", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], " ", "=", " ", 
          "100"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["all",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "u"}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->14,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[";",
            FontFamily->"Times New Roman",
            FontSize->14,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}]}], "\n", 
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalPhi]", 
            RowBox[{"(", 
              RowBox[{"u", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "1"}], ")"}]}], " ", "=", "   ", 
          "50"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->14,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", 
        RowBox[{
          StyleBox["for",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox["all",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", 
          RowBox[{"u", 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[".",
              FontFamily->"Times New Roman",
              FontSize->14,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}]}]}]],
  "  \n\t\t\t\nIn the w plane the solution is\n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalPhi]", 
            RowBox[{"(", 
              RowBox[{"u", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "v"}], ")"}]}], "  ", "=", 
          "  ", \(100\ \  + \ \ \(\(50\  - \ 100\)\/\(1\  - \ \ 0\)\) \((v - 
                  0)\)\)}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"                 ", \(\(=\)\(\ \ \)\(100\  - \ 50\ v\)\)}]}],
    AspectRatioFixed->True]
}], "Text"],

Cell[TextData[{
  "A straightforward calculation shows that  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(w\ \  = \ \ \(u + \ \[ImaginaryI]\ v\ \  = \ \ \(\[ImaginaryI]\ \
\((4 - x - \[ImaginaryI]\ y)\)\)\/\((x + \[ImaginaryI]\ y)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \(\(\(=\)\(\ \ \)\(\(\[ImaginaryI]\ \((4 - 
                  x - \[ImaginaryI]\ y)\) \((x - \[ImaginaryI]\ \
y)\)\)\/\(\((x + \[ImaginaryI]\ y)\) \((x - \[ImaginaryI]\ y)\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(\(=\)\(\ \ \)\(\(4\ y + \[ImaginaryI]\ \((4\ x - x\^2 - 
                    y\^2)\)\)\/\(x\^2 + y\^2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\ \ \)\(\(4\ y\)\/\(x\^2 + y\^2\)\ \  + \ \ \
\[ImaginaryI] \( 4\ x - x\^2 - y\^2\)\/\(x\^2 + y\^2\)\)\)\)}]],
  "  \n\nWe substitute the imaginary part,  ",
  Cell[BoxData[
      RowBox[{"v", "=", 
        RowBox[{
          RowBox[{"v", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], 
          "=", \(\(4\ x - x\^2 - y\^2\)\/\(x\^2 + y\^2\)\)}]}]]],
  "  from this equation, into  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPhi]", 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->14,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], " ", "=", 
        " ", \(100\  - \ 50\ v\)}]],
    AspectRatioFixed->True],
  "  to obtain the desired solution:   \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->14,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
          "  ", \(100\ \  - \ \ 50 \((\(4\ x - x\^2 - y\^2\)\/\(x\^2 + \
y\^2\))\)\)}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "                 ", \(\(=\)\(\ \ \ \)\(150\ \  - \ \ \(200  \
x\)\/\(\(x\^2 + y\^2\)\(\ \)\)\)\)}]}],
    AspectRatioFixed->True],
  "   "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Construct the solution with a conformal mapping.  ", "Text"],

Cell[BoxData[{
    \(z = 0; \ Remove[z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, U, V, \[Phi]];\)\ \), "\n", 
    \(\(f[z_]\  = \ \(\[ImaginaryI]\ \((4 - z)\)\)\/z;\)\ \), "\n", 
    \(\(W\  = \ \ ComplexExpand[f[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(U\  = \ 
        Together[
          ComplexExpand[Re[W], 
            TargetFunctions \[Rule] {Re, Im}]];\)\ \), "\n", 
    \(\(\(V\  = \ 
          Together[
            ComplexExpand[Im[W], 
              TargetFunctions \[Rule] {Re, Im}]];\)\ ;\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ 
        100\ \  + \ \ \(\(50\  - \ 100\)\/\(1\  - \ \ 0\)\) \((V - 
                0)\);\)\ \), "\n", 
    \(\(Print["\<w = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<w = u + \[ImaginaryI] v = \>", 
        U\  + \ \[ImaginaryI]\ V];\)\ \ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\[Phi][x,y] = 100  +  \!\(\(50\\\  - \\\ 100\)\/\(1\\\  \
- \\\ \\\ 0\)\)(v-0)\>\""];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi][x_, y_]\  = 
        FullSimplify[\[Phi][x, y]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi][x_, y_]\  = Expand[\[Phi][x, y]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the equipotentials. "
}], "Text"],

Cell[BoxData[{
    \(\(\[Phi][x_, y_] = 
        150 - \(200  x\)\/\(\(x\^2 + y\^2\)\(\ \)\);\)\), \
"\[IndentingNewLine]", 
    \(\(cont\  = \ Table[50 + 5  k, {k, 0, 10}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Phi][x, y], {x, 0, 4}, {y, \(-2\), 2}, 
        Contours\  \[Rule] \ cont, \[IndentingNewLine]PlotPoints \[Rule] 60, 
        AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, y]];\)\ \), "\n", 
    \(\(Print["\<The contours are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[Phi][x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the electrical potential  ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  in the semi-infinite strip ",
  Cell[BoxData[
      \(\(-\(\[Pi]\/2\)\) < x < \[Pi]\/2, y > 0\)]],
  " that has the boundary values shown in Figure 11.42:\n\n\t\t\t",
  Cell[BoxData[
      RowBox[{"  ", 
        RowBox[{
          RowBox[{
            RowBox[{"\[Phi]", 
              RowBox[{"(", 
                RowBox[{\(\[Pi]\/2\), 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
            "       ", "0"}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", \(for\ \ \ y > 0\), ",", 
          "\[IndentingNewLine]", "    ", 
          RowBox[{
            RowBox[{"\[Phi]", 
              RowBox[{"(", 
                RowBox[{"y", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "0"}], ")"}]}], " ", "=", 
            "     ", "50"}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          "   ", \(for\ \ \  - \[Pi]\/2 < x < \[Pi]\/2\), ",", 
          "\[IndentingNewLine]", 
          RowBox[{
            RowBox[{"\[Phi]", 
              RowBox[{"(", 
                RowBox[{\(-\(\[Pi]\/2\)\), 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", "   ",
             "100"}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "   ", \(for\ \ \ y < 0. \)}]}]]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008N0000_B000`400?l0
0000o`00003oo`3ooooo0?ooob00oooo003o0?ooool0oooo803oool00?l0
ooooo`3ooolP0?ooo`00o`3ooooo0?ooob00oooo003o0?ooool0oooo803o
ool00?l0ooooo`3ooolP0?ooo`00o`3ooooo0?ooob00oooo003o0?ooool0
oooo803oool00?l0ooooo`3ooolP0?ooo`00o`3ooooo0?ooob00oooo003o
0?ooool0oooo803oool00?l0ooooo`3ooolP0?ooo`00P@3oool500000080
oooo0P0000040?ooo`800000403oool5000000h0oooo0P0000040?ooo`80
0000103oool2000000h0oooo0P00000@0?ooo`800000103oool2000000@0
oooo0P00000@0?ooo`D000003P3oool500000080oooo0P0000040?ooo`80
0000o@3oool008<0oooo00<000000?ooo`3oool01`3oool010000000oooo
0?ooo`00000A0?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`00000<0?ooo`040000003oool0
oooo000000h0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool01`3oool010000000oooo0?ooo`00003l0?ooo`00P`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo
00X0oooo00@000000?ooo`3oool000003P3oool010000000oooo0?ooo`00
000;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?X0oooo001k
0?ooo`@00000103oool00`000000oooo0?ooo`080?ooo`8000002P3oool4
000000@0oooo00<000000?ooo`3oool01`3oool400000080oooo00@00000
0?ooo`3oool000002@3oool2000000d0oooo00@000000?ooo`3oool00000
3P3oool010000000oooo0?ooo`0000090?ooo`8000004P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo0P00002C0?ooo`D0
00006P3oool2000004T0oooo00230?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool0303oool010000000
oooo0?ooo`00000>0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0H
0?ooo`80000000<0oooo000000000000B03oool00880oooo0P00000:0?oo
o`<00000403oool200000100oooo0P00000:0?ooo`<000003@3oool20000
0100oooo0P00000:0?ooo`<00000403oool200000140oooo0P00000:0?oo
o`<00000U03oool00`000000oooo0?ooo`0E0?ooo`<000000`3oool20000
04P0oooo003o0?oookL0oooo00<000000?ooo`3oool04`3oool2000000H0
oooo0`0000170?ooo`00o`3ooong0?ooo`030000003oool0oooo0100oooo
0`0000080?ooo`040000003Wo`000000000004H0oooo003o0?oookH0oooo
0P00000@0?ooo`8000002`3oool010000000iol00>Oo000000160?ooo`00
o`3oooo50?ooo`<000003@3oool01@000000iol00>Oo003Wo`00000004D0
oooo00200?oooj400000X03oool3000000l0oooo0P0000030>Oo00800000
A03oool007X0oooo0P0000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`1K0?ooo`@00000?@3oool200000180oooo0P00
00040>Oo00030000003oool0oooo0480oooo001i0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?oo
o`1J0?ooo`040000003oool0oooo000003/0oooo0`00000D0?ooo`030000
003Wo`00000000<0iol00P0000130?ooo`00N@3oool010000000oooo0?oo
o`0000030?ooo`80000000<0oooo000000000000B`3oool00`000000oooo
0?ooo`180?ooo`<0000000<0oooo000000000000G03oool010000000oooo
0?ooo`00000i0?ooo`8000005`3oool00`000000iol0000000020>Oo0004
0000003oQ000000000000480oooo001i0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool010000019002do`0300000000ok@00?nd
04L00?nd100000020?ooo`030000003oool0oooo05T0oooo0P0000000`3o
ool000000000000f0?ooo`@00000603oool00`000000iol0000000020>Oo
00040000003oQ000oh@000000480oooo001i0?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool01`000016002do`0300000000ok@0
0?nd04@00?nd0`0000000`00oal00000000000030?ooo`030000003oool0
oooo0980oooo0P0000030?ooo`030000003oool0oooo01H0oooo00D00000
0>Oo00000000iol0000000030?n400800000@@3oool007X0oooo0P000004
0?ooo`030000003oool0oooo00@000000P007ol2000004D00;Co00<00000
003o]000ok@0@P00ok@3000000800?lO0`0000030?ooo`030000003oool0
oooo08l0oooo0`00000N0?ooo`050000003Wo`0000000>Oo00000000103o
Q00200000400oooo00200?ooo`040000003oool0oooo0?l0G@@000000P00
7ol3000004<00;Co00<00000003o]000ok@0@@00ok@2000000<00?lO00@0
000007Ko0000000000000`3oool00`000000oooo0?ooo`2=0?ooo`800000
8@3oool010000000iol00000000000050?n400800000@03oool00800oooo
00@000000?ooo`3oool0o`1M0P0000000`1f0?l00000000Oo`04000Oo`03
00000000]?l00;Co04000;Co00<00000003o]000ok@0?`00ok@2000000@0
0?lO00<0000007Ko000000000P0000030?ooo`030000003oool0oooo08X0
oooo0`00000S0?ooo`040000003Wo`000000000000H0oh@00P00000o0?oo
o`00P03oool010000000oooo0?ooo`3o05d30000000307H0o`00000001oo
00@001oo0`00000o002do`0300000000ok@00?nd03d00?nd0P000006003o
7`050000001fo`0000000?oc000000000`3oool00`000000oooo0?ooo`28
0?ooo`8000009P3oool00`000000iol0000000060?n400030000003oGP00
000003l0oooo00200?ooo`070000003oool0oooo0?l0G@000000o`3c0000
000207H0o`03000000007ol001oo00@001oo0P00000n002do`0300000000
ok@00?nd03/00?nd0`000005003o7`80000000<0M_l00000000000000P00
00020?ooo`800000Q`3oool3000002P0oooo00<000000>Oo000000001P3o
Q00010000000oeh000000000000n0?ooo`00P03oool01P000000oooo0?oo
o`3o05d000000?l0l`8000000P1f0?l00`00000001oo000Oo`05000Oo`80
0000?000]?l00`0000000?nd003o]00j003o]00300000000oal00?lO00D0
0?lO0P00000207Ko00040000003ol`0000000?mM00<0oooo00<000000?oo
o`3oool0IP3oool2000001/0oooo0P00000[0?ooo`040000003Wo`000000
000000@0oh@000@000000?mN003oGP00oeh00P00000m0?ooo`00P03oool0
0`000000oooo0?ooo`020?l0G@030000003o0?<0000000<0MP3o00<00000
000Oo`007ol01P007ol00`0000000;Co002do`0i002do`0300000000ok@0
0?nd03P00?nd0P000007003o7`8000000`1fo`0010000000oo<00000003o
G@030?ooo`030000003oool0oooo06D0oooo00@000000?ooo`3oool00000
5`3oool3000002`0oooo00D000000>Oo0000000000000=Ko000200000080
oh@000<000000?mN003oGP000P3oGP000`000000oooo0?ooo`0k0?ooo`00
P03oool00`000000oooo0?ooo`020?l0G@040000003o0?<0000000000080
MP3o0P000008000Oo`<00000>000]?l00`0000000?nd003o]00f003o]080
00002@00oal01@000000M_l007Ko001fo`0000000080oo<000<000000?mM
003oool00P3oool00`000000oooo0?ooo`1U0?ooo`040000003oool0oooo
000001@0oooo0`00000_0?ooo`040000003Wo`000000000000<0e_l00P00
00060?mN00030000003oool0oooo03X0oooo00200?ooo`030000003oool0
oooo0080o`1M00@000000?l0l`3o0?<00000101f0?l00`00000001oo000O
o`07000Oo`800000=`00]?l00`0000000?nd003o]00d003o]0<000002@00
oal00`000000M_l007Ko000207Ko00050000003ol`00oo<00000003oG@00
0`3oool00`000000oooo0?ooo`1U0?ooo`040000003oool0oooo00000180
oooo0P00000b0?ooo`80000000<0e_l00000003Fo`000`3Fo`000`000000
oeh00?mN00040?mN008000001P3oool2000000@0oooo0P0000040?ooo`80
00009`3oool00800oooo00H000000?ooo`3oool000000?l0G@0000020?l0
l`030000001f0?l0MP3o0080MP3o00<00000000Oo`007ol02@007ol00`00
00000;Co002do`0d002do`0300000000ok@00?nd03<00?nd00<00000003o
7`00oal02@00oal00`000000M_l007Ko000207Ko00040000003ol`00oo<0
00000080oed00`3oool00`000000oooo0?ooo`1U0?ooo`040000003oool0
oooo000000l0oooo0`00000d0?ooo`80000000<0e_l00000003Fo`000P3F
o`000`000000ol/0000000060?mN00030000003oool0oooo00<0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`00000V0?ooo`00
P03oool01P000000oooo0?ooo`000000o`1M000000<0o`3c00<0000007H0
o`1f0?l00P1f0?l00`00000001oo000Oo`09000Oo`800000=000]?l00`00
00000?nd003o]00b003o]08000002P00oal2000000@0M_l000@000000?oc
003ol`0000000P3oG@030?ooo`030000003oool0oooo06H0oooo0P00000>
0?ooo`800000=`3oool2000000050=Ko00000000e_l00=Ko000000000`3o
b`000`000000oeh00?mN00020?mN00030000003oCP00000000@0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`0T0?ooo`00P03o
ool01@000000oooo0?ooo`000000o`1M008000000P3o0?<00`000000MP3o
07H0o`0307H0o`03000000007ol001oo00T001oo0`00000b002do`030000
0000ok@00?nd03000?nd0P00000;003o7`800000101fo`0200000080oo<0
00<000000?mM003oG@000`3oool00`000000oooo0?ooo`1c0?ooo`<00000
>@3oool010000000e_l00=Ko000000020=Ko00050000003ob`00ol/00?o;
000000000`3oGP000`000000odh00?m>0002000000<0oooo00@000000?oo
o`3oool000002@3oool2000002L0oooo00200?ooo`040000003oool0oooo
00000080o`1M00D000000?l0l`3o0?<0o`3c0000000507H0o`0300000000
7ol001oo00X001oo0P00000a002do`0300000000ok@00?nd02l00?nd0P00
000<003o7`030000001fo`00M_l000<0M_l000D000000?oc003ol`00oo<0
000000020?mM0080oooo0P00001c0?ooo`800000>`3oool5000000030=Ko
00000000ol/000@0ol/000<000000?mN00000000103oCP001@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0V0?ooo`00P03oool010000000oooo0?ooo`0000020?l0G@05
0000003o0?<0o`3c0?l0l`0000001@1f0?l2000000d001oo00<00000002d
o`00]?l0;P00]?l00`0000000?nd003o]00]003o]08000003@00oal00`00
0000M_l007Ko000407Ko00050000003ol`00oo<00?oc000000000P3oG@03
0?ooo`030000003oool0oooo06h0oooo0`00000k0?ooo`<000000`1To`02
000000L0ol/000<000000?m>003oCP00103oCP0010000000oooo0?ooo`3o
ool2000000X0oooo0`00000V0?ooo`00P03oool010000000oooo0?ooo`00
00020?l0G@040000003o0?<0o`3c0?l0l`8000001@1f0?l2000000d001oo
0P00000^002do`0300000000ok@00?nd02`00?nd0P00000=003o7`800000
1@1fo`001@000000oo<00?oc003ol`00000000<0oed00`3oool00`000000
oooo0?ooo`1/0?ooo`800000?03oool3000000D0I?l00`0000050?o;0003
0000003oX@00000000D0odh00P00000g0?ooo`00P03oool010000000oooo
0?ooo`0000020?l0G@030000003o0?<0o`3c0080o`3c00<0000007H0o`1f
0?l0101f0?l00`00000001oo000Oo`0<000Oo`800000;@00]?l00`000000
0?nd003o]00[003o]08000003@00oal2000000H0M_l000D000000?oc003o
l`00oo<0000000030?mM00<0oooo00<000000?ooo`3oool0J@3oool30000
03/0oooo1P00000406Co00040000003Fo`0000000=Ko008000000P3ob`00
10000000oj400?nQ000000060?m>00030000003oool0oooo03D0oooo0020
0?ooo`040000003oool0oooo00000080o`1M0P0000030?l0l`030000001f
0?l0MP3o00D0MP3o00<00000000Oo`007ol030007ol2000002`00;Co00<0
0000003o]000ok@0:P00ok@00`0000000?lO003o7`0=003o7`030000001f
o`00M_l000@0M_l000<000000?oc003ol`000P3ol`0010000000oed00?mM
003oG@030?ooo`030000003oool0oooo06L0oooo0P0000030?ooo`030000
003oool0oooo03H0oooo0P000003003oUP030000000Go`005ol000800000
0P1To`000`000000e_l0000000030=Ko00030000003ob`00000000<0oj40
00<000000?m>003oCP000P3oCP000`000000odH00000000f0?ooo`00P03o
ool010000000oooo0?ooo`0000030?l0G@030000003o0?<0o`3c0080o`3c
00<0000007H0o`1f0?l0101f0?l2000000h001oo0P00000[002do`030000
0000ok@00?nd02T00?nd00<00000003o7`00oal03@00oal00`000000M_l0
07Ko000507Ko00030000003ol`00oo<00080oo<000@000000?mM003oG@00
oed00`3oool00`000000oooo0?ooo`1T0?ooo`<00000>`3oool4000000<0
0?nF00<0000001Oo000Go`000`0Go`0200000080e_l000<000000=Ko003F
o`000P3Fo`000`000000oj400?nQ00030?nQ00040000003oCP00odh00000
0080odH00P00000e0?ooo`00P03oool010000000oooo0?ooo`0000030?l0
G@030000003o0?<0o`3c0080o`3c00<0000007H0o`1f0?l01@1f0?l00`00
000001oo000Oo`0=000Oo`800000:P00]?l00`0000000?nd003o]00W003o
]08000003`00oal2000000H0M_l00P0000040?oc00040000003oG@00oed0
0?mM00<0oooo00<000000?ooo`3oool0HP3oool2000003/0oooo0`000004
003o[@<000001P0Go`001@000000ROl00000003Fo`00000000<0e_l000<0
00000?o]00000000103oX@000`000000odh0000000040?m600030000003o
ool0oooo03<0oooo00200?ooo`040000003oool0oooo000000<0o`1M00<0
00000?l0l`3o0?<00`3o0?<00`000000MP3o07H0o`0507H0o`0300000000
7ol001oo00h001oo00<00000002do`00]?l09`00]?l00`0000000?nd003o
]00V003o]08000004000oal00`000000M_l007Ko000507Ko00030000003o
l`00oo<00080oo<000<000000?mM003oG@000P3oG@030?ooo`030000003o
ool0oooo05l0oooo0`00000k0?ooo`8000000P00okd2000000<00?n]0P00
00000`00oad000000000000201Oo008000000`29o`0200000080e_l000D0
00000?o]003ok@00ond0000000040?nQ00030000003oAP00odH000<0odH0
0P00000d0?ooo`00P03oool010000000oooo0?ooo`0000030?l0G@030000
003o0?<0o`3c00<0o`3c00<0000007H0o`1f0?l01@1f0?l20000010001oo
00<00000002do`00]?l09P00]?l00`0000000?nd003o]00V003o]0030000
0000oal00?lO00h00?lO00<0000007Ko001fo`001P1fo`000`000000oo<0
0?oc00020?oc00030000003oG@00oed00080oed00P3oool2000005h0oooo
0`00000l0?ooo`8000001P00okd3000000D00?lM0P00000608Wo00030000
003Fo`00000000@0ond000L000000?nQ003oX@00oj400000003oRP000000
00D0odH00P00000c0?ooo`00P03oool010000000oooo0?ooo`0000030?l0
G@800000103o0?<2000000L0MP3o0P00000?000Oo`8000009`00]?l00`00
00000?nd003o]00T003o]08000004000oal2000000L0M_l000<000000?oc
003ol`000`3ol`000`000000oed00?mM00020?mM00<0oooo00<000000?oo
o`3oool0?03oool5000001T0oooo0P00000k0?ooo`@000000P00olP20000
00<00?nm0P0000000`00odD0000000000004003o7@030000001;o`000000
00D0ROl00P0000060?o]00030000003oX@0000000080ohX000<000000?m6
003oAP000`3oAP02000003<0oooo00200?ooo`040000003oool0oooo0000
00@0o`1M00<000000?l0l`3o0?<00`3o0?<00`000000MP3o07H0o`0607H0
o`03000000007ol001oo00l001oo00<00000002do`00]?l09000]?l00`00
00000?nd003o]00T003o]00300000000oal00?lO00l00?lO00<0000007Ko
001fo`001P1fo`000`000000oo<00?oc00030?oc00030000003oG@00oed0
0080oed00`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
01H0oooo0`00000j0?ooo`<000000P00om42000000@00?o80`000005003o
A@80000000<00?lM0000001;o`000P1;o`02000000<0ROl000<000000<ko
000000001P3ok@000`000000ohX00?n:00020?n:00030000003oAP00odH0
00<0odH00P00000b0?ooo`00P03oool010000000oooo0?ooo`0000040?l0
G@030000003o0?<0o`3c00<0o`3c00<0000007H0o`1f0?l01`1f0?l00`00
000001oo000Oo`0>000Oo`8000009@00]?l00`0000000?nd003o]00S003o
]00300000000oal00?lO00l00?lO00<0000007Ko001fo`001P1fo`000`00
0000oo<00?oc00040?oc00030000003oG@00oed00080oed00`3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo01@0oooo0P00000k0?oo
o`80000000<00?oH00000000om401000om4200000005003ob00000000000
003oH`0000001`00odD00`000000Bol004_o000404_o000400000029o`00
000000000080c_l00P0000030?o]00030000003obP00000000@0ohX000H0
00000?m6003oAP00odH00000003o@@0200000340oooo00200?ooo`040000
003oool0oooo000000@0o`1M00<000000?l0l`3o0?<00`3o0?<00`000000
MP3o07H0o`0707H0o`03000000007ol001oo00l001oo00<00000002do`00
]?l08`00]?l00`0000000?nd003o]00R003o]00300000000oal00?lO00l0
0?lO0P00000807Ko00030000003ol`00oo<000@0oo<000<000000?mM003o
G@000P3oG@030?ooo`030000003oool0oooo03H0oooo100000040?ooo`03
0000003oool0oooo0140oooo0`00000j0?ooo`<000001000omP2000000D0
0?oA00<00000003oH`00of<00P00of<2000000@00?m500<0000001Wo0000
00001P1;o`000`000000c_l0000000040<ko00030000003ok@0000000080
olX000<000000?n:003oRP000P3oRP0010000000odH00000000000020?m1
00800000<@3oool00800oooo00@000000?ooo`3oool00000103o05d00`00
0000o`3c0?l0l`040?l0l`030000001f0?l0MP3o00L0MP3o00<00000000O
o`007ol03`007ol00`0000000;Co002do`0R002do`0300000000ok@00?nd
02400?nd0P00000@003o7`8000002@1fo`000`000000oo<00?oc00030?oc
00030000003oG@00oed000<0oed00`3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo00l0oooo0P00000j0?ooo`<000000P00omh20000
00D00?oH00<00000003od@00om400P0000000`00ogX00000003oH`04003o
H`0400000000odD00000000000<06Ol000<0000004_o001;o`000P1;o`00
10000000T_l00000000000050<ko00030000003obP00olX00080olX000<0
00000?n:003oRP000P3oRP000`000000od400?m100030?m100800000<03o
ool00800oooo00@000000?ooo`3oool00000103o05d00`000000o`3c0?l0
l`040?l0l`030000001f0?l0MP3o00L0MP3o00<00000000Oo`007ol04000
7ol00`0000000;Co002do`0Q002do`0300000000ok@00?nd02400?nd00<0
0000003o7`00oal03`00oal00`000000M_l007Ko000707Ko00030000003o
l`00oo<000@0oo<000<000000?mM003oG@000`3oG@030?ooo`030000003o
ool0oooo03d0oooo0P00000>0?ooo`<00000>@3oool3000000800?oS00<0
0000003ogP00omh00P00omh00`0000000?oH003of003003of08000001000
ogX2000000@00?mS00<0000001Wo000Io`00100Io`0010000000Bol00000
0000000309;o00030000003>o`00c_l00080c_l000<000000?Wo00000000
103obP001P000000ohX00?n:00000000og/0000000D0od400P00000_0?oo
o`00P03oool010000000oooo0?ooo`0000050?l0G@030000003o0?<0o`3c
00@0o`3c00<0000007H0o`1f0?l01`1f0?l00`00000001oo000Oo`0?000O
o`8000008P00]?l00`0000000?nd003o]00P003o]00300000000oal00?lO
01000?lO00<0000007Ko001fo`001`1fo`000`000000oo<00?oc00040?oc
00030000003oG@00oed000<0oed00P3oool2000004d0oooo0P00000j0?oo
o`80000000<00?oW00000000on<00`00on<00`0000000?oN003ogP02003o
gP80000000D00?oH0000000000000?n>00000006003oNP0600000000of<0
000000000000o`h000001P0Io`000`000000T_l009;o000309;o00050000
003>o`00c_l00<ko000000000P3io`000`000000olX00?o:00020?o:0003
0000003oRP00000000<0og/000<000000?m1003o@@000P3o@@02000001P0
oooo0P00000E0?ooo`00P03oool010000000oooo0?ooo`0000050?l0G@03
0000003o0?<0o`3c00@0o`3c00<0000007H0o`1f0?l01`1f0?l200000140
01oo0P00000Q002do`0300000000ok@00?nd01l00?nd00<00000003o7`00
oal04000oal00`000000M_l007Ko000707Ko008000001P3ol`000`000000
oed00?mM00030?mM00<0oooo00<000000?ooo`3oool0B03oool3000003X0
oooo0P000004003oi`0300000000on<00?oS00800?oS00<00000003ogP00
omh00`00omh00`0000000?n>003oSP02003oSP8000001@00ogX00`000000
0?l>003o3P02003o3P8000000`0Io`000`000000Gol00000000409;o0080
000000<0c_l00000003io`000`3io`000`000000olX00?o:00020?o:0003
0000003oN`00og/000<0og/000<000000?m1003o@@000P3o@@02000001L0
oooo0P00000E0?ooo`00P03oool010000000oooo0?ooo`0000050?l0G@03
0000003o0?<0o`3c00@0o`3c0P00000907H0o`03000000007ol001oo0100
01oo00<00000002do`00]?l07`00]?l00`0000000?nd003o]00N003o]080
00004@00oal00`000000M_l007Ko000807Ko00030000003ol`00oo<000D0
oo<000<000000?mM003oG@000`3oG@030?ooo`030000003oool0oooo04H0
oooo0P00000i0?ooo`@000000P00on/00`0000000?oW003oi`02003oi`03
00000000on<00?oS00800?oS00<00000003ogP00omh00P0000000`00oih0
0000003oSP04003oSP0300000000ogX00?mj0080000000<00?l`00000000
o`h01000o`h00`0000006Ol00000000305oo008000000`2Bo`02000000H0
nOl000H000000?o:003obP0000000?nd000000050?mk00050000003o@@00
00000000003o?P000P00000E0?ooo`040000003oool0oooo000001@0oooo
00200?ooo`040000003oool0oooo000000D0o`1M00<000000?l0l`3o0?<0
1@3o0?<00`000000MP3o07H0o`0807H0o`03000000007ol001oo010001oo
00<00000002do`00]?l07P00]?l00`0000000?nd003o]00N003o]0030000
0000oal00?lO01000?lO00<0000007Ko001fo`00201fo`000`000000oo<0
0?oc00050?oc00030000003oG@00oed000<0oed00`3oool00`000000oooo
0?ooo`130?ooo`<00000>03oool3000000800?o^00<00000003oj`00on/0
0P00on/00`0000000?oW003oi`02003oi`0400000000on<00?oS003oh`<0
00001000oih2000000@00?n>0P000004003o<00300000000o`h00?l>00<0
0?l>00<0000005oo001Oo`00101Oo`001P000000T_l0000000000000`_l0
000000D0nOl000<000000?o:000000000`3o]0000`000000og/00?mk0003
0?mk00040000003o?P00och00?ln00800000503oool200000080oooo0P00
000C0?ooo`00P03oool010000000oooo0?ooo`0000050?l0G@030000003o
0?<0o`3c00D0o`3c00<0000007H0o`1f0?l0201f0?l00`00000001oo000O
o`0@000Oo`8000007`00]?l00`0000000?nd003o]00M003o]00300000000
oal00?lO01000?lO00<0000007Ko001fo`002@1fo`000`000000oo<00?oc
00040?oc00030000003oG@00oed000@0oed00`3oool00`000000oooo0?oo
o`110?ooo`80000000<0oooo0000003oool0=P3oool200000003003ol@00
00000?o^00<00?o^00<00000003oj`00on/00P00on/00`0000000?oW003o
i`02003oi`<000000P00oj`00`0000000?nN003oWP04003oWP0600000000
ohh0000000000000od`000001@00oc000`0000000?l>003o3P0200000003
03;o00000000Gol000D0Gol000<000000<;o000000000P32o`000`000000
nOl00?Wo00030?Wo00030000003o]000ok@00080ok@000<000000?mk003o
N`000P3oN`02000000@0och00P0000050?ooo`D000008P3oool00800oooo
00@000000?ooo`3oool000001@3o05d00`000000o`3c0?l0l`050?l0l`80
00002P1f0?l00`00000001oo000Oo`0@000Oo`0300000000]?l00;Co01d0
0;Co00<00000003o]000ok@07000ok@2000001800?lO00<0000007Ko001f
o`00201fo`000`000000oo<00?oc00050?oc00030000003oG@00oed000@0
oed00`3oool00`000000oooo0?ooo`0n0?ooo`<00000>@3oool2000000@0
0?oa00<00000003okP00onh00P00onh00`0000000?o[003oj`02003oj`06
00000000onL0000000000000okP000001000oj`2000000D00?nN00<00000
003oC000od`00P00od`00`0000000?l`003o<003003o<0800000100bo`00
0`000000Gol005oo000205oo00040000002@o`00000000000080`_l000<0
00000?Wo003io`000P3io`000`000000onX0000000040?nd00040000003o
N`00000000000080og8000<000000?ln003o?P000P3o?P000`000000oooo
0?ooo`050?ooo`030000003oool0oooo0280oooo001^0?ooo`800000103o
ool2000000@0oooo0P0000040?ooo`040000003oool0oooo000000H0o`1M
00<000000?l0l`3o0?<01@3o0?<00`000000MP3o07H0o`0807H0o`030000
00007ol001oo010001oo0P00000N002do`0300000000ok@00?nd01`00?nd
00<00000003o7`00oal04000oal00`000000M_l007Ko000907Ko00030000
003ol`00oo<000D0oo<000<000000?mM003oG@00103oG@030?ooo`030000
003oool0oooo03/0oooo0`00000h0?ooo`@000000P00oo@00`0000000?oa
003ol@02003ol@0300000000onh00?o^00800?o^00@00000003oj`00on/0
0?o[0P000004003o^00300000000oj`00?n/00<00?n/00<00000003oWP00
oih00P0000000`00of@00000003oC003003oC00700000000oc000?l`003o
<00000003?l00000000503;o00040000001Oo`000000000000<0T?l000H0
00000<;o0032o`00`_l00000003io`02000000<0onX000<000000?nd003o
]0000P3o]0000`000000og800?mb00020?mb00030000003o?P00och00080
och00P0000060?ooo`030000003oool0oooo0280oooo001]0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool01000
0000oooo0?ooo`0000060?l0G@030000003o0?<0o`3c00D0o`3c00<00000
07H0o`1f0?l02@1f0?l00`00000001oo000Oo`0@000Oo`0300000000]?l0
0;Co01`00;Co00<00000003o]000ok@06`00ok@2000001800?lO00<00000
07Ko001fo`00201fo`000`000000oo<00?oc00060?oc00030000003oG@00
oed000@0oed00`3oool00`000000oooo0?ooo`0i0?ooo`800000>@3oool2
000000800?og00<00000003om000oo@00P00oo@00`0000000?oa003ol@02
003ol@0300000000onh00?o^00800?o^0`000002003o`P0300000000okP0
0?nh00800?nh0P000004003o[08000001000of@00`0000000?m<003oC002
003oC00300000000oc00000000<03?l000<0000003;o000bo`000`0bo`00
0`000000T?l0093o0003093o000300000032o`00`_l00080`_l000<00000
0?oZ003ojP000`3ojP001`000000ok@00?nd003o]00000000?nU00000000
103oLP000`000000och00?ln00020?ln008000001@3oool00`000000oooo
0?ooo`0R0?ooo`00K@3oool010000000oooo0?ooo`00000;0?ooo`040000
003oool0oooo0?ooo`80000000<0oooo0000003o05d01@3o05d00`000000
o`3c0?l0l`050?l0l`8000002P1f0?l20000014001oo0P00000M002do`03
00000000ok@00?nd01/00?nd00<00000003o7`00oal04000oal00`000000
M_l007Ko000907Ko00030000003ol`00oo<000H0oo<000<000000?mM003o
G@00103oG@020?ooo`800000>03oool3000003T0oooo0P0000000`00ooT0
0000003om`02003om`0300000000oo@00?od00800?od00<00000003ol@00
oo400P00oo401P0000000?o^0000000000000?o<000000@00?o200<00000
003o^000okP00`00okP01P0000000?n/0000000000000?mi000000@00?mT
00<00000003oC000od`00`00od`00`0000003?l000co000300co00070000
000bo`00<_l003;o00000000Hol000000004093o0080000000D0`_l00000
00000000h_l0000000050?oZ00030000003o]00000000080ojD000<00000
0?mb003oLP000P3oLP000`000000och00?ln0002000000030?ll00000000
oooo00@0oooo00<000000?ooo`3oool08P3oool006d0oooo00@000000?oo
o`3oool000002@3oool2000000@0oooo00@000000?ooo`3oool000001P3o
05d00`000000o`3c0?l0l`060?l0l`030000001f0?l0MP3o00T0MP3o00<0
0000000Oo`007ol040007ol00`0000000;Co002do`0K002do`0300000000
ok@00?nd01X00?nd0P00000B003o7`030000001fo`00M_l000T0M_l000<0
00000?oc003ol`001@3ol`000`000000oed00?mM00050?mM00<0oooo00<0
00000?ooo`3oool0=03oool2000003T0oooo0`000004003on@0500000000
ooL00?og003om`0000001000oo@0100000000?oa003ol@00oo42000000@0
0?o<00<00000003o`P00ol800P00ol800`0000000?nh003o^003003o^003
00000000ogT00?mi00800?mi00<00000003oI000of@00P00of@00`000000
0?m<003oC00200000003003o5@0000003?l000@03?l000<0000003;o0000
00000`1So`001`000000T?l0093o002@o`000000093o00000000103Ro`00
0`000000onX00?oZ00030?oZ00030000003oY@00ojD00080ojD000<00000
0?mb003oLP000P3oLP02000000<0oc`00P0000030?ooo`800000903oool0
06d0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`03
0?ooo`040000003oool0oooo000000H0o`1M00<000000?l0l`3o0?<01P3o
0?<00`000000MP3o07H0o`0907H0o`8000004P007ol00`0000000;Co002d
o`0J002do`0300000000ok@00?nd01X00?nd00<00000003o7`00oal04000
oal2000000X0M_l000<000000?oc003ol`001P3ol`000`000000oed00?mM
00050?mM00<0oooo00<000000?ooo`3oool0<@3oool3000003P0oooo0`00
0002003oo00300000000ooT00?oi00800?oi00<00000003om`00ooL00P00
ooL00`0000000?od003om002003om0<000000P00omD00`0000000?o<003o
c002003oc08000000`00ol800`0000000?nh003o^00200000003003oS000
00000?mi00<00?mi00<00000003oI000of@00P00of@2000000@00?lE00<0
000000co000<o`000`0<o`000`000000Hol006?o000306?o00030000002@
o`0000000080000000<0/_l00000003Ro`000`3Ro`001`000000onX00?oZ
003ojP0000000?oG00000000103oY@001P000000og800?mb00000000of`0
000000@0oc`00P00000X0?ooo`00KP3oool2000000X0oooo0`0000030?oo
o`040000003oool0oooo000000H0o`1M00<000000?l0l`3o0?<01P3o0?<2
000000/0MP3o00<00000000Oo`007ol040007ol00`0000000;Co002do`0J
002do`0300000000ok@00?nd01T00?nd0P00000B003o7`030000001fo`00
M_l000T0M_l000<000000?oc003ol`001P3ol`000`000000oed00?mM0005
0?mM00<0oooo00<000000?ooo`3oool0;`3oool2000003P0oooo0`000002
003ooP0500000000oo`00?ol003oo00000001000ooT00`0000000?og003o
m`02003om`0600000000oo@0000000000000omh000001000omD00`000000
0?o<003oc003003oc00300000000ol800?o200<000001000oh`00`000000
0?mi003oN@02003oN@0600000000of@0000000000000oc<000001@00oaD0
0`0000003?l000co00020000000303[o00000000Hol00080Hol00`000000
0`2@o`000000000000020;;o00030000003Ro`00h_l00080h_l000<00000
0?oZ000000000`3oe`001`000000ojD00?nU003oY@0000000?mb00000000
0P3oK0000`000000oc`00?ll00020?ll00800000:03oool00800oooo00@0
00000?ooo`3oool000001`3o05d00`000000o`3c0?l0l`060?l0l`030000
001f0?l0MP3o00T0MP3o00<00000000Oo`007ol040007ol2000001/00;Co
00<00000003o]000ok@06@00ok@00`0000000?lO003o7`0@003o7`800000
2`1fo`000`000000oo<00?oc00060?oc00030000003oG@00oed000D0oed0
0`3oool00`000000oooo0?ooo`0]0?ooo`800000=`3oool3000000800?ko
00D00000003ooP00ooh00?on00000003003oo08000000`00ooT010000000
0?og003om`00ooL2000000@00?oN00<00000003oe@00omD00P00omD00`00
00000?o<003oc003003oc08000000P00oid00`0000000?n<003oS002003o
S00300000000ogT00?mi00<00?mi00<00000003o<`00oc<00P00oc<20000
00@00?lE0P00000403[o00<000000`1So`000`000000/_l0000000020;;o
00030000003Ro`00h_l000<0h_l000<000000?oG003oe`000P3oe`000`00
0000ojD00?nU00020?nU00030000003oK000of`00080of`000<000000?ll
003o?0000P3o?002000002L0oooo00200?ooo`040000003oool0oooo0000
00L0o`1M00<000000?l0l`3o0?<01P3o0?<00`000000MP3o07H0o`0:07H0
o`03000000007ol001oo010001oo00<00000002do`00]?l06@00]?l00`00
00000?nd003o]00I003o]00300000000oal00?lO01000?lO00<0000007Ko
001fo`002P1fo`000`000000oo<00?oc00060?oc00030000003oG@00oed0
00D0oed00`3oool00`000000oooo0?ooo`0]0?ooo`800000=@3oool20000
0003003lo`0000000?ko00<00?ko00D00000003ooP00ooh00?on00000004
003oo00300000000ooT00?oi00@000000P00onH00`0000000?oN003ogP02
003ogP0300000000omD00?oE00800?oE00<00000003oc000ol`00P000000
0`00ojd00000003oW@02003oW@0300000000oh`00?n<00800?n<00<00000
003oN@00ogT00P0000000`00odh00000003o<`04003o<`0700000000oaD0
00000000000Eo`00000003[o00030000000403[o00000000Hol006?o0080
000000@0Q_l00000002bo`0000000P2bo`000`000000h_l00>;o00020000
00030?Wo00000000omL000<0omL000H000000?nU0000000000000?nK0000
00040?m/00050000003o?000oc`00000003o>`000P00000V0?ooo`00P03o
ool010000000oooo0?ooo`0000070?l0G@030000003o0?<0o`3c00H0o`3c
00<0000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`0@000Oo`030000
0000]?l00;Co01T00;Co00<00000003o]000ok@06000ok@00`0000000?lO
003o7`0A003o7`030000001fo`00M_l000T0M_l000<000000?oc003ol`00
1`3ol`000`000000oed00?mM00050?mM00<0oooo00<000000?ooo`3oool0
9P3oool2000000D0oooo00<000000?ooo`000000<P3oool2000000@00?co
00D00000003no`00o_l00?ko00000004003ooP0300000000oo`00?ol0080
0?ol0P000002003ok@0300000000onH00?oV00800?oV00<00000003ogP00
omh00P00omh00`0000000?oE003oe@02003oe@8000001000ojd01@000000
0?nM003oW@00oid0000000@00?n<0P000004003oCP8000001000oc<00`00
00005Ol001Go0003000000D0>_l00P00000408Ko00030000002bo`000000
0080/_l00P0000040?Wo00030000003oe`00omL00080omL000<000000?nK
003oV`000P3oV`001`000000of`00?m/003oK00000000?ll000000000P3o
>`02000002H0oooo00200?ooo`040000003oool0oooo000000L0o`1M00<0
00000?l0l`3o0?<01`3o0?<00`000000MP3o07H0o`0907H0o`8000004P00
7ol00`0000000;Co002do`0H002do`0300000000ok@00?nd01P00?nd00<0
0000003o7`00oal04000oal00`000000M_l007Ko000:07Ko00030000003o
l`00oo<000L0oo<000<000000?mM003oG@001@3oG@030?ooo`030000003o
ool0oooo02D0oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`00000]0?ooo`@000000P00nOl00`0000000?co003lo`02003lo`05
00000000o_l00?ko003no`0000001000ooh01P0000000?ol000000000000
0?od000000<00?o]00<00000003oiP00onH00P00onH00`0000000?oN003o
gP02003ogP0600000000omD0000000000000ok/000001@00ojd01P000000
0?nM003oW@00oid00000003oS080000000<00?mV00000000odh01@00odh0
1@0000000?lc0000000000000?l;008000000`0Eo`001`000000>_l003[o
000jo`00000005go000000001026o`000`000000/_l00;;o000200000003
0<_o00000000nOl000<0nOl000L000000?oG003oe`00omL00000003ob@00
000000<0oi/000<000000?m/003oK0000P3oK0000`000000oc/00?lk0002
0?lk008000009@3oool00800oooo00@000000?ooo`3oool000001`3o05d0
0`000000o`3c0?l0l`070?l0l`030000001f0?l0MP3o00X0MP3o00<00000
000Oo`007ol040007ol00`0000000;Co002do`0H002do`0300000000ok@0
0?nd01L00?nd0P00000B003o7`030000001fo`00M_l000X0M_l000<00000
0?oc003ol`001P3ol`02000000L0oed00P3oool2000002L0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02L0oooo0`000002003go`0300000000nOl00?Wo00800?Wo00D0
0000003lo`00o?l00?co00000004003no`0400000000ooh00?on003ooP80
00001000oo@01@0000000?o]003ok@00ond0000000@00?oV00@00000003o
gP00omh00?oN0P000004003o^`0300000000ojd00?n]00<00?n]00<00000
003oW@00oid00P000004003oIP8000001@00odh400000003003o2`000000
5Ol000<05Ol000<0000003[o000000000`1Mo`000`000000Q_l008Ko0002
08Ko00030000002bo`00000000<0bol000<000000?Wo003io`000P3io`00
0`000000omL0000000020?o900030000003oV`00oi/00080oi/000H00000
0?m/0000000000000?mW000000040?lk00800000903oool00800oooo00@0
00000?ooo`3oool000001`3o05d00`000000o`3c0?l0l`070?l0l`030000
001f0?l0MP3o00X0MP3o00<00000000Oo`007ol040007ol00`0000000;Co
002do`0H002do`0300000000ok@00?nd01L00?nd00<00000003o7`00oal0
4000oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<000L0oo<0
00<000000?mM003oG@001P3oG@030?ooo`030000003oool0oooo02D0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02<0oooo0`000002003do`0500000000mol00?Oo003g
o`0000000`00nOl00`0000000?co003lo`02003lo`0300000000o_l00?ko
00800?ko0`000002003oo00500000000oo@00?od003om00000001000ond0
0`0000000?oV003oiP02003oiP<000000P00olP00`0000000?nk003o^`02
003o^`0300000000ojd00?n]00<00?n]0P000002003oO00300000000ofH0
0?mV00<00?mV00<00000003oCP00odh010000004003o2`030000000Eo`00
5Ol000805Ol000<0000005go001Mo`000`1Mo`000`000000Q_l008Ko0002
08Ko00030000003;o`0000000080bol000<000000?Wo003io`000`3io`00
0`000000olT00?o900020?o900030000003oV`00oi/00080oi/000<00000
0?mW003oI`000P3oI`0010000000oc/00?lk003o>`02000002@0oooo0020
0?ooo`040000003oool0oooo000000L0o`1M00<000000?l0l`3o0?<01`3o
0?<2000000`0MP3o00<00000000Oo`007ol040007ol00`0000000;Co002d
o`0G002do`0300000000ok@00?nd01L00?nd00<00000003o7`00oal04000
oal00`000000M_l007Ko000:07Ko00030000003ol`00oo<000L0oo<000<0
00000?mM003oG@001P3oG@030?ooo`030000003oool0oooo02D0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0200oooo0P000002003ao`0500000000m?l00?Co003do`00
00000`00mol01@0000000?Wo003io`00nOl0000000@00?co00H00000003n
o`0000000000003lo`000004003oo00500000000oo@00?od003om0000000
1000ond01P0000000?oV0000000000000?oF000000@00?o800<00000003o
^`00ok/00P00ok/00`0000000?n]003o[@0200000003003oT00000000?ml
00800?ml0P000003003oIP<000001000obT00`0000000?l;003o2`02003o
2`060000000Eo`0000000000000go`0000001@1Mo`0020000000Q_l00000
00000000X?l00000003;o`0000000P3;o`000`000000nOl00?Wo00020000
00030?og00000000olT000<0olT000H000000?nK003oV`0000000?nD0000
00030?mW00030000003o>`00oc/00080oc/00P00000S0?ooo`00P03oool0
10000000oooo0?ooo`0000080?l0G@030000003o0?<0o`3c00L0o`3c00<0
000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`0@000Oo`0300000000
]?l00;Co01L00;Co00<00000003o]000ok@05P00ok@00`0000000?lO003o
7`0@003o7`030000001fo`00M_l000/0M_l000<000000?oc003ol`001`3o
l`000`000000oed00?mM00060?mM00<0oooo00<000000?ooo`3oool09P3o
ool2000000@0oooo00<000000?ooo`3oool01@3oool2000001h0oooo0P00
00000`00k_l00000003ao`02003ao`0500000000m?l00?Co003do`000000
0`00mol01@0000000?Wo003io`00nOl0000000<00?co0P000004003lo`05
00000000oo`00?ol003oo00000001000oo@0100000000?o]003ok@00ond2
000000@00?oF00<00000003ob000olP00P00olP00`0000000?nk003o^`02
003o^`8000001000oi000`0000000?ml003oO002003oO0@0000000<00?m5
00000000obT00`00obT00`0000000?l;003o2`03003o2`030000000go`00
=ol00080=ol000<0000005go001Mo`000`1Mo`000`000000X?l00:3o0002
0:3o00030000003;o`0000000080bol00P0000030?og00030000003ob@00
olT00080olT000<000000?nK000000000P3oU0000`000000ofL00?mW0002
0?mW00050000003o>`0000000000003o>P000P00000R0?ooo`00P03oool0
10000000oooo0?ooo`0000080?l0G@030000003o0?<0o`3c00L0o`3c00<0
000007H0o`1f0?l02P1f0?l00`00000001oo000Oo`0@000Oo`8000006000
]?l00`0000000?nd003o]00F003o]00300000000oal00?lO01000?lO00<0
000007Ko001fo`002`1fo`000`000000oo<00?oc00070?oc00030000003o
G@00oed000H0oed00`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0603oool3000000<00>ko00<0
0000003ao`00lOl00P00lOl0100000000?Co003do`000004003go`030000
0000nOl00?Wo00@000000P00m?l00`0000000?co003lo`02003lo`050000
0000oo`00?ol003oo00000001000oo@3000000800?oR00<00000003oeP00
omH00P00omH00`0000000?o8003ob002003ob00600000000ok/000000000
0000oj<000001000oi000`0000000?ml0000000200000003003oO0000000
0?m500<00?m500<00000003o:@00obT00P00obT00`0000000?l;003o2`02
0000000301Co00000000=ol00080=ol000<0000005go001Mo`000P1Mo`00
0`000000N?l0000000030:3o00070000003;o`0000000<_o00000000gOl0
000000040?og00030000003ob@00olT00080olT000<000000?nD003oU000
0P3oU0000`000000ofL00?mW00020?mW00030000003o>P00ocX00080ocX0
00<000000?ooo`3oool0803oool00800oooo00@000000?ooo`3oool00000
203o05d00`000000o`3c0?l0l`070?l0l`030000001f0?l0MP3o00/0MP3o
00<00000000Oo`007ol040007ol00`0000000;Co002do`0F002do`030000
0000ok@00?nd01H00?nd00<00000003o7`00oal04000oal00`000000M_l0
07Ko000:07Ko00030000003ol`00oo<000P0oo<000<000000?mM003oG@00
1P3oG@030?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0D0?ooo`<000000P00jol00`0000000>ko
003^o`02003^o`0500000000lOl00?7o003ao`0000000`00m?l00`000000
0?Oo003go`02003go`8000000P00kOl00`0000000?Co003do`02003do`03
00000000o?l00?co00800?co00H00000003oo000oo`00?ol00000000oo@2
00000003003okP0000000?oR00<00?oR00<00000003oeP00omH00P00omH0
100000000?o8003ob000olP2000000@00?nS00<00000003oT000oi000`00
0002003oO080000000<00?mO00000000odD00`00odD00`0000000?lY003o
:@02003o:@800000100Do`001P000000=ol003Oo000go`00000005go0080
00000`1ho`001`000000X?l00:3o002Po`0000000<_o000000000`3Mo`00
1@000000ooL00?og003om`0000000080olT00P0000000`3o`00000000?nD
00030?nD00030000003oI`00ofL000800000103o>P0200000240oooo0020
0?ooo`040000003oool0oooo000000P0o`1M00<000000?l0l`3o0?<01`3o
0?<2000000`0MP3o00<00000000Oo`007ol040007ol00`0000000;Co002d
o`0F002do`0300000000ok@00?nd01D00?nd0P00000A003o7`800000301f
o`000`000000oo<00?oc00080?oc00030000003oG@00oed000H0oed00`3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0403oool3000000800>Oo00D00000003[o`00jol00>_o
00000004003^o`0500000000lOl00?7o003ao`0000000`00m?l01P000000
0?Oo0000000000000>Ko000000<00>go00D00000003do`00m?l00?Co0000
0005003lo`0300000000oo`00?ol008000001000onh00`0000000?oR003o
hP02003ohP0300000000omH00?oF00800?oF0`000002003o]P0400000000
oj<00?nS003oX`<000000`00oi02000000@00?mO00<00000003oA@00odD0
0P00odD01P0000000?lY0000000000000?l<000000@05?l000<0000003Oo
000go`000P0go`000`000000N?l007So000307So00030000002Po`00X?l0
0080X?l000<000000=go000000000P3Mo`000`000000ooL00?og00020?og
008000000`3o`0000`000000oi@00?nD00020?nD00030000003oI`000000
0080of@000<000000?lj003o>P000P3o>P0200000200oooo00200?ooo`04
0000003oool0oooo000000P0o`1M00<000000?l0l`3o0?<0203o0?<00`00
0000MP3o07H0o`0;07H0o`03000000007ol001oo00l001oo00<00000002d
o`00]?l05P00]?l00`0000000?nd003o]00E003o]00300000000oal00?lO
01000?lO00<0000007Ko001fo`002`1fo`000`000000oo<00?oc00080?oc
00030000003oG@00oed000H0oed00`3oool00`000000oooo0?ooo`0[0?oo
o`800000303oool00`000000oooo0?ooo`0<0?ooo`<000000P00hol01@00
00000>Oo003Wo`00iol0000000<00>_o00<00000003^o`00k_l00P00k_l0
1@0000000?7o003ao`00lOl0000000800?Co0P000004003Vo`0500000000
kOl00>go003]o`0000000`00m?l00`0000000?co003lo`03003lo`800000
0P00ooX00`0000000?o^003okP02003okP0300000000on800?oR00800?oR
00H00000003oeP0000000000003oa`000004003o]P<000000P00oj<01P00
00000?n@0000000000000?mh000000@00?mO00<00000003oA@00odD00`00
odD00`0000000?l<003o3002003o30030000000Do`005?l000805?l000H0
000003Oo000000000000057o0000000507So00050000002Po`0000000000
002co`000P0000030=go00060000003om`0000000000003oj`000000103o
`0000`000000oi@00?nD00020?nD00050000003oI000of@00?mT00000000
1@3o>P000`000000oooo0?ooo`0N0?ooo`00P03oool010000000oooo0?oo
o`0000080?l0G@030000003o0?<0o`3c00P0o`3c00<0000007H0o`1f0?l0
2`1f0?l00`00000001oo000Oo`0@000Oo`0300000000]?l00;Co01D00;Co
00<00000003o]000ok@05@00ok@00`0000000?lO003o7`0@003o7`030000
001fo`00M_l000/0M_l000<000000?oc003ol`001`3ol`000`000000oed0
0?mM00070?mM0080oooo0P00000]0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0203oool3000000800=ko00@00000003So`00hol0
00001000iol0100000000>_o003[o`000004003^o`0400000000lOl00?7o
003ao`<000000P00g_l00`0000000>Ko003Vo`02003Vo`0500000000kOl0
0>go003]o`0000000`00m?l00`0000000?co003lo`0200000003003jo`00
00000?oj00800?oj00<00000003okP00onh00P00onh00`0000000?oR003o
hP02003ohP0300000000olL00?o700800?o7100000000`00okH00000003o
X`03003oX`0300000000ogP00?mh00800?mh00<00000003oG`00oel00P00
oel00`0000000?m5003oA@0200000003003o:`0000000?l<00<00?l<00<0
000001Co000Do`000P0Do`000`000000DOl0057o0002057o00030000001h
o`00N?l000<0N?l000<000000;?o002co`000P2co`02000000<0gOl000<0
00000?o[003oj`000P3oj`001@000000ol000?o0003o`00000000080oi@0
0P0000000`3oS`0000000?mT00020?mT00040000003o>P00ocX00?lj00<0
00001@3oool500000080oooo0P0000040?ooo`8000002`3oool00800oooo
00@000000?ooo`3oool00000203o05d00`000000o`3c0?l0l`080?l0l`03
0000001f0?l0MP3o00/0MP3o00<00000000Oo`007ol040007ol00`000000
0;Co002do`0E002do`0300000000ok@00?nd01D00?nd00<00000003o7`00
oal03`00oal2000000`0M_l000<000000?oc003ol`00203ol`000`000000
oed00?mM00070?mM00<0oooo00<000000?ooo`3oool07P3oool4000000<0
oooo0P0000040?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01@3oool200000003003Ho`0000000=ko00800=ko00D00000003So`00
hol00>?o00000003003Wo`0500000000jol00>_o003[o`0000001000k_l3
000000800=Go00D00000003No`00g_l00=ko00000003003Vo`0300000000
kOl00>go00800>go00<00000003do`00m?l00`000004003jo`0500000000
ooX00?oj003onP0000001000onh01P0000000?oR0000000000000?oG0000
00800?o70P000005003o]P0600000000oj<0000000000000ohl000001000
ogP00`0000000?mO003oG`02003oG`8000001000ob/00`0000000?l<003o
3002003o30060000000Do`0000000000000]o`000000101Ao`000`000000
N?l007So00020000000308_o00000000/ol00080/ol000L000000=go0000
0000gOl00000003Zo`00000000<0on/000<000000?o0003o`0000P3o`002
000000<0ohl000H000000?mT003oI000of@00000003o>P0200000080ocT0
0P0000060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
00002P3oool00800oooo00@000000?ooo`3oool00000203o05d00`000000
o`3c0?l0l`090?l0l`030000001f0?l0MP3o00/0MP3o00<00000000Oo`00
7ol03`007ol00`0000000;Co002do`0E002do`0300000000ok@00?nd01@0
0?nd00<00000003o7`00oal04000oal00`000000M_l007Ko000;07Ko0003
0000003ol`00oo<000P0oo<000<000000?mM003oG@001`3oG@030?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00P3oool2000000<00=So00<00000003No`00g_l00P00g_l01000
00000>?o003So`000004003Wo`0600000000jol00>_o003[o`0000000>ko
0P0000000`00c?l00000003Eo`02003Eo`0500000000g_l00=ko003No`00
00001000i_l00`0000000>go003]o`02003]o`8000000P00k_l00`000000
0?[o003jo`02003jo`0300000000ooX00?oj00800?oj00@00000003okP00
onh00?o^0P000003003oe`<000000P00olL00`0000000?nf003o]P03003o
]P0300000000ohl00?n?00800?n?00<00000003oN000ogP00P00ogP01P00
00000?mO0000000000000?m7000000@00?l[00<00000003o3000o``00`00
o``00`000000;Ol002go000202go00030000001Ao`00DOl00080DOl00P00
000408_o00070000002co`00/ol00;?o00000000gOl0000000020>[o0003
0000003oj`00on/00080on/000H000000?o00000000000000?ni00000004
0?n?00050000003oI000of@00?mT00000000103o>@02000000H0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`00P03oool0
10000000oooo0?ooo`0000090?l0G@030000003o0?<0o`3c00P0o`3c00<0
000007H0o`1f0?l02`1f0?l00`00000001oo000Oo`0?000Oo`0300000000
]?l00;Co01D00;Co00<00000003o]000ok@05000ok@00`0000000?lO003o
7`0@003o7`030000001fo`00M_l000/0M_l000<000000?oc003ol`00203o
l`000`000000oed00?mM00070?mM00<0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000
4@3oool4000000800=7o00D00000003Ho`00f?l00=So00000003003No`05
00000000hol00>?o003So`0000001000iol00`0000000>_o003[o`020000
00@00<co00D00000003Eo`00eOl00=Go00000003003No`0300000000i_l0
0>Ko00800>Ko00H00000003]o`0000000000003Ro`000003003^o`030000
0000n_l00?[o00800?[o00<00000003onP00ooX00P00ooX3000000800?oW
0`000002003oe`0500000000olL00?o7003oa`0000000P00okH200000003
003oY@0000000?n?00<00?n?00<00000003oN000ogP00P00ogP00`000000
0?m7003oA`02003oA`0300000000ob/00?l[00800?l[00<00000003o3000
o``00P0000000`0;o`00000002go000202go00070000001Ao`00DOl0057o
00000000IOl00000000408_o00030000002co`00/ol00080/ol00P000003
0>[o00030000003oj`00on/00080on/000<000000?ni003o^@000P3o^@00
1P000000ohl00?n?003oS`0000000?mT0080000000<0of800000003o>@00
0`3o>@02000000D0oooo00<000000?ooo`3oool0203oool2000000/0oooo
00200?ooo`040000003oool0oooo000000T0o`1M00<000000?l0l`3o0?<0
203o0?<00`000000MP3o07H0o`0;07H0o`03000000007ol001oo010001oo
00<00000002do`00]?l05000]?l00`0000000?nd003o]00D003o]0030000
0000oal00?lO01000?lO00<0000007Ko001fo`002`1fo`000`000000oo<0
0?oc00080?oc00030000003oG@00oed000L0oed00`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000
003oool0oooo00d0oooo0`0000020038o`0400000000dOl00=7o000000@0
0=So00D00000003No`00g_l00=ko00000003003So`0300000000iol00>Oo
00800>Oo0P0000020032o`0300000000c?l00<co00800<co00D00000003E
o`00eOl00=Go00000003003No`0400000000i_l00>Ko003Vo`8000001000
h_l0100000000>ko003^o`00k_l2000000<00?[o00D00000003onP000000
0000003on00400000003003oi`0000000?oG00<00?oG00<00000003oa`00
olL00`000004003oY@0300000000ohl00?n?00800?n?00H00000003oN000
00000000003oH`000004003oA`0300000000ob/00?l[00800?l[0P000004
00_o00070000000]o`00;Ol002go00000000DOl00000000306Go00030000
002;o`00Rol00080Rol000D000000;?o0000000000000<;o0002000000<0
j_l000H000000?o[003oj`0000000?oR000000030?ni00030000003oS`00
ohl00080ohl000<000000?mR003oHP000P3oHP001`000000ocT00?li003o
>@0000000?ooo`000000103oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00X0oooo00200?ooo`040000003oool0oooo000000T0o`1M
00<000000?l0l`3o0?<0203o0?<00`000000MP3o07H0o`0;07H0o`030000
00007ol001oo010001oo00<00000002do`00]?l05000]?l00`0000000?nd
003o]00D003o]00300000000oal00?lO00l00?lO00<0000007Ko001fo`00
2`1fo`000`000000oo<00?oc00090?oc00030000003oG@00oed000L0oed0
0`3oool00`000000oooo0?ooo`0N0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`<0
00000P00_Ol0100000000<So0038o`000003003Ao`0300000000f?l00=So
00800=So00D00000003No`00g_l00=ko00000002003So`0300000000iol0
0>Oo0080000000<00;So00000000`_l00P00`_l01@0000000<co003<o`00
c?l0000000@00=Go00@00000003No`00g_l00=ko0`000002003Fo`050000
0000h_l00>;o003Ro`0000001@00k_l00`0000000?[o003jo`0200000003
003on00000000000008000001000onL00`0000000?oG003oe`02003oe`80
00000P00okX00`0000000?nU003oY@02003oY@0300000000ohl00?n?00<0
0?n?00<00000003oH`00of<00P00of<00`0000000?m7003oA`02003oA`06
00000000ob/0000000000000oaD00000100;o`000`000000;Ol002go0002
02go00030000001Uo`00IOl00080IOl000<0000008_o002;o`000`2;o`00
0`000000`_l00<;o00020<;o008000000P3Zo`000`000000on/000000003
0?oR00060000003o^@00okT00?ni00000000ohl00P0000000`3oR`000000
0?mR00020?mR00030000003o>@00ocT00080ocT00P0000030?ooo`800000
2P3oool3000000X0oooo00200?ooo`040000003oool0oooo000000T0o`1M
00<000000?l0l`3o0?<0203o0?<00`000000MP3o07H0o`0<07H0o`030000
00007ol001oo00l001oo00<00000002do`00]?l05000]?l00`0000000?nd
003o]00C003o]00300000000oal00?lO01000?lO00<0000007Ko001fo`00
2`1fo`000`000000oo<00?oc00090?oc00030000003oG@00oed000L0oed0
0`3oool00`000000oooo0?ooo`0O0?ooo`800000103oool300000080oooo
00<000000?ooo`3oool0203oool300000003002]o`0000000;go00800;go
00D000000038o`00b?l00<So00000003003Ao`0500000000f?l00=So003H
o`0000000`00g_l00`0000000>?o003So`03000000<00;So00<000000032
o`00`_l00P00`_l01@0000000<co003<o`00c?l0000000<00=Go00H00000
003No`00000000000038o`000004003Fo`0500000000h_l00>;o003Ro`00
00001@00k_l5000000<00?oh00<00000003oi`00onL00`00onL01P000000
0?oG0000000000000?o>000000<00?nj00<00000003oY@00ojD00P00ojD0
0`0000000?n?003oS`0200000003003oO@0000000?mS00<00?mS00<00000
003oA`00odL00P00odL00`0000000?lE003o5@02003o5@030000000;o`00
2ol000802ol000H0000002go000000000000043o0000000406Go00030000
002;o`00Rol00080000000<0V_l000000032o`000P32o`02000000<0j_l0
00<000000?oR003ohP000P3ohP000`000000okT00?ni00020?ni00030000
003oR`00oh/00080oh/000H000000?mR003oHP00of800000003o>@020000
00030?lh00000000000001/0oooo00200?ooo`040000003oool0oooo0000
00T0o`1M00<000000?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0;07H0
o`03000000007ol001oo00l001oo00<00000002do`00]?l05000]?l00`00
00000?nd003o]00C003o]00300000000oal00?lO01000?lO00<0000007Ko
001fo`002`1fo`000`000000oo<00?oc00090?oc00030000003oG@00oed0
00L0oed00P3oool2000002`0oooo00<000000?ooo`3oool01P3oool20000
0003002Fo`0000000:go00800:go00D00000002mo`00_Ol00;go00000003
0038o`0500000000dOl00=7o003Ao`0000000`00f?l00`0000000=ko003N
o`03000000800:co00<00000002ho`00^?l00P00^?l01@0000000<;o0032
o`00`_l0000000@00<co00<00000003Eo`00eOl00P0000040038o`050000
0000e_l00=Ko003Fo`0000001000h_l00`0000000>ko003^o`04000000<0
0?So00D00000003on000ooP00?oh00000005003oi`0300000000olh00?o>
00800?o>00D00000003o^P00okX00?nj00000004003oY@8000001000ogd0
0`0000000?mS003oH`02003oH`0600000000odL0000000000000oc@00000
1000oaD00`0000002ol000_o000200_o000300000010o`00@?l00080@?l0
00<0000006Go001Uo`000P1Uo`02000000@0V_l000@000000<;o0032o`00
`_l0100000000`3do`0000000?oR00030?oR00060000003o^@0000000000
003o]00000000`3oR`000`000000of800?mR00020?mR00070000003o>000
ocP00?lh00000000oooo0000000J0?ooo`00P03oool010000000oooo0?oo
o`0000090?l0G@030000003o0?<0o`3c00T0o`3c00<0000007H0o`1f0?l0
2`1f0?l00`00000001oo000Oo`0@000Oo`0300000000]?l00;Co01<00;Co
00<00000003o]000ok@04`00ok@00`0000000?lO003o7`0?003o7`800000
3@1fo`000`000000oo<00?oc00080?oc00030000003oG@00oed000P0oed0
0`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00@0oooo
0`000003002Fo`0400000000[Ol00:go000000<00;go00D000000038o`00
b?l00<So00000003003Ao`0300000000f?l00=So00800=So0P000002002N
o`0500000000[?l00:co002/o`0000001000^?l01@0000000<;o0032o`00
`_l0000000@00<co0P000002002ko`0300000000b?l00<So00800<So00D0
0000003Fo`00e_l00=Ko00000004003Ro`<000000`00iol01@0000000?So
003ho`00n?l0000000<00?oh00<00000003oi`00onL00P0000000`00on80
0000003ocP02003ocP0300000000okX00?nj00800?nj00H00000003oY@00
00000000003oUP000004003oO@0300000000of<00?mS00<00?mS00<00000
003o=000oc@00P00oc@00`0000000?lE003o5@02003o5@060000000;o`00
00000000000Mo`0000000`10o`001`000000IOl006Go001Uo`00000007Co
00000000102Jo`000`000000`_l00<;o00020<;o008000000`3do`000`00
0000on800?oR00020?oR00030000003o]000ok@00080ok@000H000000?n;
003oR`00oh/00000003oHP02000000030?mP00000000ocP00080ocP00P00
000J0?ooo`00P03oool010000000oooo0?ooo`0000090?l0G@030000003o
0?<0o`3c00T0o`3c00<0000007H0o`1f0?l02`1f0?l00`00000001oo000O
o`0@000Oo`0300000000]?l00;Co01<00;Co00<00000003o]000ok@04`00
ok@00`0000000?lO003o7`0?003o7`030000001fo`00M_l000/0M_l000<0
00000?oc003ol`002@3ol`000`000000oed00?mM00080?mM00<0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`8000000`00
L_l01000000009Ko002Fo`000003002]o`0500000000_Ol00;go002mo`00
00000`00b?l01P0000000=7o003Ao`00dOl00000003Ho`80000000<008ko
00000000W_l00P00W_l01@0000000:co002/o`00[?l0000000@00;So00H0
00000032o`00`_l00<;o00000000c?l200000003002]o`0000000;_o0080
0;_o00<000000038o`00b?l00P00b?l0100000000=Ko003Fo`00e_l40000
0003003Go`0000000>Oo00<00>Oo00<00000003ho`00n?l00P00n?l00`00
00000?oh003on003000000@00?oR00D00000003ocP00olh00?o>00000004
003o^P0300000000oiH00?nF00800?nF00<00000003oO@00ogd00P00ogd0
0`0000000?mS003oH`0200000003003oDP0000000?ld00800?ld00<00000
003o5@00oaD00`00oaD00`0000007Ol001go000201go000700000010o`00
@?l0043o00000000IOl00000000307Co00030000002Jo`00V_l00080V_l0
00D000000<;o0000000000000<co000200000080m?l000L000000?oR003o
hP00on800000003og000000000<0ok@000<000000?n;003oR`000P3oR`00
1@000000of000?mP003oH000000000<0ocP000<000000?ooo`0000006@3o
ool00800oooo00@000000?ooo`3oool000002@3o05d00`000000o`3c0?l0
l`090?l0l`030000001f0?l0MP3o00`0MP3o00<00000000Oo`007ol03`00
7ol00`0000000;Co002do`0C002do`0300000000ok@00?nd01<00?nd00<0
0000003o7`00oal03`00oal00`000000M_l007Ko000;07Ko00030000003o
l`00oo<000T0oo<000<000000?mM003oG@00203oG@030?ooo`030000003o
ool0oooo02X0oooo1@0000000`00<ol00000001bo`02001bo`0500000000
U_l009Ko002Fo`0000000P00[Ol01@0000000;go002mo`00_Ol0000000@0
0<So00D00000003Ao`00dOl00=7o00000003002>o`0300000000W_l009ko
008009ko00@00000002/o`00[?l000001000^?l0100000000<;o0032o`00
`_l2000000@00:go00@00000002ko`00^ol000001@00b?l00`0000000=Ko
00000002000000@00=Oo00<00000003Wo`00iol00P00iol00`0000000?So
003ho`02003ho`8000000P00ooH00`0000000?oR003ohP03003ohP060000
0000olh00?o>003ocP0000000?nj0P0000000`00ojh00000003oUP03003o
UP0300000000ogd00?mm00800?mm0P000004003oDP0500000000oc@00?ld
003o=00000000P00oaD200000003003o100000007Ol000807Ol000<00000
043o0010o`000P10o`000`000000M?l007Co000207Co00030000002Jo`00
V_l000<0V_l000<000000<co003<o`000P3<o`001`000000m?l00?Co003d
o`0000000?oR000000000P3og0000`000000ok@00?nd00020?nd00060000
003oR`0000000000003oR00000000`3oH00010000000ocP00?lh003o>002
000001T0oooo00200?ooo`040000003oool0oooo000000T0o`1M00<00000
0?l0l`3o0?<02@3o0?<00`000000MP3o07H0o`0<07H0o`03000000007ol0
01oo00l001oo00<00000002do`00]?l04`00]?l00`0000000?nd003o]00B
003o]00300000000oal00?lO01000?lO00<0000007Ko001fo`002`1fo`00
0`000000oo<00?oc00090?oc00030000003oG@00oed000P0oed00`3oool0
0`000000oooo0?ooo`0Y0?ooo`80000000<0oooo00000000<ol00`00<ol0
1@00000007;o001bo`00L_l00000008009Ko00D00000002]o`00[Ol00:go
00000003002mo`0600000000b?l00<So0038o`0000000=7o0P0000000`00
N_l00000002>o`02002>o`0500000000W_l009ko002No`0000000`00[?l0
0`0000000;So002ho`02002ho`<000000P00WOl01@0000000:go002]o`00
[Ol0000000<00;_o00@000000038o`00b?l00<So100000020037o`050000
0000eol00=Oo003Go`0000001@00iol01P0000000?So0000000000000?Ko
000000<00?of00<00000003ohP00on800`00on800`0000000?o>003ocP02
000000@00?n^00<00000003oUP00oiH00P00oiH01P0000000?mm00000000
00000?m^000000@00?mB00<00000003o=000oc@00P00oc@2000000@00?l4
00H0000001go000Mo`007Ol000000010o`020000000304oo00000000M?l0
00<0M?l000<0000009[o002Jo`000P0000000`2Uo`0000000<co00020<co
008000000`3do`000`000000om`00?oL00020?oL00030000003o]000ok@0
0080ok@000D000000?n8003oR000ohP0000000030?mP00050000003o>000
00000000003o>0000P00000H0?ooo`00P03oool010000000oooo0?ooo`00
00090?l0G@8000002`3o0?<00`000000MP3o07H0o`0;07H0o`0300000000
7ol001oo00l001oo00<00000002do`00]?l04`00]?l00`0000000?nd003o
]00B003o]00300000000oal00?lO00l00?lO0P00000=07Ko00030000003o
l`00oo<000T0oo<000<000000?mM003oG@00203oG@030?ooo`030000003o
ool0oooo01d0oooo0P0000040?ooo`800000103oool010000000oooo0000
00000004000co`0500000000L_l007;o001bo`0000000`00U_l010000000
0:go002]o`000003002mo`0400000000b?l00<So0038o`8000000`00N_l0
0`00000008ko002>o`02002>o`0500000000W_l009ko002No`0000000`00
[?l01P0000000;So00000000000008co000000@009go00D00000002]o`00
[Ol00:go00000003002ko`D0000000<00;Ko00000000aol00P00aol01@00
00000=Oo003Go`00eol0000000D00>Oo00<00000003fo`00m_l00P00m_l0
1@0000000?of003omP00ooH0000000D00?oR0P000002003oaP0300000000
ojh00?n^00800?n^00<00000003oUP00oiH00P00oiH00`0000000?m^003o
KP02003oKP0300000000oe800?mB00800?mB00H00000003o=00000000000
003o9@000004003o10030000000Mo`007Ol000807Ol000<0000004oo001?
o`000P1?o`000`000000M?l007Co000207Co008000000`2Uo`000`000000
c?l00<co00020<co00@0000000<0nol00000003og0000P3og0000`000000
ok@00?nd0002000000030?n`00000000ohP00080ohP000D000000?mP003o
H000of00000000040?lh008000005`3oool00800oooo00@000000?ooo`3o
ool000002P3o05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o
00/0MP3o00<00000000Oo`007ol03`007ol2000001@00;Co00<00000003o
]000ok@04P00ok@00`0000000?lO003o7`0?003o7`030000001fo`00M_l0
00`0M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM00080?mM
00<0oooo00<000000?ooo`3oool0703oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`000000i`3o
00000003000co`0500000000L_l007;o001bo`0000000`00U_l01@000000
0:go002]o`00[Ol0000000<00;go0`000002001So`0500000000N_l007[o
001jo`0000001000S_l01@00000009ko002No`00W_l0000000800:co0P00
0004002<o`0500000000WOl009go002Mo`0000001000[Ol6000000@00;Ko
00D000000037o`00aol00<Oo00000003003Go`0300000000iol00>Oo0080
000000<00>;o00000000m_l00P00m_l00`0000000?of003omP02003omP03
00000000on800?oR0080000000<00?oM00000000olH00P00olH00`000000
0?n^003o[P02003o[P0600000000oiH0000000000000ohX000001000ofh0
0`0000000?mB003oDP02003oDP0300000000obD00?lU00800?lU00<00000
003o1000o`@00P00o`@01P0000007Ol0000000000000:ol0000000@0Col0
00H0000007Co00000000000007oo000000040:Go00030000003<o`00c?l0
0080c?l00P0000020?_o00030000003og000om`00080om`00P0000030?n`
00060000003oR000ohP00?n800000000of000P0000000`3oG`0000000?lh
00020?lh008000005`3oool00800oooo00@000000?ooo`3oool000002P3o
05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00`0MP3o00<0
0000000Oo`007ol03`007ol00`0000000;Co002do`0B002do`0300000000
ok@00?nd01800?nd00<00000003o7`00oal03`00oal00`000000M_l007Ko
000<07Ko00030000003ol`00oo<000T0oo<000<000000?mM003oG@00203o
G@030?ooo`030000003oool0oooo01l0oooo00@000000?ooo`3oool00000
0P3oool02@000000oooo0?ooo`3oool000000?ooo`000000i`3o00000003
000co`0300000000L_l007;o008007;o00D00000002Fo`00U_l009Ko0000
0002002]o`0600000000_Ol0000000000000AOl000000`00Hol01@000000
07[o001jo`00N_l0000000@008ko00<00000002No`00W_l00P00W_l20000
008007Wo00<00000002<o`00S?l00P00S?l01000000009go002Mo`00WOl4
00000003002]o`000000000000800:?o00<00000002fo`00]_l00P00]_l0
0`0000000<Oo0037o`020037o`0300000000eol00=Oo00<000001000h_l0
1@0000000?Ko003fo`00m_l0000000@00?of0P000003003og@0300000000
olH00?o600800?o600<00000003o[P00ojh00P00ojh00`0000000?n:003o
RP02003oRP0300000000ofh00?m^00800?m^00H00000003oDP0000000000
003oA0000004003o9@0300000000o`@00?l400800?l400<0000002_o000[
o`000P0[o`000`000000Col004oo000204oo00030000001oo`00Ool00080
Ool000D000000:Go002Uo`00YOl0000000020<co0080000000<0e?l00000
003ko`000P3ko`001P000000om`0000000000000omL0000000@0ok0000D0
00000?n8003oR000ohP0000000040?mO00040000003o>000ocP00?lh0080
00005P3oool00800oooo00@000000?ooo`3oool000002P3o05d00`000000
o`3c0?l0l`090?l0l`030000001f0?l0MP3o00`0MP3o00<00000000Oo`00
7ol03`007ol00`0000000;Co002do`0B002do`0300000000ok@00?nd0180
0?nd00<00000003o7`00oal03`00oal00`000000M_l007Ko000;07Ko0003
0000003ol`00oo<000X0oo<000<000000?mM003oG@00203oG@020?ooo`80
00007`3oool2000000<0oooo00@000000?ooo`3oool000000`3oool01@00
0000oooo0000003W0?l0000000@003?o00D00000001bo`00L_l007;o0000
0003002Fo`0500000000[Ol00:go002]o`0000000`00AOl00`00000006?o
001So`02001So`0500000000N_l007[o001jo`0000001000S_l01P000000
09ko00000000000006Co000000<007Wo00H00000002<o`00S?l008co0000
0000WOl400000005002]o`0000000000002@o`0000000`00Xol00`000000
0;Ko002fo`02002fo`0300000000aol00<Oo00800<Oo0P000002003>o`03
00000000h_l00>;o00800>;o00<00000003fo`00m_l00P00m_l01P000000
0?of0000000000000?od000000@00?oM00<00000003oaP00olH00P00olH0
1P0000000?n^0000000000000?nU000000@00?n:00<00000003oKP00ofh0
0P00ofh00`0000000?m4003oA002003oA00300000000obD00?lU00800?lU
00H00000003o10000000000000So0000000402_o00060000001?o`000000
0000001Jo`0000000`1oo`000`000000YOl00:Go00020:Go008000000`3D
o`02000000<0nol000<000000?oG003oe`000P3oe`001P000000ok000?n`
003o/00000000?n80080000000<0ohH00000003oG`000P3oG`000`000000
ocP00?lh00020?lh008000005@3oool00800oooo00@000000?ooo`3oool0
00002P3o05d00`000000o`3c0?l0l`090?l0l`030000001f0?l0MP3o00`0
MP3o00<00000000Oo`007ol03`007ol00`0000000;Co002do`0B002do`03
00000000ok@00?nd01800?nd00<00000003o7`00oal03P00oal00`000000
M_l007Ko000<07Ko00030000003ol`00oo<000X0oo<000<000000?mM003o
G@00203oG@030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00<0oooo0P0000020>L0o`0300000000<ol003?o008003?o00D00000001b
o`00L_l007;o00000004002Fo`<0000000<001go00000000AOl00P00AOl0
1@00000006?o001So`00Hol0000000@007[o00<00000002>o`00S_l00P00
S_l01@00000006Co001To`00I?l0000000@007Wo00<00000002<o`000000
0P000004002Mo`0300000000T?l0093o0080093o00D00000002So`00Xol0
0:?o00000004002fo`0600000000aol0000000000000^_l000000`00c_l0
0`0000000>;o003Ro`02003Ro`0300000000m_l00?Ko00800?Ko00<00000
003om000oo@00P00oo@00`0000000?oM003og@02003og@0300000000olH0
0?o600800?o600<00000003oY@00ojD00P00ojD00`0000000?n:003oRP02
003oRP0600000000ofh0000000000000of8000000`00od@00`0000000?lU
003o9@03003o9@0300000008o`002?l000802?l000<0000002_o000[o`00
0P0[o`000`000000F_l005[o000205[o00060000001oo`00Ool007oo0000
0000YOl00P0000000`2^o`0000000=Co00030=Co0080000000@0nol00000
003ooP0000000`3oe`000`000000ok000?n`00020?n`00030000003oQP00
ohH00080ohH000H000000?mO003oG`00oel00000003o>002000000030?lg
00000000oooo01@0oooo00200?ooo`040000003oool0oooo000000X0o`1M
00<000000?l0l`3o0?<02P3o0?<00`000000MP3o07H0o`0;07H0o`030000
00007ol001oo00l001oo00<00000002do`00]?l04P00]?l00`0000000?nd
003o]00A003o]00300000000oal00?lO00l00?lO00<0000007Ko001fo`00
301fo`000`000000oo<00?oc000:0?oc00030000003oG@00oed000P0oed0
0`3oool00`000000oooo0?ooo`0E0?ooo`<000001@3oool3000000<0oooo
0P0000040?ooo`8000000P3W0?l00`00000003?o000co`02000co`030000
0000L_l007;o008007;o00D00000002Fo`00U_l009Ko00000003000Mo`03
00000000AOl004Go008004Go00D00000001So`00Hol006?o00000003001j
o`0300000000S_l008ko0080000000<004co00000000I?l00P00I?l00`00
000007Wo001io`03000000<008co00H00000002Mo`0000000000001lo`00
0004002@o`0500000000Xol00:?o002So`0000001000]_l00`0000000;[o
002jo`02002jo`0400000000c_l00<ko003>o`8000000`00h_l01P000000
0?Ko0000000000000?Co000000@00?od00D00000003og@00omd00?oM0000
0002003oaP80000000<00?no00000000ojD00P00ojD00`0000000?n:003o
RP03003oRP0300000000of800?mR00800?mR00D00000003oA000od@00?m4
00000002003o9@80000000<00?lH00000008o`000P08o`001`000000:ol0
02_o000[o`00000003Ko000000000`1Jo`000`000000Ool007oo000207oo
00030000002^o`00[_l00080[_l000@000000=Co003Do`00e?l00`000003
0?on00060000003oe`00omL00?oG00000000ok000P0000000`3o[@000000
0?n600020?n600030000003oG`00oel00080oel000@000000?lg003o=`00
ocL00P00000D0?ooo`00P03oool010000000oooo0?ooo`00000:0?l0G@03
0000003o0?<0o`3c00X0o`3c00<0000007H0o`1f0?l02`1f0?l00`000000
01oo000Oo`0?000Oo`0300000000]?l00;Co01800;Co00<00000003o]000
ok@04@00ok@00`0000000?lO003o7`0?003o7`030000001fo`00M_l000`0
M_l000<000000?oc003ol`002@3ol`000`000000oed00?mM00090?mM00<0
oooo00<000000?ooo`3oool0503oool01@000000oooo0000003oool00000
0100oooo0P0000030>L0o`0500000000<ol003?o000co`0000001000L_l0
1P00000009Ko002Fo`0000005`3o000000<001go00D000000015o`00AOl0
04Go00000004001So`0400000000N_l007[o001jo`8000000`00C?l01000
000006Co001To`00I?l3000000<007Wo00<00000002<o`00S?l00P000004
001lo`0500000000T?l0093o002@o`0000001000Xol01P0000000;Ko0000
000000000:Go000000<00;[o00<00000003>o`00c_l00`00c_l00`000000
0>;o003Ro`02000000@00?Co00<00000003om000oo@00P00oo@00`000000
0?oM003og@03000000@00?no00D00000003oY@00ojD00?nU00000002003o
RP80000000<00?n000000000of800P00of800`0000000?m4003oA002003o
A08000001000oaP01`0000002?l000So0008o`00000002_o000000000`0f
o`001P000000F_l005[o001Jo`00000007oo0080000000<0R?l00000002^
o`000P2^o`000`000000e?l00=Co00020=Co008000000`3ooP000`000000
omL00?oG00020?oG00050000003o[@00ojd00?n]00000000103oQP001P00
0000oel0000000000000oeh0000000<0ocL00P00000C0?ooo`00P03oool0
10000000oooo0?ooo`00000:0?l0G@030000003o0?<0o`3c00X0o`3c00<0
000007H0o`1f0?l0301f0?l00`00000001oo000Oo`0>000Oo`8000004`00
]?l00`0000000?nd003o]00A003o]00300000000oal00?lO00l00?lO00<0
000007Ko001fo`00301fo`000`000000oo<00?oc00090?oc00030000003o
G@00oed000T0oed00`3oool00`000000oooo0?ooo`0D0?ooo`050000003o
ool000000?ooo`0000003`3oool00`000000oooo000000030>L0o`030000
0000<ol003?o008003?o00<00000001bo`00L_l00P00L_l2000000805`3o
00<00000000Mo`007Ol00P007Ol01@00000004Go0015o`00AOl0000000<0
06?o00H00000001jo`0000000000000`o`000004001<o`<000000P00I?l0
0`00000007Wo001io`02001io`8000000P00I_l01@00000007co001lo`00
O?l0000000@0093o00<00000002So`00Xol00P00Xol00`0000000:Go002U
o`02002Uo`0500000000^_l00;[o002jo`0000001@00c_l2000000800=go
00<00000003do`00m?l00P00m?l00`0000000?od003om002003om0800000
0P00omT00`0000000?no003o_`02003o_`0300000000ojD00?nU00800?nU
0P000004003oP00600000000of800?mR003oHP0000000?m40P0000000`00
ocT00000003o6003003o600300000008o`002?l000802?l000<0000003Ko
000fo`000P0fo`000`000000F_l005[o000205[o000300000028o`00R?l0
0080R?l000H000000:ko002^o`00[_l00000003Do`02000000030=[o0000
0000000000<0ooh000H000000?oG0000000000000?oD000000030?n]0003
0000003oQP00ohH00080ohH000D000000?mN003oGP00oeh0000000040?lg
00030000003oool0oooo00<0oooo1000000:0?ooo`00P03oool010000000
oooo0?ooo`00000:0?l0G@030000003o0?<0o`3c00X0o`3c00<0000007H0
o`1f0?l0301f0?l00`00000001oo000Oo`0?000Oo`0300000000]?l00;Co
01400;Co00<00000003o]000ok@04@00ok@00`0000000?lO003o7`0?003o
7`030000001fo`00M_l000`0M_l000<000000?oc003ol`002@3ol`000`00
0000oed00?mM00090?mM00<0oooo00<000000?ooo`3oool0503oool01@00
0000oooo0000003oool0000000l0oooo0P0000040>L0o`0300000000<ol0
03?o008003?o00<00000001bo`00L_l00P00L_l00`0000005`3o01L0o`02
01L0o`05000000007Ol001go000Mo`0000001000AOl01@00000006?o001S
o`00Hol0000000@0033o00H00000001<o`0000000000001<o`000003001T
o`0300000000NOl007Wo0080000000<004ko00000000I_l00P00I_l01@00
000007co001lo`00O?l0000000@0093o00H00000002So`0000000000002?
o`000003002Uo`0300000000^_l00;[o00800;[o00<00000003>o`00c_l0
0P0000000`00a_l00000003Mo`02003Mo`0300000000m?l00?Co00800?Co
00H00000003om00000000000003ol`000003003of@0300000000okl00?no
00800?no00H00000003oY@0000000000003oW@000004003oP00300000000
of800?mR00800?mR00<00000003o>@00ocT00P00ocT00`0000000?lH003o
6002003o600600000008o`0000000000000Co`000000100fo`001P000000
F_l0000000000000Hol0000000<0R?l000<000000:ko002^o`000P2^o`00
0`000000f_l00=[o00020=[o008000000`3ooP001@000000om@00?oD003o
e000000000<0ojd000<000000?n6003oQP000P0000000`3oQ@0000000?mN
00020?mN00060000003o=`00ocL00000003o=`000000103oool00`000000
oooo0?ooo`0;0?ooo`00N@3oool500000080oooo00@000000?ooo`3oool0
00002P3o05d00`000000o`3c0?l0l`0:0?l0l`030000001f0?l0MP3o00`0
MP3o00<00000000Oo`007ol03`007ol00`0000000;Co002do`0A002do`03
00000000ok@00?nd01400?nd00<00000003o7`00oal03`00oal00`000000
M_l007Ko000;07Ko00030000003ol`00oo<000X0oo<000<000000?mM003o
G@002@3oG@030?ooo`030000003oool0oooo01D0oooo0`00000@0?ooo`80
0000103W0?l00`00000003?o000co`02000co`0400000000L_l007;o001b
o`800000100G0?l00`00000001go000Mo`02000Mo`0600000000AOl004Go
0015o`00000006?o0P00000010003_l00000000`o`00<?l3000000@004co
00@00000001To`00I?l006Co0P000003001>o`0500000000I_l006Ko001V
o`0000001000O?l010000000093o002@o`00T?l2000000@008oo00D00000
002Uo`00YOl00:Go00000004002jo`8000000`00a_l00`0000000=go003M
o`02003Mo`0300000000m?l00?Co00800?Co00<00000003ol`00oo<00P00
oo<01@0000000?oI003of@00omT0000000@00?no00<00000003oW@00oid0
0P00oid00`0000000?n0003oP002003oP00600000000of80000000000000
oeT000000`00ocT00`0000000?lH003o6003003o60030000000Co`004ol0
00804ol000<0000003Ko000fo`000P0fo`000`000000Hol006?o000206?o
000600000028o`00R?l008So00000000[_l00P0000000`2do`0000000=[o
00030=[o00060000003ooP0000000000003onP0000000`3oe00010000000
ojd00?n]003o[@02000000<0ohD000L000000?mN003oGP00oeh00000003o
=`0000000080ocL00P0000040?ooo`030000003oool0oooo00X0oooo001k
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000002P3o
05d00`000000o`3c0?l0l`0:0?l0l`030000001f0?l0MP3o00`0MP3o00<0
0000000Oo`007ol03`007ol00`0000000;Co002do`0A002do`0300000000
ok@00?nd01400?nd00<00000003o7`00oal03P00oal00`000000M_l007Ko
000<07Ko00030000003ol`00oo<000X0oo<000<000000?mM003oG@002@3o
G@030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03P3o
ool2000000@0i`3o00<00000000co`00<ol00P00<ol01000000007;o001b
o`00000206@0o`030000000G0?l05`3o00805`3o00<00000000Mo`007Ol0
0P007Ol01@00000004Go0015o`00AOl0000000<000ko0`000002000`o`03
00000000C?l004co008004co00H00000001To`0000000000000co`000004
001>o`0500000000I_l006Ko001Vo`0000001000O?l30000008007So00D0
0000002?o`00Sol008oo00000004002Uo`0600000000^_l0000000000000
[_l000001000a_l00`0000000=go003Mo`02003Mo`0600000000m?l00000
00000000lol000001000oo<01P0000000?oI003of@00omT00000003o_`80
000000<00?nj00000000oid00`00oid00`0000000?n0003oP002003oP003
00000000oeT00?mI00800?mI00D00000003o>@00ocT00?li00000002003o
6080000000<00?l>0000000Co`000`0Co`001P000000=_l0000000000000
?ol0000000<0Hol000<0000008So0028o`000P28o`000`000000]?l00;Co
00020;Co00030000003Jo`00f_l00080f_l000D000000?oj003onP00ooX0
000000030?oD00060000003o[@0000000000003oZ`000000103oQ@001@00
0000oeh00?mN003oGP00000000@0ocL000<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`090?ooo`00N`3oool00`000000oooo0?ooo`020?oo
o`80000000<0oooo0000003o05d02P3o05d00`000000o`3c0?l0l`090?l0
l`030000001f0?l0MP3o00`0MP3o00<00000000Oo`007ol03`007ol00`00
00000;Co002do`0A002do`0300000000ok@00?nd01400?nd00<00000003o
7`00oal03P00oal00`000000M_l007Ko000<07Ko00030000003ol`00oo<0
00X0oo<000<000000?mM003oG@002@3oG@020?ooo`8000007P3oool00`00
0000oooo0?ooo`020?ooo`8000001@3oool2000000D0i`3o00<00000000c
o`00<ol00P00<ol2000000<0I03o00<0000001L0o`0G0?l00`0G0?l01P00
000001go000Mo`007Ol000000015o`80000000@06@3o0000000000000000
0P003_l01@000000033o000`o`00<?l0000000@004co00<00000000co`00
<ol00P00<ol00`00000004ko001>o`02001>o`0600000000I_l006Ko001V
o`00000007co0P0000000`00Gol00000001ho`03001ho`0500000000Sol0
08oo002?o`0000001000YOl00`0000000:ko002^o`02002^o`0300000000
a_l00<Ko00800<Ko00<00000003Mo`00gOl00P00gOl00`0000000??o003c
o`02003co`0300000000oo<00?oc00800?oc00<00000003of@00omT00P00
0004003o^P0300000000oid00?nM00800?nM00H00000003oP00000000000
003oN0000003003oF@0300000000ocT00?li00800?li0P000004003o3P03
0000000Co`004ol000804ol000<0000003oo000oo`000P0oo`001P000000
Hol006?o001So`00000008So0080000000<0Sol00000002do`000`2do`00
1P000000f_l0000000000000gol0000000<0ooX000D000000?oD003oe000
om@0000000040?n[00060000003oQ@00ohD00?n500000000oeh00P000000
0`3oG@0000000?lg00020?lg008000000P3oool010000000oooo0?ooo`00
000:0?ooo`00N`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000/0o`1M00<000000?l0l`3o0?<02P3o0?<00`000000MP3o07H0
o`0<07H0o`03000000007ol001oo00h001oo00<00000002do`00]?l04@00
]?l00`0000000?nd003o]00@003o]00300000000oal00?lO00l00?lO00<0
000007Ko001fo`00301fo`000`000000oo<00?oc000:0?oc00030000003o
G@00oed000T0oed00`3oool00`000000oooo0?ooo`0L0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000
003W0?l0i`3o00@0i`3o00<00000000co`00<ol00P00<ol00`000000I03o
06@0o`0306@0o`030000000G0?l05`3o00805`3o00<00000000Mo`007Ol0
0P007Ol5000000@000ko00<00000000`o`00<?l00P00<?l01P00000004co
00000000000001Go000000@003?o00<00000001>o`00C_l00P00C_l01@00
000006Ko001Vo`00I_l0000000@005oo00<00000001ho`00N?l00P00N?l0
1P00000008oo002?o`00Sol00000002Uo`80000000<009Ko00000000[_l0
0P00[_l00`0000000<Ko0036o`020036o`0300000000gOl00=go00800000
00<00=Wo00000000lol00`00lol00`0000000?oc003ol`02003ol`800000
0P00omH00`0000000?nj003o^P02003o^P0300000000oid00?nM00800?nM
00<00000003oN000ogP00P00ogP01P0000000?mI003oF@00oeT00000003o
>@80000000<00?l`00000000o`h01000o`h01P0000004ol0000000000000
6ol0000000<0?ol000<0000006?o001So`000P1So`000`000000Sol008oo
000208oo00030000002do`00]?l00080]?l000D000000=oo003Oo`00gol0
000000030?oj00060000003oe00000000000003od@0000000`3oZ`000`00
0000ohD00?n500020?n500050000003oG@00oed00?mM00000000103o=`00
10000000oooo0?ooo`3oool2000000/0oooo001k0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000002`3o05d00`000000o`3c0?l0
l`0:0?l0l`030000001f0?l0MP3o00`0MP3o00<00000000Oo`007ol03P00
7ol00`0000000;Co002do`0A002do`0300000000ok@00?nd01000?nd00<0
0000003o7`00oal03`00oal00`000000M_l007Ko000<07Ko00030000003o
l`00oo<000X0oo<000<000000?mM003oG@002@3oG@030?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`3oool2000000H0i`3o00L00000000co`00<ol003?o0000003F0?l00000
00@0I03o00<0000001L0o`0G0?l00`0G0?l00`00000001go000000030000
00<06@3o00<00000000>o`003_l00P003_l00`000000033o000`o`02000`
o`03000000005Ol001Go008001Go00D00000000co`00<ol003?o00000004
001>o`0600000000I_l0000000000000AOl000001000Gol00`00000007So
001ho`02001ho`0300000000Sol008oo008000001000U_l01@0000000:ko
002^o`00[_l0000000@00<Ko0P000004003Io`0300000000lol00??o0080
0??o00H00000003ol`0000000000003olP000003003oeP0300000000okX0
0?nj00800?nj00H00000003oW@0000000000003oU`000003003oN0030000
0000oeT00?mI00800?mI00<00000003o<000oc000P00oc02000000@00?l>
00<0000001_o000Ko`000P0Ko`001P000000?ol003oo000oo`00000006?o
0080000000<0J_l00000002?o`000`2?o`001P000000]?l0000000000000
^Ol0000000<0gol000D000000?oj003onP00ooX0000000040?oA00060000
003oZ`00oj/00?n[00000000ohD00P0000000`3oP`0000000?mM00020?mM
00030000003o=`00000000800000403oool007X0oooo0P0000040?ooo`04
0000003oool0oooo000000/0o`1M00<000000?l0l`3o0?<02P3o0?<00`00
0000MP3o07H0o`0<07H0o`03000000007ol001oo00h001oo00<00000002d
o`00]?l04@00]?l00`0000000?nd003o]00@003o]00300000000oal00?lO
00l00?lO00<0000007Ko001fo`00301fo`000`000000oo<00?oc000:0?oc
00030000003oG@00oed000T0oed00`3oool00`000000oooo0?ooo`0M0?oo
o`040000003oool0oooo0?ooo`800000103oool2000000H0i`3o00L00000
000co`00<ol003?o0000003F0?l0000000D0I03o00@0000001L0o`0G0?l0
5`3o1000000204/0o`030000000I0?l06@3o00806@3o00<00000000>o`00
3_l00P003_l01P000000033o000000000000303o000000@001Go00D00000
000co`00<ol003?o00000004001>o`0300000000AOl004Go008004Go00<0
0000001Oo`00Gol00P00Gol00`00000007So001ho`02001ho`8000000P00
OOl00`00000009Ko002Fo`02002Fo`0600000000[_l00:ko002^o`000000
0<Ko0P0000000`00_ol00000003Io`03003Io`0300000000lol00??o00<0
0??o00<00000003olP00oo800P00oo80100000000?oF003oeP000005003o
^P0300000000oiL00?nG00800?nG00H00000003oN000ogP00?mh00000000
oeT200000003003oD@0000000?l`00@00?l`00H00000003o3P0000000000
003o1`00000301_o00030000000oo`00?ol00080?ol000<0000006[o001Z
o`000P1Zo`000`000000Sol008oo000208oo00050000002io`00^Ol00;Wo
000000000`3Oo`04000000030?og00000000om400080om4000<000000?n[
003oZ`000P3oZ`001@000000oh<00?n3003oP`00000000@0oed000@00000
0?ooo`3oool00000403oool00800oooo00@000000?ooo`3oool000002`3o
05d00`000000o`3c0?l0l`0:0?l0l`030000001f0?l0MP3o00`0MP3o00<0
0000000Oo`007ol03P007ol00`0000000;Co002do`0A002do`0300000000
ok@00?nd01000?nd00<00000003o7`00oal03`00oal00`000000M_l007Ko
000<07Ko00030000003ol`00oo<000X0oo<000<000000?mM003oG@002@3o
G@030?ooo`030000003oool0oooo01X0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`030?ooo`8000001P3W0?l01000000003?o
000co`0000030=H0o`030000001T0?l0I03o0080I03o1000000201L0o`03
0000001;0?l0B`3o0080B`3o00<0000001T0o`0I0?l00P0I0?l00`000000
00ko000>o`02000>o`050000000<0?l0303o00`0o`00000010005Ol00`00
000003?o000co`02000co`0600000000C_l0000000000000:Ol000000`00
AOl00`00000005oo001Oo`03001Oo`0600000000N?l0000000000000Hol0
00000`00OOl00`00000009Ko002Fo`02002Fo`0300000000[_l00:ko0080
00001000_ol00`0000000=Wo003Io`02003Io`0300000000lol00??o0080
000000<00?;o00000000oo800P00oo801@0000000?oF003oeP00omH00000
00800?nj0P0000000`00okD00000003oU`03003oU`0300000000ogP00?mh
008000001000oe400`0000000?l`003o<003003o<00300000000o`L00?l7
00800?l700H0000001_o000Ko`006ol00000000oo`020000000304Go0000
0000J_l00080J_l000L0000008oo002?o`00Sol00000002Do`00000000<0
^Ol000@000000=oo003Oo`00gol00P0000030?og00060000003od@00om40
0?oA00000000oj/00P0000000`3oZ@0000000?n300020?n300040000003o
G@000000000000@0oooo00<000000?ooo`3oool03@3oool00800oooo00@0
00000?ooo`3oool000002`3o05d00`000000o`3c0?l0l`0:0?l0l`030000
001f0?l0MP3o00`0MP3o00<00000000Oo`007ol03`007ol00`0000000;Co
002do`0@002do`0300000000ok@00?nd01000?nd00<00000003o7`00oal0
3P00oal00`000000M_l007Ko000<07Ko00030000003ol`00oo<000/0oo<0
00<000000?mM003oG@002@3oG@030?ooo`030000003oool0oooo01X0oooo
100000030?ooo`<000000`3oool00`000000i`3o0>L0o`060>L0o`800000
103F0?l00`000000I03o06@0o`04000000<05`3o00<0000008T0o`000000
0`1;0?l00`0000006@3o01T0o`0201T0o`07000000003_l000ko000>o`00
0000<P3o0000000300`0o`03000000005Ol001Go008001Go00<00000000c
o`00<ol00P00<ol00`00000002Wo000Yo`02000Yo`0500000000AOl004Go
0015o`0000001@00Gol00`00000006?o001So`02001So`0500000000OOl0
07go001mo`0000001000U_l2000000800:Go00<00000002oo`00_ol00P00
_ol00`0000000=Wo003Io`02003Io`8000001000l_l01@0000000?ob003o
lP00oo80000000800?oF0`000004003o]@0300000000oiL00?nG00800?nG
0P000002003oLP0300000000oe400?mA00800?mA00<00000003o<000oc00
0P0000000`00obT00000003o1`02003o1`030000000Ko`006ol000806ol0
00D0000004Go0015o`00AOl00000000406[o00030000002?o`0000000080
U?l000H000000;Wo002io`00^Ol00000003Oo`02000000030>;o00000000
ooL00080ooL000<000000?oA003od@000P3od@001@000000ojT00?nY003o
Z@00000000@0oh<000<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0=0?ooo`00P03oool010000000oooo0?ooo`00000;0?l0G@030000003o
0?<0o`3c00X0o`3c00<0000007H0o`1f0?l0301f0?l00`00000001oo000O
o`0?000Oo`0300000000]?l00;Co01000;Co00<00000003o]000ok@04000
ok@00`0000000?lO003o7`0>003o7`030000001fo`00M_l000`0M_l000<0
00000?oc003ol`002`3ol`000`000000oed00?mM00090?mM00<0oooo00<0
00000?ooo`3oool09`3oool00`000000i`3o0>L0o`060>L0o`800000103F
0?l3000000<0I03o00@0000001L0o`00000000000P290?l00`000000B`3o
04/0o`0204/0o`030000000I0?l06@3o00806@3o00<00000000>o`000000
0P0b0?l00`000000303o00`0o`0200`0o`03000000005Ol001Go008001Go
00H00000000co`0000000000000;o`000003000Yo`0300000000AOl004Go
008004Go00<00000001Oo`00Gol00P0000000`00Aol00000001So`02001S
o`0300000000OOl007go008007go00H00000002Fo`0000000000002:o`00
0003002Uo`0300000000_ol00;oo00800;oo00H00000003Io`0000000000
003Fo`000004003bo`0300000000oo800?ob00800?ob0P000002003od`03
00000000okD00?ne00<00?ne00H00000003oU`0000000000003oTP000003
003oLP0300000000oe400?mA00800?mA0P000003003o:@0300000000o`L0
0?l700800?l700H0000001_o000000000000027o0000000304Go00030000
001Zo`00J_l00080J_l000<0000009Co002Do`000P2Do`001@000000^Ol0
0;Wo002io`00000000@0h_l000H000000?og003om`00ooL00000003od@02
000000030?o?00000000ojT00080ojT000@000000?n30000000000001`3o
ool00`000000oooo0?ooo`0=0?ooo`00P03oool010000000oooo0?ooo`00
000;0?l0G@030000003o0?<0o`3c00X0o`3c00<0000007H0o`1f0?l03@1f
0?l00`00000001oo000Oo`0>000Oo`0300000000]?l00;Co01000;Co00<0
0000003o]000ok@04000ok@00`0000000?lO003o7`0>003o7`030000001f
o`00M_l000`0M_l000<000000?oc003ol`002P3ol`000`000000oed00?mM
000:0?mM0080oooo0P00000Y0?ooo`030000003W0?l0i`3o00H0i`3o00@0
00000=H0o`3F0?l0eP3o0P0000020=H0o`030000001T0?l0I03o0080I03o
00<0000008T0o`290?l00`290?l00`000000B`3o04/0o`0204/0o`030000
000I0?l06@3o00806@3o00<000000380o`0b0?l00P0b0?l00`000000303o
00`0o`0200`0o`03000000005Ol001Go008001Go00<00000000;o`002ol0
0P002ol01@00000002Wo000Yo`00:Ol0000000@004Go0P0000040017o`05
00000000Hol006?o001So`0000001000OOl00`00000008[o002:o`02002:
o`0500000000YOl00:Go002Uo`0000001000_ol00`0000000=Ko003Fo`02
003Fo`0300000000l_l00?;o00800?;o00H00000003olP0000000000003o
l@000003003od`8000001000okD00`0000000?nB003oTP02003oTP060000
0000og800?mb003oLP0000000?mA0P0000000`00od/00000003o:@03003o
:@0300000000o`L00?l700800?l700D00000027o000Qo`008Ol000000003
04Go00030000001Zo`00J_l00080000000<0Kol00000002Do`000P2Do`00
1P000000^Ol0000000000000_Ol0000000<0h_l00P0000030?og00050000
003oc`00oll00?o?00000000103oZ@000`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00d0oooo00200?ooo`040000003oool0oooo000000/0
o`1M00<000000?l0l`3o0?<02`3o0?<00`000000MP3o07H0o`0<07H0o`03
000000007ol001oo00h001oo00<00000002do`00]?l04000]?l00`000000
0?nd003o]00@003o]00300000000oal00?lO00h00?lO00<0000007Ko001f
o`00301fo`000`000000oo<00?oc000:0?oc00030000003oG@00oed000X0
oed00`3oool00`000000oooo0?ooo`0W0?ooo`030000003W0?l0i`3o00H0
i`3o100000040=H0o`070000001T0?l0I03o06@0o`000000eP3o00000004
08T0o`030000001;0?l0B`3o0080B`3o00<0000001T0o`0I0?l00P000000
0`1O0?l000000380o`030380o`050000000<0?l0303o00`0o`0000000P00
5Ol20000000301D0o`00000000_o008000_o00<00000000Yo`00:Ol00P00
:Ol01P00000004Go00000000000002_o000000@004Oo00<00000001So`00
Hol00P00Hol01P00000007go00000000000006ko000000<008[o00<00000
002Uo`00YOl00P00YOl01P0000000;oo0000000000000;[o000000@00=Ko
00<00000003bo`00l_l00P00l_l00`0000000?oa003ol@02003ol@030000
0000om<00?oC00800?oC00H00000003o]@0000000000003o/@000003003o
TP0300000000og800?mb00800?mb00<00000003oB`00od/00P00od/01@00
00000?lY003o:@00obT0000000800?l70P0000000`00o`400000027o0002
027o000400000015o`00AOl004Go008000000`1_o`000`000000U?l009Co
000209Co00030000002mo`00_Ol00080_Ol000@000000>;o003Ro`00h_l0
100000000`3om@0000000?o?00020?o?00040000003oZ@000000000000X0
oooo00<000000?ooo`3oool03@3oool00800oooo00@000000?ooo`3oool0
00002`3o05d00`000000o`3c0?l0l`0;0?l0l`030000001f0?l0MP3o00`0
MP3o00<00000000Oo`007ol03P007ol00`0000000;Co002do`0@002do`03
00000000ok@00?nd01000?nd00<00000003o7`00oal03P00oal00`000000
M_l007Ko000<07Ko00030000003ol`00oo<000X0oo<000<000000?mM003o
G@002P3oG@030?ooo`030000003oool0oooo02H0oooo00<000000>L0o`3W
0?l01@3W0?l4000000L0eP3o00<0000006@0o`0000000P3F0?l00`000000
R@3o08T0o`0308T0o`030000001;0?l0B`3o0080B`3o0P00000405l0o`03
0000000b0?l0<P3o0080<P3o00@0000000`0o`0<0?l0303o0P00000401D0
o`05000000002ol000_o000;o`0000001000:Ol00`00000002_o000[o`02
000[o`0300000000Aol004Oo008004Oo00<00000001So`00Hol00P00Hol0
0`00000006ko001^o`02001^o`0500000000R_l008[o002:o`0000001000
YOl00`0000000;[o002jo`02002jo`0300000000e_l00=Ko00800=Ko00H0
0000003bo`0000000000003ao`000004003ol@0300000000om<00?oC0080
0?oC00<00000003o/@00ok400P00ok401P0000000?nB003oTP00oi800000
003oLP80000000<00?m]00000000od/00P00od/00`0000000?lY003o:@02
003o:@8000000`00o`401P0000008Ol0027o000Qo`00000004Go00800000
00<0B_l00000001_o`000`1_o`001P000000U?l0000000000000V?l00000
00<0_Ol000<000000>;o003Ro`000P3Ro`001@000000ooD00?oe003om@00
000000@0oll000<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=
0?ooo`00P03oool010000000oooo0?ooo`00000;0?l0G@030000003o0?<0
o`3c00/0o`3c00<0000007H0o`1f0?l0301f0?l00`00000001oo000Oo`0>
000Oo`0300000000]?l00;Co01000;Co00<00000003o]000ok@03`00ok@0
0`0000000?lO003o7`0?003o7`030000001fo`00M_l000`0M_l000<00000
0?oc003ol`002P3ol`000`000000oed00?mM000:0?mM00<0oooo00<00000
0?ooo`3oool09P3oool00`000000i`3o0>L0o`020>L0o`<0000000D0i`3o
0000003o08@0o`24000000060=H0o`030000001T0?l0000000<0eP3o00<0
000008T0o`290?l00`290?l01P000000B`3o04/0o`000000TP3o000000@0
G`3o00<000000380o`0b0?l00P0b0?l01P000000303o000000000000>P3o
000000@05@3o00<00000000;o`002ol00P002ol01P00000002Wo00000000
000000co000000<002_o00<000000017o`00Aol00`00Aol01P00000006?o
00000000000005;o000000@006ko00H00000002:o`00R_l008[o00000000
YOl200000003002Mo`0000000;[o00<00;[o00<00000003Fo`00e_l00P00
e_l00`0000000?7o003ao`02003ao`0300000000oo400?oa00800?oa00H0
0000003od`0000000000003od@000003003o/@0300000000oi800?nB0080
0?nB00<00000003oK@00ofd00P00ofd01P0000000?m;003oB`00od/00000
003o:@80000000<00?lT00000000o`400`00o`401@0000008Ol0027o000Q
o`00000000@0B_l000<0000006oo001_o`000P1_o`000`000000V?l009So
000209So00060000002mo`00_Ol00;go00000000h_l00P0000000`3Uo`00
00000?oe00020?oe00040000003oc`000000000000d0oooo00<000000?oo
o`3oool03@3oool00800oooo00@000000?ooo`3oool000002`3o05d00`00
0000o`3c0?l0l`0;0?l0l`030000001f0?l0MP3o00`0MP3o00<00000000O
o`007ol03P007ol00`0000000;Co002do`0@002do`0300000000ok@00?nd
00l00?nd00<00000003o7`00oal03`00oal00`000000M_l007Ko000<07Ko
00030000003ol`00oo<000X0oo<000<000000?mM003oG@002P3oG@030?oo
o`030000003oool0oooo02H0oooo00<000000>L0o`0000000P0000030>L0
o`030000003o08@0o`240080o`2400<000000=H0o`3F0?l0103F0?l00`00
0000eP3o0=H0o`030=H0o`03000000290?l0R@3o0080R@3o00<0000004/0
o`0000000`2B0?l00`000000G`3o05l0o`0205l0o`030000000b0?l0<P3o
0080<P3o00<0000003X0o`0j0?l00P0j0?l00`0000005@3o01D0o`0201D0
o`03000000002ol000_o008000_o00<00000000<o`003?l00P003?l01@00
000002_o000[o`00:ol0000000D004Oo00<00000001Bo`00D_l00P00D_l0
0`00000006ko001^o`02001^o`0300000000R_l008[o008000001000WOl0
0`0000000;[o002jo`02002jo`0600000000e_l0000000000000dol00000
1000lOl00`0000000?oa003ol@02003ol@0300000000om400?oA00800?oA
00H00000003o/@00ok400?na00000000oi8200000003003oSP0000000?m]
00800?m]00<00000003oB`00od/00P00od/00`0000000?lT003o9002003o
900600000000o`400?l1003o0@0000008Ol00P0000000`0Vo`00000004[o
000304[o00060000001_o`0000000000001co`0000000`2Ho`000`000000
_Ol00;go00020;go00040000003Uo`00iOl00>Go008000000`3om@000`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00200?ooo`04
0000003oool0oooo000000/0o`1M00<000000?l0l`3o0?<02`3o0?<00`00
0000MP3o07H0o`0<07H0o`03000000007ol001oo00h001oo00<00000002d
o`00]?l04000]?l00`0000000?nd003o]00?003o]00300000000oal00?lO
00h00?lO00<0000007Ko001fo`003@1fo`000`000000oo<00?oc000:0?oc
00030000003oG@00oed000X0oed00`3oool00`000000oooo0?ooo`0B0?oo
o`D000000P3oool2000000@0oooo0P0000050?ooo`8000001P3W0?l00`00
0000o`240?l0Q0020?l0Q0030000003F0?l0eP3o00<0eP3o00<000000?l0
b`0000001@3F0?l00`000000R@3o08T0o`0208T0o`030000002B0?l0TP3o
00<0TP3o00<0000005l0o`1O0?l00P1O0?l01P000000<P3o000000000000
H`3o000000@0>P3o00<0000001D0o`0E0?l00P0E0?l01P00000000_o0000
00000000503o000000<000co00<00000000[o`00:ol00P00:ol00`000000
04Oo0017o`0200000003000do`00000005;o00<005;o00<00000001^o`00
K_l00P00K_l200000080083o00<00000002Mo`00WOl00P00WOl00`000000
0;[o002jo`02002jo`0300000000dol00=?o00800=?o00<00000003ao`00
lOl00P00lOl01P0000000?oa0000000000000?o`000000<00?oA00<00000
003o/@00ok400P00ok400`0000000?n>003oSP02003oSP0600000000ofd0
0?m]003oK@0000000?m;0P0000000`00odH00000003o9003003o90030000
0000o`400?l100800000100Vo`000`000000B_l004[o000204[o00030000
001co`00Lol00080Lol000H0000009So002Ho`00V?l00000002mo`020000
00030;oo00000000iOl00080iOl000@000000?oe0000000000004@3oool0
0`000000oooo0?ooo`0<0?ooo`00P03oool010000000oooo0?ooo`00000;
0?l0G@030000003o0?<0o`3c00/0o`3c00<0000007H0o`1f0?l0301f0?l0
0`00000001oo000Oo`0>000Oo`0300000000]?l00;Co01000;Co00<00000
003o]000ok@03`00ok@00`0000000?lO003o7`0>003o7`030000001fo`00
M_l000`0M_l000<000000?oc003ol`002`3ol`000`000000oed00?mM000:
0?mM00<0oooo00<000000?ooo`3oool0503oool01@000000oooo0?ooo`3o
ool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`030?ooo`800000103W0?l00`000000o`240?l0Q0040?l0Q0050000
003F0?l0eP3o0=H0o`0000000P3o0</00`000000eP3o0=H0o`030=H0o`07
000000290?l0R@3o08T0o`000000cP3o000000040980o`030000001O0?l0
G`3o00<0G`3o00<0000006<0o`1S0?l00P1S0?l00`000000>P3o03X0o`02
03X0o`030000000E0?l05@3o00805@3o00<0000001@0o`0D0?l00P0D0?l0
1@00000000co000<o`003?l0000000@002_o0P000004000do`0300000000
D_l005;o008005;o00H00000001^o`0000000000001Ro`0000030020o`03
00000000WOl009go008009go00H00000002jo`0000000000002eo`000003
003Co`0300000000lOl00?7o00<00?7o00<00000003ol000oo000P00oo00
1P0000000?oA003od@00om400000003o/@80000000<00?n^00000000ohh0
0P00ohh00`0000000?m]003oK@02003oK@0300000000odH00?m600800?m6
00<00000003o9000ob@00P00ob@2000000800ol000<0000002Ko000Vo`00
0P0Vo`001P000000B_l0000000000000C_l0000000<0Lol000<0000009So
002Ho`000P2Ho`001@000000_ol00;oo002oo`00000000@0iOl000<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`00P03oool01000
0000oooo0?ooo`00000<0?l0G@030000003o0?<0o`3c00X0o`3c00<00000
07H0o`1f0?l0301f0?l00`00000001oo000Oo`0>000Oo`0300000000]?l0
0;Co01000;Co00<00000003o]000ok@03`00ok@00`0000000?lO003o7`0>
003o7`030000001fo`00M_l000`0M_l000<000000?oc003ol`002`3ol`00
0`000000oed00?mM000:0?mM00<0oooo00<000000?ooo`3oool0503oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`040?ooo`<000000P3W0?l00`000000o`24
0?l0Q0050?l0Q0040000003F0?l0eP3o000000<0o`3;00<000000=H0o`3F
0?l00`3F0?l00`000000R@3o000000030<h0o`030000002B0?l0TP3o0080
TP3o00L0000005l0o`1O0?l0G`3o0000002@0?l0000000@0H`3o00<00000
03X0o`0j0?l00P0j0?l01P0000005@3o000000000000=`3o000000<0503o
00<00000000<o`003?l00P003?l01P00000002_o00000000000001Go0000
00D003Co00<00000001Bo`00D_l00P00D_l00`00000006;o001Ro`02001R
o`0500000000P?l0083o0020o`0000001000WOl00`0000000;Go002eo`02
002eo`0500000000dol00=?o003Co`0000000P00lOl200000003003`o`00
00000?o`00800?o`00<00000003od@00om400P00om400`0000000?n^003o
[P02003o[P0600000000ohh00?n>003oSP0000000?m]0P0000000`00ofT0
0000003oAP03003oAP0600000000ob@0000000000000ob0000000`03o`00
0`0000009_l002Ko000202Ko00030000001>o`00C_l00080C_l000H00000
07?o001co`00Lol00000002Ho`020000000309[o00000000_ol00080_ol0
00H000000>Go0000000000000?ooo`00000B0?ooo`030000003oool0oooo
00`0oooo00200?ooo`040000003oool0oooo000000`0o`1M00<000000?l0
l`3o0?<02P3o0?<00`000000MP3o07H0o`0<07H0o`80000040007ol00`00
00000;Co002do`0?002do`0300000000ok@00?nd00l00?nd00<00000003o
7`00oal03P00oal00`000000M_l007Ko000<07Ko00030000003ol`00oo<0
00/0oo<000<000000?mM003oG@002P3oG@020?ooo`8000005P3oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`060?ooo`<00000203o08@00`000000eP3o0000
00040?l0b`030000003F0?l0eP3o00@0eP3o00<000000<h0o`3>0?l00`3>
0?l00`000000TP3o0980o`020980o`030000001O0?l000000080T03o00<0
000006<0o`1S0?l00`1S0?l00`000000>P3o03X0o`0203X0o`030000000g
0?l0=`3o0080=`3o00D0000001@0o`0D0?l0503o00000004000<o`030000
00005Ol001Go008001Go00<00000000do`00=?l00`00=?l01P00000005;o
00000000000004Co000000<006;o00<000000020o`00P?l00P00P?l01P00
000009go00000000000009Oo000000<00;Go00<00000003Co`00dol00P00
dol2000000@00?3o00H00000003ol000oo000?o`00000000om4200000003
003oc`0000000?n^00800?n^00<00000003oSP00ohh00P00ohh00`000000
0?mY003oJ@02003oJ@0300000000odH00?m600800?m600<00000003o8000
ob000P00ob001P0000000ol000?o0003o`00000002Ko0080000000<0:_l0
0000001>o`000P1>o`000`000000Lol007?o000207?o00050000002Jo`00
V_l009[o00000000102oo`000`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0303oool00800oooo00@00000
0?ooo`3oool00000303o05d00`000000o`3c0?l0l`0:0?l0l`030000001f
0?l0MP3o00d0MP3o00<00000000Oo`007ol03P007ol00`0000000;Co002d
o`0?002do`0300000000ok@00?nd00l00?nd00<00000003o7`00oal03P00
oal00`000000M_l007Ko000<07Ko00030000003ol`00oo<000/0oo<000<0
00000?mM003oG@002P3oG@030?ooo`030000003oool0oooo01@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool01`3oool2000000T0o`2400<000000?l0b`3o
0</0103o0</00`000000eP3o0=H0o`020=H0o`030000003o0>d0000000@0
cP3o00<000000980o`2B0?l00`2B0?l00`000000T03o0900o`020900o`03
0000001S0?l0H`3o00<0H`3o00H0000003X0o`000000000005d0o`000003
03L0o`030000000D0?l0503o0080503o00H00000000<o`000000000000/0
o`000004000Eo`0300000000=?l003Co00<003Co00D000000014o`00A?l0
04Co00000004001Ro`0300000000P?l0083o0080083o00<00000002Go`00
Uol00P00Uol01P0000000;Go002eo`00]Ol00000003Co`80000000<00=7o
00000000l?l00`00l?l00`0000000?o`003ol002003ol00300000000oll0
0?o?00800?o?00H00000003o[P00ojh00?n^00000000ohh200000003003o
R`0000000?mY00<00?mY00H00000003oAP0000000000003o@`000003003o
800300000003o`000ol000800ol000<0000002[o000Zo`000P0Zo`001P00
0000C_l004ko001>o`00000007?o0080000000<0M_l00000002Jo`000P2J
o`0010000000_ol00000000000050?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0303oool00800oooo00@000000?ooo`3oool00000
303o05d00`000000o`3c0?l0l`0;0?l0l`030000001f0?l0MP3o00`0MP3o
00<00000000Oo`007ol03P007ol00`0000000;Co002do`0?002do`030000
0000ok@00?nd00l00?nd00<00000003o7`00oal03P00oal00`000000M_l0
07Ko000<07Ko00030000003ol`00oo<000/0oo<000<000000?mM003oG@00
2P3oG@030?ooo`030000003oool0oooo01<0oooo0P0000040?ooo`800000
103oool2000000/0oooo0P0000070?l0Q0030000003o05h0000000H0o`3;
00@000000=H0o`3F0?l000000P3o0>d00`000000cP3o0<h0o`030<h0o`07
0000002B0?l0TP3o0980o`000000`P3o000000040900o`030000001S0?l0
H`3o00<0H`3o00<0000005d0o`1M0?l00P1M0?l01@000000=`3o03L0o`0g
0?l0000000@0503o00<0000000/0o`0;0?l00P0;0?l00`00000001Go000E
o`02000Eo`0300000000=?l003Co0080000000<002Go00000000A?l00P00
A?l00`00000006;o001Ro`02001Ro`0600000000P?l0000000000000N?l0
00000`00Uol00`0000000;Go002eo`02002eo`0300000000dOl00=7o0080
0=7o00<00000003`o`00l?l00P00l?l01P0000000?o`0000000000000?o_
000000<00?o?00<00000003o[P00ojh00P00ojh00`0000000?n;003oR`02
003oR`0300000000ofT00?mY00800?mY00<00000003o@`00od<00P00od<0
1P0000000?lP003o8000ob00000000?o0080000000<01_l00000000Zo`00
0`0Zo`000`000000C_l004ko0002000000<0M_l000<0000009[o002Jo`00
0P2Jo`000`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0303oool00800oooo00@000000?ooo`3oool00000
303o05d00`000000o`3c0?l0l`0;0?l0l`030000001f0?l0MP3o00`0MP3o
00<00000000Oo`007ol03P007ol00`0000000;Co002do`0?002do`030000
0000ok@00?nd00l00?nd00<00000003o7`00oal03P00oal00`000000M_l0
07Ko000<07Ko00030000003ol`00oo<000/0oo<000<000000?mM003oG@00
2P3oG@030?ooo`030000003oool0oooo02d0oooo0P0000060?l0Q0040000
003o05h0o`1N000000D0o`3;00<000000=H0o`000000103o0>d00`000000
cP3o0<h0o`030<h0o`030000002B0?l0000000<0`P3o00<000000900o`2@
0?l00P2@0?l01`000000H`3o06<0o`1S0?l0000008H0o`0000000`1M0?l0
0`000000=`3o03L0o`0203L0o`060000000D0?l000000000000]0?l00000
100;0?l00`00000001Go000Eo`02000Eo`80000010009Ol01@00000004Co
0014o`00A?l0000000@006;o00<00000001ho`00N?l00P00N?l01P000000
09Oo002Go`00Uol00000002eo`80000000<00;7o00000000dOl00`00dOl0
0`0000000?3o003`o`02003`o`0300000000onl00?o_00800?o_00H00000
003oc`00oll00?o?00000000ojh200000003003o[00000000?n;00<00?n;
00H00000003oJ@0000000000003oI@000003003o@`0300000000ob000?lP
00800?lP00<0000000Ko0006o`000P06o`000`000000:_l002[o000202[o
008000000P1Ao`001P000000M_l007Ko001fo`00000009[o008000002P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo0020
0?ooo`040000003oool0oooo000000`0o`1M00<000000?l0l`3o0?<02`3o
0?<00`000000MP3o07H0o`0<07H0o`03000000007ol001oo00h001oo00<0
0000002do`00]?l03`00]?l00`0000000?nd003o]00?003o]00300000000
oal00?lO00h00?lO00<0000007Ko001fo`00301fo`000`000000oo<00?oc
000;0?oc00030000003oG@00oed000X0oed00`3oool00`000000oooo0?oo
o`0^0?ooo`<000000`3o08@00`000000o`1N0?l0GP020?l0GP030000003o
0</0o`3;00<0o`3;00<000000?l0k@3o0>d0103o0>d00`000000cP3o0<h0
o`030<h0o`03000000320?l0`P3o0080`P3o00<000000900o`2@0?l00P2@
0?l010000000H`3o00000000000308H0o`050000001M0?l0G@3o05d0o`00
0000100g0?l00`000000;@3o02d0o`0202d0o`030000000;0?l02`3o0080
2`3o00H00000000Eo`00000000000004o`000004000Uo`0500000000A?l0
04Co0014o`0000000P00H_l200000003001Io`00000007So008007So00<0
0000002Go`00Uol00P00Uol00`0000000;7o002ao`02002ao`0300000000
dOl00=7o00800=7o00H00000003`o`0000000000003_o`000003003ok`03
00000000oll00?o?00800?o?00<00000003o[000oj`00P00oj`00`000000
0?n;003oR`02003oR`0300000000ofD00?mU00800?mU00H00000003o@`00
od<00?m300000000ob0200000003003o700000001_l000<01_l000H00000
02[o00000000000002go00000002057o00030000001fo`00M_l00080M_l0
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00200?ooo`040000003oool0oooo000000`0o`1M
00<000000?l0l`3o0?<02`3o0?<00`000000MP3o07H0o`0<07H0o`030000
00007ol001oo00h001oo00<00000002do`00]?l03`00]?l00`0000000?nd
003o]00?003o]00300000000oal00?lO00d00?lO0P00000>07Ko00030000
003ol`00oo<000/0oo<000<000000?mM003oG@002P3oG@030?ooo`030000
003oool0oooo0300oooo0P0000020?l0Q0030000003o05h0o`1N00<0o`1N
00L000000?l0b`3o0</0o`3;0000003o0:40000000H0o`3]00L000000<h0
o`3>0?l0cP3o0000003i0?l0000000@0`P3o00<000000900o`2@0?l00P2@
0?l00`000000QP3o08H0o`0308H0o`030000001M0?l0G@3o0080G@3o00H0
000003L0o`00000000000540o`00000402d0o`030000000;0?l02`3o0080
2`3o00<000000004o`001?l00P001?l00`00000002Go000Uo`02000Uo`03
00000000A?l004Co00<000001000FOl01P00000007So001ho`00N?l00000
002Go`80000000<009;o00000000/Ol00`00/Ol00`0000000=7o003Ao`02
003Ao`0300000000kol00>oo00800>oo00H00000003ok`00onl00?o_0000
0000oll200000003003ocP0000000?n/00<00?n/00H00000003oR`000000
0000003oR0000003003oI@0300000000od<00?m300800?m300<00000003o
7000oa`00P00oa`00`0000001_l000Ko000200Ko00050000000]o`00;Ol0
02go000000000`1Ao`0010000000M_l000000000000>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool02`3oool00800oooo00@00000
0?ooo`3oool00000303o05d00`000000o`3c0?l0l`0;0?l0l`030000001f
0?l0MP3o00`0MP3o00<00000000Oo`007ol03P007ol00`0000000;Co002d
o`0?002do`0300000000ok@00?nd00l00?nd00<00000003o7`00oal03@00
oal00`000000M_l007Ko000=07Ko00030000003ol`00oo<000/0oo<000<0
00000?mM003oG@002P3oG@030?ooo`030000003oool0oooo0340oooo0`00
00070?l0GP030000003o0</0000000<0o`2Q00<000000?l0k@3o0>d00`3o
0>d010000000cP3o0000000000030?T0o`03000000320?l0`P3o0080`P3o
00H000000900o`00000000000;80o`00000508H0o`030000001M0?l0G@3o
0080G@3o00<000000540o`1A0?l00P1A0?l00`000000;@3o02d0o`0202d0
o`060000000;0?l000000000000M0?l0000010001?l00`00000002Go000U
o`02000Uo`8000000P00>Ol00`00000005Wo001Io`02001Io`0300000000
N?l007So008007So00<00000002Bo`00T_l00P00T_l2000000<00;7o00H0
0000003Ao`0000000000003?o`000004003_o`0300000000onl00?o_0080
00001000olh00`0000000?n/003o[002003o[00300000000ohP00?n80080
0?n800H00000003oI@00ofD00?mU00000000od<200000003003o@0000000
0?lL00<00?lL00H0000000Ko00000000000000Wo0000000302go00050000
001Ao`00DOl0057o000000004@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00/0oooo00200?ooo`040000003oool0oooo000000`0
o`1M00<000000?l0l`3o0?<02`3o0?<00`000000MP3o07H0o`0<07H0o`80
00003`007ol00`0000000;Co002do`0?002do`0300000000ok@00?nd00l0
0?nd00<00000003o7`00oal03@00oal2000000h0M_l000<000000?oc003o
l`002`3ol`000`000000oed00?mM000:0?mM00<0oooo00<000000?ooo`3o
ool0<P3oool2000000P0o`1N00<000000?l0X@3o0:400`3o0:400`000000
o`3]0?l0k@030?l0k@030000003i0?l0n@3o00<0n@3o00<000000<80o`32
0?l00`320?l00`000000/P3o0;80o`020;80o`03000000260?l0QP3o00<0
QP3o00H0000005d0o`000000000007P0o`0000040540o`030000000]0?l0
;@3o0080;@3o00<0000001d0o`0M0?l00P0M0?l00`00000000Co0004o`02
0004o`06000000009Ol00000000000006?l000000`00>Ol2000000<005Wo
00H00000001ho`0000000000001bo`000005002Bo`0300000000/Ol00;7o
008000001000col00`0000000>oo003_o`02003_o`8000000P00onl00`00
00000?o>003ocP02003ocP0600000000oj`0000000000000ojX000000`00
ohP00`0000000?mU003oI@02003oI@0300000000od000?m000800?m000<0
0000003o7000oa`00P00oa`01@0000002Ol000Wo0009o`00000000<0;Ol0
00@00000057o0000000000004`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00/0oooo00200?ooo`040000003oool0oooo000000`0
o`1M00<000000?l0l`3o0?<02`3o0?<00`000000MP3o07H0o`0<07H0o`03
000000007ol001oo00h001oo00<00000002do`00]?l03`00]?l00`000000
0?nd003o]00>003o]08000003`00oal00`000000M_l007Ko000<07Ko0080
00003@3ol`000`000000oed00?mM000:0?mM0080oooo0P00000e0?ooo`80
00001P3o05h00`000000o`1>000000050?l0X@070000003o0>d0o`3]0?l0
k@000000o`3:000000050?T0o`07000000320?l0`P3o0<80o`000000hP3o
000000040;80o`80000010260?l00`000000N03o07P0o`0207P0o`030000
001A0?l0D@3o0080D@3o00H0000002d0o`00000000000400o`00000401d0
o`03000000001?l000Co008000Co00<00000000Ho`006?l00P006?l00`00
000003Wo000io`02000io`0300000000FOl005Wo008000001000L_l20000
00@009;o0P000002002^o`0300000000col00<oo00800<oo00H00000003_
o`0000000000003_o`000003003ok`0300000000olh00?o>00800?o>00<0
0000003oZP00ojX00P00ojX01P0000000?n8003oR000ohP00000003oI@80
000000<00?mS00000000od000`00od001P0000000?lL0000000000000?lJ
000000<02Ol000D0000002go000]o`00;Ol00000000E0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02`3oool00800oooo00@00000
0?ooo`3oool00000303o05d00`000000o`3c0?l0l`0;0?l0l`030000001f
0?l0MP3o00`0MP3o00<00000000Oo`007ol03P007ol00`0000000;Co002d
o`0?002do`0300000000ok@00?nd00h00?nd00<00000003o7`00oal03P00
oal00`000000M_l007Ko000<07Ko00030000003ol`00oo<000`0oo<000<0
00000?mM003oG@002P3oG@030?ooo`030000003oool0oooo03@0oooo0P00
00050?l0GP040000003o04h0o`1>000000D0o`2Q00<000000?l0k@000000
0`3o0<X00`000000n@3o0?T0o`030?T0o`03000000320?l0000000<0hP3o
00<000000;80o`2b0?l00`2b0?l01P000000QP3o000000000000X03o0000
00@0N03o00<000000540o`1A0?l00P1A0?l00`000000@03o0400o`020400
o`030000000M0?l07@3o00807@3o00H000000004o`000000000000P0o`00
0004000Ho`0300000000>Ol003Wo008003Wo0P000002001Ao`0300000000
L_l007;o00<007;o00H00000002Bo`0000000000002>o`000003002^o`03
00000000col00<oo00800<oo00<00000003_o`00kol00P00kol01P000000
0?o_003ok`00onl00000003ocP80000000<00?o<00000000ojX00P00ojX0
0`0000000?n8003oR002003oR00300000000of<00?mS00800?mS00<00000
003o@000od000P00od001@0000000?lJ003o6P00oaX0000000<02Ol000@0
000002go0000000000005`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00/0oooo00200?ooo`040000003oool0oooo000000`0o`1M
00<000000?l0l`3o0?<02`3o0?<00`000000MP3o07H0o`0=07H0o`030000
00007ol001oo00d001oo00<00000002do`00]?l03`00]?l00`0000000?nd
003o]00>003o]00300000000oal00?lO00h00?lO00<0000007Ko001fo`00
301fo`000`000000oo<00?oc000;0?oc00030000003oG@00oed000/0oed0
0`3oool00`000000oooo0?ooo`0f0?ooo`8000000P3o05h00`000000o`1>
0?l0CP020?l0CP030000003o0:40o`2Q00<0o`2Q00<000000?l0bP3o0<X0
0`3o0<X2000000@0n@3o00<000000>80o`3R0?l00`3R0?l00`000000/P3o
0;80o`030;80o`030000002P0?l0X03o0080X03o00<0000007P0o`1h0?l0
0P1h0?l01P000000D@3o000000000000I@3o000000@0@03o00<0000001d0
o`0M0?l00P0M0?l00`000000203o00P0o`0200P0o`03000000006?l001So
008001So00H00000000io`0000000000000`o`000003001Ao`8000001000
L_l00`00000008ko002>o`02002>o`0600000000[_l00:ko002^o`000000
0<oo0P0000000`00c_l00000003_o`02003_o`0300000000onl00?o_0080
0?o_00<00000003oc000ol`00P00ol`01P0000000?nZ003oZP00ojX00000
003oR080000000<00?n600000000of<00`00of<01P0000000?m000000000
00000?ln000000<00?lJ00D0000000Wo0009o`002Ol00000000J0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool00800oooo
00@000000?ooo`3oool00000303o05d00`000000o`3c0?l0l`0;0?l0l`03
0000001f0?l0MP3o00d0MP3o00<00000000Oo`007ol03@007ol00`000000
0;Co002do`0?002do`0300000000ok@00?nd00h00?nd00<00000003o7`00
oal03P00oal00`000000M_l007Ko000<07Ko00030000003ol`00oo<000/0
oo<000<000000?mM003oG@002`3oG@030?ooo`030000003oool0oooo03L0
oooo0P0000000`3o05h000000?l0CP040?l0CP070000003o0:40o`2Q0?l0
X@000000o`2:000000060?l0bP060000003i0?l000000000003o0>X00000
1@3R0?l01`000000/P3o0;80o`2b0?l000000</0o`000000102P0?l00`00
0000N03o07P0o`0207P0o`030000001U0?l0I@3o0080I@3o00<000000400
o`100?l00P100?l01P0000007@3o000000000000:`3o000000@0203o00<0
0000000Ho`006?l00P006?l00`000000033o000`o`02000`o`0300000000
DOl0057o0080057o00H00000001bo`0000000000001]o`000003002>o`03
00000000[_l00:ko00800:ko00<00000003>o`00c_l00P00c_l01P000000
0>oo003_o`00kol00000003ok`80000000<00?o_00000000ol`00`00ol`0
0`0000000?nZ003oZP02000000@00?n600<00000003oH`00of<00P00of<0
1@0000000?ln003o?P00och0000000<00?lJ00@0000000Wo000000000000
703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo
00200?ooo`040000003oool0oooo000000`0o`1M00<000000?l0l`3o0?<0
2`3o0?<00`000000MP3o07H0o`0=07H0o`03000000007ol001oo00d001oo
00<00000002do`00]?l03`00]?l00`0000000?nd003o]00>003o]0030000
0000oal00?lO00h00?lO00<0000007Ko001fo`00301fo`000`000000oo<0
0?oc000;0?oc00030000003oG@00oed000/0oed00`3oool00`000000oooo
0?ooo`0h0?ooo`8000001`3o04h00`000000o`2Q000000030?l0RP030000
003o0<X0o`3:00@0o`3:00<000000?l0jP3o0>X00P3o0>X00`000000hP3o
0>80o`030>80o`030000002b0?l0000000<0b`3o00<000000:00o`2P0?l0
0P2P0?l01P000000N03o000000000000R`3o000000@0I@3o00<000000400
o`100?l00P100?l00`000000:`3o02/0o`0202/0o`03000000080?l0203o
0080203o00H00000000Ho`0000000000000>o`000004000`o`0300000000
DOl0057o0080057o00<00000001]o`00KOl00P00KOl01P00000008ko002>
o`00S_l00000002^o`80000000<00:co00000000c_l00P00c_l00`000000
0>oo003_o`02003_o`0300000000onl00?o_00800?o_00<00000003oc000
ol`00P00ol`2000000800?nY00<00000003oQP00ohH00P00ohH01P000000
0?mS0000000000000?mQ000000<00?ln00<00000003o6P00oaX00P00000N
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool0
0800oooo00@000000?ooo`3oool00000303o05d00`000000o`3c0?l0l`0<
0?l0l`030000001f0?l0MP3o00`0MP3o00<00000000Oo`007ol03@007ol0
0`0000000;Co002do`0?002do`0300000000ok@00?nd00h00?nd00<00000
003o7`00oal03P00oal00`000000M_l007Ko000<07Ko00030000003ol`00
oo<000/0oo<000<000000?mM003oG@002`3oG@030?ooo`030000003oool0
oooo03T0oooo0`0000060?l0CP030000003o08X0o`2:00<0o`2:0P000003
0?l0bP030000003o0;@0000000@0o`3Z00<000000>80o`3R0?l00`3R0?l0
0`000000b`3o0</0o`020</0o`030000002P0?l0X03o00<0X03o00<00000
08/0o`2;0?l00P2;0?l00`000000I@3o06D0o`0206D0o`06000000100?l0
00000000001?0?l00000100[0?l00`000000203o00P0o`0200P0o`030000
00003_l000ko008000ko00<00000000`o`00<?l00P00<?l01P000000057o
00000000000004_o000000<006go00<00000002>o`00S_l00P00S_l00`00
00000:co002/o`02002/o`0600000000c_l00<ko003>o`0000000>oo0P00
00000`00kol00000003ok`03003ok`0600000000ol`0000000000000ol`0
00000`00ojT00`0000000?n6003oQP02003oQP0500000000of400?mQ003o
H@0000001000och200000240oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0:0?ooo`00P03oool010000000oooo0?ooo`00000<0?l0
G@030000003o0?<0o`3c00`0o`3c00<0000007H0o`1f0?l0301f0?l00`00
000001oo000Oo`0=000Oo`0300000000]?l00;Co00l00;Co00<00000003o
]000ok@03P00ok@00`0000000?lO003o7`0>003o7`030000001fo`00M_l0
00`0M_l000<000000?oc003ol`002`3ol`000`000000oed00?mM000;0?mM
00<0oooo00<000000?ooo`3oool0>P3oool3000000@0o`1>00<000000?l0
AP0000001P3o08X00`000000o`3:000000030?l0]0030000003o0>X0o`3Z
0080o`3Z00<000000>80o`3R0?l00P0000000`3i0?l000000</0o`030</0
o`070000002P0?l0X03o0:00o`000000/`3o0000000408/0o`030000001U
0?l0I@3o0080I@3o00<0000004l0o`1?0?l00P1?0?l00`000000:`3o02/0
o`0202/0o`06000000080?l000000000000C0?l0000010003_l00`000000
033o000`o`02000`o`0300000000Bol004_o008004_o00H00000001]o`00
KOl006go00000000S_l200000003002;o`0000000:co00800:co00<00000
003>o`00c_l00P00c_l00`0000000>oo003_o`02003_o`0300000000onl0
0?o_00800?o_00<00000003oc000ol`00P00ol`01P0000000?nY003oZ@00
ojT00000003oQP80000000<00?n500000000of400P00of40100000000?ln
00000000000T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02P3oool00800oooo00@000000?ooo`3oool00000303o05d00`000000
o`3c0?l0l`0<0?l0l`030000001f0?l0MP3o00`0MP3o00<00000000Oo`00
7ol03@007ol00`0000000;Co002do`0?002do`0300000000ok@00?nd00h0
0?nd00<00000003o7`00oal03P00oal00`000000M_l007Ko000<07Ko0003
0000003ol`00oo<000/0oo<000<000000?mM003oG@002`3oG@030?ooo`03
0000003oool0oooo03`0oooo0`0000000`3o04h000000?l0AP020?l0AP03
0000003o08X0o`2:00@0o`2:00<000000?l0]03o0;@00P3o0;@00`000000
o`3Z0?l0jP030?l0jP800000103i0?l00`000000b`3o0</0o`020</0o`03
0000002P0?l0000000<0/`3o00<0000008/0o`2;0?l00P2;0?l01P000000
I@3o000000000000M03o000000@0C`3o00<0000002/0o`0[0?l00P0[0?l0
0`0000004`3o01<0o`0201<0o`03000000003_l000ko008000ko00H00000
000`o`0000000000000Yo`000003001;o`0300000000KOl006go008006go
00<00000002;o`00Rol00P00Rol01P0000000:co002/o`00[?l00000003>
o`80000000<00<co00000000kol00`00kol01P0000000?o_000000000000
0?o^000000<00?o<00<00000003oZ@00ojT00P00ojT01@0000000?n5003o
Q@00ohD0000000@00?mQ00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00X0oooo00200?ooo`040000003o
ool0oooo000000`0o`1M00<000000?l0l`3o0?<0303o0?<00`000000MP3o
07H0o`0<07H0o`03000000007ol001oo00h001oo00<00000002do`00]?l0
3P00]?l00`0000000?nd003o]00>003o]00300000000oal00?lO00h00?lO
00<0000007Ko001fo`00301fo`000`000000oo<00?oc000;0?oc00030000
003oG@00oed000/0oed00P3oool2000003l0oooo00<000000?ooo`000000
1@3o04H2000000<0o`2:00<000000?l0N`000000103o0;@01`000000o`3Z
0?l0jP3o0>X000000?l0e`0000001@3i0?l00`000000b`3o0</0o`020</0
o`030000002c0?l0/`3o0080/`3o00<0000008/0o`2;0?l00`2;0?l00`00
0000M03o07@0o`0207@0o`030000001?0?l0C`3o0080C`3o00H0000002/0
o`000000000003H0o`00000401<0o`03000000003_l000ko008000ko00<0
0000000Yo`00:Ol00P00:Ol01P00000004_o001;o`00Bol00000001]o`80
000000<006Wo00000000Rol00P00Rol00`0000000:co002/o`02002/o`03
00000000c?l00<co00800<co00<00000003_o`00kol00P00kol00`000000
0?o^003okP02003okP0600000000ol`00?o<003oc00000000?nY0P000000
0`00ojP00000003oQ@02003oQ@0400000000of400000000002P0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0:0?ooo`00P03oool0
10000000oooo0?ooo`00000<0?l0G@030000003o0?<0o`3c00`0o`3c00<0
000007H0o`1f0?l0301f0?l00`00000001oo000Oo`0>000Oo`0300000000
]?l00;Co00h00;Co00<00000003o]000ok@03P00ok@00`0000000?lO003o
7`0=003o7`030000001fo`00M_l000d0M_l000<000000?oc003ol`002`3o
l`000`000000oed00?mM000;0?mM00<0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo000000060?l0AP030000003o08X0000000<0o`1k00<0
00000?l0]03o0;@00P3o0;@00`000000o`3Z000000030?l0e`030000003i
0?l0n@3o00<0n@3o00H000000</0o`00000000000=d0o`0000040;<0o`07
0000002;0?l0R`3o08/0o`000000VP3o0000000407@0o`030000001?0?l0
C`3o0080C`3o00<0000003H0o`0f0?l00P0f0?l00`0000004`3o01<0o`02
01<0o`06000000003_l00000000000001ol000000`00:Ol00`00000004_o
001;o`02001;o`0300000000JOl006Wo008006Wo00H00000002;o`00Rol0
08_o00000000[?l200000003002Zo`0000000<co00<00<co00H00000003_
o`0000000000003^o`000003003okP0300000000ol`00?o<00800?o<00<0
0000003oZ000ojP00P00ojP01@0000000?n5003oQ@00ohD0000002/0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`00P03o
ool010000000oooo0?ooo`00000<0?l0G@030000003o0?<0o`3c00`0o`3c
00<0000007H0o`1f0?l0301f0?l00`00000001oo000Oo`0>000Oo`030000
0000]?l00;Co00h00;Co00<00000003o]000ok@03P00ok@00`0000000?lO
003o7`0=003o7`030000001fo`00M_l000d0M_l000<000000?oc003ol`00
2`3ol`000`000000oed00?mM000;0?mM00<0oooo00<000000?ooo`3oool0
?`3oool3000000H0o`1600<000000?l0N`3o07/00`3o07/00`000000o`2d
0?l0]0020?l0]0030000003o0=L0o`3G00<0o`3G0P0000040?T0o`030000
003M0?l0g@3o0080g@3o00<000000;<0o`2c0?l00P2c0?l00`000000R`3o
0000000309X0o`030000001d0?l0M03o0080M03o00H0000004l0o`000000
000005X0o`00000403H0o`030000000C0?l04`3o00804`3o00<000000007
o`001ol00P001ol01P00000002Wo000Yo`00:Ol00000001;o`80000000<0
04Ko00000000JOl00`00JOl00`00000008_o002;o`02000000@00:[o00<0
0000003<o`00c?l00P00c?l00`0000000>ko003^o`02003^o`0600000000
onh00?o^003okP0000000?o<0P0000000`00ol/00000003oZ003003oZ003
00000000ohD0000002d0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0:0?ooo`00P03oool010000000oooo0?ooo`00000<0?l0G@80
00003@3o0?<00`000000MP3o07H0o`0<07H0o`03000000007ol001oo00h0
01oo00<00000002do`00]?l03P00]?l00`0000000?nd003o]00>003o]003
00000000oal00?lO00d00?lO00<0000007Ko001fo`003@1fo`000`000000
oo<00?oc000;0?oc00030000003oG@00oed000/0oed00`3oool00`000000
oooo0?ooo`110?ooo`800000103o04H00`000000o`11000000050?l0N`06
0000003o0;@000000000003o0:D000001P3o0=L01P000000n@3o00000000
0000o`3g000000@0g@3o00<000000;<0o`2c0?l00P2c0?l00`000000VP3o
09X0o`0309X0o`030000001d0?l0M03o0080M03o00<0000005X0o`1J0?l0
0P1J0?l00`000000=P3o03H0o`0203H0o`060000000C0?l000000000000K
0?l000000`001ol00`00000002Wo000Yo`02000Yo`0300000000A_l004Ko
008004Ko00<00000001Yo`00JOl00P00JOl20000008008So00<00000002Z
o`00Z_l00P00Z_l01P0000000<co0000000000000<co000000@00>ko00<0
0000003okP00onh00P000004003ob`0300000000ojP00?nX00800?nX00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00X0oooo00200?ooo`040000003oool0oooo000000d0o`1M00<0
00000?l0l`3o0?<02`3o0?<00`000000MP3o07H0o`0<07H0o`0300000000
7ol001oo00h001oo00<00000002do`00]?l03P00]?l00`0000000?nd003o
]00>003o]00300000000oal00?lO00d00?lO00<0000007Ko001fo`003@1f
o`000`000000oo<00?oc000;0?oc00030000003oG@00oed000/0oed00`3o
ool00`000000oooo0?ooo`120?ooo`80000000<0o`160000000000000`3o
04400`000000o`1k0?l0N`030?l0N`030000003o0:D0o`2U0080o`2U00<0
00000?l0e`3o0=L0103o0=L00`000000o`3g0?l0m`020?l0m`030000003M
0?l0g@3o0080g@3o00H000000;<0o`00000000000<80o`00000509X0o`06
0000001d0?l000000000001o0?l00000101J0?l00`000000=P3o03H0o`02
03H0o`030000000K0?l06`3o00806`3o00H000000007o`001ol000Oo0000
0000:Ol200000003000To`00000004Ko00<004Ko00H00000001Yo`000000
0000001Uo`0000030028o`0300000000Z_l00:[o00800:[o00<00000003<
o`00c?l00P00c?l00`0000000>ko003^o`02003^o`8000000P00onh00`00
00000?o;003ob`02003ob`0400000000ojP0000000000300oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`00K@3oool50000
0080oooo0P0000040?ooo`800000103oool010000000oooo0?ooo`00000=
0?l0G@030000003o0?<0o`3c00/0o`3c00<0000007H0o`1f0?l0301f0?l0
0`00000001oo000Oo`0>000Oo`0300000000]?l00;Co00h00;Co00<00000
003o]000ok@03P00ok@00`0000000?lO003o7`0=003o7`030000001fo`00
M_l000d0M_l000<000000?oc003ol`002`3ol`000`000000oed00?mM000;
0?mM00<0oooo00<000000?ooo`3oool0@`3oool2000000H0o`1100L00000
0?l0N`3o07/0o`1k0000003o0780000000@0o`2U0P0000030?l0e`030000
003o0<T0000000@0o`3g00<000000=d0o`3M0?l00P3M0?l00`000000`P3o
0<80o`020<80o`800000102J0?l00`000000O`3o07l0o`0207l0o`030000
001J0?l0FP3o0080FP3o00H0000003H0o`000000000003l0o`00000301/0
o`03000000001ol000Oo008000Oo00<00000000To`009?l00P009?l00`00
000004Ko0016o`020016o`0300000000IOl006Go008006Go00H000000028
o`00R?l008So00000000Z_l200000003002Yo`0000000<co00<00<co00H0
0000003^o`0000000000003^o`000003003okP0300000000ol/00?o;0080
0?o;00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00T0oooo001_0?ooo`030000003oool0oooo00L0oooo
00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00000=0?l0
G@030000003o0?<0o`3c00/0o`3c00<0000007H0o`1f0?l0301f0?l00`00
000001oo000Oo`0>000Oo`0300000000]?l00;Co00h00;Co00<00000003o
]000ok@03P00ok@00`0000000?lO003o7`0=003o7`030000001fo`00M_l0
00`0M_l000<000000?oc003ol`00303ol`000`000000oed00?mM000;0?mM
00<0oooo00<000000?ooo`3oool0A03oool2000000H0o`1100<000000?l0
N`0000000`3o07800`000000o`2U0?l0Y@030?l0Y@030000003o0=L00000
00<0o`3900<000000?l0m`3o0?L00P3o0?L01P000000g@3o000000000000
jP3o000000D0`P3o00H0000009X0o`00000000000:D0o`00000407l0o`03
0000001J0?l0FP3o0080FP3o00<0000003l0o`0o0?l00P0o0?l01P000000
6`3o01/0o`0K0?l000000007o`80000000<0007o000000009?l00`009?l0
1P00000004Ko00000000000004?o000000<006Go00<000000028o`00R?l0
0P00R?l00`0000000:Wo002Yo`02002Yo`0300000000c?l00<co00800<co
00<00000003^o`00k_l00P00k_l01P0000000?o^003okP00onh00000003o
b`800000=03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00T0oooo001_0?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3o
ool0oooo0P0000000`3oool000000?l0G@0<0?l0G@030000003o0?<0o`3c
00/0o`3c00<0000007H0o`1f0?l03@1f0?l00`00000001oo000Oo`0=000O
o`0300000000]?l00;Co00h00;Co00<00000003o]000ok@03P00ok@00`00
00000?lO003o7`0=003o7`030000001fo`00M_l000`0M_l000<000000?oc
003ol`00303ol`000`000000oed00?mM000;0?mM0080oooo0P0000170?oo
o`8000001P3o04400`000000o`1b0?l0LP030?l0LP800000103o0:D00`00
0000o`390?l0b@030?l0b@030000003o0?L0o`3g0080o`3g00<000000>X0
o`3Z0?l00P3Z0?l2000000@0`P3o00<000000:D0o`2U0?l00P2U0?l00`00
0000O`3o07l0o`0207l0o`060000001J0?l000000000001S0?l000000`0o
0?l00`0000006`3o01/0o`0201/0o`03000000000Ol0007o0080007o00<0
0000000To`009?l00P009?l00`00000004?o0013o`020013o`0600000000
IOl006Go001Uo`00000008So0P0000000`00Q_l00000002Yo`03002Yo`06
00000000c?l0000000000000bol000000`00k_l00`0000000?o^003okP02
003okP030000003oool0oooo03D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`00K`3oool00`000000oooo0?ooo`080?oo
o`800000103oool010000000oooo0?ooo`00000=0?l0G@030000003o0?<0
o`3c00/0o`3c00<0000007H0o`1f0?l03@1f0?l00`00000001oo000Oo`0=
000Oo`0300000000]?l00;Co00h00;Co00<00000003o]000ok@03P00ok@0
0`0000000?lO003o7`0=003o7`030000001fo`00M_l000`0M_l000<00000
0?oc003ol`00303ol`000`000000oed00?mM000;0?mM00<0oooo00<00000
0?ooo`3oool0A`3oool2000000<0o`1100<000000?l0?P0000001P3o0780
1P000000o`2U000000000000o`2K000000D0o`3900H000000?l0m`000000
00000?l0j`0000050>X0o`06000000320?l000000000003<0?l00000102U
0?l00`000000O`3o07l0o`0207l0o`030000001S0?l0H`3o0080H`3o00H0
000003l0o`0o0?l0?`3o0000000K0?l2000000030240o`000000007o00<0
007o00H00000000To`0000000000000Po`0000030013o`0300000000IOl0
06Go008006Go00<000000026o`00Q_l00P00Q_l00`0000000:Wo002Yo`02
002Yo`0300000000bol00<_o00800<_o00H00000003^o`00k_l00>ko0000
0000onh2000003T0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`00
K`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool000003@3o05d00`000000o`3c0?l0l`0;0?l0l`03
0000001f0?l0MP3o00d0MP3o00<00000000Oo`007ol03@007ol00`000000
0;Co002do`0>002do`0300000000ok@00?nd00h00?nd00<00000003o7`00
oal03@00oal00`000000M_l007Ko000<07Ko00030000003ol`00oo<000`0
oo<000<000000?mM003oG@002`3oG@030?ooo`030000003oool0oooo04P0
oooo0P0000000`3o044000000?l0?P020?l0?P030000003o0780o`1b00@0
o`1b00<000000?l0V`3o09/00P3o09/2000000@0o`3900<000000?l0j`3o
0>/00P3o0>/00`000000jP3o0>X0o`030>X0o`030000003<0?l0c03o0080
c03o00<000000:D0o`2U0?l00P2U0?l01P000000O`3o000000000000R03o
000000@0H`3o00<0000003l0o`0o0?l00P0000040240o`03000000000Ol0
007o0080007o00<00000000Po`008?l00P008?l20000008004?o00H00000
001Uo`0000000000001So`0000040026o`0600000000ZOl0000000000000
Z?l000001000bol00`0000000>ko003^o`02000003`0oooo00@000000?oo
o`3oool000002`3oool006h0oooo0P00000:0?ooo`<000000`3oool01000
0000oooo0?ooo`00000=0?l0G@030000003o0?<0o`3c00/0o`3c00<00000
07H0o`1f0?l03@1f0?l00`00000001oo000Oo`0=000Oo`0300000000]?l0
0;Co00h00;Co00<00000003o]000ok@03P00ok@00`0000000?lO003o7`0=
003o7`030000001fo`00M_l000`0M_l000<000000?oc003ol`00303ol`00
0`000000oed00?mM000;0?mM00<0oooo00<000000?ooo`3oool0B@3oool2
000000D0o`0n00<000000?l0LP3o07800P3o07800`000000o`1/00000005
0?l0V`060000003o0<T000000000003o0<000000103o0>/01`000000jP3o
0>X0o`3Z0?l000000?@0o`000000103<0?l00`000000Y@3o0:D0o`020:D0
o`03000000280?l0R03o0080R03o00<0000006<0o`1S0?l00P1S0?l20000
0080A@3o00<000000240o`0Q0?l00P0Q0?l01P000000007o000000000000
0`3o000000D0023o00@000000013o`00@ol000001000Hol00`00000008Ko
0026o`020026o`0300000000Z?l00:So00800:So00<00000003;o`00bol0
0P00bol2000003h0oooo00@000000?ooo`3oool000002`3oool00800oooo
00@000000?ooo`3oool000003@3o05d00`000000o`3c0?l0l`0;0?l0l`03
0000001f0?l0MP3o00d0MP3o00<00000000Oo`007ol03@007ol00`000000
0;Co002do`0>002do`0300000000ok@00?nd00h00?nd00<00000003o7`00
oal03@00oal00`000000M_l007Ko000<07Ko00030000003ol`00oo<000`0
oo<000<000000?mM003oG@002`3oG@030?ooo`030000003oool0oooo04X0
oooo0P0000050?l0?P040000003o07800000000000<0o`1/00<000000?l0
V`3o09/00`3o09/00`000000o`300?l0`0020?l0`0030000003o0>/0o`3[
0080o`3[00<000000>X0o`0000000`3d0?l00`000000c03o0<`0o`020<`0
o`060000002U0?l000000000002^0?l0000010280?l01P000000H`3o0000
00000000JP3o000000<0A@3o00<000000240o`0Q0?l00P0Q0?l00`000000
0`3o00<0o`0200<0o`80000010008?l2000000030010o`00000006?o00<0
06?o00H000000026o`00000000000025o`000004002Xo`0400000000bol0
000000000440oooo00<000000?ooo`0000002`3oool00800oooo00@00000
0?ooo`3oool000003@3o05d00`000000o`3c0?l0l`0;0?l0l`030000001f
0?l0MP3o00d0MP3o00<00000000Oo`007ol03@007ol00`0000000;Co002d
o`0>002do`0300000000ok@00?nd00h00?nd00<00000003o7`00oal03@00
oal00`000000M_l007Ko000<07Ko00030000003ol`00oo<000`0oo<000<0
00000?mM003oG@002`3oG@030?ooo`030000003oool0oooo04/0oooo0`00
00040?l0?P030000003o06`0o`1/00@0o`1/00L000000?l0V`3o09/0o`2K
0000003o09@0000000@0o`3000<000000?l0j`3o0>/00P3o0>/00`000000
m03o0?@0o`030?@0o`030000003<0?l0c03o0080c03o00<000000:h0o`2^
0?l00P2^0?l00`000000R03o08P0o`0208P0o`030000001Z0?l0JP3o0080
JP3o00H0000004D0o`150?l0A@3o0000000Q0?l20000000302H0o`000000
0`3o00@00`3o00H00000000Po`0000000000000Lo`0000020010o`030000
0000Hol006?o008006?o00<000000025o`00QOl00P00QOl00`0000000:So
002Xo`02002Xo`030000003oool0oooo0480oooo00<000000?ooo`000000
2P3oool00800oooo00@000000?ooo`3oool000003@3o05d00`000000o`3c
0?l0l`0;0?l0l`8000003P1f0?l00`00000001oo000Oo`0=000Oo`030000
0000]?l00;Co00h00;Co00<00000003o]000ok@03P00ok@00`0000000?lO
003o7`0=003o7`030000001fo`00M_l000`0M_l000<000000?oc003ol`00
303ol`000`000000oed00?mM000;0?mM00<0oooo00<000000?ooo`3oool0
C@3oool2000000040?l0?P00000000000?l0?08000001@3o06`00`000000
o`2K000000030?l0U0030000003o0<00o`300080o`3000H000000?l0j`00
000000000?l0hP0000050?@0o`060000003<0?l000000000003D0?l00000
102^0?l01P000000R03o000000000000S`3o000000@0JP3o00D0000004D0
o`150?l0A@3o0000000402H0o`80000010030?l00`00000001co000Lo`02
000Lo`0500000000@?l0043o00000000Hol00P0000000`00HOl000000025
o`030025o`0400000000Z?l00000000004H0oooo0P00000:0?ooo`00P03o
ool010000000oooo0?ooo`00000=0?l0G@030000003o0?<0o`3c00`0o`3c
00<0000007H0o`1f0?l0301f0?l00`00000001oo000Oo`0=000Oo`030000
0000]?l00;Co00h00;Co00<00000003o]000ok@03@00ok@00`0000000?lO
003o7`0>003o7`030000001fo`00M_l000`0M_l000<000000?oc003ol`00
303ol`000`000000oed00?mM000;0?mM00<0oooo00<000000?ooo`3oool0
CP3oool2000000D0o`0l00<000000?l0K03o06`00`3o06`00`000000o`2D
0?l0U0030?l0U0030000003o0<00o`300080o`3000<000000?l0hP3o0>80
0P3o0>82000000@0m03o00<000000=@0o`3D0?l00P3D0?l00`000000[P3o
0:h0o`020:h0o`030000002?0?l0S`3o0080S`3o00<0000006X0o`1Z0?l0
0P1Z0?l01@000000A@3o0000001:0?l0000000D09P3o00H0000000<0o`00
0000000000H0o`000003000Lo`0500000000@?l0043o0010o`0000001000
HOl00`00000008Go0025o`020025o`030000003oool0oooo04H0oooo0P00
000:0?ooo`00P03oool010000000oooo0?ooo`00000=0?l0G@030000003o
0?<0o`3c00`0o`3c00<0000007H0o`1f0?l0301f0?l00`00000001oo000O
o`0=000Oo`0300000000]?l00;Co00h00;Co00<00000003o]000ok@03@00
ok@00`0000000?lO003o7`0>003o7`030000001fo`00M_l000`0M_l000<0
00000?oc003ol`00303ol`000`000000oed00?mM000;0?mM0080oooo0P00
001A0?ooo`<00000103o03`2000000050?l0K000000000000?l0I`000000
1@3o09@01P000000o`30000000000000o`2i000000D0o`3R00H000000?@0
o`00000000000?/0o`0000040=@0o`060000002^0?l000000000002d0?l0
0000102?0?l00`000000JP3o06X0o`0206X0o`040000001:0?l0BP3o04X0
o`800000100V0?l00`0000001P3o00H0o`0200H0o`09000000007?l001co
000Lo`000000043o00000000?_l0000000@0067o00@000000025o`000000
0000B@3oool2000000X0oooo00200?ooo`040000003oool0oooo000000d0
o`1M00<000000?l0l`3o0?<0303o0?<00`000000MP3o07H0o`0<07H0o`03
000000007ol001oo00d001oo00<00000002do`00]?l03P00]?l00`000000
0?nd003o]00=003o]00300000000oal00?lO00h00?lO00<0000007Ko001f
o`00301fo`000`000000oo<00?oc000<0?oc00030000003oG@00oed000/0
oed00`3oool00`000000oooo0?ooo`1@0?ooo`<000001@3o03`00`000000
o`1W0?l0I`020?l0I`800000103o09@00`000000o`2i0?l0^@020?l0^@80
0000103o0>800`000000n`3o0?/0o`020?/0o`030000003D0?l0e03o0080
e03o00<000000;@0o`2d0?l00P2d0?l00`000000S`3o08l0o`0208l0o`06
0000001Z0?l000000000001_0?l00000101:0?l01P0000009P3o00000000
0000:P3o000000@01P3o00<00000000Lo`007?l00P000003000no`030000
0000HOl0067o0080067o00<000000?ooo`3oool0A@3oool4000000`0oooo
00200?ooo`040000003oool0oooo000000d0o`1M00<000000?l0l`3o0?<0
303o0?<00`000000MP3o07H0o`0<07H0o`03000000007ol001oo00d001oo
00<00000002do`00]?l03P00]?l00`0000000?nd003o]00=003o]0030000
0000oal00?lO00d00?lO0P00000>07Ko00030000003ol`00oo<000`0oo<0
00<000000?mM003oG@002`3oG@030?ooo`030000003oool0oooo0580oooo
0`0000001@3o03`000000000003o03/0000000D0o`1W00H000000?l0U000
000000000?l0S`0000050?l0^@060000003o0>8000000000003o0=`00000
103k0?l01P000000e03o000000000000fP3o000000@0]03o00<0000008l0
o`2?0?l00P2?0?l00`000000K`3o06l0o`0206l0o`030000001:0?l0BP3o
0080BP3o00<0000002X0o`0Z0?l00P0Z0?l00`0000001P3o00H0o`0200H0
o`8000000P006_l01P00000003ko000no`00?_l00000001Qo`800000A03o
ool400000100oooo00200?ooo`040000003oool0oooo000000d0o`1M00<0
00000?l0l`3o0?<0303o0?<00`000000MP3o07H0o`0<07H0o`0300000000
7ol001oo00d001oo00<00000002do`00]?l03P00]?l00`0000000?nd003o
]00=003o]00300000000oal00?lO00d00?lO00<0000007Ko001fo`003@1f
o`000`000000oo<00?oc000<0?oc00030000003oG@00oed000/0oed00`3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0000000@0o`0k0P00
00040?l0I`030000003o08l0o`2?0080o`2?0P0000040?l0^@030000003o
0=`0o`3L0080o`3L00<000000?/0o`3k0?l00P3k0?l00`000000fP3o0=X0
o`020=X0o`030000002d0?l0]03o0080]03o00H0000008l0o`0000000000
09@0o`00000406l0o`060000001:0?l000000000001>0?l00000100Z0?l0
1P0000001P3o0000000000002@3o000000<001[o00D00000000no`00?_l0
03ko000000120?ooo`@00000503oool00800oooo00@000000?ooo`3oool0
00003@3o05d00`000000o`3c0?l0l`0<0?l0l`030000001f0?l0MP3o00`0
MP3o00<00000000Oo`007ol03@007ol00`0000000;Co002do`0>002do`03
00000000ok@00?nd00d00?nd00<00000003o7`00oal03@00oal00`000000
M_l007Ko000=07Ko00030000003ol`00oo<000`0oo<000<000000?mM003o
G@002`3oG@030?ooo`030000003oool0oooo05@0oooo00<000000?ooo`00
00001@3o03/01P000000o`1W000000000000o`1T000000D0o`2?00H00000
0?l0^@00000000000?l0]00000040?l0g0060000003k0?l000000000003o
0?h00000103J0?l00`000000]03o0;@0o`020;@0o`030000002D0?l0U03o
0080U03o00<0000006l0o`1_0?l00P1_0?l00`000000CP3o04h0o`0204h0
o`030000000Z0?l0:P3o0080:P3o00<0000000T0o`090?l00P090?l01`00
000001[o000Jo`006_l00000000no`000000?`3oool4000001P0oooo0020
0?ooo`040000003oool0oooo000000d0o`1M00<000000?l0l`3o0?<0303o
0?<00`000000MP3o07H0o`0<07H0o`03000000007ol001oo00d001oo00<0
0000002do`00]?l03P00]?l00`0000000?nd003o]00=003o]00300000000
oal00?lO00d00?lO00<0000007Ko001fo`003@1fo`000`000000oo<00?oc
000<0?oc00030000003oG@00oed000/0oed00`3oool00`000000oooo0?oo
o`1E0?ooo`040000003oool00000000000@0o`0k00<000000?l0I03o06@0
0P3o06@2000000@0o`2?00<000000?l0]03o0;@00P3o0;@00`000000o`3L
0?l0g0020?l0g0030000003o0?h0o`3n0080o`3n00<000000=X0o`3J0?l0
0P3J0?l01P000000]03o000000000000^@3o000000@0U03o00H0000006l0
o`000000000007<0o`00000404h0o`060000000Z0?l000000000000]0?l0
000010090?l00`00000001[o000Jo`02000003d0oooo0`00000L0?ooo`00
P03oool010000000oooo0?ooo`00000=0?l0G@030000003o0?<0o`3c00`0
o`3c00<0000007H0o`1f0?l0301f0?l00`00000001oo000Oo`0=000Oo`03
00000000]?l00;Co00h00;Co00<00000003o]000ok@03@00ok@00`000000
0?lO003o7`0=003o7`030000001fo`00M_l000d0M_l000<000000?oc003o
l`00303ol`000`000000oed00?mM000;0?mM00<0oooo00<000000?ooo`3o
ool0EP3oool2000000030?ooo`000000o`0k0080000000<0o`0j0000003o
06@0103o06@01P000000o`2?000000000000o`2;000000@0o`2d00H00000
0?l0g000000000000?l0e`0000040?l0oP030000003J0?l0fP3o0080fP3o
00<000000;T0o`2i0?l00P2i0?l00`000000U03o09@0o`0209@0o`030000
001c0?l0L`3o0080L`3o00<0000004h0o`1>0?l00P1>0?l00`000000;@3o
02d0o`0202d0o`03000000090?l02@3o00802@3o0P00000k0?ooo`@00000
7`3oool00800oooo00@000000?ooo`3oool000003@3o05d00`000000o`3c
0?l0l`0<0?l0l`030000001f0?l0MP3o00`0MP3o00<00000000Oo`007ol0
3@007ol00`0000000;Co002do`0>002do`0300000000ok@00?nd00d00?nd
00<00000003o7`00oal03@00oal00`000000M_l007Ko000=07Ko00030000
003ol`00oo<000`0oo<000<000000?mM003oG@002`3oG@030?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`000000103o03X2000000@0o`1T
00<000000?l0R`3o08/00P3o08/2000000<0o`2d00<000000?l0e`3o0=L0
0P3o0=L00`000000o`3n0?l0oP020?l0oP060000003J0?l000000000003O
0?l00000102i0?l01P000000U03o000000000000V03o000000@0L`3o00H0
000004h0o`00000000000540o`00000402d0o`04000000090?l000000000
03T0oooo1000000S0?ooo`00P03oool010000000oooo0?ooo`00000=0?l0
G@030000003o0?<0o`3c00`0o`3c00<0000007H0o`1f0?l0301f0?l00`00
000001oo000Oo`0=000Oo`0300000000]?l00;Co00h00;Co00<00000003o
]000ok@03@00ok@00`0000000?lO003o7`0=003o7`030000001fo`00M_l0
00d0M_l000<000000?oc003ol`002`3ol`000`000000oed00?mM000<0?mM
0080oooo0P00001K0?ooo`030000003oool0000000D0o`0j00H000000?l0
I000000000000?l0HP0000050?l0R`050000003o0;@000000?l0/0000000
103o0=L00`000000o`3n0?l0oP020?l0oP030000003O0?l0g`3o0080g`3o
00<000000;T0o`2i0?l00P2i0?l00`000000V03o09P0o`0209P0o`030000
001c0?l0L`3o0080L`3o00<000000540o`1A0?l00P1A0?l00`000000;@3o
02d0o`0202d0o`030000003oool0oooo03D0oooo1000000W0?ooo`00P03o
ool010000000oooo0?ooo`00000=0?l0G@030000003o0?<0o`3c00`0o`3c
00<0000007H0o`1f0?l0301f0?l00`00000001oo000Oo`0=000Oo`030000
0000]?l00;Co00h00;Co00<00000003o]000ok@03@00ok@00`0000000?lO
003o7`0=003o7`030000001fo`00M_l000d0M_l000<000000?oc003ol`00
2`3ol`000`000000oed00?mM000<0?mM00<0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo000000050?l0>P030000003o0680o`1R0080o`1R
0P0000040?l0R`040000003o0;00o`2`0?l0/08000000`3o0=L01P000000
o`3n000000000000o`3j000000@0g`3o00H000000;T0o`00000000000;d0
o`00000409P0o`060000001c0?l000000000001f0?l00000101A0?l01000
0000;@3o00000000000d0?ooo`@00000:`3oool00800oooo00@000000?oo
o`3oool000003@3o05d00`000000o`3c0?l0l`0<0?l0l`030000001f0?l0
MP3o00`0MP3o00<00000000Oo`007ol03@007ol00`0000000;Co002do`0>
002do`0300000000ok@00?nd00d00?nd00<00000003o7`00oal03@00oal0
0`000000M_l007Ko000=07Ko00030000003ol`00oo<000/0oo<000<00000
0?mM003oG@00303oG@030?ooo`030000003oool0oooo05/0oooo00<00000
0?ooo`0000000`3o03X00`000000o`0i000000050?l0HP060000003o08/0
00000000003o08P00000103o0;000`000000o`3G0?l0e`02000000@0o`3j
00<000000=l0o`3O0?l00P3O0?l00`000000_@3o0;d0o`020;d0o`030000
002H0?l0V03o0080V03o00<0000007H0o`1f0?l00P1f0?l00`000000D@3o
0540o`020540o`030000003oool0oooo0300oooo1000000_0?ooo`00P03o
ool010000000oooo0?ooo`00000=0?l0G@030000003o0?<0o`3c00`0o`3c
00<0000007H0o`1f0?l0301f0?l00`00000001oo000Oo`0=000Oo`030000
0000]?l00;Co00h00;Co00<00000003o]000ok@03@00ok@00`0000000?lO
003o7`0=003o7`030000001fo`00M_l000d0M_l000<000000?oc003ol`00
2`3ol`000`000000oed00?mM000<0?mM00<0oooo00<000000?ooo`3oool0
G03oool3000000030?l0>P000000o`0i0080o`0i0P0000040?l0HP030000
003o08P0o`280080o`2800<000000?l0/03o0;000P3o0;0200000080o`3D
00<000000?l0nP3o0?X00P3o0?X01P000000g`3o000000000000hP3o0000
00@0_@3o00H0000009P0o`000000000009X0o`00000407H0o`040000001A
0?l0000000000300oooo0`00000c0?ooo`00P03oool010000000oooo0?oo
o`00000=0?l0G@030000003o0?<0o`3c00`0o`3c00<0000007H0o`1f0?l0
301f0?l2000000h001oo00<00000002do`00]?l03P00]?l00`0000000?nd
003o]00=003o]00300000000oal00?lO00d00?lO00<0000007Ko001fo`00
301fo`02000000d0oo<000<000000?mM003oG@00303oG@030?ooo`030000
003oool0oooo05h0oooo0P0000060?l0>@060000003o068000000000003o
06000000103o08P01P000000o`2`000000000000o`2]000000<0o`3D00<0
00000?l0nP3o0?X00P3o0?X00`000000hP3o0>80o`020>80o`8000000`2m
0?l00`000000VP3o09X0o`0209X0o`030000001f0?l0MP3o0080MP3o00<0
00000?ooo`3oool0;03oool4000003H0oooo00200?ooo`040000003oool0
oooo000000d0o`1M00<000000?l0l`3o0?<0303o0?<00`000000MP3o07H0
o`0=07H0o`03000000007ol001oo00`001oo00<00000002do`00]?l03P00
]?l00`0000000?nd003o]00=003o]00300000000oal00?lO00d00?lO00<0
000007Ko001fo`00301fo`000`000000oo<00?oc000<0?oc00030000003o
G@00oed000`0oed00`3oool00`000000oooo0?ooo`1O0?ooo`8000001P3o
03T00`000000o`1P0?l0H0020?l0H0030000003o08P0o`280080o`2800<0
00000?l0[@3o0:d00P3o0:d200000080o`3D00H000000?l0nP0000000000
0?l0m`0000050>80o`050000002m0?l000000;l0o`000000102J0?l01000
0000MP3o00000000000[0?ooo`@00000>P3oool00800oooo00@000000?oo
o`3oool000003@3o05d00`000000o`3c0?l0l`0<0?l0l`030000001f0?l0
MP3o00d0MP3o00<00000000Oo`007ol03@007ol00`0000000;Co002do`0=
002do`0300000000ok@00?nd00d00?nd00<00000003o7`00oal03@00oal0
0`000000M_l007Ko000<07Ko00030000003ol`00oo<000`0oo<000<00000
0?mM003oG@00303oG@030?ooo`030000003oool0oooo0600oooo0`000003
0?l0>@030000003o03P0000000@0o`1P00H000000?l0R000000000000?l0
QP0000050?l0[@040000003o0=@0o`3D000000@0o`3g0P0000040>80o`04
0000002o0?l0_`3o0;l0o`8000000`2J0?l00`000000oooo0?ooo`0W0?oo
o`@00000?P3oool00800oooo00@000000?ooo`3oool000003@3o05d00`00
0000o`3c0?l0l`0<0?l0l`030000001f0?l0MP3o00d0MP3o00<00000000O
o`007ol03@007ol00`0000000;Co002do`0=002do`0300000000ok@00?nd
00d00?nd00<00000003o7`00oal03@00oal00`000000M_l007Ko000<07Ko
00030000003ol`00oo<000`0oo<000<000000?mM003oG@00303oG@030?oo
o`030000003oool0oooo0640oooo00D000000?ooo`000000o`0i00000003
0?l0>0030000003o0600o`1P0080o`1P00<000000?l0QP3o08H00P3o08H2
000000@0o`2]0P0000000`3o0=400000000000040?l0m`060000003R0?l0
00000000003U0?l00000102o0?l00`000000VP3o0000000V0?ooo`@00000
@P3oool00800oooo00@000000?ooo`3oool000003@3o05d00`000000o`3c
0?l0l`0<0?l0l`030000001f0?l0MP3o00d0MP3o00<00000000Oo`007ol0
3@007ol00`0000000;Co002do`0=002do`0300000000ok@00?nd00d00?nd
00<00000003o7`00oal03@00oal00`000000M_l007Ko000<07Ko00030000
003ol`00oo<000`0oo<000<000000?mM003oG@00303oG@020?ooo`800000
I03oool3000000D0o`0h00H000000?l0H000000000000?l0G`0000050?l0
QP060000003o0:d000000000003o0:/000000`3o0=4200000080o`3g0P00
00040>D0o`8000000P2o0?l2000002@0oooo0`0000160?ooo`00P03oool0
10000000oooo0?ooo`00000=0?l0G@030000003o0?<0o`3c00`0o`3c00<0
000007H0o`1f0?l03@1f0?l00`00000001oo000Oo`0=000Oo`0300000000
]?l00;Co00d00;Co00<00000003o]000ok@03@00ok@00`0000000?lO003o
7`0=003o7`030000001fo`00M_l000`0M_l000<000000?oc003ol`00303o
l`000`000000oed00?mM000<0?mM00<0oooo00<000000?ooo`3oool0I03o
ool3000000@0o`0h00<000000?l0G`3o05l00P3o05l2000000@0o`2600<0
00000?l0Z`3o0:/00P3o0:/00`000000o`3A0?l0d@020?l0d@8000000P3o
0?D00`000000i@3o0>D0o`030>D0o`8000008P3oool4000004T0oooo0020
0?ooo`040000003oool0oooo000000d0o`1M00<000000?l0l`3o0?<0303o
0?<00`000000MP3o07H0o`0=07H0o`03000000007ol001oo00d001oo00<0
0000002do`00]?l03@00]?l00`0000000?nd003o]00=003o]00300000000
oal00?lO00d00?lO00<0000007Ko001fo`00301fo`000`000000oo<00?oc
000<0?oc00030000003oG@00oed000`0oed00`3oool00`000000oooo0?oo
o`1U0?ooo`080000003oool000000000003o03P000000?l0>00000050?l0
G`060000003o08H000000000003o08D00000103o0:/01P000000o`3A0000
00000000o`3?000000<0o`3e0P0000000`3U0?l000000000000P0?ooo`@0
0000C@3oool00800oooo00@000000?ooo`3oool000003@3o05d00`000000
o`3c0?l0l`0<0?l0l`030000001f0?l0MP3o00d0MP3o00<00000000Oo`00
7ol03@007ol00`0000000;Co002do`0=002do`0300000000ok@00?nd00d0
0?nd00<00000003o7`00oal03@00oal00`000000M_l007Ko000<07Ko0003
0000003ol`00oo<000`0oo<000<000000?mM003oG@00303oG@030?ooo`03
0000003oool0oooo06H0oooo00@000000?ooo`3oool000000`3o03P20000
00@0o`1O00<000000?l0Q@3o08D00P3o08D00`000000o`2[0?l0Z`020?l0
Z`030000003o0<l0o`3?0080o`3?00<000000?l0m@3o0?D00P3o0?D00`00
0000oooo0?ooo`0L0?ooo`@00000D@3oool00800oooo00@000000?ooo`3o
ool000003@3o05d00`000000o`3c0?l0l`0<0?l0l`030000001f0?l0MP3o
00d0MP3o00<00000000Oo`007ol03@007ol00`0000000;Co002do`0=002d
o`0300000000ok@00?nd00d00?nd00<00000003o7`00oal03@00oal00`00
0000M_l007Ko000<07Ko00030000003ol`00oo<000`0oo<000<000000?mM
003oG@00303oG@030?ooo`030000003oool0oooo06L0oooo0P0000000`3o
ool000000?l0>0030?l0>0060000003o05l000000000003o05h00000103o
08D01P000000o`2[000000000000o`2Y000000@0o`3?00@000000?l0m@00
000000006`3oool4000005D0oooo00200?ooo`040000003oool0oooo0000
00d0o`1M00<000000?l0l`3o0?<0303o0?<00`000000MP3o07H0o`0=07H0
o`03000000007ol001oo00d001oo00<00000002do`00]?l03@00]?l00`00
00000?nd003o]00=003o]00300000000oal00?lO00d00?lO00<0000007Ko
001fo`00301fo`000`000000oo<00?oc000<0?oc00030000003oG@00oed0
00`0oed00`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool00000
00@0o`0h00<000000?l0GP3o05h00P3o05h00`000000o`250?l0Q@020?l0
Q@030000003o0:T0o`2Y0080o`2Y00<000000?l0c`3o0<l00P3o0<l00`00
0000oooo0?ooo`0H0?ooo`<00000F@3oool00800oooo00@000000?ooo`3o
ool000003@3o05d00`000000o`3c0?l0l`0<0?l0l`030000001f0?l0MP3o
00d0MP3o00<00000000Oo`007ol03@007ol00`0000000;Co002do`0=002d
o`0300000000ok@00?nd00d00?nd00<00000003o7`00oal03@00oal00`00
0000M_l007Ko000<07Ko00030000003ol`00oo<000`0oo<000<000000?mM
003oG@00303oG@030?ooo`030000003oool0oooo06X0oooo00@000000?oo
o`000000o`0h0P0000000`3o03L000000?l0GP030?l0GP060000003o08D0
00000000003o08<00000103o0:T010000000o`3?00000000000G0?ooo`@0
0000G03oool00800oooo00@000000?ooo`3oool000003@3o05d00`000000
o`3c0?l0l`0<0?l0l`030000001f0?l0MP3o00d0MP3o00<00000000Oo`00
7ol03@007ol00`0000000;Co002do`0=002do`0300000000ok@00?nd00d0
0?nd00<00000003o7`00oal03@00oal00`000000M_l007Ko000<07Ko0003
0000003ol`00oo<000`0oo<000<000000?mM003oG@00303oG@020?ooo`80
0000K@3oool00`000000oooo000000040?l0=`8000000`3o05h00`000000
o`230?l0P`020?l0P`8000000`3o0:T00`000000oooo0?ooo`0C0?ooo`@0
0000H03oool00800oooo00@000000?ooo`3oool000003@3o05d00`000000
o`3c0?l0l`0<0?l0l`030000001f0?l0MP3o00d0MP3o00<00000000Oo`00
7ol03@007ol00`0000000;Co002do`0=002do`0300000000ok@00?nd00d0
0?nd00<00000003o7`00oal03@00oal00`000000M_l007Ko000<07Ko0003
0000003ol`00oo<000`0oo<000<000000?mM003oG@00303oG@030?ooo`03
0000003oool0oooo06`0oooo00<000000?ooo`0000001@3o03L01@000000
o`1N0000003o05d0000000D0o`2300<000000?l0Z@0000004P3oool40000
06@0oooo00200?ooo`040000003oool0oooo000000d0o`1M00<000000?l0
l`3o0?<0303o0?<00`000000MP3o07H0o`0=07H0o`03000000007ol001oo
00d001oo00<00000002do`00]?l03@00]?l00`0000000?nd003o]00=003o
]00300000000oal00?lO00d00?lO00<0000007Ko001fo`00301fo`000`00
0000oo<00?oc000<0?oc00030000003oG@00oed000`0oed00`3oool00`00
0000oooo0?ooo`1]0?ooo`@00000103o03L010000000o`1M0?l0G@3o05d2
000000@0o`2300<000000?ooo`3oool03@3oool4000006P0oooo00200?oo
o`040000003oool0oooo000000d0o`1M00<000000?l0l`3o0?<0303o0?<2
000000h0MP3o00<00000000Oo`007ol03@007ol00`0000000;Co002do`0=
002do`0300000000ok@00?nd00d00?nd00<00000003o7`00oal03@00oal0
0`000000M_l007Ko000<07Ko00030000003ol`00oo<000`0oo<000<00000
0?mM003oG@00303oG@030?ooo`030000003oool0oooo06l0oooo00@00000
0?ooo`000000o`0g0P0000000`3o03L000000?l0G@030?l0G@040000003o
08<00000000000`0oooo1000001/0?ooo`00P03oool010000000oooo0?oo
o`00000=0?l0G@030000003o0?<0o`3c00d0o`3c00<0000007H0o`1f0?l0
301f0?l00`00000001oo000Oo`0=000Oo`0300000000]?l00;Co00d00;Co
00<00000003o]000ok@03@00ok@00`0000000?lO003o7`0=003o7`030000
001fo`00M_l000`0M_l000<000000?oc003ol`00303ol`000`000000oed0
0?mM000<0?mM00<0oooo00<000000?ooo`3oool0L03oool00`000000oooo
000000040?l0=`030000003o05d0o`1M0080o`1M00<000000?ooo`3oool0
2@3oool300000700oooo00200?ooo`040000003oool0oooo000000d0o`1M
00<000000?l0l`3o0?<03@3o0?<00`000000MP3o07H0o`0<07H0o`030000
00007ol001oo00d001oo00<00000002do`00]?l03@00]?l00`0000000?nd
003o]00=003o]00300000000oal00?lO00d00?lO00<0000007Ko001fo`00
301fo`000`000000oo<00?oc000<0?oc00030000003oG@00oed000`0oed0
0`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0000000@0o`0g
00@000000?l0G@0000000000203oool4000007<0oooo001i0?ooo`@00000
0`3oool010000000oooo0?ooo`00000=0?l0G@030000003o0?<0o`3c00d0
o`3c00<0000007H0o`1f0?l0301f0?l00`00000001oo000Oo`0=000Oo`03
00000000]?l00;Co00d00;Co00<00000003o]000ok@03@00ok@00`000000
0?lO003o7`0=003o7`030000001fo`00M_l000`0M_l000<000000?oc003o
l`00303ol`000`000000oed00?mM000<0?mM00<0oooo00<000000?ooo`3o
ool0LP3oool010000000oooo0000000000020?l0=`8000001P3oool40000
07L0oooo001i0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3o
ool000003P3o05d00`000000o`3c0?l0l`0<0?l0l`030000001f0?l0MP3o
00`0MP3o00<00000000Oo`007ol03@007ol00`0000000;Co002do`0=002d
o`0300000000ok@00?nd00d00?nd00<00000003o7`00oal03@00oal00`00
0000M_l007Ko000<07Ko00030000003ol`00oo<000`0oo<000<000000?mM
003oG@00303oG@030?ooo`030000003oool0oooo07<0oooo0P0000000`3o
ool00000000000040?ooo`@00000N`3oool007X0oooo00<000000?ooo`3o
ool00`3oool2000000030?ooo`000000o`1M00d0o`1M00<000000?l0l`3o
0?<0303o0?<00`000000MP3o07H0o`0<07H0o`03000000007ol001oo00d0
01oo00<00000002do`00]?l03@00]?l00`0000000?nd003o]00=003o]003
00000000oal00?lO00d00?lO00<0000007Ko001fo`00301fo`000`000000
oo<00?oc000<0?oc00030000003oG@00oed000`0oed00P3oool2000007L0
oooo0P0000000`3oool0000000000002000007l0oooo001k0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0W@3oool00`000000oooo
0?ooo`1f0?ooo`800000P`3oool007T0oooo00@000000?ooo`3oool00000
0`3oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00L000000?ooo`3oool0oooo0000003oool000000?d0oooo001j
0?ooo`800000103ooonQ00000?d0oooo003o0?ooool0oooo803oool00?l0
ooooo`3ooolP0?ooo`00o`3ooooo0?ooob00oooo003o0?ooool0oooo803o
ool00?l0ooooo`3ooolP0?ooo`00o`3ooooo0?ooob00oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{542, 189},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The result of Example 10.13 shows that the function  \n\n\t\t\t\
",
  Cell[BoxData[{
      \(\(\(w\ \  = \ \ \(u + \ \[ImaginaryI]\ v\ \  = \ \ sin\ z\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\ \ \)\(sin\ x\ cosh\ y\ \  + \ \ \[ImaginaryI]\ cos\
\ x\ \ sinh\ y\)\)\)}]],
  "   \n\nis a conformal mapping of the semi-infinite strip  ",
  Cell[BoxData[
      \(\(-\(\[Pi]\/2\)\) < x < \[Pi]\/2, y > 0\)]],
  "  onto the upper half-plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe new problem in the w plane is to find the electrical potential  ",
  Cell[BoxData[
      RowBox[{"\[CapitalPhi]", 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  "  that satisfies the boundary values  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalPhi]", 
            RowBox[{"(", 
              RowBox[{"u", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], " ", "=", "     ",
           "0"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", \(for\ \ \ u > 1\), ",", 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"\[CapitalPhi]", 
            RowBox[{"(", 
              RowBox[{"u", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], " ", "=", "   ", 
          "50"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", \(for\ \ \  - 1 < u < 1\), ",", 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"\[CapitalPhi]", 
            RowBox[{"(", 
              RowBox[{"u", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}], " ", "=", " ", 
          "100"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", \(for\ \ \ u < \(-1. \)\)}]]],
  " "
}], "Text"],

Cell[TextData[{
  "This is a three-value Dirichlet problem in the upper half-plane defined by \
 ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  ".  For the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane, the solution in Equation ",
  StyleBox["(11-5)",
    FontColor->RGBColor[0, 0, 1]],
  " becomes  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalPhi]", 
            RowBox[{"(", 
              RowBox[{"u", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "v"}], ")"}]}], "  ", "=", 
          "  ", \(a\_2\ \  + \ \ \(1\/\[Pi]\) \(\[Sum]\+\(k = 1\)\%2\((a\_\(k \
- 1\) - a\_k)\)\ Arg\ \((w - u\_k)\)\)\)}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{"\[CapitalPhi]", 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], "  ", "=", 
        "  ", \(a\_2\ \  + \ \ \(a\_0 - a\_1\)\/\[Pi]\ Arg\ \((w - 
                u\_1)\)\  + \ \ \(a\_1 - a\_2\)\/\[Pi]\ Arg\ \((w - 
                u\_2)\)\)}]}]],
  "\n\nHere we have  ",
  Cell[BoxData[
      RowBox[{\(a\_0 = 100\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(a\_1 = 50\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(and\ \ a\_2 = 0\)}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{\(u\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(and\ \ u\_2 = 1\)}]]],
  ",  which we substitute into the above equation for  ",
  Cell[BoxData[
      RowBox[{"\[CapitalPhi]", 
        RowBox[{"(", 
          RowBox[{"u", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "v"}], ")"}]}]]],
  "  to obtain  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"\[CapitalPhi]", 
            RowBox[{"(", 
              RowBox[{"u", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "v"}], ")"}]}], "  ", "=", 
          "  ", \(0\  + \ \(100 - 50\)\/\[Pi]\ Arg\ \((w - \((\(-1\))\))\)\  \
+ \ \ \(50 - 0\)\/\[Pi]\ Arg\ \((w - 1)\)\)}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        "                 ", \(\(=\)\(\ \ \ \)\(50\/\[Pi]\ Arg\ \((w + 
                  1)\)\ \  + \ \ 50\/\[Pi]\ Arg\ \((w - 1)\)\)\), 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{
        "                 ", \(\(=\)\(\ \ \)\(50\/\[Pi]\ Arg\ \((u + 
                  1 + \[ImaginaryI]\ v)\)\ \  + \ \ 50\/\[Pi]\ Arg\ \((u - 
                  1 + \[ImaginaryI]\ v)\)\)\), "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        "                 ", \(\(=\)\(\ \ \)\(50\/\[Pi]\ Arctan\ \((v\/\(u + \
1\))\)\ \  + \ \ 50\/\[Pi]\ Arctan\ \((v\/\(u - 1\))\)\)\)}]}]],
  "    "
}], "Text"],

Cell[TextData[{
  "Now make the substitutions  ",
  Cell[BoxData[
      RowBox[{"u", " ", "=", " ", 
        RowBox[{
          RowBox[{"u", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(sin\ x\ cosh\ y\)}]}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{"v", " ", "=", " ", 
        RowBox[{
          RowBox[{"v", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
          " ", \(cos\ x\ \ sinh\ y\)}]}]]],
  "  to get the solultion  ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  in the z plane  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Phi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
        "  ", \(\(\(\(50\)\(\ \)\)\/\[Pi]\) 
            Arg \((1 + 
                sin \((x + \[ImaginaryI]\ y)\))\)\ \  + \ \ \(\(\(50\)\(\ \
\)\)\/\[Pi]\) Arg \((\(-1\) + sin \((x + \[ImaginaryI]\ y)\))\)\)}]]],
  " \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Phi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
        "  ", \(50\/\[Pi]\ Arctan\ \((\(cos\ x\ \ sinh\ y\)\/\(1 + sin\ x\ \
cosh\ y\))\)\ \  + \ \ 50\/\[Pi]\ Arctan\ \((\(cos\ x\ \ sinh\ y\)\/\(\(-1\) \
+ sin\ x\ cosh\ y\))\)\)}]]]
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.42",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/electrostatics/\
ElectrostaticsFigures/mat1142.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The electrical potential ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " in the semi-infinite strip ",
  Cell[BoxData[
      \(\(-\(\[Pi]\/2\)\) < x < \[Pi]\/2, y > 0\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the boundary values in the w plane and construct the Dirichlet sum.\
\>", "Text"],

Cell[BoxData[{
    \(a = \(u = \(v = \(w = 0\)\)\); \ 
    Remove[a, u, v, w];\ \), "\[IndentingNewLine]", 
    \(\(Clear[a, u, v, w, \[Phi]];\)\ \), "\n", 
    \(\(x\_1\  = \ \(-1\);\)\ \), "\n", 
    \(\(x\_2\  = \ \ 1;\)\ \), "\n", 
    \(\(a\_0\  = \ \ 100;\)\ \), "\n", 
    \(\(a\_1\  = \ \ 50;\)\ \), "\n", 
    \(\(a\_2\  = \ \ 0;\)\ \), "\n", 
    \(\(w\  = \ u\  + \ \[ImaginaryI]\ v;\)\ \), "\n", 
    \(\(\[CapitalPhi][u_, v_] = 
        a\_2 + \(1\/\[Pi]\) \((a\_0 - a\_1)\) 
            Arg[w - x\_1] + \(1\/\[Pi]\) \((a\_1 - a\_2)\) 
            Arg[w - x\_2];\)\ \), "\n", 
    \(\(Print["\<\[CapitalPhi][u,v] = \>", \[CapitalPhi][u, 
          v]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "First use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(cont = Table[k, {k, 0, 100, 10}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[CapitalPhi][u, 
          v], {u, \(-\(\[Pi]\/2\)\), \[Pi]\/2}, {v, 0.000001, 2}, 
        Contours \[Rule] cont, PlotPoints \[Rule] 35, 
        AspectRatio \[Rule] 1\/2, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[CapitalPhi][u,v] = \>", \[CapitalPhi][u, 
          v]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The contours are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[CapitalPhi][u, v] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Then use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot3D[\[CapitalPhi][u, v], {u, \(-2\), 2}, {v, 0.00001, 2}, 
        PlotPoints \[Rule] {41, 16}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>", "\<\[CapitalPhi]\>"}, 
        ColorFunction \[Rule] Hue];\)\ \), "\n", 
    \(\(Print["\<\[CapitalPhi][u,v] = \>", \[CapitalPhi][u, 
          v]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The function  ",
  Cell[BoxData[
      \(\[CapitalPhi][u, v] = 
        50\/\[Pi]\ Arctan\ \((v\/\(u + 1\))\)\ \  + \ \ 50\/\[Pi]\ Arctan\ \
\((v\/\(u - 1\))\)\)]],
  " is harmonic in the upper half-plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  ",  and takes on the desired boundary values."
}], "Text"],

Cell["\<\
Construct the solution in the z plane with a conformal mapping.  \
\>", "Text"],

Cell[BoxData[{
    \(z = 0; \ Remove[z];\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, F, \[Phi], \[CapitalPhi]];\)\ \), "\n", 
    \(\(f[z_]\  = \ Sin[z];\)\ \), "\n", 
    \(\(\[CapitalPhi][u_, 
          v_]\  = \ \(\(\(50\)\(\ \)\)\/\[Pi]\) 
            Arg[u - 1 + \[ImaginaryI]\ v] + \(\(\(50\)\(\ \)\)\/\[Pi]\) 
            Arg[u + 1 + \[ImaginaryI]\ v];\)\), "\[IndentingNewLine]", 
    \(\(W\  = \ \ ComplexExpand[f[x\  + \ \[ImaginaryI]\ y]];\)\ \), "\n", 
    \(\(U\  = \ 
        Together[
          ComplexExpand[Re[W], 
            TargetFunctions \[Rule] {Re, Im}]];\)\ \), "\n", 
    \(\(\(V\  = \ 
          Together[
            ComplexExpand[Im[W], 
              TargetFunctions \[Rule] {Re, Im}]];\)\ ;\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ \[CapitalPhi][U, V];\)\ \), "\n", 
    \(\(Print["\<w = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<w = u + \[ImaginaryI] v = \>", 
        U\  + \ \[ImaginaryI]\ V];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[CapitalPhi][u,v] = \>", \[CapitalPhi][u, 
          v]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[x,y] = \>", U];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<v[x,y] = \>", V];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \[CapitalPhi][u(x,y),v(x,y)]\>"];\)\ \), "\n", \

    \(\(Print["\<\[Phi][x,y] = \[CapitalPhi][\>", U, "\<,\>", 
        V, "\<]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi][x_, y_]\  = 
        FullSimplify[\[Phi][x, y]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi][x_, y_]\  = Expand[\[Phi][x, y]];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the equipotentials. "
}], "Text"],

Cell[BoxData[{
    \(\(cont = Table[k, {k, 0, 100, 10}];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Phi][x, y], {x, \(-\(\[Pi]\/2\)\), \[Pi]\/2}, {y, 
          0.001, 2}, 
        Contours\  \[Rule] \ cont, \[IndentingNewLine]PlotPoints \[Rule] 60, 
        AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, y]];\)\ \), "\n", 
    \(\(Print["\<The contours are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[Phi][x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Then use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a 3D plot of the solution."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot3D[\[Phi][x, y], {x, \(-\(\[Pi]\/2\)\), \[Pi]\/2}, {y, 0.001, 2}, 
        PlotPoints \[Rule] {41, 16}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>", "\<\[Phi]\>"}, 
        ColorFunction \[Rule] Hue];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The function  ",
  Cell[BoxData[
      \(\[Phi] \((x, y)\) = \(\(\(50\)\(\ \)\)\/\[Pi]\) 
            Arg \((\(-1\) + 
                sin \((x + \[ImaginaryI]\ y)\))\)\  + \ \(\(\(50\)\(\ \)\)\/\
\[Pi]\) Arg \((1 + sin \((x + \[ImaginaryI]\ y)\))\)\)]],
  " is harmonic in the upper half-plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  ",  and takes on the desired boundary values."
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Dirichlet Problem",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/DirichletProblemBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Poisson Integral",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/PoissonIntegralBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Electrostatics",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ElectrostaticsBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Steady State Temperature",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/TemperaturesBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Potential",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexPotentialBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{978, 650},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 458898, 9045}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 125, 2, 33, "Text"],
Cell[2230, 66, 13716, 391, 432, "Text",
  Evaluatable->False],
Cell[15949, 459, 1240, 39, 94, "Text",
  Evaluatable->False],
Cell[17192, 500, 42203, 695, 169, 42089, 691, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[59420, 1199, 113, 2, 33, "Text"],
Cell[59536, 1203, 289, 6, 105, "Text"],
Cell[59828, 1211, 400, 9, 124, "Input"],
Cell[60231, 1222, 246, 8, 33, "Text",
  Evaluatable->False],
Cell[60480, 1232, 503, 11, 190, "Input"],
Cell[60986, 1245, 146, 5, 33, "Text"],
Cell[61135, 1252, 740, 14, 190, "Input"],
Cell[61878, 1268, 268, 8, 33, "Text"]
}, Closed]],
Cell[62161, 1279, 1195, 36, 49, "Text",
  Evaluatable->False],
Cell[63359, 1317, 33716, 556, 169, 33602, 552, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[97078, 1875, 5811, 159, 457, "Text"],
Cell[102892, 2036, 416, 14, 33, "Text"],

Cell[CellGroupData[{
Cell[103333, 2054, 113, 2, 33, "Text"],
Cell[103449, 2058, 348, 8, 124, "Text"],
Cell[103800, 2068, 513, 10, 146, "Input"],
Cell[104316, 2080, 226, 7, 33, "Text",
  Evaluatable->False],
Cell[104545, 2089, 628, 14, 230, "Input"],
Cell[105176, 2105, 146, 5, 33, "Text"],
Cell[105325, 2112, 743, 14, 190, "Input"],
Cell[106071, 2128, 298, 8, 47, "Text"]
}, Closed]],
Cell[106384, 2139, 4967, 141, 104, "Text",
  Evaluatable->False],
Cell[111354, 2282, 44541, 733, 254, 44427, 729, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[155898, 3017, 8219, 222, 527, "Text"],
Cell[164120, 3241, 432, 12, 52, "Text"],

Cell[CellGroupData[{
Cell[164577, 3257, 113, 2, 33, "Text"],
Cell[164693, 3261, 63, 0, 33, "Text"],
Cell[164759, 3263, 643, 13, 186, "Input"],
Cell[165405, 3278, 62, 0, 33, "Text"],
Cell[165470, 3280, 551, 11, 150, "Input"],
Cell[166024, 3293, 146, 5, 33, "Text"],
Cell[166173, 3300, 887, 17, 223, "Input"],
Cell[167063, 3319, 140, 4, 33, "Text",
  Evaluatable->False],
Cell[167206, 3325, 952, 20, 304, "Input"],
Cell[168161, 3347, 1223, 27, 250, "Input"],
Cell[169387, 3376, 323, 8, 36, "Text"]
}, Closed]],
Cell[169725, 3387, 5480, 150, 95, "Text",
  Evaluatable->False],
Cell[175208, 3539, 40100, 660, 254, 39986, 656, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[215311, 4201, 3463, 103, 191, "Text"],
Cell[218777, 4306, 1457, 25, 319, "Text"],
Cell[220237, 4333, 3717, 104, 199, "Text"],
Cell[223957, 4439, 1169, 37, 33, "Text"],

Cell[CellGroupData[{
Cell[225151, 4480, 113, 2, 33, "Text"],
Cell[225267, 4484, 116, 3, 33, "Text"],
Cell[225386, 4489, 1272, 29, 333, "Input"],
Cell[226661, 4520, 447, 11, 59, "Text"],
Cell[227111, 4533, 923, 18, 223, "Input"],
Cell[228037, 4553, 140, 4, 33, "Text",
  Evaluatable->False],
Cell[228180, 4559, 1337, 32, 345, "Input"],
Cell[229520, 4593, 1071, 23, 238, "Input"],
Cell[230594, 4618, 271, 7, 40, "Text"]
}, Closed]],
Cell[230880, 4628, 5086, 145, 104, "Text",
  Evaluatable->False],
Cell[235969, 4775, 35269, 581, 169, 35155, 577, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[271241, 5358, 775, 21, 159, "Text"],
Cell[272019, 5381, 925, 30, 33, "Text"],

Cell[CellGroupData[{
Cell[272969, 5415, 102, 1, 33, "Text"],
Cell[273074, 5418, 514, 16, 52, "Text",
  Evaluatable->False],
Cell[273591, 5436, 2781, 74, 277, "Text"],
Cell[276375, 5512, 3907, 107, 202, "Text"],
Cell[280285, 5621, 558, 18, 36, "Text"],
Cell[280846, 5641, 771, 21, 58, "Text",
  Evaluatable->False],
Cell[281620, 5664, 1682, 32, 466, "Input"],
Cell[283305, 5698, 181, 7, 33, "Text",
  Evaluatable->False],
Cell[283489, 5707, 587, 12, 90, "Input"],
Cell[284079, 5721, 428, 13, 33, "Text",
  Evaluatable->False],
Cell[284510, 5736, 848, 16, 130, "Input"],
Cell[285361, 5754, 195, 5, 33, "Text",
  Evaluatable->False],
Cell[285559, 5761, 665, 15, 210, "Input"],
Cell[286227, 5778, 117, 2, 33, "Text",
  Evaluatable->False],
Cell[286347, 5782, 4270, 82, 681, "Input"],
Cell[290620, 5866, 513, 16, 55, "Text"]
}, Closed]],
Cell[291148, 5885, 5975, 163, 203, "Text"],
Cell[297126, 6050, 2863, 71, 358, "Text"],

Cell[CellGroupData[{
Cell[300014, 6125, 115, 2, 33, "Text"],
Cell[300132, 6129, 66, 0, 33, "Text"],
Cell[300201, 6131, 1471, 32, 395, "Input"],
Cell[301675, 6165, 141, 5, 33, "Text"],
Cell[301819, 6172, 822, 15, 225, "Input"]
}, Closed]],
Cell[302656, 6190, 3451, 93, 122, "Text",
  Evaluatable->False],
Cell[306110, 6285, 130998, 2150, 203, 130884, 2146, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[437111, 8437, 580, 16, 148, "Text"],
Cell[437694, 8455, 3047, 83, 107, "Text"],
Cell[440744, 8540, 4439, 118, 326, "Text"],
Cell[445186, 8660, 2951, 81, 117, "Text"],
Cell[448140, 8743, 858, 27, 36, "Text"],

Cell[CellGroupData[{
Cell[449023, 8774, 115, 2, 33, "Text"],
Cell[449141, 8778, 97, 2, 33, "Text"],
Cell[449241, 8782, 743, 17, 244, "Input"],
Cell[449987, 8801, 140, 5, 33, "Text"],
Cell[450130, 8808, 783, 14, 204, "Input"],
Cell[450916, 8824, 134, 5, 33, "Text"],
Cell[451053, 8831, 462, 9, 90, "Input"],
Cell[451518, 8842, 327, 10, 37, "Text"],
Cell[451848, 8854, 89, 2, 33, "Text"],
Cell[451940, 8858, 1935, 40, 464, "Input"],
Cell[453878, 8900, 141, 5, 33, "Text"],
Cell[454022, 8907, 755, 13, 203, "Input"],
Cell[454780, 8922, 134, 5, 33, "Text"],
Cell[454917, 8929, 450, 9, 102, "Input"],
Cell[455370, 8940, 422, 11, 55, "Text"]
}, Closed]],
Cell[455807, 8954, 290, 7, 30, "Text"],
Cell[456100, 8963, 291, 7, 33, "Text"],
Cell[456394, 8972, 289, 7, 33, "Text"],
Cell[456686, 8981, 286, 7, 33, "Text"],
Cell[456975, 8990, 294, 7, 33, "Text"],
Cell[457272, 8999, 291, 7, 33, "Text"],
Cell[457566, 9008, 257, 5, 33, "Text"],
Cell[457826, 9015, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

