(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    298162,       6228]*)
(*NotebookOutlinePosition[    299282,       6268]*)
(*  CellTagsIndexPosition[    299205,       6262]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["11.7  Two-Dimensional Fluid Flow",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tSuppose that a fluid flows over the complex plane and that the velocity \
at the point  ",
  Cell[BoxData[
      \(z = x + \[ImaginaryI]\ y\)]],
  "  is given by the velocity vector  \n\n",
  StyleBox["(11-30)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["V",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", "  ", 
        RowBox[{
          RowBox[{"p", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "+", "  ", 
          RowBox[{"\[ImaginaryI]", " ", "q", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  ".  \n\nWe also require that the velocity does not depend on time and that \
the components ",
  Cell[BoxData[
      RowBox[{"p", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " and ",
  Cell[BoxData[
      RowBox[{"q", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " have continuous partial derivatives.  The divergence of the vector field \
is given by\n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"div", " ", 
          StyleBox["V",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(p\_x\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "+", "  ", 
          RowBox[{"\[ImaginaryI]", " ", \(q\_y\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  "  \n\nand is a measure of the extent to which the velocity field diverges \
near the point.  We ill consider only fluid flows for which the divergence is \
zero.  This is more precisely characterized by requiring that the net flow \
through any simple closed contour be identically zero.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tIf we consider the flow out of the small rectangle shown in Figure \
11.47, then the rate of outward flow equals the line integral of the exterior \
normal component of ",
  Cell[BoxData[
      RowBox[{
        StyleBox["V",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " taken over the sides of the rectangle.  The exterior normal component is \
given by ",
  Cell[BoxData[
      RowBox[{\(-q\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " on the bottom edge, ",
  Cell[BoxData[
      RowBox[{"p", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " on the right edge,  ",
  Cell[BoxData[
      RowBox[{"q", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " on the top edge, and ",
  Cell[BoxData[
      RowBox[{\(-p\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " on the left edge.  Integrating and setting the resulting net flow to zero \
yield  \n\n",
  StyleBox["(11-31)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(\[Integral]\_y\%\(y + \[CapitalDelta]y\)\), 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"p", 
                    RowBox[{"(", 
                      RowBox[{\(x + \[CapitalDelta]x\), 
                        StyleBox[",",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          "StrikeThrough"->False}], "t"}], ")"}]}], "-", 
                  RowBox[{"p", 
                    RowBox[{"(", 
                      RowBox[{"x", 
                        StyleBox[",",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          "StrikeThrough"->False}], "t"}], ")"}]}]}], 
                ")"}], \(\[DifferentialD]t\)}]}], "+", 
          RowBox[{\(\[Integral]\_x\%\(x + \[CapitalDelta]x\)\), 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"q", 
                    RowBox[{"(", 
                      RowBox[{"t", 
                        StyleBox[",",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          
                          "StrikeThrough"->
                            False}], \(y + \[CapitalDelta]y\)}], ")"}]}], "-",
                   
                  RowBox[{"q", 
                    RowBox[{"(", 
                      RowBox[{"t", 
                        StyleBox[",",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          "StrikeThrough"->False}], "y"}], ")"}]}]}], 
                ")"}], \(\[DifferentialD]t\)}]}]}], " ", "=", " ", "0"}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.47",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/fluidflow/FluidFlowFigures/\
mat1147.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  A two-dimensional vector field. "
}], "Text"],

Cell[TextData[{
  "\tBoth ",
  Cell[BoxData[
      RowBox[{"p", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " and ",
  Cell[BoxData[
      RowBox[{"q", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " are continuously differentiable, so we can use the mean value theorem to \
show that  \n",
  StyleBox["\n(11-32)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"p", 
                RowBox[{"(", 
                  RowBox[{\(x + \[CapitalDelta]x\), 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "t"}], ")"}]}], " ", "-", " ",
               
              RowBox[{"p", 
                RowBox[{"(", 
                  RowBox[{"x", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "t"}], ")"}]}]}], "  ", "=", 
            "  ", 
            RowBox[{\(p\_x\), 
              RowBox[{"(", 
                RowBox[{\(x\_1\), 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}], 
              "\[CapitalDelta]x"}]}], 
          StyleBox[" ",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "  ", 
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}]}], "\n"}], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"q", 
              RowBox[{"(", 
                RowBox[{"t", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], \(y + \[CapitalDelta]y\)}], 
                ")"}]}], " ", "-", " ", 
            RowBox[{"q", 
              RowBox[{"(", 
                RowBox[{"t", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}]}], "  ", "=", 
          "  ", 
          RowBox[{\(q\_y\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(y\_2\)}], ")"}], 
            "\[CapitalDelta]y"}]}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]}]],
  "\n\nwhere ",
  Cell[BoxData[
      \(x < x\_1 < x + \[CapitalDelta]x\)]],
  " and ",
  Cell[BoxData[
      \(y < y\_2 < y + \[CapitalDelta]y\)]],
  ".  Substitution of the expressions in Equation ",
  StyleBox["(11-32)",
    FontColor->RGBColor[0, 0, 1]],
  " into Equation ",
  StyleBox["(11-31)",
    FontColor->RGBColor[0, 0, 1]],
  " and subsequently dividing through by ",
  Cell[BoxData[
      \(\[CapitalDelta]x\ \[CapitalDelta]y\)]],
  " results in  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(1\/\[CapitalDelta]y\), 
            RowBox[{\(\[Integral]\_y\%\(y + \[CapitalDelta]y\)\), "  ", 
              RowBox[{\(p\_x\), 
                RowBox[{"(", 
                  RowBox[{\(x\_1\), 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "y"}], 
                  ")"}], \(\[DifferentialD]t\)}]}]}], "   ", "+", "   ", 
          RowBox[{\(1\/\[CapitalDelta]x\), 
            RowBox[{\(\[Integral]\_x\%\(x + \[CapitalDelta]x\)\), " ", 
              RowBox[{\(q\_y\), 
                RowBox[{"(", 
                  RowBox[{"x", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], \(y\_2\)}], 
                  ")"}], \(\[DifferentialD]t\)}]}]}]}], "  ", "=", "  ", 
        "0"}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tWe can use the mean value theorem for integrals with this equation to \
show that  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(p\_x\), 
            RowBox[{"(", 
              RowBox[{\(x\_1\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(y\_1\)}], ")"}]}], "  ", "+", 
          "  ", 
          RowBox[{\(q\_y\), 
            RowBox[{"(", 
              RowBox[{\(x\_2\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(y\_2\)}], ")"}]}]}], "  ", "=", 
        "  ", "0"}]]],
  ",\n\nwhere ",
  Cell[BoxData[
      \(y < y\_1 < y + \[CapitalDelta]y\)]],
  " and ",
  Cell[BoxData[
      \(x < x\_2 < x + \[CapitalDelta]x\)]],
  " .  Letting ",
  Cell[BoxData[
      \(\[CapitalDelta]x \[Rule] 0\)]],
  " and ",
  Cell[BoxData[
      \(\[CapitalDelta]y \[Rule] 0\)]],
  " in this equation yields \n\n",
  StyleBox["(11-33)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(p\_x\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "+", "  ", 
          RowBox[{\(q\_y\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}], "  ", "=", "  ",
         "0"}]]],
  ",\n\nwhich is called the equation of continuity. "
}], "Text"],

Cell[TextData[{
  "\tThe curl of the vector field in Equation ",
  StyleBox["(11-30)",
    FontColor->RGBColor[0, 0, 1]],
  " has magnitude \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"|", 
          RowBox[{"curl", " ", 
            StyleBox["V",
              FontWeight->"Bold"], 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "|"}], "  ", "=", 
        "  ", 
        RowBox[{
          RowBox[{\(q\_x\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "-", "  ", 
          RowBox[{\(p\_y\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  "\n\nand is an indication of how the field swirls in the vicinity of a \
point.  Imagine that a \"fluid element\" at the point ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"x", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "y"}], ")"}]]],
  " is suddenly frozen and then moves freely in the fluid.  The fluid element \
will rotate with an angular velocity given by \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(1\/2\), \(q\_x\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], " ", "-", " ", 
          RowBox[{\(1\/2\), \(p\_y\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}], "  ", "=", "  ",
         
        RowBox[{\(1\/2\), "|", 
          RowBox[{"curl", " ", 
            StyleBox["V",
              FontWeight->"Bold"], 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "|"}]}]]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tWe consider only fluid flows for which the curl is zero.  Such fluid \
flows are called irrotational.  This condition is more precisely \
characterized by requiring that the line integral of the tangential component \
of ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{
          StyleBox["V",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  " along any simply closed contour be identically zero.  If we consider the \
rectangle in Figure 11.47, then the tangential component is given by ",
  Cell[BoxData[
      RowBox[{"p", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " on the bottom edge, ",
  Cell[BoxData[
      RowBox[{"q", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " on the right edge, ",
  Cell[BoxData[
      RowBox[{\(-p\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " on the top edge, and ",
  Cell[BoxData[
      RowBox[{\(-q\), 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " on the left edge.  Integrating and equating the resulting circulation \
integral to zero yields \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(\[Integral]\_y\%\(y + \[CapitalDelta]y\)\), 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"q", 
                    RowBox[{"(", 
                      RowBox[{\(x + \[CapitalDelta]x\), 
                        StyleBox[",",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          "StrikeThrough"->False}], "t"}], ")"}]}], "-", 
                  RowBox[{"q", 
                    RowBox[{"(", 
                      RowBox[{"x", 
                        StyleBox[",",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          "StrikeThrough"->False}], "t"}], ")"}]}]}], 
                ")"}], \(\[DifferentialD]t\)}]}], "-", 
          RowBox[{\(\[Integral]\_x\%\(x + \[CapitalDelta]x\)\), 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"p", 
                    RowBox[{"(", 
                      RowBox[{"t", 
                        StyleBox[",",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          
                          "StrikeThrough"->
                            False}], \(y + \[CapitalDelta]y\)}], ")"}]}], "-",
                   
                  RowBox[{"p", 
                    RowBox[{"(", 
                      RowBox[{"t", 
                        StyleBox[",",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          "StrikeThrough"->False}], "y"}], ")"}]}]}], 
                ")"}], \(\[DifferentialD]t\)}]}]}], " ", "=", " ", "0"}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tAs before, we apply the mean value theorem and divide through by ",
  Cell[BoxData[
      \(\[CapitalDelta]x\ \[CapitalDelta]y\)]],
  " , and obtain the equation \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(1\/\[CapitalDelta]y\), 
            RowBox[{\(\[Integral]\_y\%\(y + \[CapitalDelta]y\)\), "  ", 
              RowBox[{\(q\_x\), 
                RowBox[{"(", 
                  RowBox[{\(x\_1\), 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "y"}], 
                  ")"}], \(\[DifferentialD]t\)}]}]}], "   ", "-", "   ", 
          RowBox[{\(1\/\[CapitalDelta]x\), 
            RowBox[{\(\[Integral]\_x\%\(x + \[CapitalDelta]x\)\), " ", 
              RowBox[{\(p\_y\), 
                RowBox[{"(", 
                  RowBox[{"x", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], \(y\_2\)}], 
                  ")"}], \(\[DifferentialD]t\)}]}]}]}], "  ", "=", "  ", 
        "0"}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tWe can use the mean value for integrals with this equation to deduce \
that  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(q\_x\), 
            RowBox[{"(", 
              RowBox[{\(x\_1\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(y\_1\)}], ")"}]}], "  ", "-", 
          "  ", 
          RowBox[{\(p\_y\), 
            RowBox[{"(", 
              RowBox[{\(x\_2\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(y\_2\)}], ")"}]}]}], "  ", "=", 
        "  ", "0"}]]],
  ".\n\nLetting ",
  Cell[BoxData[
      \(\[CapitalDelta]x \[Rule] 0\)]],
  " and ",
  Cell[BoxData[
      \(\[CapitalDelta]y \[Rule] 0\)]],
  " yields \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          RowBox[{\(q\_x\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "-", "  ", 
          RowBox[{\(p\_y\), 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}], "  ", "=", "  ",
         "0"}]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tEquations ",
  StyleBox["(11-33)",
    FontColor->RGBColor[0, 0, 1]],
  " and this equation show that the complex function  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(f \((z)\)\), "  ", "=", "  ", 
        RowBox[{
          RowBox[{"p", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "-", "  ", 
          RowBox[{"\[ImaginaryI]", " ", "q", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  "  \n\nsatisfies the Cauchy-Riemann equations and hence it is an analytic \
function.  If we let ",
  Cell[BoxData[
      \(F \((z)\)\)]],
  " denote the antiderivative of ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  ", then \n\n",
  StyleBox["(11-34)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{\(F \((z)\)\), "  ", "=", "  ", 
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "+", "  ", 
          RowBox[{"\[ImaginaryI]", " ", "\[Psi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  ",  \n\nwhich is the complex potential of the flow and has the property\n\n\
\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(\(F' \((z)\)\)\&_\), "   ", "=", "   ", 
          RowBox[{
            RowBox[{\(\[Phi]\_x\), 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], " ", "-", " ", 
            RowBox[{"\[ImaginaryI]", " ", \(\[Psi]\_x\), 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}]}]}], 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"                ", 
        RowBox[{"=", "  ", 
          RowBox[{
            RowBox[{"p", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], " ", "+", " ", 
            RowBox[{"\[ImaginaryI]", " ", "q", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}]}]}], " ", 
        "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
      RowBox[{"                ", 
        RowBox[{"=", "  ", 
          RowBox[{
            StyleBox["V",
              FontWeight->"Bold"], 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]}]],
  "\n\nSince  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\[Phi]\_x\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        RowBox[{"p", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\[Phi]\_y\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        RowBox[{"q", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  ", we also have \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"grad", " ", "\[Phi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", "  ", 
        RowBox[{
          RowBox[{
            RowBox[{"p", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], " ", "+", " ", 
            RowBox[{"\[ImaginaryI]", " ", "q", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}]}], "  ", "=", 
          "  ", 
          RowBox[{
            StyleBox["V",
              FontWeight->"Bold"], 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  ",  \n\nso  ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " is the velocity potential for the flow, and the curves  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Phi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", \(K\_1\)}]]],
  "  \n\nare called equipotentials.  The function  ",
  Cell[BoxData[
      RowBox[{"\[Psi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  is called the stream function.  The curves  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", \(K\_2\)}]]],
  "  \n\nare called streamlines, and describe the paths of the fluid \
particles.  "
}], "Text"],

Cell[TextData[{
  "\tTo demonstrate this result, we implicitly differentiate ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", \(K\_2\)}]]],
  " and find that the slope of a vector tangent is given by  \n\n\t\t\t",
  Cell[BoxData[
      \(dy\/dx\ \  = \ \ \(\(-\ \[Psi]\_x\) \((x, y)\)\)\/\(\(\[Psi]\_y\) \
\((x, y)\)\)\)]],
  ".  \n\nUsing the fact that  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\[Psi]\_y\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        RowBox[{\(\[Phi]\_x\), 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}]}]]],
  "  and this equation, we find that the tangent vector to the curve is \n\n\t\
\t\t",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(T\&\[RightVector]\),
          FontWeight->"Bold"], "  ", "=", "  ", 
        RowBox[{
          RowBox[{
            RowBox[{\(\[Phi]\_x\), 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], "-", " ", 
            RowBox[{"\[ImaginaryI]", " ", \(\[Psi]\_x\), 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}]}], "  ", "=", 
          "  ", 
          RowBox[{
            RowBox[{
              RowBox[{"p", 
                RowBox[{"(", 
                  RowBox[{"x", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "y"}], ")"}]}], " ", "+", " ",
               
              RowBox[{"\[ImaginaryI]", " ", "q", 
                RowBox[{"(", 
                  RowBox[{"x", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "y"}], ")"}]}]}], " ", "=", 
            "  ", 
            RowBox[{
              StyleBox["V",
                FontWeight->"Bold"], 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}]}]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "The main idea of the preceding discussion is the conclusion that, if \n\n\
",
  StyleBox["(11-35)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{\(F \((z)\)\), "  ", "=", "  ", 
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "+", "  ", 
          RowBox[{"\[ImaginaryI]", " ", "\[Psi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  ",  \n\nis an analytic function, then the family of curves \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          RowBox[{"\[Psi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "=", \(K\_2\)}], 
        "}"}]]],
  "\n\nrepresents the streamlines of a fluid flow."
}], "Text"],

Cell[TextData[{
  "\tThe boundary condition for an ideal fluid flow is that ",
  Cell[BoxData[
      RowBox[{
        StyleBox["V",
          FontWeight->"Bold"], 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " should be parallel to the boundary curve containing the fluid (the fluid \
flows parallel to the walls of a containing vessel).  In other words, if \
Equation ",
  StyleBox["(11-35)",
    FontColor->RGBColor[0, 0, 1]],
  " is the complex potential for the flow, then the boundary curve must be \
given by ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", "K"}]]],
  " for some constant ",
  StyleBox["K",
    FontFamily->"Courier New"],
  ";  that is, the boundary curve must be a streamline."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 11.5  (Invariance of Flow).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(\(F\_1\) \((w)\)\), "  ", "=", "  ", 
        RowBox[{
          RowBox[{"\[CapitalPhi]", 
            RowBox[{"(", 
              RowBox[{"u", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "v"}], ")"}]}], "  ", "+", "  ", 
          RowBox[{"i", " ", "\[CapitalPsi]", 
            RowBox[{"(", 
              RowBox[{"u", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "v"}], ")"}]}]}]}]]],
  "  \n\ndenote the complex potential for a fluid flow in a domain ",
  StyleBox["G",
    FontFamily->"Courier New"],
  " in the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane where the velocity is  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["V",
              FontWeight->"Bold"], "1"], 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], "  ", "=", 
        "  ", \(\(F\_1' \((w)\)\)\&_\)}]]],
  ".  \n\nIf the function    ",
  Cell[BoxData[
      RowBox[{"w", "=", 
        RowBox[{\(S \((z)\)\), " ", "=", " ", 
          RowBox[{
            RowBox[{"u", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], "+", 
            RowBox[{"i", " ", "v", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}]}]}]}]]],
  "  is a one-to-one conformal mapping from a domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " in the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane onto ",
  StyleBox["G",
    FontFamily->"Courier New"],
  ",  then the composite function  \n\n\t\t\t",
  Cell[BoxData[{\(\(\(F\_2\) \((z)\)\ \  = \ \ \(F\_1\) \((S \((z)\))\)\)\(\
\[IndentingNewLine]\)
      \), "\[IndentingNewLine]", 
      RowBox[{"              ", 
        RowBox[{"=", "  ", 
          RowBox[{
            RowBox[{"\[CapitalPhi]", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"u", 
                    RowBox[{"(", 
                      RowBox[{"x", 
                        StyleBox[",",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          "StrikeThrough"->False}], "y"}], ")"}]}], 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  RowBox[{"v", 
                    RowBox[{"(", 
                      RowBox[{"x", 
                        StyleBox[",",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          "StrikeThrough"->False}], "y"}], ")"}]}]}], ")"}]}],
             "  ", "+", "  ", 
            RowBox[{"i", " ", "\[CapitalPsi]", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"u", 
                    RowBox[{"(", 
                      RowBox[{"x", 
                        StyleBox[",",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          "StrikeThrough"->False}], "y"}], ")"}]}], 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  RowBox[{"v", 
                    RowBox[{"(", 
                      RowBox[{"x", 
                        StyleBox[",",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          "StrikeThrough"->False}], "y"}], ")"}]}]}], 
                ")"}]}]}]}]}]}]],
  "  \n\nis the complex potential for a fluid flow in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " where the velocity is  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["V",
              FontWeight->"Bold"], "2"], 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", 
        "   ", \(\(F\_2' \((z)\)\)\&_\)}]]],
  ".    \n\nThe situation is shown in Figure 11.48."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.48",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/fluidflow/FluidFlowFigures/\
mat1148.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The image of a fluid flow under conformal mapping.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 11.5 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  "\tWe note that the functions   \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"\[Phi]", 
              RowBox[{"(", 
                RowBox[{"x", 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], "y"}], ")"}]}], "=", "  ", 
            RowBox[{"\[CapitalPhi]", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"u", 
                    RowBox[{"(", 
                      RowBox[{"x", 
                        StyleBox[",",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          "StrikeThrough"->False}], "y"}], ")"}]}], 
                  StyleBox[",",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], 
                  RowBox[{"v", 
                    RowBox[{"(", 
                      RowBox[{"x", 
                        StyleBox[",",
                          FontFamily->"Times New Roman",
                          FontSize->12,
                          FontWeight->"Plain",
                          FontSlant->"Plain",
                          FontColor->GrayLevel[0],
                          FontVariations->{"Underline"->False,
                          "StrikeThrough"->False}], "y"}], ")"}]}]}], 
                ")"}]}]}], ",", "  ", "and"}], "\[IndentingNewLine]"}], 
    "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{"\[Psi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "=", "  ", 
          RowBox[{"\[CapitalPsi]", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"u", 
                  RowBox[{"(", 
                    RowBox[{"x", 
                      StyleBox[",",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], "y"}], ")"}]}], 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], 
                RowBox[{"v", 
                  RowBox[{"(", 
                    RowBox[{"x", 
                      StyleBox[",",
                        FontFamily->"Times New Roman",
                        FontSize->12,
                        FontWeight->"Plain",
                        FontSlant->"Plain",
                        FontColor->GrayLevel[0],
                        FontVariations->{"Underline"->False,
                        "StrikeThrough"->False}], "y"}], ")"}]}]}], ")"}]}]}],
         ","}]}]],
  "  \n\nare the new velocity potential and stream function, respectively, \
for the flow in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  A streamline or natural boundary curve \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "=", \(K\_2\)}]]],
  "\n\t\t\t\nin the z plane is mapped onto a streamline or natural boundary \
curve \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPsi]", 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], "=", \(K\_2\)}]]],
  "\n\n\nin the w plane by the transformation ",
  Cell[BoxData[
      \(w = S \((z)\)\)]],
  ".  One method for finding a flow inside a domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " in the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane is to conformally map ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " onto a domain ",
  StyleBox["G",
    FontFamily->"Courier New"],
  " in the w plane in which the flow is known."
}], "Text"],

Cell[TextData[{
  "\tFor an ideal fluid with uniform density , the fluid pressure  ",
  Cell[BoxData[
      RowBox[{"P", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "  and speed  ",
  Cell[BoxData[
      RowBox[{"|", 
        RowBox[{
          StyleBox["V",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "|"}]]],
  "  are related by the following special case of Bernoulli's equation:  \n\n\
\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(P \((x, y)\)\)\/\[Rho]\ \  + \ \ 1\/2\), "|", 
          RowBox[{
            StyleBox["V",
              FontWeight->"Bold"], 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "|"}], "  ", "=", 
        "  ", "constant"}]]],
  ".  \n\n Note that the pressure is greatest when the speed is least."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 11.22.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The complex potential  ",
  Cell[BoxData[
      \(F \((z)\)\  = \ \((a + \[ImaginaryI]\ b)\) z\)]],
  "  has the velocity potential and stream function of    \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Phi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
        " ", \(a\ x\  - \ b\ y\)}]]],
  "  and   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
        " ", \(b\ x\  + \ a\ y\)}]]],
  ",  \n\t\t\t\nrespectively, and gives rise to the fluid flow defined in the \
entire complex plane that has a uniform parallel velocity of  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["V",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
        "  ", \(\(F' \((z)\)\)\&_\ \ \  = \ \ \(\(a + \[ImaginaryI]\ b\)\&_\ \
\ \  = \ \ a\  - \ \[ImaginaryI]\ b\)\)}]]],
  ".  \n\nThe streamlines are parallel lines given by the equation  ",
  Cell[BoxData[
      \(bx + ay\  = \ constant\)]],
  "  and are inclined at an angle  ",
  Cell[BoxData[
      \(\[Alpha]\  = \ \(-\ Arctan\) \((b\/a)\)\)]],
  ",  as indicated in Figure 11.49."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.49",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/fluidflow/FluidFlowFigures/\
mat1149.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  A uniform parallel flow.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 11.22.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "The function  ",
  Cell[BoxData[
      \(F[z] = \((a + \[ImaginaryI]\ b)\) z\)]],
  "  is the antiderivative of   ",
  Cell[BoxData[
      \(f[z] = \((a + \[ImaginaryI]\ b)\)\)]],
  ".  It gives rise to the fluid flow defined in the entire complex plane \
that has a uniform parallel velocity vector given by  \n\n\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["V",
            FontWeight->"Bold"], \((x, y)\)}], " ", "=", 
        " ", \(\(F' \((z)\)\)\&_\  = \ \(\(a\  + \ \[ImaginaryI]\ b\)\&_\  = \
\ a\  - \ \[ImaginaryI]\ b\)\)}]]],
  ".  \n\nSince  ",
  Cell[BoxData[
      \(F \((z)\)\  = \ \(a\ x - 
            b\ y + \[ImaginaryI]\ \((b\ x + a\ y)\)\  = \ \[Phi] \((x, 
                y)\) + \[ImaginaryI]\ \[Psi] \((x, y)\)\)\)]],
  ",  the streamlines are parallel lines given by the equation  ",
  Cell[BoxData[
      \(\[Psi] \((x, y)\) = K\_1\)]],
  "  which are explicitly given by  ",
  Cell[BoxData[
      \(b\ x + a\ y = c\)]],
  "  where  c  is a constant.  They are inclined at an angle  ",
  Cell[BoxData[
      \(\[Alpha] = \(-\ arctan\) \((b\/a)\)\)]],
  ",  as indicated in Figure 11.49."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.23.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the complex potential  ",
  Cell[BoxData[
      \(F \((z)\)\  = \ A\/2\ z\^2\)],
    AspectRatioFixed->True],
  "  where ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " is a positive real number.  The velocity potential and stream function \
are given by\n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
          "  ", \(\(A\/2\) \((x\^2 - y\^2)\)\)}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}], "\n", 
      RowBox[{
        RowBox[{
          RowBox[{"\[Psi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
          "  ", \(A\ x\ y\)}], 
        StyleBox[
          RowBox[{" ", 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]}]],
  "  \n\nrespectively.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00R`3oool40000
03X0oooo1@00000g0?ooo`800000>P3oool5000003T0oooo1000000@0?oo
o`00R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03H0
oooo00@000000?ooo`3oool00000>`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo0140oooo002<0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool0=P3oool010000000oooo0?ooo`00000k0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0403oool008D0
oooo100000040?ooo`030000003oool0oooo03<0oooo100000040?ooo`03
0000003oool0oooo03H0oooo00@000000?ooo`3oool00000>`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00l0oooo002;0?ooo`04
0000003oool0oooo000003`0oooo00<000000?ooo`3oool0=P3oool01000
0000oooo0?ooo`00000k0?ooo`030000003oool0oooo03T0oooo00@00000
0?ooo`3oool00000403oool008`0oooo0P00000l0?ooo`800000>@3oool2
000003/0oooo0P00000l0?ooo`8000004@3oool00?l0ooooU03oool00?l0
ooooU03oool00?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03oool0
0?l0ooooU03oool008@0ooooo`000005000000/0oooo001m0?ooo`800000
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo001l0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0o`3oool10?ooo`030000003oool0oooo00T0oooo
001l0?ooo`040000003oool0oooo000000@0oooo0`0000030?ooooP00000
0`3oool3000000/0oooo001l0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00`3ooolR000005X0oaX000<000000?lJ003o6P00
E`3o6P0R000000D0oooo00<000000?ooo`3oool02@3oool007`0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooob80ocP0
8@00000i0?lJ00030000003o6P00oaX003H0oaX08@00000Q0?lh00H0oooo
00<000000?ooo`3oool02@3oool007d0oooo0P0000050?ooo`030000003o
ool0oooo00<0oooo@`3o>00?000002X0oaX000<000000?lJ003o6P009`3o
6P0?00000480ocP01P3oool00`000000oooo0?ooo`090?ooo`00Q03oool0
0`000000oooo0?ooo`030?oooe80ocP02@00000Q0?lJ00030000003o6P00
oaX001h0oaX02@00001A0?lh00H0oooo00<000000?ooo`3oool02@3oool0
08@0oooo00<000000?ooo`3oool00`3ooolB000004T0ocP01P00000K0?lJ
00030000003o6P00oaX001P0oaX01P00001:0?lh014000001@3oool00`00
0000oooo0?ooo`090?ooo`00Q03oool2000000@0oooo4P3oM00@000003l0
ocP01000000G0?lJ00030000003o6P00oaX001@0oaX01000000o0?lh0140
0000403oM0050?ooo`8000002`3oool008@0oooo00<000000?ooo`3oool0
0`3ooolR0?md00/00000>03o>004000001<0oaX000<000000?lJ003o6P00
403o6P04000003P0ocP02`00000Q0?md00H0oooo00<000000?ooo`3oool0
2@3oool008@0oooo00<000000?ooo`3oool00`3oool]0?md00T00000<`3o
>00200000140oaX000<000000?lJ003o6P003P3o6P0200000380ocP02P00
000/0?md00H0oooo00<000000?ooo`3oool02@3oool008@0oooo00<00000
0?ooo`3oool00`3ooolf0?md00L00000;@3o>00200000100oaX000<00000
0?lJ003o6P003@3o6P02000002d0ocP01`00000e0?md00H0oooo00<00000
0?ooo`3oool02@3oool008@0oooo00<000000?ooo`3oool00`3ooolm0?md
00H00000:@3o>002000000h0oaX000<000000?lJ003o6P002`3o6P020000
02T0ocP01P00000l0?md00H0oooo00<000000?ooo`3oool02@3oool008@0
oooo00<000000?ooo`3oool00`3oool8000003/0og@01@00000V0?lh0003
0000003o6P00oaX000/0oaX000<000000?lJ003o6P002P3o6P000`000000
ocP00?lh000T0?lh00D00000?03oM007000000D0oooo00<000000?ooo`3o
ool02@3oool008@0oooo0P0000040?ooo`P0olh02000000h0?md00@00000
8`3o>0000`000000oaX00?lJ000:0?lJ00030000003o6P00oaX000T0oaX0
00<000000?lh003o>0008@3o>004000003P0og@02@0000060?o>00D0oooo
0P00000;0?ooo`00Q03oool00`000000oooo0?ooo`030?oooa00olh02@00
000c0?md00@00000803o>0000`000000oaX00?lJ00090?lJ00030000003o
6P00oaX000P0oaX000<000000?lh003o>0007P3o>004000003<0og@02@00
000?0?o>00H0oooo00<000000?ooo`3oool02@3oool008@0oooo00<00000
0?ooo`3oool00`3ooolH0?o>00L00000<@3oM002000001h0ocP000<00000
0?lJ003o6P002@3o6P000`000000oaX00?lJ00070?lJ00030000003o>000
ocP001d0ocP00P00000a0?md00L000005`3ocP060?ooo`030000003oool0
oooo00T0oooo00240?ooo`030000003oool0oooo00<0oooo7`3ocP060000
02d0og@00`00000L0?lh008000002@3o6P000`000000oaX00?lJ00070?lJ
00030000003o>000ocP001X0ocP00`00000]0?md00H000007P3ocP060?oo
o`030000003oool0oooo00T0oooo00240?ooo`030000003oool0oooo00<0
oooo9@3ocP05000002/0og@00P00000K0?lh00030000003o6P00oaX000L0
oaX000<000000?lJ003o6P001P3o6P000`000000ocP00?lh000I0?lh0080
0000:`3oM005000002@0olh01P3oool00`000000oooo0?ooo`090?ooo`00
Q03oool00`000000oooo0?ooo`030?ooobX0olh01000000Y0?md00<00000
6@3o>0000`000000oaX00?lJ00060?lJ00030000003o6P00oaX000D0oaX0
0P00000H0?lh00<00000:@3oM004000002T0olh01P3oool00`000000oooo
0?ooo`090?ooo`00Q03oool2000000@0oooo;P3ocP05000002L0og@00P00
000G0?lh00030000003o6P00oaX000H0oaX000<000000?lJ003o6P001@3o
6P000`000000ocP00?lh000E0?lh008000009`3oM005000002d0olh01@3o
ool2000000/0oooo00240?ooo`030000003oool0oooo00<0oooo0P3ocP00
0`000000olh00?o>000^0?o>00@00000903oM002000001H0ocP000<00000
0?lJ003o6P001P3o6P000`000000oaX00?lJ00040?lJ00030000003o>000
ocP001D0ocP00P00000T0?md00@00000<P3ocP060?ooo`030000003oool0
oooo00T0oooo00240?ooo`030000003oool0oooo00<0oooo1P00000a0?o>
00800000903oM002000001D0ocP000<000000?lJ003o6P001@3o6P000`00
0000oaX00?lJ00040?lJ00030000003o>000ocP001<0ocP00P00000T0?md
00800000<@3ocP06000000D0oooo00<000000?ooo`3oool02@3oool008@0
oooo00<000000?ooo`3oool00`3oool60;[o00L00000;03ocP0400000280
og@000<000000?lh003o>0004P3o>0000`000000oaX00?lJ00050?lJ0003
0000003o6P00oaX000@0oaX000<000000?lh003o>0004P3o>0000`000000
og@00?md000P0?md00@00000;@3ocP06000000D0^_l01P3oool00`000000
oooo0?ooo`090?ooo`00Q03oool00`000000oooo0?ooo`030?ooo`d0^_l0
0`00000]0?o>00<00000803oM0000`000000ocP00?lh000B0?lh00030000
003o6P00oaX000@0oaX000<000000?lJ003o6P000`3o6P000`000000ocP0
0?lh000B0?lh00030000003oM000og@001l0og@00P00000]0?o>00@00000
2`2jo`060?ooo`030000003oool0oooo00T0oooo00240?ooo`030000003o
ool0oooo00<0oooo402jo`06000002X0olh00`00000N0?md008000004P3o
>0000`000000oaX00?lJ00040?lJ00030000003o6P00oaX000<0oaX000<0
00000?lh003o>000403o>002000001h0og@01000000Y0?o>00H000003`2j
o`060?ooo`030000003oool0oooo00T0oooo00240?ooo`800000103ooolF
0;[o00<00000:@3ocP03000001h0og@000<000000?lh003o>0003`3o>000
0`000000oaX00?lJ00040?lJ00030000003o6P00oaX000<0oaX000<00000
0?lh003o>0003`3o>0000`000000og@00?md000M0?md00800000:@3ocP04
000001@0^_l01@3oool2000000/0oooo00240?ooo`030000003oool0oooo
00<0oooo6@2jo`05000002L0olh00P00000L0?md00800000403o>0000`00
0000oaX00?lJ00040?lJ00030000003o6P00oaX000<0oaX000<000000?lh
003o>0003P3o>002000001`0og@00`00000V0?o>00D00000602jo`060?oo
o`030000003oool0oooo00T0oooo00240?ooo`030000003oool0oooo00<0
oooo7P2jo`02000002L0olh00P00000K0?md00030000003o>000ocP000l0
ocP000<000000?lJ003o6P000`3o6P000`000000oaX00?lJ00020?lJ0003
0000003o>000ocP000l0ocP000<000000?md003oM0006P3oM0000`000000
olh00?o>000U0?o>008000007@2jo`060?ooo`030000003oool0oooo00T0
oooo00240?ooo`030000003oool0oooo00<0oooo802jo`04000002@0olh0
0`00000J0?md00030000003o>000ocP000h0ocP000<000000?lJ003o6P00
0`3o6P000`000000oaX00?lJ00020?lJ00030000003o>000ocP000h0ocP0
00<000000?md003oM000603oM003000002@0olh01000000O0;[o00H0oooo
00<000000?ooo`3oool02@3oool008@0oooo00<000000?ooo`3oool00`3o
oolT0;[o00@000008`3ocP02000001T0og@000<000000?lh003o>0003@3o
>0000`000000oaX00?lJ00030?lJ00030000003o6P00oaX00080oaX000<0
00000?lh003o>0003@3o>0000`000000og@00?md000G0?md008000008`3o
cP04000002<0^_l01P3oool00`000000oooo0?ooo`090?ooo`00L@3oool2
000000@0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`03
0?ooobL0^_l00`00000R0?o>00<000005`3oM0000`000000ocP00?lh000=
0?lh00030000003o6P00oaX000<0oaX000<000000?lJ003o6P000P3o6P00
0`000000ocP00?lh000=0?lh00030000003oM000og@001H0og@00P00000R
0?o>00<000009P2jo`060?ooo`030000003oool0oooo00T0oooo001`0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`030?ooobX0^_l00`00000Q0?o>008000005`3o
M002000000d0ocP00P0000040?lJ00030000003o6P00oaX00080oaX000<0
00000?lh003o>0002`3o>002000001L0og@00P00000Q0?o>00<00000:@2j
o`060?ooo`030000003oool0oooo00T0oooo001`0?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`3oool00P3oool3000000<0oooo1000
000Y0;[o008000008@3ocP000`000000og@00?md000E0?md00030000003o
>000ocP000`0ocP000<000000?lJ003o6P000P3o6P001@000000oaX00?lJ
003o6P00000000h0ocP000<000000?md003oM0005@3oM0000`000000olh0
0?o>000O0?o>00800000:@2jo`04000000<0oooo0`00000;0?ooo`00L03o
ool010000000oooo0?ooo`0000090?ooo`8000001@3oool00`000000oooo
0?ooo`030?ooo`@09?l01000000W0;[o00<000007`3ocP000`000000og@0
0?md000E0?md00030000003o>000ocP000/0ocP000<000000?lJ003o6P00
0P3o6P001@000000oaX00?lJ003o6P00000000d0ocP000<000000?md003o
M0005@3oM0000`000000olh00?o>000M0?o>00<00000:02jo`03000000<0
9?l01P3oool00`000000oooo0?ooo`090?ooo`00L03oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool802Co00@000009P2jo`02000001h0olh00P00000E0?md0003
0000003o>000ocP000/0ocP000<000000?lJ003o6P000P3o6P001@000000
oaX00?lJ003o6P00000000d0ocP000<000000?md003oM0004`3oM0020000
01h0olh00P00000V0;[o00D000001P0To`060?ooo`030000003oool0oooo
00T0oooo001a0?ooo`8000002P3oool3000000@0oooo00<000000?ooo`3o
ool00`3oool<02Co00<000009@2jo`02000001h0olh000<000000?md003o
M0004P3oM002000000`0ocP000<000000?lJ003o6P000P3o6P001@000000
oaX00?lJ003o6P00000000`0ocP000<000000?md003oM0004`3oM0000`00
0000olh00?o>000K0?o>00<000009@2jo`04000000X09?l01P3oool00`00
0000oooo0?ooo`090?ooo`00Q03oool00`000000oooo0?ooo`030?ooo`l0
9?l00`00000T0;[o00800000703ocP02000001@0og@000<000000?lh003o
>0002P3o>0000`000000oaX00?lJ00020?lJ00050000003o6P00oaX00?lJ
00000000303o>0000`000000og@00?md000B0?md00800000703ocP020000
02D0^_l00P00000>02Co00H0oooo00<000000?ooo`3oool02@3oool008@0
oooo00<000000?ooo`3oool00`3ooolB02Co00800000902jo`000`000000
olh00?o>000K0?o>00030000003oM000og@00180og@000<000000?lh003o
>0002@3o>0000`000000oaX00?lJ00020?lJ00050000003o6P00oaX00?lJ
000000002`3o>0000`000000og@00?md000B0?md00030000003ocP00olh0
01/0olh000<000000;[o002jo`008P2jo`03000001009?l01P3oool00`00
0000oooo0?ooo`090?ooo`00Q03oool2000000@0oooo500To`0400000240
^_l00`00000K0?o>00030000003oM000og@00140og@000<000000?lh003o
>0002@3o>0000`000000oaX00?lJ00020?lJ00050000003o6P00oaX00?lJ
000000002`3o>0000`000000og@00?md000A0?md00030000003ocP00olh0
01T0olh00`00000Q0;[o00@000004`0To`050?ooo`8000002`3oool008@0
oooo00<000000?ooo`3oool00`3ooolH02Co008000008P2jo`02000001T0
olh00P00000C0?md00030000003o>000ocP000T0ocP000D000000?lJ003o
6P00oaX0000000020?lJ00030000003o>000ocP000T0ocP000<000000?md
003oM0004@3oM002000001T0olh00P00000R0;[o008000005`0To`060?oo
o`030000003oool0oooo00T0oooo00240?ooo`030000003oool0oooo00<0
oooo6P0To`0300000200^_l000<000000?o>000000006@3ocP000`000000
og@00?md000@0?md00030000003o>000ocP000T0ocP000D000000?lJ003o
6P00oaX0000000020?lJ00030000003o>000ocP000T0ocP000<000000?md
003oM000403oM0000`000000olh00?o>000H0?o>00800000802jo`030000
01T09?l01P3oool00`000000oooo0?ooo`090?ooo`00Q03oool00`000000
oooo0?ooo`030?oooa`09?l00`00000O0;[o00<00000603ocP0200000140
og@00P00000:0?lh00050000003o6P00oaX00?lJ000000000P3o6P000`00
0000ocP00?lh00080?lh008000004@3oM002000001P0olh00`00000O0;[o
00<000006`0To`060?ooo`030000003oool0oooo00T0oooo00240?ooo`03
0000003oool0oooo00<0oooo7`0To`000`000000^_l00;[o000N0;[o0080
0000603ocP000`000000og@00?md000@0?md00030000003o>000ocP000P0
ocP000D000000?lJ003o6P00oaX0000000020?lJ00030000003o>000ocP0
00P0ocP000<000000?md003oM000403oM0000`000000olh00?o>000F0?o>
00800000802jo`000`0000009?l002Co000L02Co00H0oooo00<000000?oo
o`3oool02@3oool008@0oooo00<000000?ooo`3oool00`3ooolP02Co00<0
00007`2jo`000`000000olh00?o>000F0?o>00030000003oM000og@000l0
og@000<000000?lh003o>000203o>0001@000000oaX00?lJ003o6P000000
0080oaX000<000000?lh003o>000203o>0000`000000og@00?md000?0?md
00030000003ocP00olh001H0olh000<000000;[o002jo`007@2jo`030000
01l09?l01P3oool00`000000oooo0?ooo`090?ooo`00Q03oool2000000@0
oooo8`0To`03000001d0^_l00P00000G0?o>00030000003oM000og@000l0
og@000<000000?lh003o>0001`3o>0001@000000oaX00?lJ003o6P000000
0080oaX000<000000?lh003o>0001`3o>0000`000000og@00?md000?0?md
00030000003ocP00olh001D0olh00P00000N0;[o008000008P0To`050?oo
o`8000002`3oool008@0oooo00<000000?ooo`3oool00`3oool00`000000
9?l00000000R02Co008000007P2jo`000`000000olh00?o>000D0?o>0003
0000003oM000og@000l0og@000<000000?lh003o>0001`3o>0001@000000
oaX00?lJ003o6P0000000080oaX000<000000?lh003o>0001`3o>0000`00
0000og@00?md000?0?md00030000003ocP00olh001@0olh000<000000;[o
002jo`00702jo`02000002@09?l000<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`090?ooo`00Q03oool00`000000oooo0?ooo`030?ooo`04
003oS`0000000000000002<09?l00P00000L0;[o008000005P3ocP000`00
0000og@00?md000>0?md00030000003o>000ocP000L0ocP000D000000?lJ
003o6P00oaX0000000020?lJ00030000003o>000ocP000L0ocP000<00000
0?md003oM0003P3oM0000`000000olh00?o>000D0?o>00800000702jo`02
000002<09?l00`0000060?ooo`030000003oool0oooo00T0oooo00240?oo
o`030000003oool0oooo00<0oooo1000ohl2000002<09?l000<000000;[o
002jo`006`2jo`000`000000olh00?o>000D0?o>00030000003oM000og@0
00d0og@000<000000?lh003o>0001`3o>0001@000000oaX00?lJ003o6P00
00000080oaX000<000000?lh003o>0001`3o>0000`000000og@00?md000=
0?md00030000003ocP00olh001@0olh000<000000;[o002jo`006`2jo`00
0`0000009?l002Co000Q02Co008000000`00ohl60?ooo`030000003oool0
oooo00T0oooo00240?ooo`030000003oool0oooo00<0oooo1P00ohl30000
02409?l00`00000K0;[o008000005@3ocP000`000000og@00?md000=0?md
00030000003o>000ocP000H0ocP000D000000?lJ003o6P00oaX000000002
0?lJ00030000003o>000ocP000H0ocP000<000000?md003oM0003@3oM000
0`000000olh00?o>000D0?o>00030000002jo`00^_l001T0^_l00`00000Q
02Co00<000001@00ohl60?ooo`030000003oool0oooo00T0oooo00240?oo
o`030000003oool0oooo00<0oooo2@00ohl3000002409?l000<000000;[o
002jo`006P2jo`000`000000olh00?o>000B0?o>00030000003oM000og@0
00d0og@000<000000?lh003o>0001P3o>0001@000000oaX00?lJ003o6P00
00000080oaX000<000000?lh003o>0001P3o>0000`000000og@00?md000=
0?md00030000003ocP00olh001<0olh000<000000;[o002jo`006@2jo`00
0`0000009?l002Co000O02Co00<000002000ohl60?ooo`030000003oool0
oooo00T0oooo00240?ooo`800000103oool<003oS`800000800To`000`00
0000^_l00;[o000I0;[o00030000003ocP00olh00180olh000<000000?md
003oM0003@3oM0000`000000ocP00?lh00060?lh00050000003o6P00oaX0
0?lJ000000000P3o6P000`000000ocP00?lh00060?lh00030000003oM000
og@000`0og@000<000000?o>003ocP004`3ocP000`000000^_l00;[o000I
0;[o00030000000To`009?l001h09?l00`00000:003oS`D0oooo0P00000;
0?ooo`00Q03oool00`000000oooo0?ooo`030?ooo`h00?n?0P00000O02Co
008000006P2jo`000`000000olh00?o>000B0?o>00030000003oM000og@0
00`0og@000<000000?lh003o>0001`3o>00010000000oaX00?lJ00000002
0?lJ00030000003o>000ocP000H0ocP000<000000?md003oM000303oM000
0`000000olh00?o>000B0?o>00030000002jo`00^_l001P0^_l00P00000O
02Co008000003@00ohl60?ooo`030000003oool0oooo00T0oooo00240?oo
o`030000003oool0oooo00<0oooo4000ohl3000001h09?l00P00000I0;[o
00030000003ocP00olh00180olh000<000000?md003oM000303oM0000`00
0000ocP00?lh00060?lh00040000003o6P00oaX000000080oaX000<00000
0?lh003o>0001@3o>0000`000000og@00?md000<0?md00030000003ocP00
olh00180olh000<000000;[o002jo`005`2jo`02000001h09?l00`00000?
003oS`H0oooo00<000000?ooo`3oool02@3oool008@0oooo00<000000?oo
o`3oool00`3ooolC003oS`030000000To`009?l001d09?l000<000000;[o
002jo`005`2jo`000`000000olh00?o>000A0?o>008000003@3oM0000`00
0000ocP00?lh00060?lh00060000003o6P00oaX00000003o6P000000203o
>0000`000000og@00?md000<0?md00030000003ocP00olh00140olh000<0
00000;[o002jo`005`2jo`000`0000009?l002Co000M02Co000300000000
ohl00?n?01000?n?1P3oool00`000000oooo0?ooo`090?ooo`00Q03oool0
0`000000oooo0?ooo`030?oooa@00?n?0`00000M02Co00800000602jo`00
0`000000olh00?o>000A0?o>00030000003oM000og@000/0og@000<00000
0?lh003o>0001P3o>0001P000000oaX00?lJ00000000oaX0000000P0ocP0
00<000000?md003oM0002`3oM0000`000000olh00?o>000A0?o>00800000
5`2jo`02000001h09?l00P00000C003oS`H0oooo00<000000?ooo`3oool0
2@3oool008@0oooo00<000000?ooo`3oool00`3ooolG003oS`030000000T
o`009?l001`09?l000<000000;[o002jo`005P2jo`000`000000olh00?o>
000@0?o>00030000003oM000og@000/0og@000<000000?lh003o>0001P3o
>0001P000000oaX00?lJ00000000oaX0000000P0ocP000<000000?md003o
M0002`3oM0000`000000olh00?o>000@0?o>00030000002jo`00^_l001H0
^_l000<0000002Co000To`00700To`02000001D00?n?1P3oool00`000000
oooo0?ooo`090?ooo`00Q03oool2000000@0oooo6000ohl2000001`09?l0
0P00000G0;[o00030000003ocP00olh00140olh000<000000?md003oM000
2P3oM0000`000000ocP00?lh00060?lh00060000003o6P00oaX00000003o
6P000000203o>0000`000000og@00?md000:0?md008000004P3ocP000`00
0000^_l00;[o000E0;[o00800000700To`02000001L00?n?1@3oool20000
00/0oooo00240?ooo`030000003oool0oooo00<0oooo6P00ohl2000001`0
9?l000<000000;[o002jo`005@2jo`000`000000olh00?o>000@0?o>0003
0000003oM000og@000/0og@000<000000?lh003o>0001@3o>0001P000000
oaX00?lJ00000000oaX0000000L0ocP000<000000?md003oM0002`3oM000
0`000000olh00?o>000@0?o>00030000002jo`00^_l001D0^_l000<00000
02Co000To`006`0To`000`0000000?n?003oS`0G003oS`H0oooo00<00000
0?ooo`3oool02@3oool008@0oooo00<000000?ooo`3oool00`3ooolL003o
S`030000000To`009?l001X09?l00P00000F0;[o00030000003ocP00olh0
0100olh000<000000?md003oM0002P3oM0000`000000ocP00?lh00050?lh
00060000003o6P00oaX00000003o6P0000001`3o>0000`000000og@00?md
000:0?md00030000003ocP00olh00100olh000<000000;[o002jo`005@2j
o`000`0000009?l002Co000J02Co008000006P00ohl60?ooo`030000003o
ool0oooo00T0oooo00240?ooo`030000003oool0oooo00<0oooo7@00ohl2
000001`09?l000<000000;[o002jo`00502jo`000`000000olh00?o>000?
0?o>00030000003oM000og@000X0og@000<000000?lh003o>0001@3o>000
1P000000oaX00?lJ00000000oaX0000000L0ocP000<000000?md003oM000
2P3oM0000`000000olh00?o>000?0?o>00030000002jo`00^_l001@0^_l0
0P00000K02Co008000007000ohl60?ooo`030000003oool0oooo00T0oooo
001l0?ooo`D000000`3oool00`000000oooo0?ooo`030?oooal00?n?00<0
000002Co000To`006@0To`000`000000^_l00;[o000D0;[o00030000003o
cP00olh000l0olh000<000000?md003oM0002P3oM0000`000000ocP00?lh
00050?lh00060000003o6P00oaX00000003o6P0000001`3o>0000`000000
og@00?md00090?md00030000003ocP00olh00100olh000<000000;[o002j
o`004`2jo`000`0000009?l002Co000J02Co000300000000ohl00?n?01`0
0?n?1P3oool00`000000oooo0?ooo`090?ooo`00OP3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<00000003oS`00ohl0
7@00ohl2000001X09?l000<000000;[o002jo`00502jo`000`000000olh0
0?o>000?0?o>00030000003oM000og@000T0og@000<000000?lh003o>000
1@3o>0001P000000oaX00?lJ00000000oaX0000000L0ocP000<000000?md
003oM0002@3oM0000`000000olh00?o>000?0?o>00030000002jo`00^_l0
01@0^_l000<0000002Co000To`00600To`02000001l00?n?00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`090?ooo`00OP3oool00`000000
oooo0?ooo`030?ooo`<000000`3oool01000W_l0000000000000000N003o
S`030000000To`009?l001P09?l00P00000E0;[o00030000003ocP00olh0
00h0olh000<000000?md003oM0002P3oM0000`000000ocP00?lh00040?lh
00060000003o6P00oaX00000003o6P0000001`3o>0000`000000og@00?md
00090?md00030000003ocP00olh000h0olh000<000000;[o002jo`00502j
o`000`0000009?l002Co000H02Co000300000000ohl00?n?01`00?n?0`00
00040?ooo`<000002`3oool007h0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`@009ko00<00000003oS`00ohl07000ohl2
000001T09?l00P00000E0;[o00030000003ocP00olh000h0olh000<00000
0?md003oM0002@3oM0000`000000ocP00?lh00040?lh00060000003o6P00
oaX00000003o6P0000001P3o>0000`000000og@00?md000:0?md00030000
003ocP00olh000h0olh000<000000;[o002jo`004`2jo`000`0000009?l0
02Co000G02Co008000007P00ohl01000000009ko002No`00W_l60?ooo`03
0000003oool0oooo00T0oooo001n0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool5002No`<000007000ohl3000001T09?l0
00<000000;[o002jo`004P2jo`000`000000olh00?o>000>0?o>00030000
003oM000og@000T0og@000<000000?lh003o>000103o>0001P000000oaX0
0?lJ00000000oaX0000000H0ocP000<000000?md003oM0002@3oM0000`00
0000olh00?o>000>0?o>00030000002jo`00^_l00180^_l00P00000H02Co
00<000007@00ohl2000000@009ko1P3oool00`000000oooo0?ooo`090?oo
o`00O@3oool2000000D0oooo00<000000?ooo`3oool00`3oool8002No`03
00000000ohl00?n?01`00?n?00<0000002Co000To`005P0To`000`000000
^_l00;[o000B0;[o00030000003ocP00olh000h0olh000<000000?md003o
M0002@3oM0000`000000ocP00?lh00040?lh00060000003o6P00oaX00000
003o6P0000001P3o>0000`000000og@00?md00090?md00030000003ocP00
olh000d0olh000<000000;[o002jo`004P2jo`000`0000009?l002Co000G
02Co000300000000ohl00?n?01`00?n?0P000006002No`H0oooo00<00000
0?ooo`3oool02@3oool008@0oooo00<000000?ooo`3oool00`3oool9002N
o`8000007000ohl2000001P09?l000<000000;[o002jo`004P2jo`000`00
0000olh00?o>000=0?o>00030000003oM000og@000T0og@000<000000?lh
003o>000103o>0001P000000oaX00?lJ00000000oaX0000000H0ocP000<0
00000?md003oM0002@3oM0000`000000olh00?o>000=0?o>00030000002j
o`00^_l00180^_l000<0000002Co000To`005P0To`02000001`00?n?0P00
0008002No`H0oooo00<000000?ooo`3oool02@3oool008@0oooo00<00000
0?ooo`3oool00`3oool;002No`8000007000ohl00`0000009?l002Co000F
02Co00030000002jo`00^_l00180^_l000<000000?o>003ocP003@3ocP00
0`000000og@00?md00080?md00030000003o>000ocP000@0ocP000H00000
0?lJ003o6P0000000?lJ000000060?lh00030000003oM000og@000P0og@0
00<000000?o>003ocP003@3ocP000`000000^_l00;[o000B0;[o00030000
000To`009?l001H09?l000<00000003oS`00ohl06`00ohl00`00000009ko
002No`08002No`H0oooo00<000000?ooo`3oool02@3oool008@0oooo00<0
00000?ooo`3oool00`3oool=002No`0300000000ohl00?n?01X00?n?0P00
000G02Co00030000002jo`00^_l00140^_l000<000000?o>003ocP003@3o
cP000`000000og@00?md00090?md00030000003o>000ocP000<0ocP000H0
00000?lJ003o6P0000000?lJ000000060?lh00030000003oM000og@000P0
og@000<000000?o>003ocP003@3ocP000`000000^_l00;[o000A0;[o0003
0000000To`009?l001D09?l00P00000L003oS`8000002`00W_l60?ooo`03
0000003oool0oooo00T0oooo00240?ooo`800000103oool>002No`800000
7000ohl00`0000009?l002Co000E02Co00030000002jo`00^_l00140^_l0
00<000000?o>003ocP003@3ocP000`000000og@00?md00080?md00030000
003o>000ocP000<0ocP000H000000?lJ003o6P0000000?lJ000000050?lh
00030000003oM000og@000P0og@00P00000>0?o>00030000002jo`00^_l0
0140^_l00P00000F02Co000300000000ohl00?n?01X00?n?0P00000=002N
o`D0oooo0P00000;0?ooo`00Q03oool00`000000oooo0?ooo`030?oooa00
09ko0P00000K003oS`030000000To`009?l001D09?l000<000000;[o002j
o`004@2jo`000`000000olh00?o>000<0?o>00030000003oM000og@000P0
og@000<000000?lh003o>0000`3o>0001P000000oaX00?lJ00000000oaX0
000000D0ocP00P0000090?md00030000003ocP00olh000`0olh00P00000B
0;[o00030000000To`009?l001D09?l000<00000003oS`00ohl06@00ohl2
000000l009ko1P3oool00`000000oooo0?ooo`090?ooo`00Q03oool00`00
0000oooo0?ooo`030?oooa8009ko00<00000003oS`00ohl06000ohl00`00
00009?l002Co000E02Co00030000002jo`00^_l00140^_l000<000000?o>
003ocP00303ocP000`000000og@00?md00080?md00030000003o>000ocP0
00<0ocP000H000000?lJ003o6P0000000?lJ000000050?lh00030000003o
M000og@000P0og@000<000000?o>003ocP00303ocP000`000000^_l00;[o
000@0;[o00030000000To`009?l001D09?l000<00000003oS`00ohl06@00
ohl00`00000009ko002No`0?002No`H0oooo00<000000?ooo`3oool02@3o
ool008@0oooo00<000000?ooo`3oool00`3ooolC002No`0300000000ohl0
0?n?01P00?n?0P00000F02Co00030000002jo`00^_l00100^_l000<00000
0?o>003ocP00303ocP000`000000og@00?md00080?md00030000003o>000
ocP000<0ocP000H000000?lJ003o6P0000000?lJ000000050?lh00030000
003oM000og@000P0og@000<000000?o>003ocP00303ocP000`000000^_l0
0;[o000@0;[o00030000000To`009?l001D09?l000<00000003oS`00ohl0
6000ohl00`00000009ko002No`0@002No`H0oooo00<000000?ooo`3oool0
2@3oool008@0oooo00<000000?ooo`3oool00`3ooolD002No`8000006P00
ohl00`0000009?l002Co000D02Co00030000002jo`00^_l00100^_l000<0
00000?o>003ocP00303ocP000`000000og@00?md00070?md00030000003o
>000ocP000<0ocP000H000000?lJ003o6P0000000?lJ000000050?lh0003
0000003oM000og@000L0og@000<000000?o>003ocP00303ocP000`000000
^_l00;[o000@0;[o00030000000To`009?l001@09?l00P00000J003oS`03
00000000W_l009ko014009ko1P3oool00`000000oooo0?ooo`090?ooo`00
Q03oool00`000000oooo0?ooo`030?oooaH009ko00<00000003oS`00ohl0
6000ohl00`0000009?l002Co000D02Co00030000002jo`00^_l000l0^_l0
00<000000?o>003ocP00303ocP000`000000og@00?md00070?md00030000
003o>000ocP000<0ocP000H000000?lJ003o6P0000000?lJ000000050?lh
00030000003oM000og@000L0og@000<000000?o>003ocP00303ocP000`00
0000^_l00;[o000?0;[o00030000000To`009?l001@09?l000<00000003o
S`00ohl06000ohl2000001@009ko1P3oool00`000000oooo0?ooo`090?oo
o`00Q03oool2000000@0oooo5`00W_l2000001T00?n?00<0000002Co000T
o`00500To`000`000000^_l00;[o000?0;[o00030000003ocP00olh000/0
olh000<000000?md003oM0001`3oM0000`000000ocP00?lh00040?lh0005
0000003o6P0000000?lJ000000001@3o>0000`000000og@00?md00070?md
00030000003ocP00olh000/0olh000<000000;[o002jo`003`2jo`020000
01D09?l000<00000003oS`00ohl05`00ohl2000001H009ko1@3oool20000
00/0oooo00240?ooo`030000003oool0oooo00<0oooo6000W_l2000001P0
0?n?00<0000002Co000To`00500To`000`000000^_l00;[o000?0;[o0003
0000003ocP00olh000/0olh000<000000?md003oM0001`3oM0000`000000
ocP00?lh00040?lh00050000003o6P0000000?lJ000000001@3o>0000`00
0000og@00?md00070?md00030000003ocP00olh000/0olh000<000000;[o
002jo`003`2jo`000`0000009?l002Co000C02Co000300000000ohl00?n?
01L00?n?0P00000G002No`H0oooo00<000000?ooo`3oool02@3oool008@0
oooo00<000000?ooo`3oool00`3ooolJ002No`8000005`00ohl2000001D0
9?l000<000000;[o002jo`003`2jo`000`000000olh00?o>000;0?o>0003
0000003oM000og@000L0og@000<000000?lh003o>0000`3o>0001@000000
oaX00000003o6P00000000D0ocP000<000000?md003oM0001`3oM0000`00
0000olh00?o>000;0?o>00030000002jo`00^_l000h0^_l00P00000E02Co
000300000000ohl00?n?01H00?n?0P00000H002No`H0oooo00<000000?oo
o`3oool02@3oool008@0oooo00<000000?ooo`3oool00`3ooolK002No`80
00006000ohl00`0000009?l002Co000B02Co00030000002jo`00^_l000l0
^_l000<000000?o>003ocP002`3ocP000`000000og@00?md00070?md0003
0000003o>000ocP000<0ocP000D000000?lJ00000000oaX0000000040?lh
00030000003oM000og@000L0og@000<000000?o>003ocP002`3ocP000`00
0000^_l00;[o000?0;[o00030000000To`009?l001809?l00P00000G003o
S`8000006P00W_l60?ooo`030000003oool0oooo00T0oooo00240?ooo`03
0000003oool0oooo00<0oooo7@00W_l00`0000000?n?003oS`0F003oS`03
0000000To`009?l001809?l000<000000;[o002jo`003P2jo`02000000`0
olh000<000000?md003oM0001`3oM0000`000000ocP00?lh00030?lh0004
0000003o6P000000000000D0ocP000<000000?md003oM0001`3oM0000`00
0000olh00?o>000;0?o>00030000002jo`00^_l000h0^_l000<0000002Co
000To`004P0To`000`0000000?n?003oS`0F003oS`0300000000W_l009ko
01X009ko1P3oool00`000000oooo0?ooo`090?ooo`00Q03oool00`000000
oooo0?ooo`030?ooo`<000006`00W_l00`0000000?n?003oS`0F003oS`03
0000000To`009?l001809?l000<000000;[o002jo`003P2jo`000`000000
olh00?o>000:0?o>00030000003oM000og@000L0og@000<000000?lh003o
>0000`3o>00010000000oaX00000000000050?lh00030000003oM000og@0
00L0og@000<000000?o>003ocP002P3ocP000`000000^_l00;[o000>0;[o
00030000000To`009?l001809?l000<00000003oS`00ohl05P00ohl00`00
000009ko002No`0I002No`<000001@3oool00`000000oooo0?ooo`090?oo
o`00Q03oool2000000@0oooo0`1A0?l00`00000009ko002No`0H002No`03
00000000ohl00?n?01H00?n?00<0000002Co000To`004P0To`000`000000
^_l00;[o000>0;[o00030000003ocP00olh000X0olh000<000000?md003o
M0001`3oM0000`000000ocP00?lh00030?lh00040000003o6P0000000000
00D0ocP000<000000?md003oM0001P3oM0000`000000olh00?o>000;0?o>
00030000002jo`00^_l000h0^_l000<0000002Co000To`004P0To`000`00
00000?n?003oS`0E003oS`0300000000W_l009ko01T009ko00<000000540
o`1A0?l01@3oool2000000/0oooo00240?ooo`030000003oool0oooo00<0
oooo0`1A0?l2000001X009ko0P00000G003oS`030000000To`009?l00180
9?l000<000000;[o002jo`003P2jo`000`000000olh00?o>000:0?o>0003
0000003oM000og@000H0og@000<000000?lh003o>0000`3o>00010000000
oaX00000000000050?lh00030000003oM000og@000H0og@000<000000?o>
003ocP002P3ocP02000000l0^_l000<0000002Co000To`004P0To`000`00
00000?n?003oS`0E003oS`8000006P00W_l200000080D@3o1P3oool00`00
0000oooo0?ooo`090?ooo`00Q03oool00`000000oooo0?ooo`030?ooo`D0
D@3o00<00000002No`00W_l06@00W_l00`0000000?n?003oS`0E003oS`03
0000000To`009?l001409?l00P00000?0;[o00030000003ocP00olh000X0
olh000<000000?md003oM0001P3oM0000`000000ocP00?lh00030?lh0004
0000003o6P000000000000D0ocP000<000000?md003oM0001P3oM0000`00
0000olh00?o>000:0?o>00030000002jo`00^_l000h0^_l000<0000002Co
000To`004@0To`000`0000000?n?003oS`0E003oS`0300000000W_l009ko
01T009ko00<000000540o`1A0?l00P1A0?l60?ooo`030000003oool0oooo
00T0oooo00240?ooo`030000003oool0oooo00<0oooo1P1A0?l2000001X0
09ko00<00000003oS`00ohl05@00ohl00`0000009?l002Co000A02Co0003
0000002jo`00^_l000d0^_l000<000000?o>003ocP002P3ocP000`000000
og@00?md00060?md00030000003o>000ocP000<0ocP000@000000?lJ0000
000000001@3o>0000`000000og@00?md00060?md00030000003ocP00olh0
00X0olh000<000000;[o002jo`003@2jo`000`0000009?l002Co000A02Co
008000005P00ohl00`00000009ko002No`0H002No`8000001@1A0?l60?oo
o`030000003oool0oooo00T0oooo00240?ooo`030000003oool0oooo00<0
oooo201A0?l2000001T009ko0P00000F003oS`030000000To`009?l00140
9?l000<000000;[o002jo`003@2jo`000`000000olh00?o>00090?o>0003
0000003oM000og@000H0og@000<000000?lh003o>0000`3o>00010000000
oaX00000000000050?lh00030000003oM000og@000H0og@000<000000?o>
003ocP002@3ocP000`000000^_l00;[o000=0;[o00030000000To`009?l0
01409?l000<00000003oS`00ohl05000ohl2000001T009ko0P0000070540
o`H0oooo00<000000?ooo`3oool02@3oool008@0oooo00<000000?ooo`3o
ool00`3oool90540o`0300000000W_l009ko01P009ko00<00000003oS`00
ohl05000ohl00`0000009?l002Co000A02Co00030000002jo`00^_l000d0
^_l000<000000?o>003ocP002@3ocP000`000000og@00?md00060?md0003
0000003o>000ocP000<0ocP000@000000?lJ0000000000001@3o>0000`00
0000og@00?md00050?md00030000003ocP00olh000X0olh000<000000;[o
002jo`003@2jo`000`0000009?l002Co000@02Co000300000000ohl00?n?
01D00?n?00<00000002No`00W_l06000W_l00`000000D@3o0540o`060540
o`H0oooo00<000000?ooo`3oool02@3oool008@0oooo0P0000040?ooo`X0
D@3o00<00000002No`00W_l06000W_l2000001D00?n?00<0000002Co000T
o`00400To`000`000000^_l00;[o000=0;[o00030000003ocP00olh000X0
olh000<000000?md003oM0001@3oM0000`000000ocP00?lh00030?lh0004
0000003o6P000000000000D0ocP000<000000?md003oM0001@3oM0000`00
0000olh00?o>000:0?o>00030000002jo`00^_l000d0^_l000<0000002Co
000To`00400To`000`0000000?n?003oS`0C003oS`8000006P00W_l00`00
0000D@3o0540o`070540o`D0oooo0P00000;0?ooo`00Q03oool00`000000
oooo0?ooo`030?ooo`/0D@3o0P00000I002No`0300000000ohl00?n?01@0
0?n?00<0000002Co000To`00400To`000`000000^_l00;[o000=0;[o0003
0000003ocP00olh000T0olh000<000000?md003oM0001P3oM0000`000000
ocP00?lh00020?lh00040000003o6P000000000000D0ocP000<000000?md
003oM0001@3oM0000`000000olh00?o>00090?o>00030000002jo`00^_l0
00d0^_l000<0000002Co000To`00400To`000`0000000?n?003oS`0D003o
S`0300000000W_l009ko01L009ko0P00000:0540o`H0oooo00<000000?oo
o`3oool02@3oool008@0oooo00<000000?ooo`3oool00`3oool=0540o`80
00006000W_l00`0000000?n?003oS`0C003oS`8000004P0To`000`000000
^_l00;[o000<0;[o00030000003ocP00olh000T0olh000<000000?md003o
M0001P3oM0000`000000ocP00?lh00020?lh00040000003o6P0000000000
00@0ocP000<000000?md003oM0001P3oM0000`000000olh00?o>00090?o>
00030000002jo`00^_l000`0^_l000<0000002Co000To`00400To`020000
01D00?n?00<00000002No`00W_l05P00W_l2000000`0D@3o1P3oool00`00
0000oooo0?ooo`090?ooo`00Q03oool00`000000oooo0?ooo`030?ooo`h0
D@3o0P00000H002No`8000005@00ohl00`0000009?l002Co000?02Co0003
0000002jo`00^_l000`0^_l000<000000?o>003ocP002@3ocP000`000000
og@00?md00060?md00030000003o>000ocP00080ocP000@000000?lJ0000
00000000103o>0000`000000og@00?md00060?md00030000003ocP00olh0
00T0olh000<000000;[o002jo`00302jo`000`0000009?l002Co000@02Co
000300000000ohl00?n?01<00?n?00<00000002No`00W_l05P00W_l20000
00d0D@3o1P3oool00`000000oooo0?ooo`090?ooo`00L03oool500000080
oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`l0
D@3o00<00000002No`00W_l05`00W_l00`0000000?n?003oS`0C003oS`03
0000000To`009?l000l09?l000<000000;[o002jo`00302jo`000`000000
olh00?o>00090?o>00030000003oM000og@000H0og@000<000000?lh003o
>0000P3o>00010000000oaX00000000000040?lh00030000003oM000og@0
00H0og@000<000000?o>003ocP00203ocP000`000000^_l00;[o000<0;[o
00030000000To`009?l001009?l000<00000003oS`00ohl04`00ohl00`00
000009ko002No`0G002No`030000001A0?l0D@3o00`0D@3o1P3oool00`00
0000oooo0?ooo`090?ooo`00LP3oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool@0540
o`8000006000W_l00`0000000?n?003oS`0B003oS`8000004@0To`000`00
0000^_l00;[o000<0;[o00030000003ocP00olh000T0olh000<000000?md
003oM0001@3oM0000`000000ocP00?lh00020?lh00040000003o6P000000
000000@0ocP000<000000?md003oM0001@3oM002000000X0olh000<00000
0;[o002jo`00302jo`000`0000009?l002Co000?02Co008000005000ohl0
0`00000009ko002No`0F002No`8000003`1A0?l60?ooo`030000003oool0
oooo00T0oooo001b0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool3000000<0oooo4P1A0?l00`00000009ko002No`0F002N
o`0300000000ohl00?n?01800?n?00<0000002Co000To`003`0To`000`00
0000^_l00;[o000<0;[o00030000003ocP00olh000T0olh000<000000?md
003oM0001@3oM0000`000000ocP00?lh00020?lh00040000003o6P000000
000000@0ocP000<000000?md003oM0001@3oM0000`000000olh00?o>0009
0?o>00030000002jo`00^_l000`0^_l000<0000002Co000To`003`0To`00
0`0000000?n?003oS`0B003oS`0300000000W_l009ko01H009ko00<00000
0540o`1A0?l03`1A0?l40?ooo`<000002`3oool00780oooo00<000000?oo
o`3oool0203oool2000000D0oooo00<000000?ooo`3oool00`3ooolC0540
o`0300000000W_l009ko01H009ko00<00000003oS`00ohl04P00ohl00`00
00009?l002Co000?02Co00030000002jo`00^_l000/0^_l00P00000:0?o>
00030000003oM000og@000D0og@000<000000?lh003o>0000P3o>0001000
0000oaX00000000000040?lh00030000003oM000og@000D0og@000<00000
0?o>003ocP002@3ocP000`000000^_l00;[o000;0;[o00030000000To`00
9?l000l09?l000<00000003oS`00ohl04P00ohl00`00000009ko002No`0F
002No`030000001A0?l0D@3o0100D@3o1P3oool00`000000oooo0?ooo`09
0?ooo`00LP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3ooolD0540o`8000005`00W_l00`00
00000?n?003oS`0B003oS`030000000To`009?l000h09?l000<000000;[o
002jo`00302jo`000`000000olh00?o>00080?o>00030000003oM000og@0
00D0og@000<000000?lh003o>0000P3o>00010000000oaX0000000000004
0?lh00030000003oM000og@000D0og@000<000000?o>003ocP00203ocP00
0`000000^_l00;[o000<0;[o00030000000To`009?l000h09?l000<00000
003oS`00ohl04P00ohl00`00000009ko002No`0E002No`8000004`1A0?l6
0?ooo`030000003oool0oooo00T0oooo001a0?ooo`8000002P3oool30000
00@0oooo00<000000?ooo`3oool00`3ooolF0540o`0300000000W_l009ko
01@009ko00<00000003oS`00ohl04P00ohl00`0000009?l002Co000?02Co
00030000002jo`00^_l000/0^_l000<000000?o>003ocP00203ocP000`00
0000og@00?md00050?md00030000003o>000ocP00080ocP000@000000?lJ
000000000000103o>0000`000000og@00?md00050?md00030000003ocP00
olh000P0olh000<000000;[o002jo`002`2jo`000`0000009?l002Co000?
02Co000300000000ohl00?n?01800?n?00<00000002No`00W_l05@00W_l0
0`000000D@3o0540o`0B0540o`H0oooo00<000000?ooo`3oool02@3oool0
08@0oooo00<000000?ooo`3oool00`3ooolF0540o`8000005P00W_l00`00
00000?n?003oS`0B003oS`030000000To`009?l000h09?l000<000000;[o
002jo`002`2jo`000`000000olh00?o>00080?o>00030000003oM000og@0
00D0og@000<000000?lh003o>0000P3o>00010000000oaX0000000000004
0?lh00030000003oM000og@000D0og@000<000000?o>003ocP00203ocP00
0`000000^_l00;[o000;0;[o00030000000To`009?l000l09?l000<00000
003oS`00ohl04@00ohl00`00000009ko002No`0D002No`8000005@1A0?l6
0?ooo`030000003oool0oooo00T0oooo00240?ooo`030000003oool0oooo
00<0oooo5`1A0?l2000001H009ko00<00000003oS`00ohl04@00ohl20000
00l09?l000<000000;[o002jo`00302jo`000`000000olh00?o>00070?o>
00030000003oM000og@000D0og@000<000000?lh003o>0000P3o>0001000
0000oaX00000000000040?lh00030000003oM000og@000D0og@000<00000
0?o>003ocP001`3ocP02000000d0^_l000<0000002Co000To`003P0To`00
0`0000000?n?003oS`0A003oS`0300000000W_l009ko01@009ko0P00000F
0540o`H0oooo00<000000?ooo`3oool02@3oool008@0oooo0P0000040?oo
oaT0D@3o00<00000002No`00W_l05000W_l00`0000000?n?003oS`0A003o
S`030000000To`009?l000h09?l000<000000;[o002jo`002`2jo`000`00
0000olh00?o>00080?o>00030000003oM000og@000@0og@000<000000?lh
003o>0000P3o>00010000000oaX00000000000040?lh00030000003oM000
og@000@0og@000<000000?o>003ocP00203ocP000`000000^_l00;[o000;
0;[o00030000000To`009?l000h09?l000<00000003oS`00ohl04@00ohl0
0`00000009ko002No`0D002No`030000001A0?l0D@3o01H0D@3o1@3oool2
000000/0oooo00240?ooo`030000003oool0oooo00<0oooo6@1A0?l20000
01H009ko00<00000003oS`00ohl04@00ohl00`0000009?l002Co000=02Co
00030000002jo`00^_l000/0^_l000<000000?o>003ocP00203ocP000`00
0000og@00?md00040?md00030000003o>000ocP00080ocP000@000000?lJ
000000000000103o>0000`000000og@00?md00040?md00030000003ocP00
olh000P0olh000<000000;[o002jo`002`2jo`000`0000009?l002Co000=
02Co000300000000ohl00?n?01400?n?00<00000002No`00W_l05000W_l2
000001P0D@3o1P3oool00`000000oooo0?ooo`090?ooo`00Q03oool00`00
0000oooo0?ooo`030?ooo`030000001A0?l0000001P0D@3o00<00000002N
o`00W_l04`00W_l00`0000000?n?003oS`0A003oS`030000000To`009?l0
00d09?l000<000000;[o002jo`002`2jo`000`000000olh00?o>00080?o>
00030000003oM000og@000@0og@000<000000?lh003o>0000P3o>0001000
0000oaX00000000000040?lh00030000003oM000og@000@0og@000<00000
0?o>003ocP00203ocP000`000000^_l00;[o000:0;[o00030000000To`00
9?l000h09?l000<00000003oS`00ohl04000ohl00`00000009ko002No`0E
002No`030000001A0?l0D@3o01L0D@3o00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`090?ooo`00Q03oool00`000000oooo0?ooo`030?oo
o`030?l0X@000000000001P0D@3o0P00000E002No`0300000000ohl00?n?
01000?n?00<0000002Co000To`003P0To`000`000000^_l00;[o000:0;[o
00030000003ocP00olh000P0olh000<000000?md003oM0001@3oM0001P00
0000ocP00?lh003o>00000000?lJ00800000103o>0000`000000og@00?md
00040?md00030000003ocP00olh000P0olh000<000000;[o002jo`002P2j
o`000`0000009?l002Co000>02Co000300000000ohl00?n?01000?n?00<0
0000002No`00W_l04`00W_l2000001P0D@3o0P0000060?ooo`030000003o
ool0oooo00T0oooo00240?ooo`030000003oool0oooo00<0oooo0`3o0:40
0`000000D@3o0540o`0F0540o`0300000000W_l009ko01@009ko00<00000
003oS`00ohl04000ohl00`0000009?l002Co000=02Co00030000002jo`00
^_l000/0^_l000<000000?o>003ocP001`3ocP000`000000og@00?md0005
0?md00060000003o>000ocP00?lh00000000oaX00P0000040?lh00030000
003oM000og@000@0og@000<000000?o>003ocP001`3ocP000`000000^_l0
0;[o000;0;[o00030000000To`009?l000d09?l000<00000003oS`00ohl0
4000ohl00`00000009ko002No`0D002No`030000001A0?l0D@3o01H0D@3o
00<000000?l0X@3o0:401P3oool00`000000oooo0?ooo`090?ooo`00Q03o
ool00`000000oooo0?ooo`030?ooo`@0o`2Q0P00000G0540o`8000005000
W_l2000001800?n?00<0000002Co000To`003@0To`000`000000^_l00;[o
000:0;[o00030000003ocP00olh000L0olh000<000000?md003oM0001@3o
M0001P000000ocP00?lh003o>00000000?lJ008000000`3o>0000`000000
og@00?md00050?md00030000003ocP00olh000L0olh000<000000;[o002j
o`002P2jo`000`0000009?l002Co000=02Co000300000000ohl00?n?0140
0?n?00<00000002No`00W_l04`00W_l00`000000D@3o0540o`0F0540o`04
0000003o0:40o`2Q0?l0X@H0oooo00<000000?ooo`3oool02@3oool008@0
oooo00<000000?ooo`3oool00`3oool50?l0X@8000005`1A0?l2000001@0
09ko00<00000003oS`00ohl04000ohl2000000h09?l000<000000;[o002j
o`002P2jo`000`000000olh00?o>00070?o>00030000003oM000og@000D0
og@000H000000?lh003o>000ocP00000003o6P02000000<0ocP000<00000
0?md003oM0001@3oM0000`000000olh00?o>00070?o>00030000002jo`00
^_l000X0^_l000<0000002Co000To`003@0To`000`0000000?n?003oS`0@
003oS`0300000000W_l009ko018009ko0P00000G0540o`800000103o0:46
0?ooo`030000003oool0oooo00T0oooo00240?ooo`800000103oool70?l0
X@030000001A0?l0D@3o01D0D@3o00<00000002No`00W_l04`00W_l00`00
00000?n?003oS`0?003oS`030000000To`009?l000d09?l000<000000;[o
002jo`002P2jo`000`000000olh00?o>00070?o>00030000003oM000og@0
00D0og@000H000000?lh003o>000ocP00000003o6P02000000<0ocP000<0
00000?md003oM000103oM0000`000000olh00?o>00080?o>00030000002j
o`00^_l000X0^_l000<0000002Co000To`00300To`000`0000000?n?003o
S`0@003oS`0300000000W_l009ko01<009ko00<000000540o`1A0?l05P1A
0?l00`000000o`2Q0?l0X@030?l0X@D0oooo0P00000;0?ooo`00Q03oool0
0`000000oooo0?ooo`030?ooo`L0o`2Q0P00000G0540o`0300000000W_l0
09ko018009ko00<00000003oS`00ohl04000ohl00`0000009?l002Co000=
02Co00030000002jo`00^_l000X0^_l000<000000?o>003ocP001`3ocP00
0`000000og@00?md00040?md00060000003o>000ocP00?lh00000000oaX0
0P0000030?lh00030000003oM000og@000@0og@000<000000?o>003ocP00
203ocP000`000000^_l00;[o00090;[o00030000000To`009?l000d09?l0
00<00000003oS`00ohl04000ohl00`00000009ko002No`0B002No`030000
001A0?l0D@3o01D0D@3o0P0000060?l0X@H0oooo00<000000?ooo`3oool0
2@3oool008@0oooo00<000000?ooo`3oool00`3oool90?l0X@030000001A
0?l0D@3o01D0D@3o00<00000002No`00W_l04P00W_l00`0000000?n?003o
S`0@003oS`030000000To`009?l000`09?l000<000000;[o002jo`002P2j
o`000`000000olh00?o>00070?o>00030000003oM000og@000@0og@000H0
00000?lh003o>000ocP00000003o6P02000000<0ocP000<000000?md003o
M000103oM0000`000000olh00?o>00070?o>00030000002jo`00^_l000X0
^_l000<0000002Co000To`003@0To`000`0000000?n?003oS`0?003oS`03
00000000W_l009ko018009ko00<000000540o`1A0?l05@1A0?l00`000000
o`2Q0?l0X@060?l0X@H0oooo00<000000?ooo`3oool02@3oool008@0oooo
00<000000?ooo`3oool00`3oool:0?l0X@030000001A0?l0D@3o01D0D@3o
00<00000002No`00W_l04P00W_l00`0000000?n?003oS`0?003oS`030000
000To`009?l000d09?l000<000000;[o002jo`002@2jo`000`000000olh0
0?o>00070?o>00030000003oM000og@000@0og@000H000000?lh003o>000
ocP00000003o6P02000000<0ocP000<000000?md003oM000103oM0000`00
0000olh00?o>00070?o>00030000002jo`00^_l000X0^_l000<0000002Co
000To`00300To`000`0000000?n?003oS`0?003oS`0300000000W_l009ko
018009ko00<000000540o`1A0?l05@1A0?l00`000000o`2Q0?l0X@070?l0
X@H0oooo00<000000?ooo`3oool02@3oool008@0oooo00<000000?ooo`3o
ool00`3oool;0?l0X@030000001A0?l0D@3o01D0D@3o00<00000002No`00
W_l04P00W_l00`0000000?n?003oS`0?003oS`030000000To`009?l000`0
9?l000<000000;[o002jo`002@2jo`000`000000olh00?o>00070?o>0003
0000003oM000og@000@0og@000H000000?lh003o>000ocP00000003o6P02
000000<0ocP000<000000?md003oM000103oM0000`000000olh00?o>0007
0?o>00030000002jo`00^_l000T0^_l000<0000002Co000To`00300To`00
0`0000000?n?003oS`0?003oS`0300000000W_l009ko018009ko00<00000
0540o`1A0?l05@1A0?l00`000000o`2Q0?l0X@080?l0X@H0oooo00<00000
0?ooo`3oool02@3oool008@0oooo00<000000?ooo`3oool00`3oool<0?l0
X@030000001A0?l0D@3o01@0D@3o00<00000002No`00W_l04P00W_l00`00
00000?n?003oS`0?003oS`030000000To`009?l000`09?l000<000000;[o
002jo`002@2jo`000`000000olh00?o>00070?o>00030000003oM000og@0
00@0og@000H000000?lh003o>000ocP00000003o6P02000000<0ocP000<0
00000?md003oM000103oM0000`000000olh00?o>00060?o>00030000002j
o`00^_l000X0^_l000<0000002Co000To`00300To`000`0000000?n?003o
S`0?003oS`0300000000W_l009ko018009ko00<000000540o`1A0?l05@1A
0?l00`000000o`2Q0?l0X@080?l0X@H0oooo00<000000?ooo`3oool02@3o
ool008@0oooo0P0000040?ooo`d0o`2Q00<000000540o`1A0?l0501A0?l0
0`00000009ko002No`0A002No`0300000000ohl00?n?00l00?n?00<00000
02Co000To`00300To`000`000000^_l00;[o000:0;[o00030000003ocP00
olh000H0olh000<000000?md003oM000103oM0001P000000ocP00?lh003o
>00000000?lJ008000000`3o>0000`000000og@00?md00040?md00030000
003ocP00olh000H0olh000<000000;[o002jo`002P2jo`000`0000009?l0
02Co000<02Co000300000000ohl00?n?00l00?n?00<00000002No`00W_l0
4@00W_l00`000000D@3o0540o`0D0540o`8000002`3o0:450?ooo`800000
2`3oool008@0oooo00<000000?ooo`3oool00`3oool>0?l0X@030000001A
0?l0D@3o01@0D@3o00<00000002No`00W_l04@00W_l00`0000000?n?003o
S`0?003oS`030000000To`009?l000`09?l000<000000;[o002jo`002@2j
o`000`000000olh00?o>00060?o>00030000003oM000og@000@0og@000H0
00000?lh003o>000ocP00000003o6P02000000<0ocP000<000000?md003o
M000103oM0000`000000olh00?o>00060?o>00030000002jo`00^_l000T0
^_l000<0000002Co000To`00300To`000`0000000?n?003oS`0?003oS`03
00000000W_l009ko014009ko00<000000540o`1A0?l0501A0?l00`000000
o`2Q0?l0X@0;0?l0X@H0oooo00<000000?ooo`3oool02@3oool008@0oooo
00<000000?ooo`3oool00`3oool?0?l0X@030000001A0?l0D@3o01@0D@3o
00<00000002No`00W_l04@00W_l00`0000000?n?003oS`0>003oS`030000
000To`009?l000`09?l000<000000;[o002jo`002@2jo`000`000000olh0
0?o>00060?o>00030000003oM000og@000@0og@000H000000?lh003o>000
ocP00000003o6P02000000<0ocP000<000000?md003oM000103oM0000`00
0000olh00?o>00060?o>00030000002jo`00^_l000T0^_l000<0000002Co
000To`00300To`000`0000000?n?003oS`0>003oS`8000004P00W_l00`00
0000D@3o0540o`0D0540o`030000003o0:40o`2Q00`0o`2Q1P3oool00`00
0000oooo0?ooo`090?ooo`00Q03oool00`000000oooo0?ooo`030?oooa00
o`2Q00<000000540o`1A0?l0501A0?l00`00000009ko002No`0A002No`03
00000000ohl00?n?00h00?n?00<0000002Co000To`002`0To`000`000000
^_l00;[o00090;[o00030000003ocP00olh000L0olh000<000000?md003o
M0000`3oM0001P000000ocP00?lh003o>00000000?lJ008000000`3o>000
0`000000og@00?md00030?md00030000003ocP00olh000L0olh000<00000
0;[o002jo`002@2jo`000`0000009?l002Co000;02Co000300000000ohl0
0?n?00l00?n?00<00000002No`00W_l04000W_l00`000000D@3o0540o`0D
0540o`030000003o0:40o`2Q00d0o`2Q1P3oool00`000000oooo0?ooo`09
0?ooo`00Q03oool00`000000oooo0?ooo`030?oooa40o`2Q00<000000540
o`1A0?l04`1A0?l00`00000009ko002No`0A002No`0300000000ohl00?n?
00h00?n?00<0000002Co000To`002`0To`000`000000^_l00;[o00090;[o
00030000003ocP00olh000L0olh000<000000?md003oM0000`3oM0001P00
0000ocP00?lh003o>00000000?lJ008000000`3o>0000`000000og@00?md
00030?md00030000003ocP00olh000L0olh000<000000;[o002jo`00202j
o`000`0000009?l002Co000<02Co000300000000ohl00?n?00h00?n?00<0
0000002No`00W_l04@00W_l00`000000D@3o0540o`0D0540o`030000003o
0:40o`2Q00d0o`2Q1P3oool00`000000oooo0?ooo`090?ooo`00Q03oool0
0`000000oooo0?ooo`030?oooa40o`2Q0P00000E0540o`0300000000W_l0
09ko010009ko00<00000003oS`00ohl03P00ohl00`0000009?l002Co000<
02Co00030000002jo`00^_l000T0^_l000<000000?o>003ocP001P3ocP00
0`000000og@00?md00030?md00060000003o>000ocP00?lh00000000oaX0
0P0000030?lh00030000003oM000og@000<0og@000<000000?o>003ocP00
1`3ocP000`000000^_l00;[o00080;[o00030000000To`009?l000`09?l0
00<00000003oS`00ohl03P00ohl00`00000009ko002No`0@002No`030000
001A0?l0D@3o01<0D@3o0P00000@0?l0X@H0oooo00<000000?ooo`3oool0
2@3oool008@0oooo0P0000040?oooa80o`2Q0P00000E0540o`0300000000
W_l009ko010009ko00<00000003oS`00ohl03P00ohl00`0000009?l002Co
000;02Co00030000002jo`00^_l000T0^_l000<000000?o>003ocP001P3o
cP000`000000og@00?md00030?md00060000003o>000ocP00?lh00000000
oaX00P0000030?lh00030000003oM000og@000<0og@000<000000?o>003o
cP001P3ocP000`000000^_l00;[o00090;[o00030000000To`009?l000/0
9?l000<00000003oS`00ohl03P00ohl00`00000009ko002No`0A002No`03
0000001A0?l0D@3o0180D@3o0P00000A0?l0X@D0oooo0P00000;0?ooo`00
Q03oool00`000000oooo0?ooo`030?oooa@0o`2Q00<000000540o`1A0?l0
4P1A0?l00`00000009ko002No`0A002No`0300000000ohl00?n?00d00?n?
0P00000<02Co00030000002jo`00^_l000T0^_l000<000000?o>003ocP00
1P3ocP000`000000og@00?md00030?md00060000003o>000ocP00?lh0000
0000oaX00P0000030?lh00030000003oM000og@000<0og@000<000000?o>
003ocP001P3ocP000`000000^_l00;[o00090;[o00030000000To`009?l0
00/09?l000<00000003oS`00ohl03@00ohl00`00000009ko002No`0A002N
o`030000001A0?l0D@3o01<0D@3o00<000000?l0X@3o0:40403o0:460?oo
o`030000003oool0oooo00T0oooo00240?ooo`030000003oool0oooo00<0
oooo503o0:42000001@0D@3o00<00000002No`00W_l04000W_l00`000000
0?n?003oS`0>003oS`030000000To`009?l000/09?l000<000000;[o002j
o`00202jo`000`000000olh00?o>00060?o>00030000003oM000og@000<0
og@000H000000?lh003o>000ocP00000003o6P02000000<0ocP000<00000
0?md003oM0000`3oM0000`000000olh00?o>00060?o>00030000002jo`00
^_l000P0^_l000<0000002Co000To`002`0To`000`0000000?n?003oS`0>
003oS`0300000000W_l009ko010009ko00<000000540o`1A0?l04P1A0?l2
000001<0o`2Q1P3oool00`000000oooo0?ooo`090?ooo`00Q03oool00`00
0000oooo0?ooo`030?oooaH0o`2Q00<000000540o`1A0?l04P1A0?l00`00
000009ko002No`0?002No`0300000000ohl00?n?00h00?n?00<0000002Co
000To`002`0To`000`000000^_l00;[o00080;[o00030000003ocP00olh0
00H0olh000<000000?md003oM0000`3oM0001P000000ocP00?lh003o>000
00000?lJ008000000`3o>0000`000000og@00?md00030?md00030000003o
cP00olh000H0olh000<000000;[o002jo`00202jo`000`0000009?l002Co
000;02Co000300000000ohl00?n?00d00?n?00<00000002No`00W_l04000
W_l00`000000D@3o0540o`0C0540o`030000003o0:40o`2Q0180o`2Q1P3o
ool00`000000oooo0?ooo`090?ooo`00O03oool4000000@0oooo00<00000
0?ooo`3oool00`3ooolF0?l0X@030000001A0?l0D@3o0180D@3o00<00000
002No`00W_l04000W_l00`0000000?n?003oS`0=003oS`030000000To`00
9?l000/09?l000<000000;[o002jo`00202jo`000`000000olh00?o>0006
0?o>00030000003oM000og@000@0og@000D000000?lh003o>00000000?lJ
0002000000<0ocP000<000000?md003oM0000`3oM0000`000000olh00?o>
00060?o>00030000002jo`00^_l000P0^_l000<0000002Co000To`002`0T
o`000`0000000?n?003oS`0=003oS`0300000000W_l009ko010009ko00<0
00000540o`1A0?l04P1A0?l00`000000o`2Q0?l0X@0C0?l0X@H0oooo00<0
00000?ooo`3oool02@3oool007`0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?oooaL0o`2Q00<000000540o`1A0?l04P1A0?l0
0`00000009ko002No`0@002No`0300000000ohl00?n?00d00?n?00<00000
02Co000To`002P0To`02000000X0^_l000<000000?o>003ocP001@3ocP02
000000D0og@000<000000?lh003o>000100000030?lh00030000003oM000
og@000<0og@000<000000?o>003ocP001@3ocP02000000X0^_l000<00000
02Co000To`002P0To`02000000l00?n?00<00000002No`00W_l03`00W_l0
0`000000D@3o0540o`0B0540o`8000005@3o0:460?ooo`030000003oool0
oooo00T0oooo001m0?ooo`030000003oool0oooo00@0oooo0`0000030?oo
oaP0o`2Q00<000000540o`1A0?l04P1A0?l00`00000009ko002No`0?002N
o`0300000000ohl00?n?00d00?n?00<0000002Co000To`002`0To`000`00
0000^_l00;[o00080;[o00030000003ocP00olh000D0olh000<000000?md
003oM000103oM0001@000000ocP00?lh00000000oaX0008000000P3o>000
0`000000og@00?md00040?md00030000003ocP00olh000D0olh000<00000
0;[o002jo`00202jo`000`0000009?l002Co000;02Co000300000000ohl0
0?n?00d00?n?00<00000002No`00W_l03`00W_l00`000000D@3o0540o`0B
0540o`030000003o0:40o`2Q01D0o`2Q103oool3000000/0oooo001n0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02@3oool007`0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00T0oooo001m0?ooo`8000001@3ooooo000000D0
00002`3oool00?l0ooooU03oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "The streamlines  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        "constant"}]]],
  "  form a family of hyperbolas with asymptotes along the coordinate axes.  \
The velocity vector  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["V",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
        " ", \(\(F' \((z)\)\)\&_\  = \ \ \(\(A\ z\)\&_\ \  = \ 
            A\ \(\(\ \)\(z\)\)\&_\)\)}]]],
  "  indicates that in the upper half-plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  ", the fluid flows down along the streamlines and spreads out along the x \
axis, as against a wall, as depicted in Figure 11.50."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.50",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/fluidflow/FluidFlowFigures/\
mat1150.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The fluid flow with complex potential  ",
  Cell[BoxData[
      \(F \((z)\)\  = \ A\/2\ z\^2\)],
    AspectRatioFixed->True],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.23.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the complex potential and determine the velocity potential and stream \
function.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[A, x, y, u, v, w, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, F];\)\ \), "\n", 
    \(\(F[z_]\  = \ A\/2\ z\^2;\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ 
        ComplexExpand[
          A\/2\ Re[\((x\  + \ \[ImaginaryI]\ y)\)\^2]];\)\ \), "\n", 
    \(\(\[Psi][x_, y_]\  = \ 
        ComplexExpand[
          A\/2\ Im[\((x\  + \ \[ImaginaryI]\ y)\)\^2]];\)\ \), "\n", 
    \(\(Print["\<The  complex potential is   F[z] = \>", F[z]];\)\ \), "\n", 
    \(\(Print["\<F[z]  =  \[Phi][x,y] + \[ImaginaryI] \[Psi][x,y]\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<F[z]  =  (\>", \[Phi][x, 
          y], "\<) + \[ImaginaryI](\>", \ \[Psi][x, 
          y], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential is \[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\n", 
    \(\(Print["\<The   stream function  is \[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a plot of the stream function.\n\nFor illustration purposes, we \
choose A = 1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(A = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(cont\  = \ Table[\((0.2  k)\)\^2, {k, 0, 10}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Psi][x, y], {x, 0, 2}, {y, 0, 2}, 
        Contours\  \[Rule] cont, PlotPoints \[Rule] 55, 
        AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, y]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[Psi][x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The inverse of  ",
  Cell[BoxData[
      \(w\  = \ \(f[z] = \(z\^2\ \ is\ \ z\  = \ \(g[w]\  = \ \@w\)\)\)\)]],
  ".  Use conformal mapping  z = g(w)  to make an image of the flow."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(g[w_]\  = \ \@w;\)\ \), "\[IndentingNewLine]", 
    \(\(Iden[w_]\  = \ w;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[Iden, {\(-4\), 4, 0.4}, {0, 4, 0.4}, 
        AspectRatio \[Rule] 1\/2, 
        Ticks \[Rule] {Range[\(-4\), 4, 1], Range[0, 4, 1]}, 
        PlotRange \[Rule] {{\(-4\), 4}, {0, 4}}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Red}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The horizontal flow in the z-plane.\>"];\)\ \), "\n", 
    \(\(CartesianMap[g, {\(-4\), 4, 0.4}, {0, 4, 0.4}, AspectRatio \[Rule] 1, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[0, 3, 1]}, 
        PlotRange \[Rule] {{0, 2}, {0, 2}}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        PlotStyle \[Rule] {Blue, Red}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image flow in the first quadrant,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<under the mapping z = g(w) = \>", 
        g[w]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The velocity potential is \[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\n", 
    \(\(Print["\<The   stream function  is \[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the complex potential  ",
  Cell[BoxData[
      \(F \((z)\)\  = \ A\ z\^\(4/3\)\)],
    AspectRatioFixed->True],
  "  where ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " is a positive real number.  The velocity potential and stream function \
are given by\n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{
          RowBox[{"\[Phi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
          "  ", \(A\ Re[\((x\  + \ \[ImaginaryI]\ y)\)\^\(4/3\)]\)}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "\[IndentingNewLine]", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}], "\n", 
      RowBox[{
        RowBox[{
          RowBox[{"\[Psi]", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "  ", "=", 
          "  ", \(A\ Im[\((x\  + \ \[ImaginaryI]\ y)\)\^\(4/3\)]\)}], 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]}]],
  "  \n\nrespectively.  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004e0000a2000`400?l0
0000o`00003oo`3ooolf0?ooo`00o`3ooolf0?ooo`00o`3ooolf0?ooo`00
o`3ooolf0?ooo`00o`3ooolf0?ooo`00L@3oool010000?l0oooo0?ooo`3o
00030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`000?l01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00H0oooo00<000000?ooo`3oool0I`3o
ool00740oooo00@0003o0?ooo`3oool0oooo0P3o00000`3oool0o`000?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00P0003o1@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000003o
ool0oooo06L0oooo001`0?ooo`030000o`3oool0oooo00@0oooo103o0005
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@000?l00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030000003oool0oooo06L0oooo001`0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3o00000`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000000
o`000?l01`000?l70?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`000000oooo0?ooo`1W0?ooo`00K`3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?l0003o
00000P3o00020?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0000o`060000o`03
0?l000000?l0003o00h0003o00<000000?ooo`3oool0I`3oool006l0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo0080oooo103o00070?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<000000?ooo`3oool0
I`3oool006`0oooo10000?l70?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?l000040?l000030?ooo`00
0?l0oooo00L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
00000?ooo`3oool0I`3oool006l0oooo0P000?l60?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`030?l000000?l0o`000080o`00103oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`000000oooo0?ooo`1W0?ooo`00KP3oool00`00
0?l0oooo0?ooo`030000o`<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00@0003o0?oo
o`3oool0oooo1@3o00070?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`1W
0?ooo`00KP3oool00`000?l0oooo0?ooo`030?ooo`<0003o00<0o`000000
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool80?l000030000o`3o0000o`00
00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`00
0000oooo0?ooo`1W0?ooo`00KP3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0003o1`3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?l000030?ooo`3o0000oooo00L0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<000000?ooo`3oool0I`3oool006h0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`@0003o103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`H0o`000`3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`000000oooo0?ooo`1W0?ooo`00K@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3o
ool20000o`80oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`020?ooo`<0o`0000<0003o0?l0003o00002P3o
00050?ooo`030000o`3oool0oooo00H0oooo00<000000?ooo`3oool0I`3o
ool006d0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo0P000?l00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01P3oool0103o0000oooo0?ooo`3oool50?l000030000o`3o
0000o`0000H0o`0000<000000?ooo`3oool0I`3oool006`0oooo00<0o`00
0000o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`000?l010000?l20?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<00000
0?ooo`3oool0I`3oool006d0oooo00@0003o0?l0003o0000o`000`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool50000o`D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<000000?ooo`3oool0I`3oool006d0oooo00@0003o0?oo
o`3oool0oooo0P3o00000`3oool0o`000?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?ooo`3o
ool50000o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030000003o
ool0oooo06L0oooo001/0?ooo`030000o`3oool0oooo00@0oooo103o0005
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l000000?l0003o00@0003o0P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
000000<00000103oool00`000000oooo0?ooo`1W0?ooo`00K03oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0o`0000<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool50000o`H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`0000001`3oool00`000000oooo0?ooo`1W0?oo
o`00K03oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?l0003o00000P3o00030?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0003o00<0oooo0?l0003oool01`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00@0003o0?ooo`3o
ool000001P3oool2000006P0oooo001c0?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool00P3oool40?l000P0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000000o`000?l020000?l70?ooo`030?l0003oool0oooo0080
oooo100000001@000?l0oooo0?ooo`3oool0000000D0oooo00<000000?oo
o`3oool0I`3oool007<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`<0o`001@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0003o00H0003o00<0o`000000o`00
0?l00P000?l40?ooo`030000o`3oool000000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`1W0?ooo`00K03oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool0103o0000oooo0?ooo`3oool40?l000030?ooo`000?l0oooo00H0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`020?ooo`h0003o00<000000?ooo`3oool0I`3oool006d0oooo
0`000?l20?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030?l000000?l0o`000080o`00
103oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`000000oooo
0?ooo`1W0?ooo`00L03oool20000o`030?l000000?l0003o00H0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`070?ooo`040000o`3o
ool0oooo0?ooo`D0o`00203oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3oool0
I`3oool00740oooo00@0o`000?ooo`3oool0oooo10000?l00`3oool0003o
0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1@3oool60?l000<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`070?ooo`030000003oool0oooo06L0oooo
001a0?ooo`030?l0003oool0oooo00D0oooo0P000?l70?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`030?ooo`<0o`0000<0003o0?l0003oool01@3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`070?ooo`030000003oool0oooo06L0oooo001a
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`000?l00`000?l3
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0o`0000H0o`00203oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01`3oool00`000000oooo0?ooo`1W0?ooo`00L@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo0P000?l00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`D0o`00103oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01`3oool00`000000oooo0?ooo`1W0?ooo`00L03oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000000o`00
0?l01`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`@0
o`0000<0003o0?l0003oool01`3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00L0oooo00<000000?ooo`3oool0I`3oool006`0oooo
00D0o`000?ooo`3oool0oooo0?l000080?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool010000?l20?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3o00001@3o00020?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`000000
oooo0?ooo`1W0?ooo`00K@3oool20?l000030?ooo`3o0000oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`H0003o
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`/0o`00
00<0003o0?l0003o00001`3o00000`000000oooo0?ooo`1W0?ooo`00K`3o
ool30?l000H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo0080oooo10000?l00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01`3oool00`000000oooo0?ooo`1W0?ooo`00K`3oool0
0`3o0000oooo0?ooo`040?l00080oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0000o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3oool0I`3oool0
06h0oooo00<0o`000?ooo`3oool01@3oool20?l000030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0003o0`3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<000000?oo
o`3oool0I`3oool006h0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
o`000?l000020?l000@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo1P000?l60?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3o
ool0I`3oool006h0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`020?ooo`D0o`001`3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00@0003o0?ooo`3oool0oooo1@000?l00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`070?ooo`030000003oool0oooo06L0
oooo001^0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1`3oool20?l000H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000000o`000?l0
0`000?l40?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`070?ooo`030000003oool0oooo06L0oooo
001]0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`040?l00080oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool00`3oool60000o`P0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`070?ooo`030000003oool0oooo06L0oooo001/
0?ooo`030000o`3o0000003o00L0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`040?ooo`80o`0000<0003o0?l0003oool01@3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060000o`80oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030000003oool0
oooo06L0oooo001]0?ooo`040?l0003oool0003o0000o`@0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo0080o`00103oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3o0000003o00<0003o1@3oool00`000?l0oooo0?ooo`08
0?ooo`030000003oool0oooo06L0oooo001]0?ooo`040?l0003oool0oooo
0?ooo`<0003o00<0oooo0000o`3oool01`3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo0080oooo1@3o00080?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo0080oooo40000?l00`000000oooo0?ooo`1W
0?ooo`00K03oool00`3o0000oooo0?ooo`050?ooo`80003o1`3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo1P3o00040?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool0203oool00`000000oooo0?ooo`1W0?ooo`00K03oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0003o00<0003o0`3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool00`3oool20?l00080oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`080?ooo`030000003oool0oooo06L0
oooo001d0?ooo`030000o`3oool0oooo00<0oooo0P000?l00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool20?l000030000o`3o0000oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`1W0?ooo`00M03o
ool00`000?l0oooo0?ooo`050?ooo`030?l000000?l0003o00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00D0o`000P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`080?ooo`030000003oool0oooo06L0oooo001c0?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool00`000?l30?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`05
0?ooo`<0o`00203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`1W
0?ooo`00K03oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool00`3oool30000o`T0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0o`00
00<0o`00103oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`1W0?oo
o`00K@3oool20?l000@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`D0003o1@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00`3oool40?l00003
0000o`3o0000oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030000003oool0oooo06L0oooo001_0?ooo`<0o`00
00<0oooo0000o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo0080oooo10000?l00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?l000060?l000030?ooo`3o0000oooo00T0oooo00<0003o0?ooo`3oool0
203oool00`000000oooo0?ooo`1W0?ooo`00LP3oool010000?l0o`000?l0
003o00050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000003o0?ooo`070?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`H0o`00
1P3oool00`000?l0oooo0?ooo`080?ooo`030000003oool0oooo06L0oooo
001b0?ooo`040000o`3oool0oooo0?ooo`80o`000`3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`000?l0
0P000?l40?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0080oooo
1P3o00000`000?l0o`000?l000020?l000H0oooo00<000000?ooo`3oool0
I`3oool00740oooo00<0003o0?ooo`3oool0103oool30?l000P0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`020?ooo`<0003o00<0
oooo0000o`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`020?ooo`H0o`0000<000000?ooo`3oool0I`3oool00740oooo00<0003o
0?ooo`3oool01P3oool30?l000H0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`<0003o203oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`080?ooo`030000003oool0oooo06L0oooo001`0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00`3o00030?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool01000
0?l0oooo0000o`000?l50?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00T0oooo00<000000?ooo`3oool0I`3oool00700oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`80o`0000<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`040000o`3oool0oooo
0?ooo`@0003o00<0oooo0?l0003oool02@3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00P0oooo00@0003o0?ooo`3oool0oooo1@00
00030?ooo`030000003oool0oooo06L0oooo001/0?ooo`80003o00<0oooo
0000o`3oool0203oool00`3o0000oooo0?ooo`060?ooo`030000o`3o0000
o`0000H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3o0000003o0080003o1P3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo06L0oooo001^0?oo
o`80003o2@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
0080o`00103oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00L0oooo00@0o`000?ooo`3oool0oooo0`000?l30?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`03
0?ooo`030000003oool0oooo00<0oooo0P00001X0?ooo`00K`3oool40000
o`D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?oo
o`@0o`002@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00@0oooo1@000?l90?ooo`030?l0003oool0oooo00H0oooo0P0000000`00
0?l000000?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0I`3oool006h0oooo00<0003o0?ooo`3oool00P3oool20000o`<0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`80
o`00203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`000?l010000?l30?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo06L0oooo001^0?ooo`030000o`3oool0oooo00@0oooo
0P000?l00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3o00000P3o00050?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`040?ooo`<0003o
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`800000
1@3oool00`000000oooo0?ooo`1W0?ooo`00K@3oool00`000?l0oooo0?oo
o`060?ooo`80o`0000<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00<0oooo0`3o00000`3oool0003o0?oo
o`090?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000003o0000o`030000o`D0oooo00<0003o0?ooo`3oool02P3o
ool00`000000oooo0?ooo`1W0?ooo`00K@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00<0003o103oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0o`000000o`3o0000203oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool00`3oool70000o`/0oooo00<000000?ooo`3oool0I`3oool0
06d0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`@0003o2@3oool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0o`00
0?l000H0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`000?l02P000?l0
0`000000oooo0?ooo`1W0?ooo`00K03oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo10000?l60?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool00P3oool30?l000<0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`1W0?oo
o`00K03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00L0
oooo00@0003o0?ooo`3oool0oooo0P000?l40?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01@3oool30?l000X0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00X0oooo00<000000?ooo`3oool0I`3oool006d0oooo0P000?l50?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool20000o`03
0?ooo`3o0000oooo00T0oooo00<0003o0?ooo`3oool01`3oool40?l000L0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00X0oooo00<000000?ooo`3oool0I`3oool006l0oooo
0P000?l30?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0o`000?ooo`080?ooo`030000o`3oool0oooo00P0oooo
00@0o`000?ooo`3oool0oooo103o00030?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`03
0000003oool0oooo06L0oooo001a0?ooo`80003o00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`080?ooo`030?l000000?l0003o00L0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`80o`00
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00/0oooo00<000000?ooo`3oool0I`3oool007<0oooo00<0
o`000000o`000?l01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo0080003o1@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00P0oooo00@0003o0?l0003o0000o`00203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00/0oooo00<000000?ooo`3oool0
I`3oool00780oooo00@0o`000?ooo`3oool0oooo0P000?l40?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00`3oool30000o`030?oo
o`000?l0oooo00T0oooo00<0o`000?ooo`3oool0203oool010000?l0oooo
0?ooo`3oool30?l000D0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`0;0?ooo`030000003oool0oooo06L0oooo001b0?ooo`030?l0
003oool0oooo00<0oooo0P000?l00`3oool0003o0?ooo`090?ooo`030?l0
003oool0oooo00H0oooo0`000?l80?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool01@3oool50?l000/0oooo00<0003o0?ooo`3oool0
2`3oool00`000000oooo0?ooo`1W0?ooo`00L@3oool00`3o0000oooo0?oo
o`060?ooo`80003o2@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo0080003o1P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00T0oooo0`3o00090?ooo`030000o`3oool0oooo00/0oooo00<0
00000?ooo`3oool0I`3oool00740oooo00<0o`000?ooo`3oool01P3oool0
10000?l0oooo0000o`000?l70?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool00`3oool30000o`<0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`080?ooo`040?l0003oool0oooo0?ooo`@0o`00
1@3oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo06L0oooo
001/0?ooo`050?l0003oool0oooo0?ooo`3o00002@3oool010000?l0oooo
0?ooo`3oool20000o`@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`060?ooo`80003o00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00D0oooo103o00000`3oool0
003o0?ooo`0<0?ooo`030000003oool0oooo06L0oooo001]0?ooo`80o`00
00<0oooo0?l0003oool0203oool00`000?l0oooo0?ooo`030?ooo`<0003o
00<0oooo0?l0003oool01`3oool00`000?l0oooo0?ooo`080?ooo`80o`00
0P000?l80?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
2P3oool00`3o0000003o0?l000040?l000P0oooo00<000000?ooo`3oool0
I`3oool006l0oooo0P3o00080?ooo`030000o`3oool0oooo00L0oooo00<0
o`000000o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`040?l0003o
ool0oooo0?ooo`80003o1@3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool00`3oool80?l000030000
003oool0oooo06L0oooo001_0?ooo`<0o`001`3oool00`000?l0oooo0?oo
o`070?ooo`040?l0003oool0003o0000o`H0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`040?ooo`80003o0`3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
2`3oool00`000000oooo0?ooo`1W0?ooo`00K`3oool00`3o0000oooo0?oo
o`030?l000<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`020?ooo`80003o0`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00H0oooo0`000?l;0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool0303oool00`000000oooo0?ooo`1W0?ooo`00KP3oool0
0`3o0000oooo0?ooo`040?ooo`80o`0000<0oooo0000o`3oool0203oool0
0`3o0000oooo0?ooo`040?ooo`80003o00<0oooo0000o`3oool02@3oool0
0`3o0000oooo0?ooo`080?ooo`<0003o2@3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0I`3oool0
06h0oooo00<0o`000?ooo`3oool01P3oool00`000?l0o`000?ooo`070?oo
o`030?l0003oool0oooo00L0oooo0`000?l80?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool00P000?l70?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`1W0?oo
o`00K@3oool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0o`000?l0
00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`020000
o`H0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`030?oo
o`80003o1@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00d0oooo00<000000?ooo`3oool0I`3oool006d0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`020?ooo`80o`000`3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo0P000?l30?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01@3oool20000o`80
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0=0?ooo`03
0000003oool0oooo06L0oooo001/0?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool0103oool0103o0000oooo0?ooo`3o00090?ooo`03
0000o`3oool0oooo00D0oooo0P000?l00`3oool0o`000?ooo`0:0?ooo`03
0000o`3oool0oooo00L0oooo0P000?l00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00h0oooo00<000000?ooo`3oool0I`3oool006`0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`80o`00
2P3oool00`000?l0oooo0?ooo`070?ooo`030?l000000?l0oooo00T0oooo
00<0003o0?ooo`3oool02P3oool30000o`X0oooo00<0003o0?ooo`3oool0
3P3oool00`000000oooo0?ooo`1W0?ooo`00K@3oool20000o`H0oooo00<0
003o0?ooo`3oool01`3oool30?l0008000001@3oool00`000?l0oooo0?oo
o`080?ooo`040?l0003oool0003o0000o`P0oooo00<0003o0?ooo`3oool0
0`3oool5000000030?ooo`3o0000oooo0080oooo10000?l60?ooo`030000
o`3oool0oooo00h0oooo00<000000?ooo`3oool08@3oool500000240oooo
1000000L0?ooo`00K`3oool20000o`<0oooo00<0003o0?ooo`3oool01`3o
ool0103o0000oooo0000003oool20?l000D0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`020?ooo`80003o1@3oool00`000?l0oooo
0?ooo`060?ooo`050000003oool0oooo0?ooo`3o00001`3oool30000o`80
oooo00<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool07@3oool00740oooo
0P000?l00`3oool0003o0?ooo`080?ooo`040?l0003oool0oooo00000080
oooo0P3o00020?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01@3oool20000o`<0oooo00<0003o0?ooo`3oool01P3oool010000000
oooo0?ooo`3o000;0?ooo`<0003o4@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0703oool007<0
oooo0P000?l50?ooo`<0000000<0o`000?ooo`3oool00P3oool01P000000
oooo0?ooo`3oool0o`000000o`X0oooo00<0o`000?ooo`3oool01`3oool3
0000o`030?ooo`000000000000800000103oool010000000oooo0?ooo`3o
000=0?ooo`80003o403oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool06`3oool007<0oooo00@0003o
0?ooo`000?l0003o1@3oool01@3o0000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo0000o`020?l000L0oooo00<0o`000?ooo`3o
ool02@3oool30000o`P0oooo00<000000?ooo`3o00003P3oool010000?l0
oooo0000o`000?l>0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool08@3oool010000000oooo0?ooo`00000L0?ooo`00LP3oool00`00
0?l0oooo0?ooo`020?ooo`80003o0`3oool00`3o0000oooo0?ooo`020?oo
o`8000000`3oool010000?l0oooo0?ooo`3oool20?l000D0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`020000o`D0oooo0P000000
0`3oool0o`000?ooo`0<0?ooo`030000o`3oool0oooo0080oooo0`000?l;
0?ooo`030000003oool0oooo0280oooo0P00000T0?ooo`8000007@3oool0
0740oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?l0000:0?oo
o`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0?l0000;
0?ooo`030000o`3oool0oooo00<0oooo0P000?l50?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool01@3oool30000o`P0oooo00<00000
0?ooo`3oool0I`3oool00740oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0o`000?ooo`080?ooo`030000o`3oool0oooo00D0oooo0P3o00000`3o
ool0o`000?ooo`090?ooo`030000o`3oool0oooo00H0oooo0P000?l30?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool30000
o`D0oooo00<000000?ooo`3oool0I`3oool006`0oooo00D0o`000?ooo`3o
ool0oooo0000o`090?ooo`040?l0003oool0003o0000o`H0oooo00<0003o
0?ooo`3oool0203oool20?l000X0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?l0000>0?ooo`030000o`3oool0oooo00`0oooo0`000?l2
0?ooo`030000003oool0oooo06L0oooo001]0?ooo`030?l0003oool0003o
00X0oooo00@0o`000?ooo`3oool0oooo0P000?l40?ooo`030000o`3oool0
oooo00P0oooo00@0o`000?ooo`3o0000o`001`3oool00`000?l0oooo0?oo
o`0:0?ooo`030000o`3o0000oooo00`0oooo00<0003o0?ooo`3oool0403o
ool20000o`030000003oool0oooo06L0oooo001/0?ooo`80000000<0o`00
0000o`000000200000000`3o000000000000000400000080003o00<00000
0000o`0000002@0000000`3o000000000000000200000080o`001@000000
0`000?l000000000000:000000030?l000000000003o00`0000000<0003o
0000000000004P0000000`3o0000003o0000o`1M0000o`X0oooo001^0?oo
o`030000o`3oool0o`0000P0oooo00<0o`000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020000o`X0oooo00<0o`000?ooo`3oool0103oool20?l0
0080oooo00<0003o0?ooo`3oool02@3oool00`000000oooo0?l000020?oo
o`80003o2@3oool00`000?l0oooo0?ooo`0B0?ooo`80003o4P3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01`3oool0103o0000oooo0?ooo`000005
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool03@3oool0
06h0oooo00<0003o0?ooo`3oool00P3o00050?ooo`030?l0003oool0oooo
00@0oooo00D000000?ooo`3oool0003o0?ooo`020000o`L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0000o`0;0?ooo`030000003o0000
oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0B
0?ooo`040000o`3oool000000?l00140oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00L0oooo00@0o`000?ooo`3oool000001@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00d0oooo001]0?ooo`030000o`3o
ool0oooo00<0oooo0P3o00030?ooo`030?l0003oool0oooo00L0oooo00@0
003o0?ooo`3oool0oooo0P000?l40?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?l0003oool02P3oool00`3o0000oooo0?ooo`050?ooo`80003o
1@3oool00`000?l0oooo0?ooo`0A0?ooo`050000o`3oool0oooo0000003o
00004@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00d0oooo001]0?ooo`030000
o`3oool0oooo00D0oooo0`3o00090?ooo`030000o`3oool0oooo00@0oooo
00D0003o0?ooo`3oool0oooo0?l0000;0?ooo`030000o`3oool0o`0000T0
oooo00<0o`000?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0003o
01<0oooo00L0003o0?ooo`3oool0oooo0000003oool0o`000100oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0=0?ooo`00K03oool00`000?l0oooo0?ooo`08
0?ooo`80o`001`3oool00`000?l0oooo0?ooo`060?ooo`80003o00<0o`00
0?ooo`3oool02@3oool010000?l0oooo0?ooo`3oool20?l000L0oooo00<0
o`000?ooo`3oool02@3oool30000oa<0oooo00<0003o0?ooo`3oool00P3o
ool00`000000oooo0?l0000@0?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool03@3o
ool006`0oooo00<0003o0?ooo`3oool01`3oool0103o0000oooo0?ooo`3o
00060?ooo`030000o`3oool0oooo00P0oooo00<0o`000000o`3oool02@3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool02`3oool30000oa40oooo00<0003o0?ooo`3oool00`3o
ool00`000000oooo0?l0000@0?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool03@3o
ool007H0oooo00@0o`000?ooo`3oool0oooo0P3o00030?ooo`030000o`3o
ool0oooo00P0oooo00@0o`000?ooo`3oool0003o203oool00`000?l0oooo
0?ooo`050?ooo`80o`000P3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo0080003o3P3oool00`000?l0oooo0?ooo`040?ooo`040000
003oool0oooo0?l000l0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0=0?ooo`00
K03oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo
0P3o00000`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`80o`00
3P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00X0oooo
00<0003o0?ooo`3oool01@3oool010000000oooo0?ooo`3o000?0?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool0303oool006d0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool00`3oool20000o`@0oooo00<0003o0?ooo`3oool0
2@3oool30?l000/0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00@000000?ooo`3oool0
o`003`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool>0?l000X0
oooo001^0?ooo`80003o0`3oool00`3o0000oooo0?ooo`070?ooo`040000
o`3oool0o`000?l000L0oooo00<0o`000?ooo`3oool01P3oool010000?l0
oooo0?ooo`000?l;0?ooo`050?l0003oool0oooo0?ooo`3o00002P3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0o`0000h0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool00P3ooolG0?l000030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool0303oool00700oooo00@0003o
0?ooo`3oool0o`002@3oool010000?l0oooo0?ooo`3oool20?l000D0oooo
00<0o`000?ooo`3oool01`3oool20000o``0oooo00<0o`000?ooo`3oool0
0P3oool20?l000L0oooo00<0003o0?ooo`3oool0203oool20000o`D0oooo
00<0003o0?ooo`3oool0203oool01@000000oooo0?ooo`3oool0o`0000h0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00d0o`001@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`0<0?ooo`00L@3oool00`000?l0o`000?ooo`080?ooo`030000
o`3oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo0?l0000;0?ooo`80
003o2P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool02`3oool01@000?l0oooo0?ooo`3oool0003o
00/0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02`3o00080?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0303oool00740oooo00@0o`000?ooo`000?l0003o1P3oool00`00
0?l0oooo0?ooo`060?ooo`<0o`002`3oool00`000?l0oooo0?ooo`020000
o`P0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00`0oooo00<0003o0?ooo`000?l0303oool00`00
0000oooo0?ooo`020?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool01@3oool70?l000T0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00`0oooo001`0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`080?ooo`80o`002@3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0203oool0103o0000oooo0?ooo`000?l@0?ooo`030000o`3oool0oooo
00/0oooo00<000000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?oo
o`X0o`00103oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`0<0?ooo`00L03oool00`3o0000oooo0?ooo`030?ooo`05
0000o`3oool0oooo0?ooo`000?l02P3oool0103o0000oooo0?ooo`3o0008
0?ooo`030000o`3oool0oooo00@0oooo0P000?l40?ooo`030?l0003oool0
oooo00T0oooo00<0o`000000o`3oool03`3oool00`000?l0oooo0000o`0<
0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool3
0?l00080oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0<0?ooo`00K`3oool00`3o
0000oooo0?ooo`050?ooo`80003o00<0oooo0000o`3oool02@3oool01@3o
0000oooo0?ooo`3oool0o`0000H0oooo00<0003o0?ooo`3oool01`3oool0
10000?l0oooo0?ooo`3o000<0?ooo`030000o`3o0000o`0000h0oooo00D0
003o0?ooo`3oool0oooo0000o`0;0?ooo`030000003oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool20?l000D0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`0<0?ooo`00KP3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00P0oooo00<0003o0?l0003oool02`3o
ool01@000?l0oooo0?ooo`3oool0o`0000`0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo
00@0o`000?ooo`3oool0oooo0`3o00080?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000000o`00
0?l00P000?l:0?ooo`00K03oool00`3o0000oooo0?l000090?ooo`040000
o`3oool0003o0000o`L0oooo00<0o`000?ooo`3oool01@3oool01@3o0000
oooo0?ooo`3oool0003o00`0oooo00<0o`000000o`3oool02P3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`080?ooo`030000003oool0oooo
00@0oooo0`3o000;0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool0103ooolE0000o`h0oooo001]0?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool20000o`D0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0000o`0<0?ooo`04
0?l0003oool0oooo0000o`T0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`<0o`003@3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`P0003o0P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0303oool006d0oooo0`3o00070?ooo`030000o`3oool0oooo00@0
oooo00D0003o0?ooo`3oool0oooo0?l0000:0?ooo`030000o`3o0000oooo
00X0oooo00<0o`000?ooo`3oool00P3oool20000o`H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00P0oooo00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`020?l0
0080oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0000o`050000o`030?ooo`000?l0oooo00L0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00`0oooo001/0?ooo`050?l0003oool0oooo0?ooo`3o00001@3oool00`00
0?l0oooo0?ooo`060?ooo`040000o`3oool0oooo0?l000X0oooo00@0003o
0?ooo`3o0000o`00203oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool0203oool20?l000<0oooo00<0
003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`050?ooo`030000003o
0000o`0000D0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool00P3o
ool70000o`L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0303o
ool006`0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00X0oooo00<0003o0?l0003oool02@3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool010000?l0oooo0?ooo`000?l=0?ooo`030?l0003oool0003o00h0oooo
00<0003o0?ooo`3oool00`3oool20?l000L0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00L0oooo
1P000?l50?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0303oool00780oooo0P3o00000`3oool0003o0?oo
o`090?ooo`030?l0003oool0003o00P0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`000?l03P3oool00`3o0000oooo0?ooo`0=0?ooo`040000o`3o
ool0oooo0?ooo`80o`0000<0oooo0000003oool01P3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
1`000?l00`3oool0003o0?ooo`080?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0303oool007@0oooo00<0
003o0?ooo`3oool0203oool0103o0000oooo0?ooo`3oool20000o`D0oooo
00<0003o0?ooo`3oool01P3oool20?l00080oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0o`0000l0oooo
00<0003o0?l0003o00000`3oool00`000000oooo0?ooo`060?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool01P3oool50000o`P0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00`0oooo001d0?ooo`030000o`3o
0000o`0000L0oooo00<0o`000?ooo`3oool0103oool20000o`80oooo00<0
003o0?ooo`3oool02@3oool20?l000`0oooo00<0003o0?ooo`000?l0303o
ool01@000?l0oooo0?ooo`3oool0o`0000d0oooo0P3o00000`000?l0oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`020?ooo`@0003o0P3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0;0?ooo`00L`3o
ool010000?l0oooo0?ooo`3oool20?l000@0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0000o`0;0?ooo`80o`002`3oool01@000?l0oooo
0?ooo`3oool0003o00X0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0:0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`00
0000oooo0?ooo`070?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`000?l00P000?l60?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool>0?l000X0oooo001b0?ooo`03
0000o`3oool0oooo00@0oooo00@0o`000?ooo`3oool0o`002`3oool00`00
0?l0oooo0?ooo`090?ooo`040?l0003oool0oooo0?l000T0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`0000002@3oool00`3o0000oooo0?oo
o`080?ooo`@0003o2P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`060?ooo`P0o`0000<0oooo0000o`3oool01`3oool00`3o0000oooo0?oo
o`0;0?ooo`00K03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3o00002P3oool010000?l0oooo0000o`00
0?l80?ooo`030?l0003oool0oooo0080oooo0P3o00060?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00D0oooo0P3o00060?ooo`040000o`3o
ool0oooo000000X0oooo00<0o`000?ooo`3oool0103oool30000o`<0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`050?l000030?ooo`3o0000oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`0;0?ooo`00K@3oool01@000?l0oooo0?oo
o`3oool0003o00T0oooo0P3o00090?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool20000o`<0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`030?ooo`030?l0
003oool0oooo00H0oooo00@0003o0?ooo`3oool000002P3oool00`3o0000
oooo0?ooo`040000o`H0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01@3oool50?l000H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00/0oooo001^0?ooo`030000
o`3oool0003o00X0oooo00<0o`000?ooo`3o0000203oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
1`3oool0103o0000oooo0?ooo`000?l<0?ooo`030000o`3oool0003o00`0
oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`030000o`3oool00000
00X0oooo00<0o`000000o`000?l02P3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?l000050?l00080oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool02`3oool006l0oooo00<0003o0?ooo`3oool0203oool01@3o0000
oooo0?ooo`3oool0o`0000H0oooo00<0003o0?ooo`3oool01@3oool01@00
0?l0oooo0?ooo`3oool0o`0000X0oooo00<0o`000000o`3oool03@3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0o`0000/0oooo00<0003o
0?ooo`0000002@3oool20000o`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`040000o`3oool0
oooo0?ooo`L0o`00203oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0;0?ooo`00KP3oool00`000?l0oooo0000o`080?ooo`030?l0003oool0
oooo00<0oooo0P3o00030?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3o00002`3oool00`000?l0o`000?l0000<0?ooo`030000o`3oool0
003o00d0oooo0P3o000=0?ooo`030000o`000000oooo00H0oooo0P000?l2
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`060?ooo`H0o`001@3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00/0oooo001^0?oo
o`030000o`3oool0oooo0080003o1@3oool00`3o0000oooo0?ooo`060?oo
o`030?l0003oool0003o00/0oooo00<0o`000?ooo`3oool02P3oool01000
0?l0oooo0?ooo`3o000:0?ooo`050000o`3oool0oooo0?ooo`000?l02`3o
ool30?l000d0oooo00<0003o0000003oool0103oool20000o`D0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`040?l0003o
ool0oooo0?ooo`D0o`000P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
2`3oool006d0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0000o`0:0?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00P0oooo00D0o`000?ooo`3oool0oooo0?l0000=0?ooo`040000
o`3oool0oooo0?ooo`80003o1`3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00L0oooo103o00070?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool40000o`X0
oooo001/0?ooo`030000o`3oool0oooo00D0oooo0P000?l00`3oool0o`00
0?ooo`090?ooo`030000o`3o0000o`0000P0oooo00@0o`000?ooo`3oool0
oooo0P000?l70?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`0:0?ooo`04
000000000?l0003o0000o`X0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`030?ooo`@0o`0000<0oooo0?l0003oool0203oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`P0003o00<0o`000?oo
o`3oool02`3oool006`0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
003o0?ooo`080?ooo`050000o`3oool0oooo0?ooo`3o00001P3oool00`3o
0000oooo0?ooo`040?ooo`80003o103oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00@0o`000?oo
o`3oool0oooo1@0000030?ooo`80003o303oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0o`0000<0o`001@3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l000000?l0003o00L0003o203oool0
0`3o0000oooo0?ooo`0:0?ooo`00M@3oool0103o0000oooo0?ooo`000?l7
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo0000o`T0oooo00D0
o`000?ooo`3oool0oooo0000o`0:0?ooo`040000o`3oool0oooo0?ooo`80
o`002@3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00@0003o0000003oool0003o2`3oool00`3o0000oooo0?ooo`090?oo
o`80o`002@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01P3oool010000?l0oooo0?ooo`3oool6
0000o`T0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:
0?ooo`00K03oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?oo
o`040?l0003oool0oooo0?l000/0oooo0P000?l;0?ooo`030?l0003oool0
003o00`0oooo00<0003o0?ooo`3o00002`3oool00`3o0000oooo0?ooo`02
0?ooo`030000003oool0oooo0080003o00D0oooo000000000000oooo0000
o`0;0?ooo`030?l0003oool0oooo00D0oooo0`3o00000`3oool0003o0?oo
o`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`D0003o1P3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool02P3o
ool006d0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`80003o0P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
o`0000/0oooo0P000?l<0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?l0003oool0303oool01@3o0000oooo0?ooo`3oool000000080003o0`3o
ool010000000oooo0?ooo`000?l;0?ooo`030?l0003oool0oooo0080oooo
0`3o00040?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`070?ooo`030?l000000?l0003o00@0003o
0P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?ooo`00KP3o
ool01@3o0000oooo0?ooo`3oool0o`0000T0oooo0P000?l;0?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`000?l02`3oool00`000?l0oooo
0?l0000<0?ooo`030?l000000?l0oooo00d0oooo00@0o`000?ooo`3oool0
003o1@3oool01@000000oooo0?ooo`3oool0003o00/0oooo00@0o`000?oo
o`3o0000o`001`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool0103oool40000o`P0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool02P3oool006l0oooo00<0o`000?oo
o`3o00002P3oool20000o`/0oooo0P3o00090?ooo`050000o`3oool0oooo
0?ooo`000?l02@3oool010000?l0oooo0?ooo`3oool20?l000T0oooo00@0
o`000?ooo`3oool0003o3@3oool0103o0000003o0000o`0000050?ooo`05
0000003oool0oooo0?ooo`000?l02P3oool30?l000X0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00@0003o0`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00T0oooo001`0?ooo`80o`002P3oool00`000?l0
oooo0000o`090?ooo`040?l0003oool0oooo0?l000L0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool20?l000@0oooo00<0003o0?oo
o`3oool02@3oool20000o`030?l0003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`80o`000P3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01P3oool40000o`P0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool30?l000X0oooo001`0?ooo`80o`002@3oool01@000?l0
oooo0?ooo`3oool0003o00L0oooo00<0o`000?ooo`3oool00P3oool20?l0
00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo0P000?l20?oo
o`030?l0003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`030?ooo`80o`00103oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool40000
o`80oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?l000050?l000030?ooo`3o0000oooo00X0oooo001_0?ooo`04
0?l0003oool0oooo0?l000P0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00@0o`000?oo
o`3oool0003o2@3oool01@000?l0oooo0?ooo`3oool0003o00X0oooo00@0
o`000?ooo`3oool0o`002@3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000o`3oool0o`000080o`001`3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00L0oooo10000?l60?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo0080oooo1@3o00070?ooo`030?l0
003oool0oooo00T0oooo001^0?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`050000o`3o
ool0oooo0?ooo`3o00002@3oool00`3o0000003o0?ooo`0:0?ooo`030000
o`3oool0003o00`0oooo0P3o000:0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo0P3o000:0?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool00`3oool40000o`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00@0oooo1`3o00030?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool02@3oool006h0oooo00<0o`000?ooo`3oool00`3o
ool20?l000<0oooo00<0003o0?ooo`3oool01P3oool20000o`030?l0003o
ool0oooo00T0oooo00<0003o0?l0003oool02P3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool00P00
0?l80?ooo`030?l0003oool0oooo00<0oooo00@000000?ooo`3oool0oooo
0P3o00000`3oool0003o0?ooo`090?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`000?l00`000?l40?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`L0o`00
0P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool02@3oool006d0oooo00<0o`000?ooo`3oool01P3o
ool00`3o0000oooo0000o`0:0?ooo`030?l000000?l0oooo00T0oooo00@0
003o0?ooo`3oool0o`002@3oool00`000?l0oooo0000o`0;0?ooo`030?l0
003oool0o`0000`0oooo0P000?l;0?ooo`030?l0003oool0oooo0080oooo
00@000000?ooo`3o0000o`000`3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00H0oooo0`000?l90?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01`3oool0103o0000oooo0?ooo`3oool40?l0
00030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00T0oooo001/0?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?l0003oool0203oool0103o0000
oooo0?ooo`000?l80?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool01@3oool01@000?l0oooo0?ooo`3oool0003o00P0oooo0P3o0003
0?ooo`030?l0003oool0oooo00T0oooo0P000?l;0?ooo`030?l0003oool0
oooo0080oooo00<000000?l0003oool01@3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00<0oooo0`000?l20?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`07
0?ooo`@0o`00103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`09
0?ooo`00K03oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
0080o`001`3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo00L0oooo00@0003o0?ooo`3oool0003o2`3o
ool00`3o0000oooo0?ooo`020?l000L0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`030000o`D0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo103o
00080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo001]
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`050?l0003oool0
oooo0?ooo`000?l01`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00H0oooo00<0o`000?ooo`3oool0103oool20000o`<0oooo00<0
003o0?ooo`3oool02P3oool20?l000030?ooo`000000oooo00L0oooo00<0
003o0?ooo`3oool0203oool20000o`T0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0o`0000<0o`000`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`80003o2P3o
ool006h0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`050?l0003oool0oooo0?ooo`3o00001`3oool01@000?l0oooo0?oo
o`3oool0003o00T0oooo00<0o`000?ooo`000?l02@3oool010000?l0oooo
0?ooo`3o00090?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`080?ooo`80o`000P3oool00`000000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo0P000?l00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01@3oool40?l000L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@000?l<0?ooo`00K`3oool20000o`<0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?l000090?ooo`030000o`3oool0003o00/0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0o`000?ooo`0:0?ooo`050?l0
003oool0oooo0?ooo`000?l0203oool00`000?l0oooo0?ooo`050?ooo`80
o`000P3oool00`3o0000oooo000000090?ooo`030000o`3oool0oooo00<0
oooo0P000?l30?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`040?l00080oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool00P3oool60000oa40oooo001a0?ooo`030000
o`3oool0003o00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0o`0000X0oooo00<0o`000000o`3oool0
2`3oool00`3o0000oooo0000o`0:0?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`3o000000000?ooo`080?ooo`040000
o`3oool0oooo0?ooo`80003o1@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00H0oooo103o00060?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`D0
003o103oool00`000?l0oooo0?ooo`0@0?ooo`00LP3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0o`0000T0oooo00<0003o0?ooo`000?l0
2@3oool01@000?l0oooo0?ooo`3oool0o`0000P0oooo00@0o`000?ooo`3o
ool0003o2`3oool20000o`/0oooo00@0003o0?ooo`3oool0oooo0P3o0006
0?ooo`030?l000000000oooo00T0oooo0`000?l80?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool00P3oool40?l000030?ooo`3o0000
oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0003o00<0oooo0?l0003oool01P3oool0
0`000?l0oooo0?ooo`0@0?ooo`00L@3oool00`000?l0oooo0000o`080?oo
o`050?l0003oool0oooo0?ooo`3o00001`3oool01@000?l0oooo0?ooo`3o
ool0003o00L0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01`3o
ool010000?l0oooo0?ooo`3o000;0?ooo`030000o`3oool0o`0000T0oooo
00<0o`000?ooo`3oool01`3oool20000o`X0oooo00<0o`000?ooo`3oool0
203oool010000?l0o`000?l0003o00060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`@0
003o1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0100
oooo001`0?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0?l0000;0?oo
o`030000o`3o0000oooo00T0oooo00<0o`000?ooo`3oool01@3oool20000
o`80oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?oo
o`80o`002@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool00P3oool30000o`80oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
0100oooo001_0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`050?l0003oool0oooo0?oo
o`000?l01`3oool01@000?l0oooo0?ooo`3oool0003o00T0oooo00@0o`00
0?ooo`3oool0o`001`3oool00`000?l0oooo0?ooo`030?ooo`80003o1@3o
ool00`3o0000oooo0?ooo`070?ooo`80o`0000<0003o0?ooo`3oool0203o
ool00`000000o`000?ooo`030?ooo`80003o103oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00@0oooo0P3o00000`3oool0003o0?oo
o`080?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000003o0000o`020000o`D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00l0oooo001^
0?ooo`030000o`3oool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0?l0
00080?ooo`030?l0003oool0003o00T0oooo00<0003o0?ooo`000?l02`3o
ool20?l000T0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`030?l0
003oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo0000o`090?ooo`04
0000003o0000oooo0?ooo`80003o1`3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo0080oooo0P3o00040?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?oo
o`<0003o00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool03`3oool006`0
oooo00<0o`000?ooo`000?l0203oool20000o`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`000?l02P3oool00`3o0000
oooo0?ooo`020?ooo`80o`00103oool00`000?l0oooo0?ooo`070?ooo`04
0000003oool0003o0000o`T0oooo00<0003o0?ooo`3oool0203oool0103o
0000oooo0?l0003o00060?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0000o`030000o`<0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3o00001@3o000:0?ooo`00K@3oool00`00
0?l0oooo0?ooo`080?ooo`030?l000000?l0oooo00P0oooo00<0003o0?oo
o`3o00002@3oool00`000?l0oooo0000o`0:0?ooo`030?l0003oool0o`00
00/0oooo00<0003o0?ooo`3oool02@3oool01@3o0000oooo0?ooo`3oool0
o`0000L0oooo00<0003o0?ooo`3oool01P3oool20000o`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool01P3oool30?l000P0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`040?ooo`@0003o1`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool00P3oool50?l00100oooo001/0?ooo`030000o`3oool0o`00
00P0oooo00@0o`000?ooo`3oool0003o1`3oool01@000?l0oooo0?ooo`3o
ool0o`0000L0oooo00@0003o0?ooo`3oool0oooo0P000?l70?ooo`050?l0
003oool0oooo0?ooo`3o00002@3oool00`000?l0oooo0000o`0;0?ooo`<0
o`00203oool00`000?l0oooo0?ooo`040?ooo`80003o00@000000?ooo`3o
ool0o`002P3oool00`000?l0oooo0?ooo`030?ooo`<0o`0000<0oooo0?l0
003oool02@3oool00`000?l0oooo0?ooo`060?ooo`040?l0003oool0oooo
0?ooo`<0003o0`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01@3oool50?l000<0oooo00<0003o
0?ooo`3oool03`3oool006`0oooo00@0003o0?ooo`3oool0o`001P3oool0
0`3o0000oooo0?ooo`020?ooo`80003o103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0o`00
0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0003o00X0oooo00<0
o`000?ooo`3oool02@3oool010000?l0oooo0?ooo`3oool20000o`80oooo
00@000000?ooo`3oool0o`002P3oool010000?l0oooo0?ooo`3oool20?l0
00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?oo
o`@0003o1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3o00080?ooo`030000o`3oool0oooo
00h0oooo001`0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool01@3oool010000?l0oooo0?ooo`000?l70?ooo`050?l0003oool0oooo
0?ooo`000?l0203oool01@000?l0oooo0?ooo`3oool0o`0000H0oooo00<0
o`000?ooo`3oool00`3oool20000o`D0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?l0000;0?ooo`030000o`3oool0003o00@0oooo00D0
00000?ooo`3oool0oooo0?l0000:0?ooo`<0o`001`3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo0080oooo10000?l00`3oool0o`00
0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool40?l000D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`0>0?ooo`00L@3oool0103o0000oooo0?ooo`3o00090?ooo`80003o
2@3oool00`3o0000oooo0000o`0:0?ooo`030000o`3o0000o`0000P0oooo
00D0o`000?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0oooo00<0
oooo0P3o00030?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo00D0
oooo0P3o00000`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0
oooo10000?l50?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01`3oool0103o0000oooo0?ooo`3oool30?l000030?ooo`000?l0oooo
00L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0>0?oo
o`00LP3oool20?l000X0oooo0P000?l:0?ooo`030?l0003oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0000o`0:0?ooo`05
0000o`3oool0oooo0?ooo`3o00001P3oool00`3o0000oooo0?ooo`060?oo
o`<0003o1@3oool00`000000oooo0?ooo`020?ooo`030?l0003oool0oooo
00<0oooo0P3o00030?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01@3oool30000o`P0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`060?ooo`@0o`00103oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool03P3oool00780
oooo00<0o`000?ooo`3o0000203oool010000?l0oooo0?ooo`000?l80?oo
o`030000o`3oool0o`0000T0oooo00<0o`000?ooo`000?l02`3oool00`00
0?l0oooo0?ooo`090?ooo`040000o`3oool0o`000?l000P0oooo00<0o`00
0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00<0
00000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?l000D0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`030?ooo`80003o0`3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool00`3oool40?l000P0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00h0oooo001a
0?ooo`050?l0003oool0oooo0?ooo`3o00001P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0oooo
0P3o00060?ooo`050?l0003oool0oooo0?ooo`000?l02@3oool00`000?l0
oooo0?l0000;0?ooo`030?l0003oool0oooo00T0oooo00@0o`000?ooo`3o
ool0oooo0P000?l50?ooo`050000o`3oool0oooo0?ooo`0000001@3oool0
0`3o0000oooo0?l000080?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`000?l00P000?l50?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?l000030?l000<0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`000?l00`000?l:0?ooo`00L@3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0?l00009
0?ooo`030?l0003oool0003o00/0oooo00<0o`000?ooo`000?l0203oool0
10000?l0oooo0?ooo`0000050?ooo`80o`002@3oool00`000?l0oooo0?oo
o`070?ooo`80003o203oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00@0oooo103o00080?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`D0003o3P3o
ool006`0oooo00D0003o0?ooo`3oool0oooo0?l000060?ooo`040?l0003o
ool0oooo0000o`L0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`04
0?l0003oool0oooo0?l000L0oooo00<0003o0?ooo`3oool00P3oool20000
o`D0oooo00<0o`000?ooo`3oool0103oool20?l000<0oooo00<0003o0?oo
o`3oool0203oool20000o`T0oooo00@0003o0?ooo`3oool000000`3oool2
0?l000030?ooo`3o0000oooo00T0oooo00<0003o0?ooo`3oool0103oool2
0000o`030?ooo`3o0000oooo00P0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`030?l000<0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo1@000?l3
0?ooo`030000o`3oool0oooo00d0oooo001]0?ooo`030000o`3oool0o`00
00P0oooo00<0o`000?ooo`000?l0203oool00`000?l0oooo0000o`0:0?oo
o`80o`002@3oool010000?l0oooo0?ooo`000?l80?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0o`0000X0oooo00<0003o0?ooo`0000000P3oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool00P3oool20000o`<0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`060?ooo`<0o`001P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0oooo1@00
0?l00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00d0oooo001]
0?ooo`030000o`3o0000oooo00T0oooo00<0003o0?ooo`3oool0203oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo0P000?l9
0?ooo`050?l0003oool0oooo0?ooo`3o00001`3oool00`000?l0oooo0?oo
o`040?ooo`80003o0P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool000000080o`001@3oool00`3o0000oooo0?ooo`080?ooo`040000o`3o
ool0003o0000o`H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`020?ooo`D0o`002@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo10000?l50?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool03@3oool006d0oooo00<0o`000000o`3oool0203o
ool00`000?l0oooo0?l000080?ooo`030000o`3oool0003o00T0oooo00<0
o`000?ooo`3o00002@3oool30000o`X0oooo0`3o00080?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`080?ooo`80o`00203oool00`3o0000oooo0?ooo`070?ooo`80003o203o
ool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0o`000?l000D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`040?l0
003oool0oooo0?ooo`<0003o00<0oooo0000o`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00`0oooo001/0?ooo`040?l0
003oool0oooo0000o`H0oooo0P000?l30?ooo`030?l0003oool0oooo00@0
oooo00@0003o0?ooo`3oool0oooo0P000?l60?ooo`050?l0003oool0oooo
0?ooo`3o00001`3oool010000?l0oooo0?ooo`000?l:0?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool00P000?l70?ooo`030?l0003o
ool0oooo00H0oooo00<0o`000000o`000000203oool00`3o0000oooo0?oo
o`050?ooo`80003o00<0oooo0000o`3oool0203oool00`3o0000oooo0?oo
o`060?ooo`80o`001`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo10000?l40?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0<0?ooo`00L03oool2
0000o`<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
o`0000/0oooo0P000?l90?ooo`030?l0003oool0oooo00@000000P3o0002
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00P3oool2
0000o`<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`04
0?ooo`80o`0000<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo0080oooo0`000?l00`3oool0o`000?ooo`05
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0<0?ooo`00LP3oool00`000?l0oooo0000o`080?oo
o`040?l0003oool0oooo0000o`P0oooo00@0003o0?ooo`3oool0o`001P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0o`0000X0oooo
00<0003o0?ooo`3oool02@3oool0103o0000oooo0000003oool20?l000@0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`020000o`H0
oooo00<0003o0?ooo`3oool01`3oool0103o0000oooo0?ooo`3oool20?l0
00<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0003o0080003o103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?l000020?l000X0oooo001c0?ooo`030000o`3oool0oooo00P0
oooo00<0o`000000o`3oool02@3oool00`000?l0o`000?ooo`070?ooo`04
0?l0003oool0oooo0000o`P0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo0P000?l00`3o
ool0003o0?ooo`090?ooo`040?l0003oool0oooo0?l000H0oooo00<00000
0000o`3oool0203oool20000o`P0oooo00<0003o0?ooo`3oool01`3oool0
103o0000oooo0?l0003o00050?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool0103oool40000o`L0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo103o
000=0?ooo`00L`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
o`0000T0oooo00<0o`000000o`3oool0203oool00`3o0000003o0?ooo`09
0?ooo`040000o`3oool0oooo0?l000L0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo0P3o
00000`3oool000000?ooo`040?ooo`03000000000?l0oooo00H0oooo0P00
0?l00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00D0oooo0`3o
00080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`00
0?l30?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`D0o`000`3oool00`000?l0oooo0?oo
o`0;0?ooo`00LP3oool00`000?l0oooo0000o`080?ooo`040000o`3oool0
oooo0?l000P0oooo00@0o`000?ooo`3oool0003o1`3oool20000o`030?l0
003oool0oooo00T0oooo0P3o00090?ooo`050?l0003oool0oooo0?ooo`00
0?l01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0o`000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0000o`040?ooo`80
003o0`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00<0
oooo0P3o00020?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000003o0000o`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?l000L0
oooo00<0003o0?ooo`3oool02`3oool00740oooo00D0003o0?ooo`3oool0
oooo0000o`060?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00`3oool20?l000@0oooo00<0003o0?ooo`3oool00`3oool010000?l0
oooo0?ooo`3oool20?l000P0oooo00<0o`000?ooo`000?l02P3oool00`3o
0000003o0000o`070?ooo`030000o`3oool0oooo00@0oooo0P3o00020?oo
o`030?l000000000000000D0oooo00<000000?ooo`000?l00P3oool20000
o`H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?l000020?l0
00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?oo
o`<0003o00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00@0oooo103o00060?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool02`3oool006`0oooo00D0o`000?ooo`3o
ool0oooo0000o`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0103oool01@3o0000oooo0?ooo`3oool0o`0000H0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00D0o`000?ooo`3oool0oooo0000o`090?ooo`030000o`3o
ool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00<000000?ooo`3oool00P00
0?l80?ooo`030?l0003oool0oooo00L0oooo0P3o00080?ooo`030?l0003o
ool0oooo00H0oooo00@0003o0?ooo`3oool0oooo0P000?l30?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0103o0000oooo
0?ooo`3oool30?l00080oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00/0oooo001/0?ooo`050?l0
003oool0oooo0?ooo`000?l01P3oool20000o`030?ooo`000?l0oooo00L0
oooo00<0o`000?ooo`3o0000203oool010000?l0oooo0?ooo`000?l80?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0o`0000T0oooo00<0003o0?oo
o`3oool00P3o00060?ooo`030?l0003oool0oooo00@0oooo00@000000000
o`000?l0003o2P3oool00`3o0000oooo0?ooo`040?ooo`80o`0000<0oooo
0000o`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`@0003o1@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo103o0005
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0;0?ooo`00K@3oool00`3o0000oooo0000o`090?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool20000
o`T0oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`030000o`3oool0
oooo00<0oooo0P000?l30?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?l0003oool0203oool00`3o0000oooo0?ooo`020?ooo`80003o0`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo0080oooo0P3o0003
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool3
0000o`L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`03
0?ooo`<0o`00203oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool02P3oool006h0oooo00<0003o0?l0
003oool01`3oool00`000?l0oooo0000o`080?ooo`030?l0003oool0o`00
00T0oooo0P000?l:0?ooo`<0o`00203oool01@000?l0oooo0?ooo`3oool0
003o00H0oooo00<0o`000?ooo`3oool01@3oool20?l000030000o`3oool0
oooo00P0oooo00H0o`000?ooo`000?l0003o0?ooo`0000040?ooo`030000
o`3oool0oooo00L0oooo00@0o`000?ooo`3o0000o`001P3oool00`000?l0
oooo0?ooo`060?ooo`040?l0003oool0oooo0?ooo`<0003o0P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool00`3o00030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`@0003o2P3oool006d0
oooo00@0003o0?ooo`3oool0o`001P3oool010000?l0oooo0?ooo`000?l7
0?ooo`050?l0003oool0oooo0?ooo`3o00001`3oool00`000?l0oooo0000
o`0:0?ooo`80o`002P3oool30000o`L0oooo00<0o`000?ooo`3oool0103o
ool0103o0000oooo0?ooo`000?l:0?ooo`80003o0`3oool00`000000oooo
0?ooo`020?ooo`030000o`3oool0oooo00L0oooo0P3o00080?ooo`030000
o`3oool0oooo00L0oooo00<0o`000000o`000?l01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00@0oooo103o00060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000003o
0000o`030000o`030?ooo`000?l0oooo00/0oooo001/0?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l0
203oool0103o0000oooo0?ooo`3o00090?ooo`030000o`3oool0oooo00P0
oooo00@0o`000?ooo`3oool0oooo0P3o00040?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3o00000`3oool00`000000oooo0?ooo`030?oo
o`030000o`3oool0oooo00@0oooo0P3o00000`3oool0o`000?ooo`070?oo
o`030000o`3oool0oooo00D0oooo0`000?l80?ooo`030000o`3oool0oooo
00D0oooo00@0o`000?ooo`3oool0oooo0`3o00020?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`03
0?ooo`<0003o1`3oool00`000?l0oooo0?ooo`090?ooo`00LP3oool0103o
0000oooo0?ooo`000?l60?ooo`050000o`3oool0oooo0?ooo`3o00001P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool00`3oool20?l000<0oooo00<0o`000?ooo`3oool01@3o
ool20000o`030?ooo`000?l0oooo00P0oooo00@0o`000?ooo`3oool0o`00
1`3oool00`000?l0oooo0?ooo`030?ooo`80003o0P3oool01@3o0000oooo
0?ooo`3oool0000000D0oooo00<0003o0?ooo`3oool00`3oool01@3o0000
oooo0?ooo`3oool0o`0000T0oooo00<0003o0?ooo`3oool00P3oool20000
o`80oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`@0o`001P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool00`000?l20?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool02@3oool007<0oooo00<0o`000000o`3o
ool01`3oool00`000?l0oooo0?l000080?ooo`040?l0003oool0oooo0000
o`L0oooo00D0003o0?ooo`3oool0oooo0?l000060?ooo`030?l0003oool0
oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`0:0?ooo`80o`002@3o
ool01@000?l0oooo0?ooo`3oool0003o00D0oooo00@0o`000?ooo`3oool0
00001P3oool00`000?l0oooo0?ooo`020?l000D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`020000o`D0oooo00<0o`000?ooo`3o
ool01P3oool010000?l0oooo0?ooo`3oool50?l000P0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`<0003o1@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo001c0?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000000o`3oool0203oool00`3o0000
003o0?ooo`080?ooo`030000o`3oool0o`0000P0oooo00D0o`000?ooo`3o
ool0oooo0000o`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3o00002@3oool010000?l0oooo0000o`000?l60?ooo`040?l0003oool0
oooo000000H0oooo00<0003o0?l0003o00001`3oool00`3o0000oooo0?oo
o`070?ooo`80003o1`3oool00`3o0000oooo0?ooo`060?ooo`040000o`3o
0000o`000?l000@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo0080oooo10000?l80?ooo`030?l0
003oool0oooo0100oooo001b0?ooo`030000o`3oool0o`0000P0oooo00@0
o`000?ooo`3oool0003o203oool00`000?l0o`000?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00<0o`000?ooo`000?l01`3oool00`000?l0oooo
0?ooo`030?ooo`80o`000P3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`0000001@3oool20?l000030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool40000o`T0oooo
00<0o`000?ooo`3oool0103oool20?l000P0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`@0003o103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo0100oooo001a0?ooo`040000o`3o
ool0oooo0?ooo`80o`001@3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0o`00203oool00`3o0000
oooo0000o`0:0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00H0
oooo0P000?l90?ooo`030?l0003oool0000000<0oooo0P3o00020?ooo`03
0000o`3oool0oooo00L0oooo00@0o`000?ooo`3oool0oooo0P000?l30?oo
o`030000o`3oool0oooo00L0oooo00@0o`000?ooo`3oool0oooo0`3o0002
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`020?ooo`<0003o00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo0P3o000:
0?ooo`00K03oool01@000?l0oooo0?ooo`3oool0003o00H0oooo00D0o`00
0?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`80o`000`3o
ool00`000?l0oooo0?ooo`050?ooo`80003o00<0o`000?ooo`3oool01`3o
ool010000?l0oooo0?l0003o00070?ooo`030?l0003oool0oooo00<0oooo
0P000?l20?ooo`030000o`3oool0oooo00L0oooo00<0o`000000003oool0
0P3o00050?ooo`030000o`3oool0oooo00H0oooo00@0o`000000o`000?l0
003o1P3oool00`000?l0oooo0?ooo`060?ooo`040?l0003oool0o`000?l0
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0003o0080003o0`3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool20?l0
00`0oooo001]0?ooo`030000o`3oool0003o00P0oooo0`3o00070?ooo`05
0000o`3oool0oooo0?ooo`000?l01P3oool01@3o0000oooo0?ooo`3oool0
o`0000D0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3o
ool0o`0000T0oooo00<0o`000?ooo`3oool0203oool01@3o0000oooo0?oo
o`3oool0003o00D0oooo00<0003o0?ooo`3oool01`3oool20?l000L0oooo
00<0003o0?ooo`3oool01@3oool20000o`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool30?l000L0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`030?ooo`@0003o1`3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo1@3o000>0?ooo`00KP3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`000?l0203oool00`3o0000oooo0?l000070?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`80o`0000<0oooo0000o`3oool0203oool0103o0000oooo0?oo
o`000?l60?ooo`030000o`3oool0oooo00D0oooo0`3o00090?ooo`030000
o`3oool0oooo0080oooo0P000?l30?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool00P3oool20?l00080oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0003o
0`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00@0003o0?ooo`3oool0oooo1@3o000A0?ooo`00K@3oool00`000?l0oooo
0000o`070?ooo`030?l0003oool0o`0000X0oooo0P000?l90?ooo`030?l0
003oool0oooo00L0oooo00@0003o0?ooo`3oool0003o1`3oool00`3o0000
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool01`3oool20000o`P0oooo00<0003o0?ooo`3oool00P3oool20?l00080
oooo00<000000?l0003oool01`3oool00`000?l0oooo0?ooo`020000o`D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?l000D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`@0
003o1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo1@3o00040?ooo`030?l0003oool0oooo00l0oooo001/0?ooo`050000
o`3oool0oooo0?ooo`000?l01@3oool0103o0000oooo0?ooo`3oool20?l0
00H0oooo0P000?l20?ooo`030000o`3oool0oooo00@0oooo0P3o00000`3o
ool0o`000?ooo`080?ooo`80003o2@3oool0103o0000oooo0?l0003o0006
0?ooo`030000o`3oool0oooo00<0oooo0`000?l00`3oool0o`000?ooo`08
0?ooo`040000o`3oool0o`000?l000@0oooo00<000000?ooo`3o0000203o
ool20000o`P0oooo00<0o`000?ooo`3oool01P3oool20?l000L0oooo00<0
o`000?ooo`3oool01P3oool010000?l0oooo0?ooo`3oool20000o`80oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00<0o`000P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00h0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{309, 196},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "The streamlines  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        "constant"}]]],
  "  form a family of hyperbolas with asymptotes along the coordinate axes.  \
The velocity vector  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["V",
            FontWeight->"Bold"], 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", 
        " ", \(\(F' \((z)\)\)\&_\  = \ \(4\/3\) 
            A\ \(\((x + \[ImaginaryI]\ y)\)\^\(1/3\)\)\&_\)}]]],
  "  indicates that in the upper half-plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  ", the fluid flows down along the streamlines and spreads out along the \
positive x axis and negative y axis, as shown in Figure 11.55. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the complex potential and determine the velocity potential and stream \
function.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[A, x, y, u, v, w, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, F];\)\ \), "\n", 
    \(\(F[z_]\  = \ A\ z\^\(4/3\);\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ 
        ComplexExpand[
          A\ Re[\((x\  + \ \[ImaginaryI]\ y)\)\^\(4/3\)]];\)\ \), "\n", 
    \(\(\[Psi][x_, y_]\  = \ 
        ComplexExpand[
          A\ Im[\((x\  + \ \[ImaginaryI]\ y)\)\^\(4/3\)]];\)\ \), "\n", 
    \(\(Print["\<The  complex potential is   F[z] = \>", F[z]];\)\ \), "\n", 
    \(\(Print["\<F[z]  =  \[Phi][x,y] + \[ImaginaryI] \[Psi][x,y]\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<F[z]  =  (\>", \[Phi][x, 
          y], "\<) + \[ImaginaryI](\>", \ \[Psi][x, 
          y], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential is \[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\n", 
    \(\(Print["\<The   stream function  is \[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a plot of the stream function.\n\nFor illustration purposes, we \
choose A = 1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(A = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(cont\  = \ Table[\((0.25  k)\), {k, 0, 16}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Psi][x, y], {x, \(-2\), 1.5}, {y, 00.1, 2.5}, 
        Contours\  \[Rule] cont, PlotPoints \[Rule] 55, 
        AspectRatio \[Rule] 2.5\/3.5, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, y]];\)\ \), "\n", 
    \(\(Print["\<The contours are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[Psi][x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The inverse of  ",
  Cell[BoxData[
      \(w\  = \ \(f[
            z] = \(z\^\(4/3\)\ \ is\ \ z\  = \ \(g[
                w]\  = \ \ w\^\(3/4\)\)\)\)\)]],
  ".  Use conformal mapping  z = g(w)  to make an image of the flow."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(g1[w_]\  = \ w\^\(3/4\);\)\ \), "\[IndentingNewLine]", 
    \(\(g2[
          w_]\  = \ \ \(-\[ImaginaryI]\)\ w\^\(3/4\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(Iden[w_]\  = \ w;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[Iden, {\(-4\), 4, 0.4}, {0, 4, 0.4}, 
        AspectRatio \[Rule] 1\/2, 
        Ticks \[Rule] {Range[\(-4\), 4, 1], Range[0, 4, 1]}, 
        PlotRange \[Rule] {{\(-4\), 4}, {0, 4}}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Red}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The horizontal flow in the z-plane.\>"];\)\ \), "\n", 
    \(\(graph1 = 
        CartesianMap[g1, {\(-4\), 5, 0.4}, {0, 4, 0.4}, 
          AspectRatio \[Rule] 1, PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(graph2 = 
        CartesianMap[g2, {\(-4\), \(-0.01\), 0.4}, {\(-4\), \(-0.01\), 0.4}, 
          AspectRatio \[Rule] 1, PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(graph3 = 
        CartesianMap[g2, {0.01, 5, 0.4}, {\(-4\), \(-0.01\), 0.4}, 
          AspectRatio \[Rule] 1, PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, 
        PlotRange \[Rule] {{\(-2.5\), 2.5}, {\(-2.5\), 2.5}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[\(-3\), 3, 1]}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<The image flow in quadrants 1-3,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<under the mapping z = g(w) = \!\(w\^\(3/4\)\)\>\""];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The velocity potential is \[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\n", 
    \(\(Print["\<The   stream function  is \[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.24.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the complex potential for an ideal fluid flowing from left to right \
across the complex plane and around the unit circle  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006F0000UB000`400?l0
0000o`00003oo`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00
o`3ooonG0?ooo`00o`3ooonG0?ooo`00o`3ooonG0?ooo`00R`3oool40000
03X0oooo1@00000g0?ooo`800000>P3oool5000003T0oooo1000000C0?oo
o`00R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03H0
oooo00@000000?ooo`3oool00000>`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo01@0oooo002<0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool0=P3oool010000000oooo0?ooo`00000k0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool04`3oool008D0
oooo100000040?ooo`030000003oool0oooo03<0oooo100000040?ooo`03
0000003oool0oooo03H0oooo00@000000?ooo`3oool00000>`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo0180oooo002;0?ooo`04
0000003oool0oooo000003`0oooo00<000000?ooo`3oool0=P3oool01000
0000oooo0?ooo`00000k0?ooo`030000003oool0oooo03T0oooo00@00000
0?ooo`3oool000004`3oool008`0oooo0P00000l0?ooo`800000>@3oool2
000003/0oooo0P00000l0?ooo`800000503oool00?l0ooooU`3oool00?l0
ooooU`3oool00?l0ooooU`3oool00?l0ooooU`3oool00?l0ooooU`3oool0
0?l0ooooU`3oool007h0oooo0P0000050?ooool000000`00000?0?ooo`00
O@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool007d0oooo
00@000000?ooo`3oool00000103oool2000000<0oooo?P00001l0?oooch0
00000`3oool2000000l0oooo001m0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00P3oooln003oQ`030000003o0000o`0007P0
o`0000<00000003oQ`00ohL0>`00ohL50?ooo`030000003oool0oooo00d0
oooo001m0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3oooln003oQ`030000003o0000o`0007P0o`0000<00000003oQ`00
ohL0>`00ohL50?ooo`030000003oool0oooo00d0oooo001n0?ooo`800000
1@3oool00`000000oooo0?ooo`020?oooch00?n700<000000?l0003o0000
N03o00000`0000000?n7003oQ`0k003oQ`D0oooo00<000000?ooo`3oool0
3@3oool008D0oooo00<000000?ooo`3oool00P3oooln003oQ`030000003o
0000o`0007P0o`0000<00000003oQ`00ohL0>`00ohL50?ooo`030000003o
ool0oooo00d0oooo00250?ooo`030000003oool0oooo0080oooo?P00ohL0
0`000000o`000?l0001h0?l0000300000000ohL00?n703/00?n71@3oool0
0`000000oooo0?ooo`0=0?ooo`00Q@3oool2000000<0oooo?P00ohL00`00
0000o`000?l0001h0?l0000300000000ohL00?n703/00?n7103oool20000
00l0oooo00250?ooo`030000003oool0oooo0080oooo?P00ohL00`000000
o`000?l0001h0?l0000300000000ohL00?n703/00?n71@3oool00`000000
oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooch00?n7
00<000000?l0003o0000N03o00000`0000000?n7003oQ`0k003oQ`D0oooo
00<000000?ooo`3oool03@3oool008D0oooo00<000000?ooo`3oool00P3o
ooln003oQ`030000003o0000o`0007P0o`0000<00000003oQ`00ohL0>`00
ohL50?ooo`030000003oool0oooo00d0oooo00250?ooo`030000003oool0
oooo0080oooo?P00ohL00`000000o`000?l0001h0?l0000300000000ohL0
0?n703/00?n71@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?ooocl00?n700<000000?l0003o0000M`3o00000`00
00000?n7003oQ`0k003oQ`D0oooo00<000000?ooo`3oool03@3oool008D0
oooo00<000000?ooo`3oool00P3ooolo003oQ`030000003o0000o`0007H0
o`0000<00000003oQ`00ohL0?000ohL50?ooo`030000003oool0oooo00d0
oooo00250?ooo`8000000`3ooolo003oQ`030000003o0000o`0007H0o`00
00<00000003oQ`00ohL0?000ohL40?ooo`8000003`3oool008D0oooo00<0
00000?ooo`3oool00P3ooolo003oQ`030000003o0000o`0007H0o`0000<0
0000003oQ`00ohL0?000ohL50?ooo`030000003oool0oooo00d0oooo0025
0?ooo`030000003oool0oooo0080oooo?`00ohL00`000000o`000?l0001f
0?l0000300000000ohL00?n703`00?n71@3oool00`000000oooo0?ooo`0=
0?ooo`00Q@3oool00`000000oooo0?ooo`020?oood000?n700<000000?l0
003o0000M03o00000`0000000?n7003oQ`0m003oQ`D0oooo00<000000?oo
o`3oool03@3oool008D0oooo00<000000?ooo`3oool00P3oool9000003L0
0?n700<000000?l0003o0000M03o00000`0000000?n7003oQ`0e003oQ`T0
0000103oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo
0?ooo`020?ooo`T00?ol2000000_003oQ`030000003o0000o`0007@0o`00
00<00000003oQ`00ohL0;@00ohL8000000P00?ol1@3oool00`000000oooo
0?ooo`0=0?ooo`00Q@3oool2000000<0oooo4000oo`6000002/00?n700<0
00000?l0003o0000LP3o0002000002X00?n71P00000?003oo0@0oooo0P00
000?0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooaH00?ol1@00000V
003oQ`030000003o0000o`000780o`0000<00000003oQ`00ohL09000ohL5
000001D00?ol1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?oooa/00?ol1000000R003oQ`030000003o0000o`00
0780o`0000<00000003oQ`00ohL08000ohL4000001X00?ol1@3oool00`00
0000oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooal0
0?ol0`00000P003oQ`030000003o0000o`000740o`0000<00000003oQ`00
ohL07@00ohL3000001h00?ol1@3oool00`000000oooo0?ooo`0=0?ooo`00
Q@3oool00`000000oooo0?ooo`020?ooob800?ol0`00000M003oQ`030000
003o0000o`000700o`0000<00000003oQ`00ohL06`00ohL3000002400?ol
1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo0?oo
o`020?ooob@00?ol0`00000K003oQ`800000L@3o00000`0000000?n7003o
Q`0I003oQ`<000008`00oo`50?ooo`030000003oool0oooo00d0oooo0025
0?ooo`8000000`3ooolW003oo08000006P00ohL00`000000o`000?l0001^
0?l0000300000000ohL00?n701P00?n70P00000V003oo0@0oooo0P00000?
0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooobT00?ol0P00000H003o
Q`030000003o0000o`0006h0o`0000<00000003oQ`00ohL05P00ohL20000
02P00?ol1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`000000
oooo0?ooo`020?ooob/00?ol00<00000003oQ`00ohL05P00ohL00`000000
o`000?l0001/0?l0000300000000ohL00?n701H00?n700<00000003oo000
oo`0:000oo`50?ooo`030000003oool0oooo00d0oooo00250?ooo`030000
003oool0oooo0080oooo;000oo`3000001D00?n700<000000?l0003o0000
K03o00000`0000000?n7003oQ`0C003oQ`<00000:`00oo`50?ooo`030000
003oool0oooo00d0oooo001b0?ooo`800000103oool2000000@0oooo0P00
00050?ooo`030000003oool0oooo0080oooo;P00oo`2000001D00?n700<0
00000?l0003o0000JP3o00000`0000000?n7003oQ`0C003oQ`800000;@00
oo`50?ooo`030000003oool0oooo00d0oooo001a0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`020?oooc000?ol00<00000003oQ`00ohL04P00ohL2000006/0o`00
00<00000003oQ`00ohL04P00ohL00`0000000?ol003oo00]003oo0D0oooo
00<000000?ooo`3oool03@3oool00740oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`020?ooo`8000000`3ooola003oo0800000
4`00ohL00`000000o`000?l0001X0?l0000300000000ohL00?n701400?n7
0P00000`003oo0@0oooo0P00000?0?ooo`00L@3oool010000000oooo0?oo
o`0000090?ooo`8000001@3oool00`000000oooo0?ooo`020?oooc<00?ol
00<00000003oQ`00ohL04000ohL00`000000o`000?l0001X0?l000030000
0000ohL00?n701000?n700<00000003oo000oo`0<000oo`50?ooo`030000
003oool0oooo00d0oooo001a0?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`L00000
;@00oo`2000001400?n700<000000?l0003o0000IP3o00000`0000000?n7
003oQ`0?003oQ`800000;P00oo`6000000@0oooo00<000000?ooo`3oool0
3@3oool00780oooo0P00000:0?ooo`<00000103oool00`000000oooo0?oo
o`020?ooo`H008ko1@00000Z003oo08000004@00ohL00`000000o`000?l0
001T0?l0000300000000ohL00?n700l00?n70P00000Z003oo0D000001@00
S_l50?ooo`030000003oool0oooo00d0oooo00250?ooo`030000003oool0
oooo0080oooo2`00S_l5000002L00?ol00<00000003oQ`00ohL03P00ohL0
0`000000o`000?l0001T0?l0000300000000ohL00?n700h00?n70P00000V
003oo0D000002P00S_l50?ooo`030000003oool0oooo00d0oooo00250?oo
o`030000003oool0oooo0080oooo4000S_l5000002<00?ol00<00000003o
Q`00ohL03P00ohL00`000000o`000?l0001R0?l0000300000000ohL00?n7
00h00?n700<00000003oo000oo`08@00oo`5000000l008ko1@3oool00`00
0000oooo0?ooo`0=0?ooo`00Q@3oool2000000<0oooo5@00S_l300000240
0?ol00<00000003oQ`00ohL03P00ohL00`000000o`000?l0001Q0?l00003
00000000ohL00?n700d00?n700<00000003oo000oo`07`00oo`3000001@0
08ko103oool2000000l0oooo00250?ooo`030000003oool0oooo0080oooo
6000S_l3000001l00?ol0P00000>003oQ`800000H03o0002000000h00?n7
0P00000O003oo0<000005`00S_l50?ooo`030000003oool0oooo00d0oooo
00250?ooo`030000003oool0oooo0080oooo6`00S_l4000001d00?ol00<0
0000003oQ`00ohL03@00ohL00`000000o`000?l0001M0?l0000300000000
ohL00?n700`00?n70P00000L003oo0@000006P00S_l50?ooo`030000003o
ool0oooo00d0oooo00250?ooo`030000003oool0oooo0080oooo7`00S_l0
0`0000000?ol003oo00K003oo00300000000ohL00?n700`00?n700<00000
0?l0003o0000G03o00000`0000000?n7003oQ`0=003oQ`0300000000oo`0
0?ol01X00?ol00<00000002>o`00S_l07000S_l50?ooo`030000003oool0
oooo00d0oooo00250?ooo`030000003oool0oooo0080oooo8000S_l40000
01T00?ol0P00000>003oQ`030000003o0000o`0005X0o`0000<00000003o
Q`00ohL03@00ohL00`0000000?ol003oo00G003oo0@000007`00S_l50?oo
o`030000003oool0oooo00d0oooo00250?ooo`030000003oool0oooo0080
oooo8`00S_l2000001T00?ol0P00000>003oQ`030000003o0000o`0005P0
o`0000<00000003oQ`00ohL03000ohL2000001T00?ol0P00000R002>o`D0
oooo00<000000?ooo`3oool03@3oool008D0oooo00<000000?ooo`3oool0
0P3ooolU002>o`<000005`00oo`2000000d00?n70P00001H0?l000800000
3@00ohL2000001L00?ol0`00000T002>o`D0oooo00<000000?ooo`3oool0
3@3oool008D0oooo0P0000030?ooobP008ko0P00000G003oo00300000000
ohL00?n700`00?n700<000000?l0003o0000E03o0002000000d00?n70P00
000F003oo08000009`00S_l40?ooo`8000003`3oool008D0oooo00<00000
0?ooo`3oool00P3ooolZ002>o`8000005P00oo`00`0000000?n7003oQ`0<
003oQ`030000003o0000o`000580o`0000<00000003oQ`00ohL03000ohL0
0`0000000?ol003oo00D003oo0800000:@00S_l50?ooo`030000003oool0
oooo00d0oooo00250?ooo`030000003oool0oooo0080oooo;000S_l20000
01D00?ol0P00000=003oQ`030000003o0000o`000500o`0000<00000003o
Q`00ohL02`00ohL2000001D00?ol0P00000[002>o`D0oooo00<000000?oo
o`3oool03@3oool008D0oooo00<000000?ooo`3oool00P3oool^002>o`03
00000000oo`00?ol01<00?ol00<00000003oQ`00ohL03000ohL00`000000
o`000?l0001>0?l0000300000000ohL00?n700`00?n700<00000003oo000
oo`04`00oo`00`00000008ko002>o`0[002>o`D0oooo00<000000?ooo`3o
ool03@3oool008D0oooo00<000000?ooo`3oool00P3oool5000002X008ko
0`00000C003oo08000003@00ohL2000004`0o`000P00000=003oQ`800000
4`00oo`3000002X008ko1@0000040?ooo`030000003oool0oooo00d0oooo
00250?ooo`030000003oool0oooo0080oooo1@006Ol4000002T008ko00<0
0000003oo000oo`04P00oo`00`0000000?n7003oQ`0<003oQ`030000003o
0000o`0004P0o`0000<00000003oQ`00ohL03000ohL00`0000000?ol003o
o00B003oo00300000000S_l008ko02L008ko10000004000Io`D0oooo00<0
00000?ooo`3oool03@3oool008D0oooo0P0000030?ooo`T001Wo1@00000U
002>o`8000004`00oo`2000000`00?n70P0000180?l0008000003000ohL2
000001<00?ol0P00000U002>o`D0000020006Ol40?ooo`8000003`3oool0
08D0oooo00<000000?ooo`3oool00P3oool>000Io`<000009000S_l00`00
00000?ol003oo00B003oo00300000000ohL00?n700/00?n700<000000?l0
003o0000A03o00000`0000000?n7003oQ`0<003oQ`0300000000oo`00?ol
01400?ol00<00000002>o`00S_l08P00S_l3000000d001Wo1@3oool00`00
0000oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooa40
01Wo100000000`00S_l00000002>o`0N002>o`<000004P00oo`00`000000
0?n7003oQ`0;003oQ`030000003o0000o`000480o`0000<00000003oQ`00
ohL02`00ohL2000001400?ol0`00000P002>o`D0000040006Ol50?ooo`03
0000003oool0oooo00d0oooo00250?ooo`030000003oool0oooo0080oooo
5@006Ol4000001l008ko0`00000A003oo08000003000ohL3000003h0o`00
0`00000<003oQ`8000004@00oo`3000001l008ko1000000D000Io`D0oooo
00<000000?ooo`3oool03@3oool008D0oooo00<000000?ooo`3oool00P3o
oolI000Io`<000007P00S_l2000001800?ol00<00000003oQ`00ohL03000
ohL00`000000o`000?l0000j0?l0000300000000ohL00?n700`00?n700<0
0000003oo000oo`04000oo`2000001h008ko0`00000H000Io`D0oooo00<0
00000?ooo`3oool03@3oool008D0oooo00<000000?ooo`3oool00P3ooolL
000Io`<000007@00S_l2000001400?ol0P00000=003oQ`800000>03o0002
000000h00?n700<00000003oo000oo`03`00oo`3000001`008ko0`00000K
000Io`D0oooo00<000000?ooo`3oool03@3oool008D0oooo0P0000030?oo
oal001Wo0`00000L002>o`8000004@00oo`00`0000000?n7003oQ`0<003o
Q`<00000<P3o0003000000h00?n70P00000@003oo08000007000S_l30000
01h001Wo103oool2000000l0oooo00250?ooo`030000003oool0oooo0080
oooo8P006Ol3000001X008ko0`00000@003oo08000003P00ohL200000300
o`000P00000>003oQ`8000004@00oo`2000001X008ko0`00000Q000Io`D0
oooo00<000000?ooo`3oool03@3oool008D0oooo00<000000?ooo`3oool0
0P3ooolT000Io`@000006@00S_l2000001400?ol0P00000>003oQ`<00000
:P3o0003000000h00?n70`00000@003oo08000006P00S_l3000002<001Wo
1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo0?oo
o`020?ooobP001Wo0P00000I002>o`8000004@00oo`2000000l00?n70`00
000T0?l000<000004000ohL00`0000000?ol003oo00?003oo08000006@00
S_l3000002H001Wo1@3oool00`000000oooo0?ooo`0=0?ooo`00O@3oool5
000000<0oooo00<000000?ooo`3oool00P3ooolZ000Io`8000006@00S_l2
000001400?ol00<00000003oQ`00ohL03`00ohL4000001`0o`001000000A
003oQ`8000004@00oo`00`00000008ko002>o`0G002>o`800000:@006Ol5
0?ooo`030000003oool0oooo00d0oooo001o0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool/000Io`<000006000S_l00`00
00000?ol003oo00?003oo0<000004P00ohL500000180o`001@00000B003o
Q`<000004@00oo`2000001L008ko0`00000[000Io`D0oooo00<000000?oo
o`3oool03@3oool007l0oooo00<000000?ooo`3oool00`3oool2000000<0
oooo0P00000]000Io`8000005`00S_l2000001800?ol0P00000E003oQa80
00005@00ohL2000001800?ol0P00000G002>o`800000;@006Ol2000000<0
oooo0P00000?0?ooo`00O`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo0P1J0?l5000002X001Wo0`00000F002>o`800000
4P00oo`3000003H00?n71000000A003oo08000005P00S_l3000002X001Wo
1@0000000`1J0?l0oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo
001o0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool705X0o`D000009`006Ol3000001H008ko0P00000B003oo0<00000<P00
ohL3000001800?ol0P00000F002>o`<000009`006Ol5000000H0FP3o1@3o
ool00`000000oooo0?ooo`0=0?ooo`00OP3oool2000000D0oooo00<00000
0?ooo`3oool00P3oool<05X0o`@000009P006Ol2000001H008ko0`00000B
003oo0<00000;000ohL3000001<00?ol0P00000G002>o`03000000006Ol0
01Wo02@001Wo1000000;05X0o`D0oooo00<000000?ooo`3oool03@3oool0
08D0oooo00<000000?ooo`3oool00P3oool@05X0o`D000008`006Ol00`00
000008ko002>o`0F002>o`0300000000oo`00?ol01800?ol0`00000V003o
Q`<000005000oo`2000001L008ko0P00000R000Io`D000003`1J0?l50?oo
o`030000003oool0oooo00d0oooo00250?ooo`030000003oool0oooo0080
oooo5@1J0?l40000020001Wo1000000E002>o`<000005000oo`7000001P0
0?n71`00000D003oo0<000005@00S_l40000020001Wo1@00000C05X0o`D0
oooo00<000000?ooo`3oool03@3oool008D0oooo0P0000030?oooaT0FP3o
0`00000Q000Io`8000005@00S_l3000001P00?ol2@000008003oQ`T00000
6000oo`3000001D008ko0P00000Q000Io`<00000601J0?l40?ooo`800000
3`3oool008D0oooo00<000000?ooo`3oool00P3ooolL05X0o`<000008000
6Ol3000001D008ko0`00000N003oo0P000007P00oo`3000001H008ko0P00
000P000Io`<000006`1J0?l50?ooo`030000003oool0oooo00d0oooo0025
0?ooo`030000003oool0oooo0080oooo7`1J0?l30000020001Wo00<00000
002>o`00S_l05@00S_l2000004000?ol0P00000G002>o`8000007`006Ol3
000001h0FP3o1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`00
0000oooo0?ooo`020?ooob80FP3o0`00000N000Io`@000005@00S_l30000
03X00?ol0`00000F002>o`<000007P006Ol300000240FP3o1@3oool00`00
0000oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooobD0
FP3o1000000M000Io`<000005P00S_l5000003000?ol1@00000F002>o`<0
00007@006Ol4000002@0FP3o1@3oool00`000000oooo0?ooo`0=0?ooo`00
Q@3oool00`000000oooo0?ooo`020?ooobT0FP3o0`00000M000Io`<00000
5`00S_l5000002P00?ol1@00000H002>o`8000007@006Ol3000002P0FP3o
1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool2000000<0oooo;01J
0?l3000001d001Wo00<00000002>o`00S_l06@00S_l5000001h00?ol1@00
000K002>o`80000070006Ol3000002/0FP3o103oool2000000l0oooo0025
0?ooo`030000003oool0oooo0080oooo;`1J0?l2000001`001Wo1000000L
002>o`P000003P00oo`8000001d008ko0`00000L000Io`800000;P1J0?l5
0?ooo`030000003oool0oooo00d0oooo00250?ooo`030000003oool0oooo
0080oooo1000000]05X0o`<000007@006Ol30000024008ko3P00000Q002>
o`@0000070006Ol3000002d0FP3o100000040?ooo`030000003oool0oooo
00d0oooo00250?ooo`030000003oool0oooo0080oooo103?0?l5000002/0
FP3o1000000K000Io`@00000BP00S_l4000001/001Wo1000000[05X0o`D0
00000`3?0?l50?ooo`030000003oool0oooo00d0oooo00250?ooo`030000
003oool0oooo0080oooo2@3?0?l5000002X0FP3o0`00000K000Io`@00000
A000S_l4000001/001Wo0`00000Z05X0o`D00000203?0?l50?ooo`030000
003oool0oooo00d0oooo00250?ooo`030000003oool0oooo0080oooo3P3?
0?l3000002X0FP3o0P00000M000Io`@00000?000S_l4000001d001Wo0P00
000Z05X0o`<000003@3?0?l50?ooo`030000003oool0oooo00d0oooo0025
0?ooo`030000003oool0oooo0080oooo4@3?0?l5000002L0FP3o0`00000N
000Io`<00000=P00S_l3000001h001Wo0`00000W05X0o`D00000403?0?l5
0?ooo`030000003oool0oooo00d0oooo00250?ooo`8000000`3ooolF0<l0
o`D000009@1J0?l3000001h001Wo1@00000/002>o`D000007P006Ol30000
02D0FP3o1@00000E0<l0o`@0oooo0P00000?0?ooo`00Q@3oool00`000000
oooo0?ooo`020?oooa/0c`3o1000000T05X0o`@000007`006Ol8000001`0
08ko2000000O000Io`@00000901J0?l4000001X0c`3o1@3oool00`000000
oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo0?ooo`020?oooal0c`3o
0`00000U05X0o`<000008`006OlN000002<001Wo0`00000U05X0o`<00000
7P3?0?l50?ooo`030000003oool0oooo00d0oooo00250?ooo`030000003o
ool0oooo0080oooo8P3?0?l5000002<0FP3o0`00001N000Io`<000008`1J
0?l500000240c`3o1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooobL0c`3o0`00000S05X0o`@00000E`006Ol3
000002<0FP3o0`00000V0<l0o`D0oooo00<000000?ooo`3oool03@3oool0
08D0oooo00<000000?ooo`3oool00P3ooolZ0<l0o`@000008`1J0?l30000
050001Wo1000000R05X0o`@00000:@3?0?l50?ooo`030000003oool0oooo
00d0oooo00250?ooo`8000000`3oool^0<l0o`@000008P1J0?l5000004H0
01Wo1@00000R05X0o`@00000;@3?0?l40?ooo`8000003`3oool008D0oooo
00<000000?ooo`3oool00P3ooolb0<l0o`<00000901J0?l5000003`001Wo
1@00000T05X0o`<00000<@3?0?l50?ooo`030000003oool0oooo00d0oooo
00250?ooo`030000003oool0oooo0080oooo0P00000c0<l0o`@000009@1J
0?l50000038001Wo1@00000U05X0o`@00000<`3?0?l2000000@0oooo00<0
00000?ooo`3oool03@3oool008D0oooo00<000000?ooo`3oool00P3oool2
0?l0^`D00000<P3?0?l4000002H0FP3o1P00000V000Io`H000009`1J0?l3
00000380c`3o1@0000000`3o0;/0oooo0?ooo`030?ooo`030000003oool0
oooo00d0oooo001a0?ooo`D000000P3oool2000000@0oooo0P0000050?oo
o`030000003oool0oooo0080oooo1`3o0;/500000340c`3o0`00000Y05X0
o``000003P006Ol<000002T0FP3o1000000`0<l0o`D000001P3o0;/50?oo
o`030000003oool0oooo00d0oooo001c0?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oo
o``0o`2k1`00000]0<l0o`@00000<@1J0?l>00000340FP3o1000000]0<l0
o`L000002`3o0;/50?ooo`030000003oool0oooo00d0oooo001c0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool2000000<0
oooo4`3o0;/5000002`0c`3o1000001X05X0o`@00000;03?0?l500000180
o`2k103oool2000000l0oooo001c0?ooo`030000003oool0oooo00P0oooo
0P0000050?ooo`030000003oool0oooo0080oooo603o0;/3000002d0c`3o
1000001Q05X0o`<00000;@3?0?l3000001L0o`2k1@3oool00`000000oooo
0?ooo`0=0?ooo`00L`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3ooolK0?l0^`D00000;03?
0?l5000005L0FP3o1@00000[0<l0o`D000006P3o0;/50?ooo`030000003o
ool0oooo00d0oooo001b0?ooo`8000002P3oool3000000@0oooo00<00000
0?ooo`3oool00P3ooolP0?l0^`D00000;03?0?l4000004h0FP3o1@00000[
0<l0o`D000007`3o0;/50?ooo`030000003oool0oooo00d0oooo00250?oo
o`030000003oool0oooo0080oooo9@3o0;/5000002/0c`3o1P00001205X0
o`H00000:`3?0?l5000002@0o`2k1@3oool00`000000oooo0?ooo`0=0?oo
o`00Q@3oool00`000000oooo0?ooo`020?ooobX0o`2k1000000]0<l0o`H0
0000=P1J0?l6000002d0c`3o1000000Y0?l0^`D0oooo00<000000?ooo`3o
ool03@3oool008D0oooo0P0000030?ooobh0o`2k1@00000^0<l0o`P00000
9P1J0?l8000002h0c`3o1@00000]0?l0^`@0oooo0P00000?0?ooo`00Q@3o
ool00`000000oooo0?ooo`020?oooc<0o`2k1@00000a0<l0obH00000<P3?
0?l400000380o`2k1@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool0
0`000000oooo0?ooo`020?ooocP0o`2k0`0000220<l0o`@00000=P3o0;/5
0?ooo`030000003oool0oooo00d0oooo00250?ooo`030000003oool0oooo
0080oooo0`00000h0?l0^`H00000MP3?0?l6000003P0o`2k0`0000040?oo
o`030000003oool0oooo00d0oooo00250?ooo`030000003oool0oooo0080
oooo0`3o0006000003P0o`2k1000001^0<l0o`D00000=`3o0;/600000080
o`001@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool00`000000oooo
0?ooo`020?ooo`T0o`001`00000e0?l0^`D00000I03?0?l5000003D0o`2k
1`0000080?l000D0oooo00<000000?ooo`3oool03@3oool008D0oooo0P00
00030?oooa00o`001@00000e0?l0^`L00000E`3?0?l6000003D0o`2k1@00
000?0?l000@0oooo0P00000?0?ooo`00Q@3oool00`000000oooo0?ooo`02
0?oooaD0o`001P00000f0?l0^`@00000CP3?0?l5000003D0o`2k1P00000D
0?l000D0oooo00<000000?ooo`3oool03@3oool008D0oooo00<000000?oo
o`3oool00P3ooolK0?l000D00000=@3o0;/9000003`0c`3o2@00000e0?l0
^`D000006P3o00050?ooo`030000003oool0oooo00d0oooo00250?ooo`03
0000003oool0oooo0080oooo803o0005000003T0o`2k2000000/0<l0o`P0
0000>@3o0;/5000001l0o`001@3oool00`000000oooo0?ooo`0=0?ooo`00
Q@3oool00`000000oooo0?ooo`020?ooobD0o`001@00000l0?l0^a800000
203?0?lB000003`0o`2k1@00000T0?l000D0oooo00<000000?ooo`3oool0
3@3oool008D0oooo00<000000?ooo`3oool00P3ooolZ0?l000L00000A`3o
0;/8000004L0o`2k1`00000Y0?l000D0oooo00<000000?ooo`3oool03@3o
ool008D0oooo00<000000?ooo`3oool00P3ooola0?l000D00000S03o0;/5
00000300o`001@3oool00`000000oooo0?ooo`0=0?ooo`00Q@3oool20000
00<0oooo=P3o000500000880o`2k1@00000e0?l000@0oooo0P00000?0?oo
o`00Q@3oool00`000000oooo0?ooo`020?oooc/0o`001`00001e0?l0^`H0
0000>P3o00050?ooo`030000003oool0oooo00d0oooo00250?ooo`030000
003oool0oooo0080oooo@P3o0005000006/0o`2k1@0000100?l000D0oooo
00<000000?ooo`3oool03@3oool008D0oooo00<000000?ooo`3oool00P3o
oom70?l000H00000GP3o0;/7000004D0o`001@3oool00`000000oooo0?oo
o`0=0?ooo`00Q@3oool00`000000oooo0?ooo`020?ooodd0o`002000001>
0?l0^`P00000C03o00050?ooo`030000003oool0oooo00d0oooo00250?oo
o`030000003oool0oooo0080ooooE@3o0009000003`0o`2k2@00001D0?l0
00D0oooo00<000000?ooo`3oool03@3oool008D0oooo0P0000030?oooeh0
o`002`00000V0?l0^`/00000G@3o00040?ooo`8000003`3oool008D0oooo
00<000000?ooo`3oool00P3ooomY0?l002H00000J03o00050?ooo`030000
003oool0oooo00d0oooo00250?ooo`030000003oool0oooo0080oooom`3o
00050?ooo`030000003oool0oooo00d0oooo00250?ooo`030000003oool0
oooo0080oooom`3o00050?ooo`030000003oool0oooo00d0oooo001m0?oo
o`@00000103oool00`000000oooo0?ooo`020?ooooL0o`001@3oool00`00
0000oooo0?ooo`0=0?ooo`00O@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooom`3o00050?ooo`030000003oool0oooo00d0
oooo001n0?ooo`030000003oool0oooo00@0oooo0P0000030?ooooL0o`00
103oool2000000l0oooo001o0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3o
ool007d0oooo00@000000?ooo`3oool00000103ooooo000000<000003`3o
ool007h0oooo0P00003o0?oooaL0oooo003o0?oooiL0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{406, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  We use the fact that the conformal mapping  ",
  Cell[BoxData[
      \(w\  = \ \(S \((z)\)\  = \ z + 1\/z\)\)]],
  "  maps the domain  ",
  Cell[BoxData[
      \(D = {z : \(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)}\)]],
  "  one-to-one and onto the w plane slit along the segment  ",
  Cell[BoxData[
      \(\(-2\) \[LessEqual] u \[LessEqual] 2, v = 0\)]],
  ".  The complex potential for a uniform horizontal flow parallel to this \
slit in the w plane is  \n\n\t\t\t",
  Cell[BoxData[
      \(\(F\_1\) \((w)\)\  = \ A\ w\)]],
  ",  \n\nwhere ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " is a positive real number.  The stream function for the flow in the w \
plane is  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPsi]", 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], " ", "=", 
        " ", \(A\ v\)}]]],
  "  so that the slit lies along the streamline  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPsi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        "0"}]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe composite function  ",
  Cell[BoxData[
      \(\(F\_2\) \((z)\)\  = \ \(F\_1\) \((S \((z)\))\)\)]],
  "  determines the fluid flow in the domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ", where the complex potential is \n\n\t\t\t",
  Cell[BoxData[
      \(\(F\_2\) \((z)\)\  = \ \(\(F\_1\) \((S \((z)\))\)\ \  = \ \ A\ \((z + 
                1\/z)\)\)\)]],
  ",  \n\nwhere ",
  Cell[BoxData[
      \(A > 0\)]],
  ".  We can use polar coordinates to express ",
  Cell[BoxData[
      \(\(F\_2\) \((z)\)\)]],
  " as \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\(F\_2\) \((z)\)\ \  = \ \ \(\(F\_2\) \((r\ \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Theta]\))\)\ \  = \ \ A\ \((r\ \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Theta]\) + 
                1\/\(r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\))\)\)\)\
\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ \((r\ cos\ \[Theta]\  \
+ \ \[ImaginaryI]\ r\ sin\ \[Theta]\  + 
              1\/\(r\ cos\ \[Theta]\  + \ \[ImaginaryI]\ r\ sin\ \
\[Theta]\))\)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ \((r\ cos\ \[Theta]\  \
+ \ \[ImaginaryI]\ r\ sin\ \[Theta]\  + \(r\ cos\ \[Theta]\  - \ \ \
\[ImaginaryI]\ r\ sin\ \[Theta]\)\/\(\((r\ cos\[Theta]\  + \ \[ImaginaryI]\ r\
\ Sin\ \[Theta])\) \((r\ cos\ \[Theta]\  - \ \[ImaginaryI]\ r\ sin\ \[Theta])\
\)\))\)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ \((r\ cos\ \[Theta]\  \
+ \ \[ImaginaryI]\ r\ sin\ \[Theta]\  + \(r \((\ cos\ \[Theta]\  - \ \ \
\[ImaginaryI]\ r\ sin\ \[Theta])\)\)\/r\^2)\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ \((r + 
                1\/r)\)\ cos\ \[Theta]\ \ \  + \ \ \(\(\[ImaginaryI]\)\(\ \
\)\(A\) \((r - 1\/r)\) \(sin\)\(\ \)\(\[Theta]\)\(\ \)\)\)\)\)}]]
}], "Text"],

Cell[TextData[{
  "The streamline   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{"r", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "\[Theta]"}], ")"}]}], "  ", "=", 
        "  ", \(A \((r - 1\/r)\) sin\ \[Theta]\ \  = \ \ 0\)}]]],
  "  consists of the rays \n\n\t\t\t",
  Cell[BoxData[
      \(r > 1, \[Theta] = 0\)]],
  "   and   ",
  Cell[BoxData[
      \(r > 1, \[Theta] = \[Pi]\)]],
  " \n\nalong the x axis and the curve  ",
  Cell[BoxData[
      \(r - 1\/r\  = \ 0\)]],
  ",  which is the unit circle  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\)\  = \ \(r\  = \ 1\)\)]],
  ".  Thus the unit circle can be considered as a boundary curve for the \
fluid flow."
}], "Text"],

Cell[TextData[{
  "\tThe approximation  ",
  Cell[BoxData[
      \(\(F\_2\) \((z)\)\  = \ \ A\ \((z + 
                1\/z)\)\ \  \[TildeTilde] \ \ A\ z\)]],
  "  is valid for large values of z, so we can approximate the flow with a \
uniform horizontal flow having speed  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"|", 
          RowBox[{
            StyleBox["V",
              FontWeight->"Bold"], 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "|"}], " ", "=", 
        " ", "A"}]]],
  "  at points that are distant from the origin.  The streamlines  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        "constant"}]]],
  "  and their images  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPsi]", 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], " ", "=", " ", 
        "constant"}]]],
  "  under the mapping ",
  Cell[BoxData[
      \(w = \(S \((z)\) = z + 1\/z\)\)]],
  " are illustrated in Figure 11.51."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.51",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/fluidflow/FluidFlowFigures/\
mat1151.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Fluid flow around a circle.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Consider the complex potential  ",
  Cell[BoxData[
      \(F[z] = A \((z + 1\/z)\)\)],
    AspectRatioFixed->True],
  " where  A  is a positive real number.  The velocity potential and stream \
function are given by  \n",
  Cell[BoxData[
      \(u[x, y] = A\ \((x + x\/\(x\^2 + y\^2\))\), \n
      v[x, y] = A\ \(\((y - y\/\(x\^2 + y\^2\))\)\(.\)\)\)]],
  "  \n",
  "Enter the complex potential and determine the velocity potential and \
stream function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[A, x, y, u, v, w, z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[cont, f, F, g, g1, g2, solset];\)\ \), "\n", 
    \(\(F[z_]\  = A \((z\  + \ 1\/z)\);\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ 
        ComplexExpand[Re[F[x + \[ImaginaryI]\ y]], 
          TargetFunctions \[Rule] {Re, Im}];\)\ \), "\n", 
    \(\(\[Psi][x_, y_]\  = 
        ComplexExpand[Im[F[x + \[ImaginaryI]\ y]], 
          TargetFunctions \[Rule] {Re, Im}];\)\ \), "\n", 
    \(\(Print["\<The  complex potential is   F[z] = \>", F[z]];\)\ \), "\n", 
    \(\(Print["\<F[z]  =  \[Phi][x,y] + \[ImaginaryI] \[Psi][x,y]\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<F[z]  =  (\>", \[Phi][x, 
          y], "\<) + \[ImaginaryI](\>", \ \[Psi][x, 
          y], "\<)\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential is \[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\n", 
    \(\(Print["\<The   stream function  is \[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a plot of the stream function.\n\nFor illustration purposes, we \
choose A = 1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(A = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(cont\  = \ Table[0 + 0.2  k, {k, 0, 7}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Psi][x, y], {x, \(-2\), 2}, {y, 0, 
          2}, \[IndentingNewLine]Contours\  \[Rule] cont, 
        PlotPoints \[Rule] 55, 
        AspectRatio \[Rule] 1\/2, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, y]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[Psi][x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where  c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The inverse of  ",
  Cell[BoxData[
      \(w = \(f \((z)\) = \(z + 
              1\/z\ \ is\ \ z = \(g \((w)\) = \ \(w\  + \ \@\(w\^2\  - \ \
4\)\)\/2\)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[z_]\  = \ z\  + \ 1\/z;\)\ \), "\n", 
    \(\(solset\  = \ Solve[w \[Equal] f[z], z];\)\ \), "\n", 
    \(\(g[w_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Z\_0\  = \ PowerExpand[ExpandAll[g[f[z]]]];\)\ \), "\n", 
    \(\(Z\_1\  = 
        ReplaceAll[
          Z\_0\ , \@\(1 - 2\ z\^2 + z\^4\)\  \[Rule] \ \(-\((1 - 
                  z\^2)\)\)];\)\ \), "\n", 
    \(\(Z\_2\  = \ Together[Z\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_3 = MapAll[Factor, Z\_2];\)\ \), "\n", 
    \(\(Z\_4 = \(1 + z\^2 + \@\(\((\(-1\) + z)\)\^2\ \((1 + z)\)\^2\)\)\/\(2\ \
z\);\)\ \), "\n", 
    \(\(Z\_5 = PowerExpand[Z\_4];\)\ \), "\n", 
    \(\(Z\_6 = Simplify[Z\_5];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\n", 
    \(\(Print["\<g[w] = \>", g[w]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", Z\_0];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", Z\_1];\)\ \), "\n", 
    \(\(Print["\<g[f[z]] = \>", Z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[f[z]] = \>", Z\_3];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[f[z]] = \>", Z\_4];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[f[z]] = \>", Z\_5];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[f[z]] = \>", Z\_6];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<f[g[w]] = \>", f[g[w]]];\)\ \), "\n", 
    \(\(Print["\<f[g[w]] = \>", 
        Together[f[g[w]]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\
Use conformal mapping  z = g(w)  to make an image of the flow.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(g1[w_]\  = \ \ \(w\  + \ \@\(w\^2\  - \ 4\)\)\/2;\)\ \), "\n", 
    \(\(g2[
          w_]\  = \ \ \(w\  - \ \@\(w\^2\  - \ 4\)\)\/2;\)\ \), "\
\[IndentingNewLine]", 
    \(\(Iden[w_]\  = \ w;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\ \(CartesianMap[Iden, {\(-3.2\), 3.2, 0.2}, {0, 1.2, 0.2}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[0, 2, 1]}, 
        PlotStyle \[Rule] {Blue, Red}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The horizontal flow in the z-plane.\>"];\)\ \), "\n", 
    \(\(gr1\  = \ 
        CartesianMap[g1, {0.00001, 3.20001, 0.2}, {0.00001, 1.20001, 0.2}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(gr2\  = \ 
        CartesianMap[
          g2, {\(-3.20001\), \(-0.00001\), 0.2}, {\ 0.00001, 1.20001, 0.2}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{\(-3\), 3}, {0, 2}}, 
        Ticks \[Rule] {Range[\(-3\), 3, 1], Range[0, 2, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The image flow across the complex plane,\>"];\)\ \), "\n", 
    \(\(Print["\<and around the unit circle |z| = 1,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<under the mapping z = g(w) = \>", 
        g1[w]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The velocity potential is \[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\n", 
    \(\(Print["\<The   stream function  is \[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.25.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  "Find the complex potential for an ideal fluid flowing from left to right \
across the complex plane and around the segment from",
  "  ",
  Cell[BoxData[
      \(z = \(\(-\[ImaginaryI]\)\ \ to\ \ z = \(-\[ImaginaryI]\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000Qb000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?oo
o`00SP3oool4000003X0oooo1@00000g0?ooo`800000>P3oool5000003T0
oooo1000000=0?ooo`00SP3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo03H0oooo00@000000?ooo`3oool00000>`3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00h0oooo002?0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool0=P3oool010000000oooo
0?ooo`00000k0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool03@3oool008P0oooo100000040?ooo`030000003oool0oooo03<0oooo
100000040?ooo`030000003oool0oooo03H0oooo00@000000?ooo`3oool0
0000>`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0
oooo002>0?ooo`040000003oool0oooo000003`0oooo00<000000?ooo`3o
ool0=P3oool010000000oooo0?ooo`00000k0?ooo`030000003oool0oooo
03T0oooo00@000000?ooo`3oool000003@3oool008l0oooo0P00000l0?oo
o`800000>@3oool2000003/0oooo0P00000l0?ooo`8000003P3oool00?l0
ooooU03oool00?l0ooooU03oool00?l0ooooU03oool00?l0ooooU03oool0
0?l0ooooU03oool008L0ooooo`000005000000P0oooo00200?ooo`800000
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00H0oooo001o0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1P3oool007l0oooo00@000000?ooo`3oool00000103oool3000000<0oooo
n00000030?ooo`<00000203oool007l0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`030?ooooL0od@01P3oool00`000000oooo
0?ooo`060?ooo`00O`3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00<0oooom`3oA0060?ooo`030000003oool0oooo00H0oooo
00200?ooo`8000001@3oool2000000@0oooom`3oA0050?ooo`800000203o
ool008L0oooo00<000000?ooo`3oool00`3oooog0?m400H0oooo00<00000
0?ooo`3oool01P3oool008L0oooo00<000000?ooo`3oool00`3oooog0?m4
00H0oooo00<000000?ooo`3oool01P3oool008L0oooo0P0000040?ooooL0
od@01@3oool2000000P0oooo00270?ooo`030000003oool0oooo00<0oooo
9P00002/0?m402H000001@3oool00`000000oooo0?ooo`060?ooo`00Q`3o
ool00`000000oooo0?ooo`030?ooobH0ojD05`00001n0?m401L000009@3o
Y@060?ooo`030000003oool0oooo00H0oooo00270?ooo`800000103ooolm
0?nU00`00000IP3oA00<000003`0ojD01@3oool2000000P0oooo00270?oo
o`030000003oool0oooo00<0ooooB03oY@08000005P0od@0200000170?nU
00H0oooo00<000000?ooo`3oool01P3oool008L0oooo00<000000?ooo`3o
ool00`3ooom@0?nU00H00000C03oA006000004l0ojD01P3oool00`000000
oooo0?ooo`060?ooo`00Q`3oool2000000@0ooooEP3oY@05000004<0od@0
1000001E0?nU00D0oooo0P0000080?ooo`00KP3oool2000000@0oooo0P00
00030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool00`3o
oomJ0?nU00@00000?@3oA003000005T0ojD01P3oool00`000000oooo0?oo
o`060?ooo`00K@3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo00<0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`030?oooa`00000@@3oY@03000003P0od@00`0000110?nU01`00000
1@3oool00`000000oooo0?ooo`060?ooo`00K@3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool3000000<0oooo703io`0B00000380ojD00P00000d0?m400800000
<`3oY@0B000001X0nOl0103oool3000000P0oooo001]0?ooo`040000003o
ool0oooo000000X0oooo00<000000?ooo`3oool00P3oool2000000D0oooo
00<000000?ooo`3oool00`3oool]0?Wo00`00000:@3oY@03000002l0od@0
0P00000X0?nU00d00000;03io`060?ooo`030000003oool0oooo00H0oooo
001]0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo>@3io`08000002<0ojD00P00000/0?m4008000008`3oY@08000003P0
nOl01P3oool00`000000oooo0?ooo`060?ooo`00KP3oool2000000X0oooo
0P0000040?ooo`<00000103oool2000000@0oooo@@3io`06000001l0ojD0
0P00000X0?m4008000007`3oY@0600000400nOl01@3oool2000000P0oooo
00270?ooo`030000003oool0oooo00<0ooooA`3io`05000001/0ojD00P00
000V0?m4008000006`3oY@05000004H0nOl01P3oool00`000000oooo0?oo
o`060?ooo`00Q`3oool00`000000oooo0?ooo`030?oood`0nOl01000000H
0?nU00800000903oA002000001P0ojD01@00001:0?Wo00H0oooo00<00000
0?ooo`3oool01P3oool008L0oooo0P0000040?oooaP00000=`3io`050000
01H0ojD000<000000?m4003oA000803oA0000`000000ojD00?nU000E0?nU
00@00000=`3io`0H000000@0oooo0P0000080?ooo`00Q`3oool00`000000
oooo0?ooo`030?oooaP0Uol03`00000/0?Wo00<00000503oY@0200000200
od@00P00000D0?nU00<00000;03io`0?000001L0Uol01P3oool00`000000
oooo0?ooo`060?ooo`00Q`3oool00`000000oooo0?ooo`030?ooobH0Uol0
3000000T0?Wo008000004`3oY@02000001h0od@00P00000C0?nU00800000
9@3io`0;000002D0Uol01P3oool00`000000oooo0?ooo`060?ooo`00Q`3o
ool00`000000oooo0?ooo`030?oooc00Uol02000000P0?Wo00<000004@3o
Y@02000001`0od@00P00000A0?nU00<00000803io`08000002l0Uol01P3o
ool00`000000oooo0?ooo`060?ooo`00Q`3oool2000000@0oooo>02Go`08
000001X0nOl00`00000@0?nU00030000003oA000od@001X0od@000<00000
0?nU003oY@003P3oY@03000001X0nOl02000000g09Oo00D0oooo0P000008
0?ooo`00Q`3oool00`000000oooo0?ooo`030?oooch0Uol01P00000H0?Wo
00<000003`3oY@000`000000od@00?m4000H0?m400030000003oY@00ojD0
00d0ojD00`00000I0?Wo00D00000?@2Go`060?ooo`030000003oool0oooo
00H0oooo00270?ooo`030000003oool0oooo00<0oooo1@00000n09Oo00D0
00005P3io`02000000h0ojD00P00000H0?m4008000003P3oY@02000001H0
nOl01@00000o09Oo00@000001@3oool00`000000oooo0?ooo`060?ooo`00
Q`3oool2000000@0oooo100fo`0B00000380Uol01000000D0?Wo00030000
003oY@00ojD000`0ojD000<000000?m4003oA0005P3oA0000`000000ojD0
0?nU000<0?nU00030000003io`00nOl00180nOl01000000b09Oo01800000
0`0fo`050?ooo`800000203oool007@0oooo0P0000040?ooo`800000103o
ool2000000D0oooo00<000000?ooo`3oool00`3ooolF03Ko00d00000:02G
o`0400000180nOl00P00000<0?nU008000005P3oA002000000`0ojD00P00
000B0?Wo00@00000:02Go`0=000001D0=_l01P3oool00`000000oooo0?oo
o`060?ooo`00L`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00`3ooolS03Ko00T00000
8`2Go`0300000140nOl00P00000;0?nU00030000003oA000od@001@0od@0
00<000000?nU003oY@002P3oY@000`000000nOl00?Wo000?0?Wo00<00000
8`2Go`0:00000240=_l01P3oool00`000000oooo0?ooo`060?ooo`00L`3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo
0`0000030?ooob`0=_l02000000M09Oo00<00000403io`02000000/0ojD0
00<000000?m4003oA0004P3oA002000000/0ojD00P00000?0?Wo00<00000
7@2Go`08000002/0=_l0103oool3000000P0oooo001c0?ooo`040000003o
ool0oooo000000T0oooo0P0000050?ooo`030000003oool0oooo00<0oooo
=00fo`05000001X0Uol00`00000?0?Wo00030000003oY@00ojD000T0ojD0
00<000000?m4003oA0004P3oA0000`000000ojD00?nU00090?nU00030000
003io`00nOl000d0nOl00`00000J09Oo00H00000<P0fo`060?ooo`030000
003oool0oooo00H0oooo001c0?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooocT0=_l0
1P00000G09Oo008000003P3io`02000000T0ojD00P00000B0?m400800000
2P3oY@000`000000nOl00?Wo000<0?Wo008000005`2Go`06000003P0=_l0
1P3oool00`000000oooo0?ooo`060?ooo`00M03oool2000000X0oooo0`00
00040?ooo`800000103oool8000003H0=_l01000000F09Oo008000003@3i
o`000`000000ojD00?nU00080?nU00030000003oA000od@00100od@000<0
00000?nU003oY@00203oY@000`000000nOl00?Wo000;0?Wo008000005P2G
o`04000003H0=_l0200000040?ooo`800000203oool008L0oooo00<00000
0?ooo`3oool00`3oool7003o:Pl00000;00fo`0500000180Uol00`00000<
0?Wo00030000003oY@00ojD000L0ojD00P00000@0?m4008000002@3oY@00
0`000000nOl00?Wo000:0?Wo00<000004P2Go`05000002`0=_l03`000006
003o:PH0oooo00<000000?ooo`3oool01P3oool008L0oooo00<000000?oo
o`3oool00`3ooolF003o:P/000009@0fo`03000001<0Uol00P00000;0?Wo
00030000003oY@00ojD000L0ojD000<000000?m4003oA0003P3oA0000`00
0000ojD00?nU00070?nU00030000003io`00nOl000X0nOl000<0000009Oo
002Go`004@2Go`03000002D0=_l02`00000E003o:PH0oooo00<000000?oo
o`3oool01P3oool008L0oooo0P0000040?ooob400?lZ2@00000O03Ko00@0
0000402Go`000`000000nOl00?Wo000:0?Wo00030000003oY@00ojD000H0
ojD000<000000?m4003oA0003P3oA0000`000000ojD00?nU00060?nU0080
00002`3io`000`000000Uol009Oo000?09Oo00<000007`0fo`0900000200
0?lZ1@3oool2000000P0oooo00270?ooo`030000003oool0oooo00<0oooo
:@00obX8000001/0=_l01000000>09Oo008000002P3io`02000000L0ojD0
0P00000>0?m4008000001`3oY@02000000X0nOl00P00000>09Oo00@00000
6`0fo`08000002P00?lZ1P3oool00`000000oooo0?ooo`060?ooo`00Q`3o
ool00`000000oooo0?ooo`030?oooc000?lZ1P0000000`0fo`00000003Ko
000F03Ko00<000003P2Go`000`000000nOl00?Wo00080?Wo00030000003o
Y@00ojD000H0ojD000<000000?m4003oA000303oA0000`000000ojD00?nU
00060?nU00030000003io`00nOl000P0nOl000<0000009Oo002Go`00302G
o`03000001P0=_l01`00000_003o:PH0oooo00<000000?ooo`3oool01P3o
ool008L0oooo0P0000040?ooocH00?lZ1P00000F03Ko008000003@2Go`02
000000T0nOl000<000000?nU003oY@001@3oY@000`000000od@00?m4000<
0?m400030000003oY@00ojD000D0ojD000<000000?Wo003io`001`3io`02
000000d0Uol00P00000G03Ko00D00000=@00obX50?ooo`800000203oool0
08L0oooo00<000000?ooo`3oool00`3oool;000000<00?lZ00<00000003o
:P00obX0:P00obX4000001D0=_l00P00000=09Oo00030000003io`00nOl0
00L0nOl000<000000?nU003oY@001@3oY@000`000000od@00?m4000;0?m4
00030000003oY@00ojD000@0ojD000<000000?Wo003io`001`3io`000`00
0000Uol009Oo000;09Oo008000005@0fo`04000003000?lZ2`0000050?oo
o`030000003oool0oooo00H0oooo00270?ooo`030000003oool0oooo00<0
oooo2`00oh/<000002P00?lZ1@00000B03Ko00800000302Go`000`000000
nOl00?Wo00060?Wo008000001P3oY@000`000000od@00?m4000:0?m40003
0000003oY@00ojD000D0ojD000<000000?Wo003io`001P3io`02000000/0
Uol00P00000B03Ko00D00000:000obX=000000T00?n;1P3oool00`000000
oooo0?ooo`060?ooo`00Q`3oool2000000@0oooo5`00oh/:000002800?lZ
1000000A03Ko008000002`2Go`000`000000nOl00?Wo00060?Wo00030000
003oY@00ojD000@0ojD000<000000?m4003oA0002P3oA0000`000000ojD0
0?nU00040?nU00030000003io`00nOl000H0nOl000<0000009Oo002Go`00
2@2Go`0200000140=_l01000000R003o:PX000005P00oh/50?ooo`800000
203oool006h0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?oo
o`020?ooo`8000001@3oool00`000000oooo0?ooo`030?ooob400?n;2000
000N003o:P<000003`0fo`02000000/0Uol000<000000?Wo003io`001@3i
o`000`000000ojD00?nU00040?nU00030000003oA000od@000X0od@000<0
00000?nU003oY@00103oY@000`000000nOl00?Wo00050?Wo00030000002G
o`00Uol000T0Uol00P00000?03Ko00<000007P00obX8000002000?n;1P3o
ool00`000000oooo0?ooo`060?ooo`00K@3oool010000000oooo0?ooo`00
000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo:000oh/7000001/00?lZ
0`00000>03Ko00<000002@2Go`000`000000nOl00?Wo00050?Wo00030000
003oY@00ojD000@0ojD000<000000?m4003oA000203oA002000000D0ojD0
00<000000?Wo003io`001@3io`02000000T0Uol00P00000?03Ko00<00000
6P00obX7000002L00?n;1P3oool00`000000oooo0?ooo`060?ooo`00K@3o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool3000000<0oooo;`00oh/6000001L00?lZ
1000000=03Ko008000002@2Go`000`000000nOl00?Wo00050?Wo00030000
003oY@00ojD000<0ojD000<000000?m4003oA000203oA0000`000000ojD0
0?nU00030?nU00030000003io`00nOl000D0nOl000<0000009Oo002Go`00
1`2Go`02000000d0=_l01000000G003o:PH00000;P00oh/40?ooo`<00000
203oool006d0oooo00@000000?ooo`3oool000002`3oool010000000oooo
0?ooo`3oool2000000D0oooo00<000000?ooo`3oool00`3ooole003oR`D0
00005@00obX3000000`0=_l00P00000909Oo00030000003io`00nOl000@0
nOl000<000000?nU003oY@000`3oY@000`000000od@00?m400080?m40003
0000003oY@00ojD000<0ojD000<000000?Wo003io`00103io`02000000P0
Uol00P00000<03Ko00<000005@00obX5000003@00?n;1P3oool00`000000
oooo0?ooo`060?ooo`00K@3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`h00000;000oh/5000001<00?lZ0`00000;03Ko
00030000002Go`00Uol000L0Uol000<000000?Wo003io`00103io`000`00
0000ojD00?nU00030?nU00030000003oA000od@000L0od@000<000000?nU
003oY@000P3oY@000`000000nOl00?Wo00040?Wo00030000002Go`00Uol0
00L0Uol000<0000003Ko000fo`002@0fo`03000001<00?lZ1@00000/003o
R`h000001@3oool00`000000oooo0?ooo`060?ooo`00KP3oool2000000T0
oooo100000030?ooo`<00000103oool2000000@0oooo3P00on`;000002D0
0?n;1000000B003o:P<000002P0fo`02000000L0Uol00P0000050?Wo0080
0000103oY@000`000000od@00?m400060?m400030000003oY@00ojD00080
ojD00P0000050?Wo008000001`2Go`02000000X0=_l00`00000B003o:P@0
00009@00oh/;000000d00?o/1@3oool2000000P0oooo00270?ooo`030000
003oool0oooo00<0oooo6000on`:000002000?n;1000000@003o:P800000
2`0fo`02000000H0Uol00P0000050?Wo00030000003oY@00ojD00080ojD0
00<000000?m4003oA0001P3oA0000`000000ojD00?nU00020?nU00030000
003io`00nOl000<0nOl00P00000709Oo00030000000fo`00=_l000T0=_l0
0P00000A003o:P<000008000oh/:000001L00?o/1P3oool00`000000oooo
0?ooo`060?ooo`00Q`3oool00`000000oooo0?ooo`030?ooob800?o/1`00
000L003oR`@000003`00obX2000000X0=_l000<0000009Oo002Go`001@2G
o`02000000@0nOl000<000000?nU003oY@000P3oY@000`000000od@00?m4
00060?m400030000003oY@00ojD00080ojD000<000000?Wo003io`000P3i
o`02000000L0Uol000<0000003Ko000fo`00200fo`02000000l00?lZ1000
000L003oR`L000008@00on`60?ooo`030000003oool0oooo00H0oooo0027
0?ooo`800000103ooolX003ok0L000006@00oh/4000000h00?lZ0P000009
03Ko008000001P2Go`02000000@0nOl000@000000?nU003oY@00ojD00P00
00060?m4008000000`3oY@000`000000nOl00?Wo00020?Wo008000001P2G
o`02000000T0=_l00P00000>003o:P@000006@00oh/7000002L00?o/1@3o
ool2000000P0oooo00270?ooo`030000003oool0oooo00<0oooo;`00on`6
000001L00?n;0`00000=003o:P8000002@0fo`000`000000Uol009Oo0004
09Oo00030000003io`00nOl00080nOl00P0000030?nU00030000003oA000
od@000@0od@000@000000?nU003oY@00ojD00P0000040?Wo00030000002G
o`00Uol000@0Uol00P00000803Ko008000003@00obX4000001L00?n;1@00
000^003ok0H0oooo00<000000?ooo`3oool01P3oool008L0oooo00<00000
0?ooo`3oool00`3oool5000002l00?o/1P00000D003oR`<000003000obX3
000000L0=_l00P00000609Oo00030000003io`00nOl00080nOl000D00000
0?nU003oY@00ojD0000000060?m400050000003oY@00ojD00?nU00000000
103io`02000000D0Uol00P00000703Ko00<000003000obX3000001@00?n;
1P00000_003ok0D000001@3oool00`000000oooo0?ooo`060?ooo`00Q`3o
ool2000000@0oooo1@00/_l<000002T00?o/1000000C003oR`<000003000
obX00`000000=_l003Ko000603Ko00030000002Go`00Uol000@0Uol000<0
00000?Wo003io`000P3io`0010000000ojD00?nU000000060?m400030000
003oY@00ojD0008000000`3io`000`000000Uol009Oo000409Oo00030000
000fo`00=_l000H0=_l00P00000<003o:P8000004`00oh/4000002T00?o/
30000004002bo`D0oooo0P0000080?ooo`00Q`3oool00`000000oooo0?oo
o`030?oooa400;;o2P00000S003ok0@000004@00oh/3000000/00?lZ0P00
000703Ko00800000102Go`02000000<0nOl000D000000?nU003oY@00ojD0
000000040?m4008000000P3oY@0010000000nOl00?Wo003io`02000000@0
Uol00P00000703Ko008000002`00obX3000001400?n;1000000S003ok0X0
00004000/_l60?ooo`030000003oool0oooo00H0oooo00270?ooo`030000
003oool0oooo00<0oooo6`00/_l9000001d00?o/1@00000@003oR`800000
2`00obX2000000H0=_l00P00000409Oo008000000`3io`0010000000ojD0
0?nU000000040?m400040000003oY@00ojD0000000@0nOl000<0000009Oo
002Go`000`2Go`000`000000=_l003Ko000503Ko000300000000obX00?lZ
00T00?lZ0P00000A003oR`@000007P00on`8000001X00;;o1P3oool00`00
0000oooo0?ooo`060?ooo`00Q`3oool2000000@0oooo8`00/_l7000001/0
0?o/1000000?003oR`<000002@00obX2000000H0=_l00P00000409Oo0080
00000P3io`02000000030?nU00000000od@000<0od@000@000000?nU0000
000000000P3io`02000000@0Uol00P00000603Ko008000002@00obX30000
00l00?n;1000000K003ok0L000008P00/_l50?ooo`800000203oool007l0
oooo1@0000030?ooo`030000003oool0oooo00<0oooo:P00/_l7000001L0
0?o/1@00000=003oR`<000002@00obX2000000H0=_l000<0000009Oo002G
o`000P2Go`001@000000nOl00?Wo003io`0000000080ojD000@000000?m4
003oA00000000P3oY@001@000000nOl00?Wo003io`00000000@0Uol000<0
000003Ko000fo`00100fo`02000000T00?lZ0`00000>003oR`@000005`00
on`7000002T00;;o1P3oool00`000000oooo0?ooo`060?ooo`00P@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo<000/_l5
000001L00?o/0`00000>003oR`0300000000obX00?lZ00L00?lZ0P000005
03Ko00800000102Go`0200000080nOl000<000000?nU000000000P3oA000
0`000000ojD0000000030?Wo00030000002Go`00Uol00080Uol00P000005
03Ko008000002@00obX2000000d00?n;0`00000G003ok0D00000;`00/_l6
0?ooo`030000003oool0oooo00H0oooo00210?ooo`030000003oool0oooo
00<0oooo0`0000030?ooo`X00000:`00/_l6000001@00?o/0`00000<003o
R`<000001`00obX3000000D0=_l00P00000309Oo00030000003io`00nOl0
00P000000P3io`0010000000Uol009Oo002Go`02000000D0=_l00`000007
003o:P<000003000oh/3000001@00?o/1P00000[002bo`X000000`3oool3
000000P0oooo00210?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`3oool:001Ao`/000009P00/_l4000001<00?o/0P00000<003o
R`8000002@00obX00`000000=_l003Ko000303Ko00030000002Go`00Uol0
0080Uol00P000000103io`0000000000003oY@03000000030?Wo00000000
000000@0Uol000<0000003Ko000fo`000`0fo`02000000P00?lZ0P00000<
003oR`8000004`00on`5000002D00;;o2`000009001Ao`H0oooo00<00000
0?ooo`3oool01P3oool00840oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?oooaD0057o2@00000P002bo`D000004@00on`30000
00/00?n;0`000007003o:P800000100fo`02000000<0Uol00P0000020?Wo
008000000P3io`02000000<0Uol00P00000403Ko00<000001`00obX20000
00/00?n;0`00000A003ok0D000008000/_l:000001<0057o1P3oool00`00
0000oooo0?ooo`060?ooo`00P03oool2000000D0oooo00<000000?ooo`3o
ool00`3ooolN001Ao`P000007@00/_l4000001000?o/0`00000:003oR`80
00002000obX00`000000=_l003Ko000303Ko008000000`2Go`06000000@0
Uol000<0000003Ko000fo`000`0fo`000`0000000?lZ003o:P06003o:P80
00002P00oh/3000001000?o/1000000M002bo`P000007@00DOl60?ooo`03
0000003oool0oooo00H0oooo00270?ooo`800000103ooolV001Ao`H00000
6`00/_l4000000h00?o/0`00000:003oR`<000001P00obX2000000@0=_l0
0`00000809Oo00<00000100fo`02000000L00?lZ0P00000:003oR`<00000
3`00on`3000001/00;;o1P00000U001Ao`D0oooo0P0000080?ooo`00Q`3o
ool00`000000oooo0?ooo`030?ooob`0057o1P00000H002bo`@000003P00
on`2000000X00?n;0P000007003o:P8000001@0fo`08000000D0=_l00P00
0007003o:P8000002P00oh/2000000h00?o/1000000H002bo`H00000:`00
DOl60?ooo`030000003oool0oooo00H0oooo00270?ooo`030000003oool0
oooo00<0oooo0`00000_001Ao`H000005P00/_l3000000d00?o/0`000009
003oR`8000001`00obX3000000d0=_l00P000007003o:P8000002@00oh/3
000000d00?o/0`00000F002bo`H00000;`00DOl3000000D0oooo00<00000
0?ooo`3oool01P3oool008L0oooo0P0000040?ooo`<03`3o3000000X001A
o`D000005000/_l4000000`00?o/0`000009003oR`<000001P00obX40000
00H0=_l010000006003o:P<000002@00oh/3000000`00?o/1000000D002b
o`D00000:000DOl<000000803`3o1@3oool2000000P0oooo00270?ooo`03
0000003oool0oooo00<0oooo3P0?0?l<00000280057o1@00000C002bo`<0
00003000on`3000000P00?n;0`000008003o:PH000002000obX3000000P0
0?n;0`00000<003ok0<000004`00/_l5000002<0057o2`00000=00l0o`H0
oooo00<000000?ooo`3oool01P3oool008L0oooo00<000000?ooo`3oool0
0`3ooolH00l0o`T000008000DOl5000001400;;o0`00000;003ok0<00000
2@00oh/3000001000?lZ0`000009003oR`<000002`00on`3000001800;;o
1000000P001Ao`T000005`0?0?l60?ooo`030000003oool0oooo00H0oooo
00270?ooo`800000103ooolQ00l0o`P000007000DOl4000001000;;o1000
000;003ok0<000002@00oh/5000000H00?lZ1@000009003oR`<000002`00
on`4000001000;;o1000000L001Ao`P00000800?0?l50?ooo`800000203o
ool008L0oooo00<000000?ooo`3oool00`3ooolY00l0o`H000006P00DOl4
000001000;;o0`00000;003ok0<000002P00oh/8000000X00?n;1000000:
003ok0@000003`00/_l4000001X0057o1P00000X00l0o`H0oooo00<00000
0?ooo`3oool01P3oool008L0oooo00<000000?ooo`3oool00`3oool_00l0
o`H000006000DOl3000001000;;o0`00000;003ok0<000005P00oh/30000
00/00?o/0`00000@002bo`<000006000DOl6000002h03`3o1P3oool00`00
0000oooo0?ooo`060?ooo`00Q`3oool2000000@0oooo2P00000[00l0o`H0
00005@00DOl5000000h00;;o0`00000;003ok0D000003000oh/5000000/0
0?o/0`00000?002bo`@000005@00DOl6000002`03`3o2@0000040?ooo`80
0000203oool006d0oooo1@0000020?ooo`8000000`3oool4000000<0oooo
0P0000050?ooo`030000003oool0oooo00<0oooo2@1`0?l;000002L03`3o
1000000E001Ao`<000003P00/_l4000000`00?o/3P00000<003ok0@00000
3P00/_l3000001D0057o1@00000V00l0o`/00000201`0?l60?ooo`030000
003oool0oooo00H0oooo001_0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo00<0oooo501`0?l9000002803`3o1@00000C001Ao`@00000
3P00/_l3000002000?o/0`00000>002bo`@000004`00DOl5000002803`3o
2@00000C0700o`H0oooo00<000000?ooo`3oool01P3oool006l0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo0`0000030?oooad0L03o2000000O00l0o`D000004P00
DOl3000000h00;;o1@00000F003ok0D000003P00/_l300000180057o1@00
000O00l0o`P00000701`0?l40?ooo`<00000203oool006l0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`8000001@3oool0
0`000000oooo0?ooo`030?ooobD0L03o2000000K00l0o`D000004@00DOl4
000000l00;;o1P00000:003ok0H000003`00/_l400000180057o1000000K
00l0o`P00000901`0?l60?ooo`030000003oool0oooo00H0oooo001_0?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo;@1`0?l6
000001T03`3o1@00000A001Ao`@000004@00/_l:000001400;;o1000000A
001Ao`D000006@0?0?l7000002/0L03o1P3oool00`000000oooo0?ooo`06
0?ooo`00KP3oool2000000X0oooo0P0000040?ooo`<00000103oool20000
00@0oooo1000000_0700o`H00000600?0?l400000140057o1000000T002b
o`@000004@00DOl4000001P03`3o1P00000_0700o`@00000103oool20000
00P0oooo00270?ooo`030000003oool0oooo00<0oooo103A0?l;000002X0
L03o1P00000F00l0o`@000004@00DOl5000001X00;;o1@00000A001Ao`@0
00005P0?0?l6000002X0L03o300000020=40o`H0oooo00<000000?ooo`3o
ool01P3oool008L0oooo00<000000?ooo`3oool00`3oool?0=40o`X00000
9@1`0?l6000001D03`3o1@00000@001Ao`P000003000/_l800000140057o
1000000E00l0o`H000009@1`0?l:000000h0d@3o1P3oool00`000000oooo
0?ooo`060?ooo`00Q`3oool2000000@0oooo6@3A0?l900000280L03o1@00
000D00l0o`D000005000DOl<000001D0057o1000000D00l0o`D000008P1`
0?l9000001P0d@3o1@3oool2000000P0oooo00270?ooo`030000003oool0
oooo00<0oooo8P3A0?l8000001h0L03o1@00000D00l0o`D00000;000DOl5
000001@03`3o1@00000N0700o`P000008@3A0?l60?ooo`030000003oool0
oooo00H0oooo00270?ooo`030000003oool0oooo00<0oooo:@3A0?l80000
01`0L03o1@00000D00l0o`H000008@00DOl5000001@03`3o1@00000L0700
o`P00000:03A0?l60?ooo`030000003oool0oooo00H0oooo00270?ooo`80
0000103ooola0=40o`L000006P1`0?l5000001@03`3o2000000B001Ao`P0
0000500?0?l5000001X0L03o1`00000`0=40o`D0oooo0P0000080?ooo`00
Q`3oool00`000000oooo0?ooo`030?ooo``00000:`3A0?l7000001P0L03o
1P00000G00l0oa8000005`0?0?l6000001P0L03o1`00000/0=40o`/00000
1@3oool00`000000oooo0?ooo`060?ooo`00Q`3oool00`000000oooo0?oo
o`030?ooo`/0o`3=2`00000X0=40o`H00000601`0?l5000003H03`3o1@00
000I0700o`D00000:03A0?l;000000X0o`3=1P3oool00`000000oooo0?oo
o`060?ooo`00Q`3oool2000000@0oooo5P3o0<d:000002<0d@3o1P00000G
0700o`L00000:P0?0?l7000001L0L03o1P00000S0=40o`X000005@3o0<d5
0?ooo`800000203oool007<0oooo1@0000020?ooo`800000103oool20000
00D0oooo00<000000?ooo`3oool00`3ooolO0?l0c@T000008@3A0?l60000
01P0L03o1P00000N00l0o`H00000601`0?l600000240d@3o2@00000N0?l0
c@H0oooo00<000000?ooo`3oool01P3oool007D0oooo00<000000?ooo`3o
ool01`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00<0oooo:03o0<d8000001h0d@3o1P00000I0700oah000006@1`0?l60000
01h0d@3o2@00000V0?l0c@H0oooo00<000000?ooo`3oool01P3oool007D0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`<0
00000`3oool`0?l0c@L000007@3A0?l6000004@0L03o1P00000M0=40o`L0
0000;`3o0<d40?ooo`<00000203oool007D0oooo00<000000?ooo`3oool0
203oool2000000D0oooo00<000000?ooo`3oool00`3oool700000300o`3=
1`00000K0=40o`L00000>01`0?l7000001/0d@3o1`00000`0?l0c@L00000
1@3oool00`000000oooo0?ooo`060?ooo`00M@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool70?l000/00000;03o0<d6000001`0d@3o1P00000/0700o`H00000703A
0?l6000002`0o`3=2`0000060?l000H0oooo00<000000?ooo`3oool01P3o
ool007@0oooo0P00000:0?ooo`<00000103oool2000000@0oooo4P3o000;
000002L0o`3=1P00000L0=40o`T000006P1`0?l9000001`0d@3o1P00000W
0?l0c@/000004@3o00050?ooo`800000203oool008L0oooo00<000000?oo
o`3oool00`3ooolM0?l000T00000903o0<d6000001l0d@3o6P00000O0=40
o`H00000903o0<d9000001`0o`001P3oool00`000000oooo0?ooo`060?oo
o`00Q`3oool00`000000oooo0?ooo`030?ooobH0o`002@00000Q0?l0c@L0
0000BP3A0?l700000240o`3=2@00000U0?l000H0oooo00<000000?ooo`3o
ool01P3oool008L0oooo0P0000040?ooobh0o`002000000P0?l0c@P00000
?@3A0?l700000200o`3=2000000]0?l000D0oooo0P0000080?ooo`00Q`3o
ool00`000000oooo0?ooo`030?ooocH0o`002000000O0?l0c@P00000;P3A
0?l8000001l0o`3=2000000e0?l000H0oooo00<000000?ooo`3oool01P3o
ool008L0oooo00<000000?ooo`3oool00`3oooln0?l000L00000803o0<d<
000001H0d@3o3000000P0?l0c@L00000?@3o00060?ooo`030000003oool0
oooo00H0oooo00270?ooo`800000103ooom50?l000L000009@3o0<dF0000
02D0o`3=200000130?l000D0oooo0P0000080?ooo`00Q`3oool00`000000
oooo0?ooo`030?oood`0o`002000001A0?l0c@P00000BP3o00060?ooo`03
0000003oool0oooo00H0oooo00270?ooo`030000003oool0oooo00<0oooo
D`3o000800000480o`3=2000001B0?l000H0oooo00<000000?ooo`3oool0
1P3oool008L0oooo00<000000?ooo`3oool00`3ooomK0?l000T00000<03o
0<d9000005X0o`001P3oool00`000000oooo0?ooo`060?ooo`00Q`3oool2
000000@0ooooI03o000<000001P0o`3=3@00001R0?l000D0oooo0P000008
0?ooo`00K@3oool500000080oooo0P0000050?ooo`030000003oool0oooo
0080oooo0P0000050?ooo`030000003oool0oooo00<0ooooL03o000H0000
06l0o`001P3oool00`000000oooo0?ooo`060?ooo`00K`3oool00`000000
oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooom`3o00060?oo
o`030000003oool0oooo00H0oooo001_0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`<0
00000`3oooog0?l000@0oooo0`0000080?ooo`00K`3oool00`000000oooo
0?ooo`0:0?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000
oooo0?ooo`030?ooooL0o`001P3oool00`000000oooo0?ooo`060?ooo`00
K`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooooL0
o`001P3oool00`000000oooo0?ooo`060?ooo`00KP3oool2000000T0oooo
100000030?ooo`<00000103oool2000000@0oooom`3o00050?ooo`800000
203oool008L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01P3oool008L0ooooo`000005000000P0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 135},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  We use the conformal mapping  \n\n\t\t\t",
  Cell[BoxData[
      \(w\ \  = \ \ \(S \((z)\)\ \  = \ \ \(\((z\^2 + 1)\)\^\(1\/2\)\ \  = \ \
\ \(\((z + \[ImaginaryI])\)\^\(1\/2\)\) \((z - \[ImaginaryI])\)\^\(1\/2\)\)\)\
\)]],
  "  \n\nwhere the branch of the square root of  ",
  Cell[BoxData[
      \(Z = z \[PlusMinus] \[ImaginaryI]\)]],
  "   in each factor is  ",
  Cell[BoxData[
      \(Z\^\(1\/2\)\ \  = \ \ \(R\^\(1\/2\)\) \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\/2\)\)]],
  ",  where  ",
  Cell[BoxData[
      \(\(\(\ \)\(R\  = \ \(\(|\)\(Z\)\(|\)\)\)\)\)]],
  ",  and  ",
  Cell[BoxData[
      \(\[Theta]\  = \ \(arg\_\(\(-\[Pi]\)/2\)\) \((Z)\)\)]],
  ",  where  ",
  Cell[BoxData[
      \(\(-\(\[Pi]\/2\)\) < \[Theta] \[LessEqual] \ \(3  \[Pi]\)\/2\)]],
  ".  The transformation  ",
  Cell[BoxData[
      \(w = \(S \((z)\) = \((z\^2 + 1)\)\^\(1\/2\)\)\)]],
  "  is a one-to-one conformal mapping of the domain D consisting of the z \
plane slit along the segment  ",
  Cell[BoxData[
      \(x = 0, \(-1\) \[LessEqual] y \[LessEqual] 1\)]],
  "  onto the domain G consisting of the w plane slit along the segment  ",
  Cell[BoxData[
      \(\(-1\) \[LessEqual] u \[LessEqual] 1, v = 0\)]],
  ".  The complex potential for a uniform horizontal flow parallel to the \
slit in the w plane is given by ",
  Cell[BoxData[
      \(\(F\_1\) \((w)\)\  = \ A\ w\)]],
  ", where for convenience we choose ",
  Cell[BoxData[
      \(A = 1\)]],
  " and where the slit lies along the streamline  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPsi]", 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], " ", "=", 
        " ", \(c\  = \ 0\)}]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe composite function \n\n\t\t\t",
  Cell[BoxData[
      \(\(F\_2\) \((z)\)\  = \ \(\(F\_1\) \((S \((z)\))\)\ \  = \ \ A\ \
\((z\^2 + 1)\)\^\(1\/2\)\)\)]],
  "\n\nis the complex potential for a fluid flow in the domain D.  The \
streamlines given by  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        "c"}]]],
  "  for the flow in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " are obtained by finding the preimage of the streamline  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[CapitalPsi]", 
          RowBox[{"(", 
            RowBox[{"u", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "v"}], ")"}]}], " ", "=", " ", 
        "c"}]]],
  "  in ",
  StyleBox["G",
    FontFamily->"Courier New"],
  " given by the parametric equations  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"v", "=", 
          RowBox[{
            RowBox[{"c", "   ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "   ", "u"}], "=", "t"}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "   ", 
        RowBox[{
          RowBox[{
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "-", "\[Infinity]"}], "<", "t", 
          "<", "\[Infinity]"}]}]]],
  ".  \n\nThe corresponding streamline in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " is found by solving the equation \n\n\t\t\t",
  Cell[BoxData[
      \(t\  + \ \[ImaginaryI]\ c\ \  = \ \ \(\((z\^2 + 1)\)\^\(1\/2\)\ \  = \ \
\ \((\((x + \[ImaginaryI]\ y)\)\^2 + 1)\)\^\(1\/2\)\)\)]],
  "\n\nfor ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " in terms of ",
  StyleBox["t",
    FontFamily->"Courier New"],
  ".  Squaring both sides of this equation yields  \n\n\t\t\t",
  Cell[BoxData[{
      \(\ \ \ \ \ \ \ \ \ \ \ \(\(\((t\  + \ \[ImaginaryI]\ c)\)\^2\ \  = \ \ \
\((x + \[ImaginaryI]\ y)\)\^2\  + \ 1\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(t\^2 - c\^2\  + \ 2\ \[ImaginaryI]\ c\ t\ \ \  = \ \ 1 + x\^2 - 
          y\^2\  + \ 2\ \[ImaginaryI]\ x\ y\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "Equating the real and imaginary parts leads to the system of equations  \n\
\n\t\t\t",
  Cell[BoxData[
      \(t\^2 - c\^2\  = \ 1 + x\^2 - y\^2\)]],
  "   and   ",
  Cell[BoxData[
      \(2\ c\ t\  = \ 2\ x\ y\)]],
  ".  \n\nTo eliminate the parameter ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " in the last two equations, first use the equations  \n\n\t\t\t",
  Cell[BoxData[
      \(\(c\^2\) t\^2 - 
          c\^4\  = \ \(c\^2 + \(c\^2\) x\^2 - \(c\^2\) 
              y\^2\ \ \ and\ \ c\^2\ t\^2\  = \ x\^2\ y\^2\)\)]],
  ",  \n\t\t\t\nthen get  ",
  Cell[BoxData[
      \(x\^2\ y\^2 - c\^4\  = \ c\^2 + \(c\^2\) x\^2 - \(c\^2\) y\^2\)]],
  "  which can be rewritten as  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\(c\^2\) y\^2 + x\^2\ y\^2\ \  = \ \ c\^2 + 
          c\^4 + \(c\^2\) x\^2\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\(\(\(y\^2\) \((c\^2 + x\^2)\)\ \  = \ \ \(c\^2\) \((1 + c\^2 + 
              x\^2)\)\)\(\[IndentingNewLine]\)
      \)\ \), "\[IndentingNewLine]", 
      \(\ y \@\( c\^2 + x\^2\)\ \  = \ \ c \@\( 1 + c\^2 + x\^2\)\)}]],
  "\n\nand we can solve for ",
  StyleBox["y",
    FontFamily->"Courier New"],
  " in terms of ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " to obtain \n\n\t\t\t",
  Cell[BoxData[
      \(y\ \  = \ \ c \@\(\( 1 + c\^2 + x\^2\)\/\(c\^2 + x\^2\)\)\)]],
  "  \n\nfor streamlines in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  For large values of ",
  StyleBox["x",
    FontFamily->"Courier New"],
  ", this streamline approaches the asymptote  ",
  Cell[BoxData[
      \(y\  = \ c\)]],
  "  and approximates a horizontal flow, as shown in Figure 11.52."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.52",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/fluidflow/FluidFlowFigures/\
mat1152.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Flow around a segment.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.25.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the complex potential and determine the velocity potential and stream \
function.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Remove[A, x, y, u, v, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[cont, f, F, g1, g2];\)\ \), "\n", 
    \(\(F[z_]\  = \ A \@\( z\^2\  + \ 1\);\)\ \), "\n", 
    \(\(\[Phi][x_, y_]\  = \ 
        ComplexExpand[Re[F[x + \[ImaginaryI]\ y]], 
          TargetFunctions \[Rule] {Re, \ Im, \ }];\)\ \), "\n", 
    \(\(\[Psi][x_, y_]\  = \ 
        ComplexExpand[Im[F[x + \[ImaginaryI]\ y]], 
          TargetFunctions \[Rule] {Re, \ Im, \ }];\)\ \), "\n", 
    \(\(Print["\<The  complex potential is   F[z] = \>", F[z]];\)\), "\n", 
    \(\(Print["\<F[z]  =  \[Phi][x,y] + \[ImaginaryI] \[Psi][x,y]\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential is\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, y]];\)\ \), "\n", 
    \(\(Print["\<The   stream function  is\>"];\)\ \), "\n", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a plot of the stream function.\n\nFor illustration purposes, we \
choose A = 1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(A = 1;\)\ \), "\[IndentingNewLine]", 
    \(\(cont\  = \ Table[0 + 0.1  k, {k, 0, 14}];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ContourPlot[\[Psi][x, y], {x, 0.000001, 2}, {y, 0, 1.8}, 
          Contours\  \[Rule] cont, PlotPoints \[Rule] 25, 
          AspectRatio \[Rule] 0.9, ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ContourPlot[\(-\[Psi][x, y]\), {x, \(-2\), \(-0.000001\)}, {y, 0, 
            1.8}, Contours\  \[Rule] cont, PlotPoints \[Rule] 25, 
          AspectRatio \[Rule] 0.9, ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, AspectRatio \[Rule] 0.45, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<Contour plot for\>"];\)\ \), "\n", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\[Psi][x, y] \[Equal] c];\)\ \), "\n", 
    \(\(Print["\<where c = \>", cont];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The inverse of  ",
  Cell[BoxData[
      \(w = \(f[
            z] = \(\@\(z\^2 + 1\)\ \ is\ \ z = \(g[
                w] = \@\(w\^2 - 1\)\)\)\)\)]],
  ".  Use conformal mapping  z = g(w)  to make an image of the flow."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(g1[w_]\  = \ \ \@\(w\^2\  - \ 1\);\)\ \), "\n", 
    \(\(g2[w_]\  = \ \(-\@\(w\^2\  - \ 1\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Iden[w_]\  = \ w;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        Iden, {\(-2.2\), 2.2, 0.1}, {0, 1, 
          0.1}, \[IndentingNewLine]AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Red}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The horizontal flow in the z-plane.\>"];\)\ \), "\n", 
    \(\(gr1\  = \ 
        CartesianMap[g1, {0.00001, 2.20001, 0.1}, {0.00001, 1.00001, 0.1}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(gr2\  = \ 
        CartesianMap[
          g2, {\(-2.20001\), \(-0.00001\), 0.1}, {\ 0.00001, 1.00001, 0.1}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{\(-2.05\), 2.05}, {0, 1.5}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0, 2, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The image flow across the complex plane,\>"];\)\ \), "\n", 
    \(\(Print["\<slit along the segment from z=-\[ImaginaryI] to z=-\
\[ImaginaryI],\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<under the mapping z = g(w) = \>", 
        g1[w]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The velocity potential is\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, y]];\)\ \), "\n", 
    \(\(Print["\<The   stream function  is\>"];\)\ \), "\n", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Ideal Fluid Flow",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/FluidFlowBib.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Joukowski Transformation and Airfoils",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/JoukowskiTransBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Potential",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexPotentialBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Green's Function",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/GreensFunctionBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{991, 650},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[62017, 1690, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 298986, 6251}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 122, 2, 33, "Text"],
Cell[2227, 66, 4490, 120, 223, "Text",
  Evaluatable->False],
Cell[6720, 188, 5232, 137, 112, "Text"],
Cell[11955, 327, 340, 11, 33, "Text"],
Cell[12298, 340, 7409, 201, 189, "Text"],
Cell[19710, 543, 2528, 73, 185, "Text"],
Cell[22241, 618, 3834, 103, 169, "Text",
  Evaluatable->False],
Cell[26078, 723, 5343, 136, 131, "Text"],
Cell[31424, 861, 1601, 38, 76, "Text"],
Cell[33028, 901, 2247, 64, 147, "Text"],
Cell[35278, 967, 11002, 294, 563, "Text"],
Cell[46283, 1263, 4444, 115, 154, "Text"],
Cell[50730, 1380, 1802, 48, 185, "Text"],
Cell[52535, 1430, 1431, 40, 71, "Text"],
Cell[53969, 1472, 7334, 189, 373, "Text",
  Evaluatable->False],
Cell[61306, 1663, 360, 11, 33, "Text"],

Cell[CellGroupData[{
Cell[61691, 1678, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[61839, 1684, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[62017, 1690, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[62377, 1702, 5751, 148, 332, "Text"],
Cell[68131, 1852, 1802, 50, 113, "Text"],
Cell[69936, 1904, 2371, 65, 188, "Text",
  Evaluatable->False],
Cell[72310, 1971, 334, 11, 33, "Text"],

Cell[CellGroupData[{
Cell[72669, 1986, 105, 2, 33, "Text"],
Cell[72777, 1990, 1171, 31, 150, "Text"]
}, Closed]],
Cell[73963, 2024, 2972, 87, 150, "Text",
  Evaluatable->False],
Cell[76938, 2113, 48994, 806, 163, 48880, 802, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[125935, 2921, 1507, 42, 52, "Text",
  Evaluatable->False],
Cell[127445, 2965, 440, 15, 36, "Text"],

Cell[CellGroupData[{
Cell[127910, 2984, 113, 2, 33, "Text"],
Cell[128026, 2988, 159, 5, 33, "Text",
  Evaluatable->False],
Cell[128188, 2995, 1013, 21, 272, "Input"],
Cell[129204, 3018, 230, 8, 71, "Text",
  Evaluatable->False],
Cell[129437, 3028, 756, 14, 211, "Input"],
Cell[130196, 3044, 260, 7, 33, "Text",
  Evaluatable->False],
Cell[130459, 3053, 1471, 27, 327, "Input"]
}, Closed]],
Cell[131945, 3083, 2959, 85, 142, "Text",
  Evaluatable->False],
Cell[134907, 3170, 80096, 1316, 210, 79982, 1312, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[215006, 4488, 1522, 42, 55, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[216553, 4534, 115, 2, 33, "Text"],
Cell[216671, 4538, 159, 5, 33, "Text",
  Evaluatable->False],
Cell[216833, 4545, 1022, 21, 232, "Input"],
Cell[217858, 4568, 230, 8, 71, "Text",
  Evaluatable->False],
Cell[218091, 4578, 789, 14, 224, "Input"],
Cell[218883, 4594, 305, 9, 33, "Text",
  Evaluatable->False],
Cell[219191, 4605, 2276, 43, 406, "Input"]
}, Closed]],
Cell[221482, 4651, 360, 11, 30, "Text",
  Evaluatable->False],
Cell[221845, 4664, 21869, 361, 163, 21755, 357, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[243717, 5027, 1735, 49, 131, "Text"],
Cell[245455, 5078, 1984, 41, 333, "Text"],
Cell[247442, 5121, 1010, 30, 115, "Text"],
Cell[248455, 5153, 2043, 58, 77, "Text"],
Cell[250501, 5213, 337, 11, 33, "Text"],

Cell[CellGroupData[{
Cell[250863, 5228, 113, 2, 33, "Text"],
Cell[250979, 5232, 534, 15, 107, "Text",
  Evaluatable->False],
Cell[251516, 5249, 1080, 21, 244, "Input"],
Cell[252599, 5272, 230, 8, 71, "Text",
  Evaluatable->False],
Cell[252832, 5282, 813, 15, 266, "Input"],
Cell[253648, 5299, 249, 9, 42, "Text",
  Evaluatable->False],
Cell[253900, 5310, 1550, 31, 529, "Input"],
Cell[255453, 5343, 134, 4, 33, "Text",
  Evaluatable->False],
Cell[255590, 5349, 2014, 39, 452, "Input"]
}, Closed]],
Cell[257619, 5391, 408, 13, 30, "Text",
  Evaluatable->False],
Cell[258030, 5406, 25411, 419, 149, 25297, 415, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[283444, 5827, 2033, 55, 181, "Text"],
Cell[285480, 5884, 3498, 99, 362, "Text"],
Cell[288981, 5985, 1699, 47, 430, "Text"],
Cell[290683, 6034, 332, 11, 33, "Text"],

Cell[CellGroupData[{
Cell[291040, 6049, 113, 2, 33, "Text"],
Cell[291156, 6053, 159, 5, 33, "Text",
  Evaluatable->False],
Cell[291318, 6060, 988, 19, 253, "Input"],
Cell[292309, 6081, 230, 8, 71, "Text",
  Evaluatable->False],
Cell[292542, 6091, 1276, 24, 290, "Input"],
Cell[293821, 6117, 299, 9, 33, "Text",
  Evaluatable->False],
Cell[294123, 6128, 2027, 38, 456, "Input"]
}, Closed]],
Cell[296165, 6169, 290, 7, 30, "Text"],
Cell[296458, 6178, 278, 6, 33, "Text"],
Cell[296739, 6186, 309, 7, 33, "Text"],
Cell[297051, 6195, 291, 7, 33, "Text"],
Cell[297345, 6204, 288, 7, 33, "Text"],
Cell[297636, 6213, 257, 5, 33, "Text"],
Cell[297896, 6220, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

