(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    191005,       3925]*)
(*NotebookOutlinePosition[    192009,       3961]*)
(*  CellTagsIndexPosition[    191932,       3955]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["11.8  The Joukowski Airfoil",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tThe Russian scientist ",
  StyleBox[ButtonBox["Nikolai Egorovich Joukowsky",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Zhukovsky.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " studied the function \n\n\t\t\t",
  Cell[BoxData[
      \(J \((z)\) = z\  + 1\/z\)]],
  ".  \n\t\t\t\nHe showed that the image of a circle passing through ",
  Cell[BoxData[
      \(z\_1 = 1\)]],
  " and containing the point ",
  Cell[BoxData[
      \(z\_2 = \(-1\)\)]],
  " is mapped onto a curve shaped like the cross section of an airplane wing. \
 We call this curve the Joukowski airfoil.  If the streamlines for a flow \
around the circle are known, then their images under the mapping ",
  Cell[BoxData[
      \(w = J \((z)\)\)]],
  " will be streamlines for a flow around the Joukowski airfoil, as shown in \
Figure 11.60.  "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.60",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1160.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Image of a fluid flow under ",
  Cell[BoxData[
      \(w = \(J \((z)\) = z\  + 1\/z\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe mapping ",
  Cell[BoxData[
      \(w = J \((z)\)\)]],
  " is two-to-one, because  ",
  Cell[BoxData[
      \(J \((z)\)\  = \ J \((1\/z)\)\)]],
  ",  for  ",
  Cell[BoxData[
      \(z \[NotEqual] 0\)]],
  ".  The region  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(1\)\)\)\)]],
  "  is mapped one-to-one onto the w plane slit along the segment of the real \
axis ",
  Cell[BoxData[
      \(\(-2\) \[LessEqual] u \[LessEqual] 2, v = 0\)]],
  ".  To visualize this mapping, we investigate the implicit form, which we \
obtain by using the substitutions  \n\n\t\t\t",
  Cell[BoxData[
      \(w - 
          2\  = \ \ \(z\  - 2 + 
            1\/z\ \  = \ \ \(\(z\^2 - 2  z + 1\)\/z\ \  = \ \ \((z - \
1)\)\^2\/z\)\)\)]],
  ",  and    \n\t\t\t\n\t\t\t",
  Cell[BoxData[
      \(w + 
          2\  = \ \ \(z\  + 2 + 
            1\/z\ \  = \ \ \(\(z\^2 + 2  z + 1\)\/z\ \  = \ \ \((z + \
1)\)\^2\/z\)\)\)]],
  ".  \n\nForming the quotient of these two quantities results in the \
relationship \n\n\t\t\t",
  Cell[BoxData[
      \(\(w - 2\)\/\(w + 2\)\ \  = \ \ \ \(\(\((z - 1)\)\^2\/z\)/\(\((z + \
1)\)\^2\/z\)\ \  = \ \ \((z - 1)\)\^2\/\((z + 1)\)\^2\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe inverse of  ",
  Cell[BoxData[
      \(z\  = \ \(T \((w)\)\  = \ \(w - 2\)\/\(w + 2\)\)\)]],
  "  is  ",
  Cell[BoxData[
      \(w\  = \ \(\(S\_3\) \((z)\)\  = \ \(2 + 2  z\)\/\(1 - z\)\)\)]],
  ".  If we use the notation  ",
  Cell[BoxData[
      \(\(\(\ \)\(\(S\_1\) \((z)\)\  = \ \(z - 1\)\/\(z + 1\)\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(\(S\_2\) \((z)\)\  = \ z\^2\)]],
  ",  then we can express ",
  Cell[BoxData[
      \(J \((z)\)\)]],
  " as the composition of  ",
  Cell[BoxData[
      \(\(S\_1\) \((z)\)\)]],
  ", ",
  Cell[BoxData[
      \(\(S\_2\) \((z)\)\)]],
  ", and ",
  Cell[BoxData[
      \(\(S\_3\) \((z)\)\)]],
  ",  that is\n\n",
  StyleBox["(11-36)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(w\  = \(J \((z)\)\  = \ \(S\_3\) \((\(S\_2\) \((\(S\_1\) \
\((z)\))\))\)\)\)]],
  ".  \n\nWhich is verified by the calculation\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\(S\_3\) \((\(S\_2\) \((\(S\_1\) \((z)\))\))\)\ \  = \ \ \(S\_3\) \
\((\(S\_2\) \((\(z - 1\)\/\(z + 1\))\))\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(\(S\_3\) \((\((z - 1)\)\^2\/\((z + 1)\)\^2)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(\(=\)\(\ \ \)\(\(2 + 
              2 \((z - 1)\)\^2\/\((z + 1)\)\^2\)\/\(1 - \((z - 1)\)\^2\/\((z \
+ 1)\)\^2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\(\(=\)\(\ \ \)\(z\ \  + \ \ 1\/z\)\)\)}]],
  "  "
}], "Text"],

Cell[TextData[{
  "\tWe can easily show that ",
  Cell[BoxData[
      \(w\  = \ \(J \((z)\) = z\  + 1\/z\)\)]],
  "  maps the four points  ",
  Cell[BoxData[
      RowBox[{\(z\_1 = \(-\[ImaginaryI]\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2 = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_3 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", \(z\_4\)}], "=", \(-1\)}]}]]],
  "  onto  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = 2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_3 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", \(w\_4\)}], "=", \(-2\)}]}]]],
  ",  respectively.  \nHowever, the composition functions in Equation ",
  StyleBox["(11-36)",
    FontColor->RGBColor[0, 0, 1]],
  " must be considered in order to visualize the geometry involved.  First, \
the bilinear transformation  ",
  Cell[BoxData[
      \(Z\  = \ \(\(S\_1\) \((z)\)\  = \ \(z - 1\)\/\(z + 1\)\)\)]],
  "  maps the region  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(>\)\(1\)\)\)\)]],
  "  onto the right half-plane  ",
  Cell[BoxData[
      \(Re \((Z)\) > 0\)]],
  ",  and the points  ",
  Cell[BoxData[
      RowBox[{\(z\_1 = \(-\[ImaginaryI]\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_2 = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(z\_3 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", \(z\_4\)}], "=", \(-1\)}]}]]],
  "  are mapped onto  ",
  Cell[BoxData[
      RowBox[{\(Z\_1 = \(-\[ImaginaryI]\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(Z\_2 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(Z\_3 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", \(Z\_4\)}], 
          "=", \(\[ImaginaryI]\ \[Infinity]\)}]}]]],
  ",  respectively.  Second, the function  ",
  Cell[BoxData[
      \(W\  = \ \(\(S\_2\) \((Z)\)\  = \ Z\^2\)\)]],
  "  maps the right half plane onto the ",
  StyleBox["W",
    FontFamily->"Courier New"],
  " plane slit along its negative real axis, and the points ",
  Cell[BoxData[
      RowBox[{\(Z\_1 = \(-\[ImaginaryI]\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(Z\_2 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(Z\_3 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", \(Z\_4\)}], 
          "=", \(\[ImaginaryI]\ \[Infinity]\)}]}]]],
  ",  are mapped onto  ",
  Cell[BoxData[
      RowBox[{\(W\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(W\_3 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(W\_3 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", \(W\_4\)}], 
          "=", \(-\[Infinity]\)}]}]]],
  ",  respectively.  Then the bilinear transformation ",
  Cell[BoxData[
      \(w\  = \ \(\(S\_3\) \((W)\)\  = \ \(2 + 2  W\)\/\(1 - W\)\)\)]],
  "  maps the latter region onto the ",
  StyleBox["W",
    FontFamily->"Courier New"],
  " plane slit along the portion of the real axis ",
  Cell[BoxData[
      RowBox[{\(U \[LessEqual] \(-2\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(V = 0\)}]]],
  ", and the points  ",
  Cell[BoxData[
      RowBox[{\(W\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(W\_3 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(W\_3 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", \(W\_4\)}], 
          "=", \(-\[Infinity]\)}]}]]],
  "  are mapped onto  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = 2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_3 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", \(w\_4\)}], "=", \(-2\)}]}]]],
  ",  respectively.  These three compositions are shown in Figure 11.61.  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(S\_1[z_]\  = \ \(z - 1\)\/\(z + 1\);\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<      \!\(S\_1\)[z] = \>\"", 
        S\_1[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Z\_1\) = \!\(S\_1\)[\!\(z\_1\)] = \!\(S\_1\)[-\
\[ImaginaryI]] = \>\"", 
        S\_1[\(-\[ImaginaryI]\)]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Z\_2\) = \!\(S\_1\)[\!\(z\_2\)] =  \!\(S\_1\)[1] = \
\>\"", S\_1[1]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Z\_3\) = \!\(S\_1\)[\!\(z\_3\)] =  \!\(S\_1\)[\
\[ImaginaryI]] = \>\"", S\_1[\[ImaginaryI]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(Z\_4\) = \!\(S\_1\)[\!\(z\_4\)] = \!\(S\_1\)[-1] = \
\>\"", Limit[S\_1[z], z \[Rule] \(-1\), 
          Direction \[Rule] \(-\[ImaginaryI]\)]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(S\_2[Z_]\  = \ Z\^2;\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<      \!\(S\_2\)[Z] = \>\"", 
        S\_2[Z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(W\_1\) = \!\(S\_2\)[\!\(Z\_1\)] =  \!\(S\_3\)[-\
\[ImaginaryI]] = \>\"", 
        S\_2[\(-\[ImaginaryI]\)]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(W\_2\) = \!\(S\_2\)[\!\(Z\_2\)] =  \!\(S\_2\)[0]  = \
\>\"", S\_2[0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(W\_3\) = \!\(S\_2\)[\!\(Z\_3\)] =  \!\(S\_2\)[\
\[ImaginaryI]]  = \>\"", S\_2[\[ImaginaryI]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(W\_4\) = \!\(S\_2\)[\!\(Z\_4\)] = \!\(S\_2\)[\
\[ImaginaryI] \[Infinity]] = \>\"", 
        S\_2[\[ImaginaryI]\ \[Infinity]]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(S\_3[W_]\  = \ \(2 + 2  W\)\/\(1 - W\);\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<      \!\(S\_3\)[W] = \>\"", 
        S\_3[W]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \!\(S\_3\)[\!\(W\_1\)] = \!\(S\_3\)[-1] = \
\>\"", S\_3[\(-1\)]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \!\(S\_3\)[\!\(W\_2\)] =  \!\(S\_3\)[0] = \
\>\"", S\_3[0]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_3\) = \!\(S\_3\)[\!\(W\_3\)] = \!\(S\_3\)[-1] = \
\>\"", S\_3[\(-1\)]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_4\) = \!\(S\_3\)[\!\(W\_4\)] = \!\(S\_3\)[-\
\[Infinity]] = \>\"", 
        Limit[S\_3[W], W \[Rule] \(-\[Infinity]\)]\ ];\)\)}], "Input"],

Cell[BoxData[{
    \(\(Print[\*"\"\<\!\(S\_3\)[\!\(S\_2\)[\!\(S\_1\)[z]]] = \>\"", 
        S\_3[S\_2[S\_1[z]]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(S\_3\)[\!\(S\_2\)[\!\(S\_1\)[z]]] = \>\"", 
        Simplify[S\_3[S\_2[S\_1[z]]]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_1\) = \
\!\(S\_3\)[\!\(S\_2\)[\!\(S\_1\)[\!\(z\_1\)] = \!\(S\_3\)[\!\(S\_2\)[\!\(S\_1\
\)[-\[ImaginaryI]] = \>\"", 
        S\_3[S\_2[S\_1[\(-\[ImaginaryI]\)]]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_2\) = \
\!\(S\_3\)[\!\(S\_2\)[\!\(S\_1\)[\!\(z\_2\)] =  \
\!\(S\_3\)[\!\(S\_2\)[\!\(S\_1\)[1] = \>\"", 
        S\_3[S\_2[S\_1[1]]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_3\) = \
\!\(S\_3\)[\!\(S\_2\)[\!\(S\_1\)[\!\(z\_3\)] =  \
\!\(S\_3\)[\!\(S\_2\)[\!\(S\_1\)[\[ImaginaryI]] = \>\"", 
        S\_3[S\_2[S\_1[\[ImaginaryI]]]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(w\_4\) = \
\!\(S\_3\)[\!\(S\_2\)[\!\(S\_1\)[\!\(z\_4\)] = \!\(S\_3\)[\!\(S\_2\)[\!\(S\_1\
\)[-1] = \>\"", 
        Limit[S\_3[S\_2[S\_1[z]]], z \[Rule] \(-1\)]\ ];\)\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.61",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1161.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The composition mappings for  ",
  Cell[BoxData[
      \(w\  = \(J \((z)\)\  = \ \(S\_3\) \((\(S\_2\) \((\(S\_1\) \
\((z)\))\))\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe circle  ",
  Cell[BoxData[
      \(C\_0\)]],
  "  with center  ",
  Cell[BoxData[
      \(c\_0\  = \ \[ImaginaryI]\ a\)]],
  "  on the imaginary axis passes through the points  ",
  Cell[BoxData[
      RowBox[{\(z\_2 = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", \(z\_4\)}], "=", \(-1\)}]}]]],
  "  and has radius  ",
  Cell[BoxData[
      \(r\_0 = \@\(1 + a\^2\)\)]],
  ".  With the restriction that  ",
  Cell[BoxData[
      \(0 < a < 1\)]],
  ",  then this circle intersects the ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " axis at the point ",
  Cell[BoxData[
      \(z\_2 = 1\)]],
  " with angle  ",
  Cell[BoxData[
      \(\[Alpha]\_0\  = \ \[Pi]\/2 - Arctan\ a\)]],
  ", with  ",
  Cell[BoxData[
      \(\[Pi]\/2\  < \ \[Alpha]\_0\  < \ \[Pi]\/2\)]],
  ".  We want to track the image of  ",
  Cell[BoxData[
      \(C\_0\)]],
  "  in the ",
  StyleBox["Z",
    FontFamily->"Courier New"],
  ",  ",
  StyleBox["W",
    FontFamily->"Courier New"],
  ", and ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " planes.  First, the image of this circle  ",
  Cell[BoxData[
      \(C\_0\)]],
  "  under  ",
  Cell[BoxData[
      \(Z\  = \ \(\(S\_1\) \((z)\)\  = \ \(z - 1\)\/\(z + 1\)\)\)]],
  "  is the line  ",
  Cell[BoxData[
      \(L\_0\)]],
  "  that passes through the origin and is inclined at the angle  ",
  Cell[BoxData[
      \(\[Alpha]\_0\)]],
  ".  Second, the function  ",
  Cell[BoxData[
      \(W\  = \ \(\(S\_2\) \((Z)\)\  = \ Z\^2\)\)]],
  "  maps the line  ",
  Cell[BoxData[
      \(L\_0\)]],
  "  onto the ray  ",
  Cell[BoxData[
      \(R\_0\)]],
  "  inclined at the angle  ",
  Cell[BoxData[
      \(2  \[Alpha]\_0\)]],
  ".  Finally, the transformation given by  ",
  Cell[BoxData[
      \(w\  = \ \(\(S\_3\) \((W)\)\  = \ \(2 + 2  W\)\/\(1 - W\)\)\)]],
  "  maps the ray  ",
  Cell[BoxData[
      \(R\_0\)]],
  "  onto the arc of the circle  ",
  Cell[BoxData[
      \(A\_0\)]],
  "  that passes through the points  ",
  Cell[BoxData[
      RowBox[{\(w\_2 = 2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", \(w\_4\)}], "=", \(-2\)}]}]]],
  "  and intersects the u axis at  ",
  Cell[BoxData[
      \(w\_2 = 2\)]],
  " with angle ",
  Cell[BoxData[
      \(2  \[Alpha]\_0\)]],
  ", where    ",
  Cell[BoxData[
      \(\[Pi]\  < \ 2  \[Alpha]\_0\  < \ \[Pi]\)]],
  ".  The restriction on the angle ",
  Cell[BoxData[
      \(\[Alpha]\_0\)]],
  ", and hence ",
  Cell[BoxData[
      \(2  \[Alpha]\_0\)]],
  ", is necessary in order for the arc ",
  Cell[BoxData[
      \(A\_0\)]],
  " to have a low profile.  The arc ",
  Cell[BoxData[
      \(A\_0\)]],
  " lies in the center of the Joukowski airfoil and is shown in Figure 11.62. \
"
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.62",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1162.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The images of the circles ",
  Cell[BoxData[
      \(C\_0\)]],
  " and ",
  Cell[BoxData[
      \(C\_1\)]],
  " under the composition mappings for  ",
  Cell[BoxData[
      \(w\  = \(J \((z)\)\  = \ \(S\_3\) \((\(S\_2\) \((\(S\_1\) \
\((z)\))\))\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tIf we let ",
  StyleBox["b",
    FontFamily->"Courier New"],
  " be fixed, ",
  Cell[BoxData[
      \(0 < b < 1\)]],
  ", then the larger circle ",
  Cell[BoxData[
      \(C\_1\)]],
  " with center given by ",
  Cell[BoxData[
      \(\(\(\ \ \)\(c\_1\  = \ \(-h\) + \[ImaginaryI] \((1 + h)\) b\)\)\)]],
  "  (just a bit to the left of the imaginary axis) will pass through the \
points    ",
  Cell[BoxData[
      RowBox[{\(z\_2 = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", \(z\_4\%*\)}], 
          "=", \(\(-1\) - 2  h\)}]}]]],
  " and has radius  ",
  Cell[BoxData[
      \(r\_1 = \((1 + h)\) \@\(1 + b\^2\)\)]],
  ".  The circle ",
  Cell[BoxData[
      \(C\_1\)]],
  " also intersects the x axis at the point  ",
  Cell[BoxData[
      \(z\_2 = 1\)]],
  "  at the angle  ",
  Cell[BoxData[
      \(\[Alpha]\_0\)]],
  ".  The image of circle ",
  Cell[BoxData[
      \(C\_1\)]],
  " under  ",
  Cell[BoxData[
      \(Z\  = \ \(\(S\_1\) \((z)\)\  = \ \(z - 1\)\/\(z + 1\)\)\)]],
  "  is the circle  ",
  Cell[BoxData[
      \(K\_1\)]],
  ",  which is tangent to  ",
  Cell[BoxData[
      \(L\_0\)]],
  " at the origin in the ",
  StyleBox["Z",
    FontFamily->"Courier"],
  "-plane.  The function  ",
  Cell[BoxData[
      \(W\  = \ \(\(S\_2\) \((Z)\)\  = \ Z\^2\)\)]],
  "  maps the circle  ",
  Cell[BoxData[
      \(K\_1\)]],
  "  onto the cardioid  ",
  Cell[BoxData[
      \(H\_1\)]],
  "  in the ",
  StyleBox["W",
    FontFamily->"Courier"],
  "-plane.  Finally,  ",
  Cell[BoxData[
      \(w\  = \ \(\(S\_3\) \((W)\)\  = \ \(2 + 2  W\)\/\(1 - W\)\)\)]],
  "  maps the cardioid  ",
  Cell[BoxData[
      \(H\_1\)]],
  "  onto the Joukowski airfoil  ",
  Cell[BoxData[
      \(A\_1\)]],
  "  that passes through the point  ",
  Cell[BoxData[
      \(w\_2 = 2\)]],
  "  and surrounds the point  ",
  Cell[BoxData[
      \(w\_4 = \(-2\)\)]],
  ",  as shown in Figure 11.62.  An observer traversing ",
  Cell[BoxData[
      \(C\_1\)]],
  " counterclockwise will traverse the image curves  ",
  Cell[BoxData[
      \(K\_1\)]],
  "  and  ",
  Cell[BoxData[
      \(H\_1\)]],
  "  clockwise but will traverse  ",
  Cell[BoxData[
      \(A\_1\)]],
  "  counterclockwise.  Thus the points  ",
  Cell[BoxData[
      RowBox[{\(z\_4\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(Z\_4\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(W\_4\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          StyleBox["and",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], " ", \(w\_4\)}]}]]],
  "  will always be to the observer's left."
}], "Text"],

Cell[TextData[{
  "\tNow we are ready to visualize the flow around the Joukowski airfoil.  We \
start with the fluid flow around a circle (see Figure 11.51).  This flow is \
adjusted with a linear transformation  ",
  Cell[BoxData[
      \(\(z\^*\)\  = \ a\ z + b\)]],
  "  so that it flows horizontally around the circle ",
  Cell[BoxData[
      \(C\_1\)]],
  ", as shown in Figure 11.63.  Then the mapping  ",
  Cell[BoxData[
      \(w = \(J \((z)\) = \(z\^*\)\  + 1\/\(z\^*\)\)\)]],
  "  creates a flow around the Joukowski airfoil, as illustrated in Figure \
11.64. "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.63",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1163.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The horizontal flow around the circle ",
  Cell[BoxData[
      \(C\_1\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.64",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1164.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The horizontal flow around the Joukowski airfoil ",
  Cell[BoxData[
      \(A\_1\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["11.8.1  Flow with Circulation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tThe function  ",
  Cell[BoxData[
      \(F \((z)\)\  = \ 
        s\ z\  + s\/z\  + \ \(k\/\(2  \[Pi]\ \[ImaginaryI]\)\) Log\ z\)]],
  ",  where ",
  Cell[BoxData[
      \(s > 0\)]],
  " and ",
  StyleBox["k",
    FontFamily->"Courier New"],
  " is real, is the complex potential for a uniform horizontal flow past the \
unit circle ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = 1\)]],
  ", with circulation strength ",
  StyleBox["k",
    FontFamily->"Courier New"],
  " and velocity at infinity  ",
  Cell[BoxData[
      \(V\_\[Infinity] = s\)]],
  ".  \n\t\nFor illustrative purposes, we let ",
  Cell[BoxData[
      \(s = 1\)]],
  " and use the substitution  ",
  Cell[BoxData[
      \(a = \(-k\)\/\(2  \[Pi]\)\)]],
  ".  Now the complex potential has the form  \n\n",
  StyleBox["(11-37)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(F \((z)\)\  = \ z\  + 1\/z\  + \ a\ \[ImaginaryI]\ Log\ z\)]],
  "\n\nand the corresponding velocity function is  \n\n\t\t\t",
  Cell[BoxData[
      \(V \((x, y)\)\ \  = \ \(\(\(\ \)\(F' \((z)\)\)\)\&_\  = \ 
          1 - \((\(\(\ \)\(z\)\)\&_\ )\)\^\(-2\) - 
            a\ \[ImaginaryI] \((\(\(\ \)\(z\)\)\&_\ )\)\^\(-1\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tWe can express the complex potential in  ",
  Cell[BoxData[
      \(F \((x + \[ImaginaryI]\ y)\)\  = \ \[Phi] \((x, 
              y)\)\ \  + \ \[ImaginaryI]\ \[Psi] \((x, y)\)\)]],
  "  form: \n\n\t\t\t",
  Cell[BoxData[{
      \(F \((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\))\)\ \  = \ \ r\ \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\ \ \  + \ \ 1\/\(r\ \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\)\ \  + \ \ a\ \[ImaginaryI]\ \
Log\ \((r\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\))\)\[IndentingNewLine]\
\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \ \)\(r\ \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Theta]\)\ \  + \ \(1\/r\) \[ExponentialE]\
\^\(\(-\[ImaginaryI]\)\ \[Theta]\)\ \ \  + \ \ a\ \[ImaginaryI]\ \((ln\ r\ \  \
+ \ \ \[ImaginaryI]\ \[Theta])\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\((r + \ 
                1\/r)\)\ cos\ \[Theta]\  - \ 
          a\ \ \[Theta]\ \ \  + \ \ \[ImaginaryI]\ \((r - \ 1\/r)\) 
            sin\ \[Theta]\  + \ a\ ln\ r\)\)\)}]],
  "   \n\nand we have the formulas for the velocity potential ",
  Cell[BoxData[
      RowBox[{"\[Phi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  " stream function  ",
  Cell[BoxData[
      RowBox[{"\[Psi]", 
        RowBox[{"(", 
          RowBox[{"x", 
            StyleBox[",",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "y"}], ")"}]}]]],
  "   \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Phi]", 
          RowBox[{"(", 
            RowBox[{\(r\ cos\ \[Theta]\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(r\ sin\ \[Theta]\)}], ")"}]}], 
        " ", "=", 
        " ", \(\((r + \ 1\/r)\)\ cos\ \[Theta]\  - \ a\ \ \[Theta]\)}]]],
  ",  and  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{\(r\ cos\ \[Theta]\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(r\ sin\ \[Theta]\)}], ")"}]}], 
        " ", "=", " ", \(\((r - \ 1\/r)\) sin\ \[Theta]\  + \ a\ ln\ r\)}]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tFor the flow given by  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{"x", 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "y"}], ")"}]}], " ", "=", " ", 
        "c"}]]],
  ",  where c is a constant, we have  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{\(r\ cos\ \[Theta]\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(r\ sin\ \[Theta]\)}], ")"}]}], 
        " ", "=", 
        " ", \(\((r - \ 1\/r)\) sin\ \[Theta]\  + \ 
            a\ ln\ r\ \  = \ \ c\)}]]],
  ".     (Streamlines.)\n\nSetting ",
  Cell[BoxData[
      \(r = 1\)]],
  " in this equation, we get  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Psi]", 
          RowBox[{"(", 
            RowBox[{\(cos\ \[Theta]\), 
              StyleBox[",",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], \(sin\ \[Theta]\)}], ")"}]}], " ", 
        "=", " ", \(\((1 - \ 1\/1)\) sin\ \[Theta]\  + \ 
            a\ ln\ 1\ \  = \ \ 0\)}]]],
  "  for all ",
  Cell[BoxData[
      \(\[Theta]\)]],
  ", so the unit circle is a natural boundary curve for the flow."
}], "Text"],

Cell[TextData[{
  "\tPoints at which the flow has zero velocity are called stagnation points. \
 To find them we solve   ",
  Cell[BoxData[
      \(F' \((z)\) = 0\)]],
  ";  for the function in Equation ",
  StyleBox["(11-37)",
    FontColor->RGBColor[0, 0, 1]],
  " we have  \n\n\t\t\t",
  Cell[BoxData[{
      \(F' \((z)\)\ \  = \ \ \(1 - \((z)\)\^\(-2\) + 
            a\ \[ImaginaryI] \((z)\)\^\(-1\)\ \  = \ \ 0\)\[IndentingNewLine]\
\), "\[IndentingNewLine]", 
      \(F' \((z)\)\ \  = \ \ \(1 - 1\/z\^2 + 
            a\ \[ImaginaryI]  1\/z\ \  = \ \ 0\)\)}]],
  "\n\nMultiplying through by ",
  Cell[BoxData[
      \(z\^2\)]],
  " and rearranging terms gives   \n\n\t\t\t",
  Cell[BoxData[
      \(z\^2\  + \ a\ \[ImaginaryI]\ z\  - \ 1\ \  = \ \ 0\)]],
  "\n\nNow we invoke the quadratic equation to obtain  \n\n\n\t\t\t",
  Cell[BoxData[
      \(z\ \  = \ \ \(\(\ \)\(\(\[PlusMinus]\ \@\(4 - a\^2\)\)\  - \ \ a\ \
\[ImaginaryI]\)\)\/2\)]],
  "    (stagnation point(s).) "
}], "Text"],

Cell[TextData[{
  "\tIf  ",
  Cell[BoxData[
      \(\(\(0\)\(\ \)\(\[LessEqual]\)\)\  | a | \(\(<\)\(\ \)\(2\)\)\)]],
  ",  then there are two stagnation points on the unit circle ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = 1\)]],
  ".  If ",
  Cell[BoxData[
      \(a = 2\)]],
  ", then there is one stagnation point on the unit circle.  If ",
  Cell[BoxData[
      \(a > 2\)]],
  ", then the stagnation point lies outside the unit circle.  We are mostly \
interested in the case with two stagnation points.  When ",
  Cell[BoxData[
      \(a = 0\)]],
  ", the two stagnation points are ",
  Cell[BoxData[
      \(z = \(\[PlusMinus]1\)\)]],
  ", which is the flow discussed in Example 11.25. The cases ",
  Cell[BoxData[
      RowBox[{\(a = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(a = \@3\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(a = 2\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", "a"}], "=", "2.2"}]}]]],
  " are shown in Figure 11.65.  "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.65",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1165.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Flows past the unit circle with circulation ",
  Cell[BoxData[
      RowBox[{\(a = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(a = \@3\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], \(a = 2\), 
        StyleBox[",",
          FontFamily->"Times New Roman"], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", "a"}], "=", "2.2"}]}]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe are now ready to combine the preceding ideas.  For illustrative \
purposes, we consider a ",
  Cell[BoxData[
      \(C\_1\)]],
  " circle with center  ",
  Cell[BoxData[
      \(c\_0\  = \ \(-0.15\) + 0.23  \[ImaginaryI]\)]],
  "  that passes through the points  ",
  Cell[BoxData[
      RowBox[{\(z\_2 = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], " ", \(z\_4\%*\)}], 
          "=", \(-1.3\)}]}]]],
  "  and has radius  ",
  Cell[BoxData[
      \(r\_0\  = \ 0.23 \@\( 13\/2\)\)]],
  ".  We use the linear transformation  ",
  Cell[BoxData[
      \(Z\ \  = \ \ \(S \((z)\)\ \  = \ \ \(-\ 0.15\)\  + \ 
            0.23  \[ImaginaryI]\  + \ \(r\_0\) z\)\)]],
  "  to map the flow with circulation ",
  Cell[BoxData[
      \(k = \(-\ 0.52\) \[Pi]\)]],
  " (or ",
  Cell[BoxData[
      \(a = \(\(-k\)\/\(2  \[Pi]\) = \(\(-\((\(-0.52\) \[Pi])\)\)\/\(2  \[Pi]\
\) = 0.26\)\)\)]],
  ") around ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\) = 1\)]],
  " onto the flow around the circle ",
  Cell[BoxData[
      \(C\_1\)]],
  ", as shown in Figure 11.66. "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.66",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1166.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Flow with circulation around ",
  Cell[BoxData[
      \(C\_1\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThen we use the mapping  ",
  Cell[BoxData[
      \(J \((Z)\) = Z\  + 1\/Z\)]],
  "  to map this flow around the Joukowski airfoil, as shown in Figure 11.67 \
and compare it to the flows shown in Figures 11.63 and 11.64.  \nIf the \
second transformation in the composition given by  ",
  Cell[BoxData[
      \(w\  = \(J \((z)\)\  = \ \(S\_3\) \((\(S\_2\) \((\(S\_1\) \
\((z)\))\))\)\)\)]],
  "  is modified to be  ",
  Cell[BoxData[
      \(\(S\_2\) \((z)\)\  = \ z\^1.925\)]],
  ",  then the image of the flow shown in Figure 11.66 will be the flow \
around the modified airfoil shown in Figure 11.68.  The advantage of this \
latter airfoil is that the sides of its tailing edge form an angle of ",
  Cell[BoxData[
      \(0.15  \[Pi]\)]],
  " radians, or ",
  Cell[BoxData[
      \(27\^o\)]],
  ", which is more realistic than the angle of ",
  Cell[BoxData[
      \(0\^o\)]],
  " of the traditional Joukowski airfoil."
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.67",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1167.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Flow with circulation around a traditional Joukowski airfoil. "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.68",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1168.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Flow with circulation around a modified Joukowski airfoil. "
}], "Text"],

Cell[TextData[{
  "The following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " subroutine will form the functions that are needed to graph a Joukowski \
airfoil. "
}], "Text"],

Cell[BoxData[{
    \(\(Clear[F, F1, F2, F3, F4, dx, dy, r0, w, z, 
        Z];\)\ \), "\[IndentingNewLine]", 
    \(\(JoukowskiFun[dx_, dy_] := 
        Module[{}, \[IndentingNewLine]r0\  = \ \@\(\((1 - dx)\)\^2 + \((0 - \
dy)\)\^2\); \ \[IndentingNewLine]Z\_1\  = \ \ \(z\  + \ \@\(z\^2\  - \ \
4\)\)\/2; \ \ Z\_2\  = \ \ \(z\  - \ \@\(z\^2\  - \ 4\)\)\/2; \ \
\[IndentingNewLine]Z\_3 = \ \(\(-z\)\  - \ \@\(z\^2\  - \ 4\)\)\/2; \ \ Z\_4\ \
 = \ \(\(-z\)\  + \@\(\(\ \)\(z\^2\  - \ 4\)\)\)\/2; \ \[IndentingNewLine]w[
              z_]\  = \ \ r0\ z\  + \ 
              dx\  + \ \[ImaginaryI]\ dy; \ \[IndentingNewLine]F[
              z_]\  = \ \ z\  + \ 1\/z; \ \[IndentingNewLine]F1[z_]\  = \ \ F[
              w[Z\_1]]; \ \ F2[z_]\  = \ \ F[
              w[Z\_2]]; \ \[IndentingNewLine]F3[z_]\  = \ \ F[
              w[Z\_3]]; \ \ F4[z_]\  = \ \ F[w[Z\_4]];\ ];\)\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  For a fixed value ",
  StyleBox["dx",
    FontFamily->"Courier New"],
  ", increasing the parameter ",
  StyleBox["dy",
    FontFamily->"Courier New"],
  " will bend the airfoil. "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3oool<0?ooo`030000003oool0
oooo08D0oooo003o0?ooo``0oooo00<000000?ooo`3oool0Q@3oool00?l0
oooo303oool00`000000oooo0?ooo`250?ooo`00o`3oool<0?ooo`030000
003oool0oooo08D0oooo003o0?ooo``0oooo00<000000?ooo`3oool0Q@3o
ool00?l0oooo303oool00`000000oooo0?ooo`250?ooo`00o`3oool<0?oo
o`030000003oool0oooo08D0oooo003o0?ooo``0oooo00<000000?ooo`3o
ool0Q@3oool00?l0oooo303oool00`000000oooo0?ooo`250?ooo`00o`3o
ool<0?ooo`030000003oool0oooo08D0oooo003o0?ooo``0oooo00<00000
0?ooo`3oool0Q@3oool00?l0oooo303oool00`000000oooo0?ooo`250?oo
o`00o`3oool<0?ooo`030000003oool0oooo08D0oooo003o0?ooo``0oooo
00<000000?ooo`3oool0Q@3oool00?l0oooo303oool00`000000oooo0?oo
o`250?ooo`00o`3oool<0?ooo`030000003oool0oooo08D0oooo003o0?oo
o``0oooo00<000000?ooo`3oool0Q@3oool00?l0oooo303oool00`000000
oooo0?ooo`250?ooo`00o`3oool<0?ooo`030000003oool0oooo08D0oooo
003o0?ooo``0oooo00<000000?ooo`3oool0Q@3oool00?l0oooo303oool0
0`000000oooo0?ooo`250?ooo`00o`3oool<0?ooo`030000003oool0oooo
08D0oooo003o0?ooo``0oooo00<000000?ooo`3oool0Q@3oool00?l0oooo
303oool00`000000oooo0?ooo`250?ooo`00o`3oool<0?ooo`030000003o
ool0oooo08D0oooo003o0?ooo`<0oooo1@0000040?ooo`030000003oool0
oooo08D0oooo003o0?ooo`D0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`250?ooo`00o`3oool50?ooo`030000003oool0oooo00@0
oooo0P0000260?ooo`00o03oool4000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`250?ooo`00o`3oool50?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0Q@3oool00?l0oooo103oool2
000000H0oooo00<000000?ooo`3oool0Q@3oool00?l0oooo303oool00`00
0000oooo0?ooo`250?ooo`00o`3oool<0?ooo`030000003oool0oooo08D0
oooo003o0?ooo``0oooo00<000000?ooo`3oool0Q@3oool00?l0oooo303o
ool00`000000oooo0?ooo`250?ooo`00o`3oool<0?ooo`030000003oool0
oooo08D0oooo003o0?ooo``0oooo00<000000?ooo`3oool0Q@3oool00?l0
oooo303oool00`000000oooo0?ooo`250?ooo`00o`3oool<0?ooo`030000
003oool0oooo08D0oooo003o0?ooo``0oooo00<000000?ooo`3oool0Q@3o
ool00?l0oooo303oool00`000000oooo0?ooo`250?ooo`00o`3oool<0?oo
o`030000003oool0oooo08D0oooo003o0?ooo``0oooo00<000000?ooo`3o
ool0Q@3oool00;X0oooo6@000?lh0?ooo`030000003oool0oooo08D0oooo
002_0?ooo`/0003o1`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool02`000?l]0?ooo`030000003o
ool0oooo08D0oooo002Y0?ooo`030?l000000?l0003o00<0003o0P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool00`3oool;0000ob80oooo00<00000
0?ooo`3oool0Q@3oool009h0oooo30000?l70?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo1P000?lL0?oo
o`030000003oool0oooo03P0oooo9P000?lW0?ooo`00S03ooolB0000o`80
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo6P3o00050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo``0
003o00<0o`000?ooo`3oool03@3oool00`000000oooo0?ooo`0/0?ooo``0
003o203oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?oooa80
003o5@3oool007`0oooo40000?l20?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00<0oooo303o00060?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?l000<0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo3@000?l30?ooo`030000003oool0oooo01`0oooo
00<0003o0?ooo`000?l03@000?l30?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool:0000o`/0oooo001l0?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool60?l000<0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo0080oooo1P3o00060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`060?ooo`040000o`3oool0oooo0?ooob@0003o203oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`0@0?ooo`00O03oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`040?ooo``0o`00203oool00`000?l0oooo0?ooo`050?ooo`040?l0003o
ool0oooo0?ooo`l0003o0`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool02`3o00030?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`040?ooo`040000003oool0oooo0?l000P0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooob40
o`00203oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool0403oool007`0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0oooo0?ooo``0
o`000P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00@0003o0?ooo`3oool0oooo20000?l30?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00P3oool:0000o`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?oo
o`H0o`001`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00@0oooo00@000000?ooo`3oool0o`00203oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0o`001`3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3ooolB0?l000P0oooo00<0003o0?ooo`3oool0403oool0
07`0oooo5P3o00050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`H0003o103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`H0003o0P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool03@3o00030?ooo`030000o`3oool0oooo00@0oooo00@000000?oo
o`3oool0o`00203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01`3oool<0?l000H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00H0oooo4@3o000;0?ooo`00O03oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00H0oooo00<0o`000000o`000?l00`000?l20?ooo`030000o`3oool0oooo
00D0oooo00@0o`000?ooo`3oool0oooo0`0000000`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`030?ooo`D0003o1P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103ooolF
0?l000030000o`3oool0oooo00<0oooo603o00080?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?ooo`3o
ool;0000o`030?ooo`000?l0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool0403oool007`0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool010000?l0oooo0?ooo`3oool60000o`P0oooo00<0
003o0?ooo`3oool0103ooolH0?l000D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060000o`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00@0oooo00<000000?ooo`3o00002@3oool60?l000@0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool<0000o`@0oooo00<0
o`000000003oool0103oool90000o`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo0100oooo001l0?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l000000?l0
003o00X0003o1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0o`000`3oool00`000000oooo0000o`060?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01P3o00070?ooo`030000o`3oool0
oooo00H0oooo30000?l60?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool0103oool00`000000oooo0?l000090?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00@0003o0?ooo`3oool0oooo1@00
0?l00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`000000103oool00`000?l0oooo0?ooo`050?ooo`030?l00000
0?l0003o00T0003o1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo0100oooo001l0?ooo`040000o`3oool0oooo0?oooaT0003o203o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo1@3o
00020?ooo`<0000000<0o`000?ooo`3oool00P3oool00`000000003o0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool50?l000<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0003o00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`040?ooo`030000003oool0o`0000T0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool0103oool60000o`D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`040?l0003o
ool0oooo000000<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo01L0003o2`3oool007`0oooo1000
0?l50?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo1`3o
00020?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`000?l04000
0?l00`3oool0003o0?ooo`050?ooo`030?l0003oool0oooo00<0oooo1P3o
00050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3o
ool<0000o`D0oooo00<000000?ooo`3o00002@3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo40000?l30?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool00`3ooolD0?l000D0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0403oool007`0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool010000?l0oooo0?ooo`3o
ool70?l000P0oooo00@0003o0?ooo`3oool0oooo1@000?l20?ooo`800000
00<0oooo0000o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`<0003o
1@3oool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0oooo0?ooo`H0
o`00203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool09P000?l90?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool50?l000<0oooo00<0003o0?ooo`3o
ool0103oool0103o0000oooo0000000000030?ooo`030000o`3oool0oooo
00H0o`00203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool0403oool007`0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool00`3oool70?l000H0oooo00<0o`000?ooo`3o
ool01P3oool010000?l0oooo0000o`000?l40?ooo`030?l0003oool0oooo
0080oooo0P3o00050?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool01@000?l00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo1P3o00030?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000003oool0o`00
00T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool01000
0?l0oooo0?ooo`3oool60?l000L0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo303o0006
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0403oool0
07`0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?oo
oa80o`000`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00D0oooo0`000?l60?oooa00o`000P3oool00`000?l0oooo0?ooo`050?oo
o`D0003o0`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00<0oooo1P3o00060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01@3oool00`000000oooo0?l000090?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00@0oooo1P3o00050?ooo`030?l0003oool0oooo
00D0oooo00@0003o0?ooo`3oool0oooo2@000?l00`3oool0003o0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0303o0003
0?ooo`030000o`3oool0oooo0100oooo001l0?oooa00o`000`3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`<0003o0P3oool00`00
0?l0oooo0?ooo`030?ooo`<0o`000`3oool20000o`@0oooo00<0o`000?oo
o`3oool00P3oool40?l000H0oooo00<0o`000?ooo`3oool00P3oool60000
o`H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0=0?l0
00<0oooo00<0003o0?ooo`3oool01@3oool00`000000oooo0?l000090?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`070?ooo`L0o`000P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00<0oooo1P000?l30?ooo`030?l0003oool0oooo
00<0oooo10000?l50?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`/0o`002`3oool007`0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`050?ooo`H0003o1@3oool010000?l0oooo0?ooo`3oool20?l0
0080oooo2@000?l00`3oool0o`000?ooo`050?ooo`030000o`3oool0o`00
00D0o`00203oool00`000?l0oooo0?ooo`050000o`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?oo
o`H0o`001@3oool00`000000oooo0?l000090?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool<0?l000T0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000003o0000o`030000o`<0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?l000030?ooo`040000o`3oool0oooo
0?ooo`@0003o00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0403oool0
07`0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool01000
0?l0oooo0?ooo`3oool40000o`80oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?l000030?ooo`80003o203oool50000o`<0oooo00<0003o
0?ooo`3oool0103oool40?l000@0oooo00<0003o0?ooo`3oool01P3oool6
0000o`<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo02@0o`0000<0oooo0000o`3oool0203oool0
0`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo0?ooo`D0003o00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?l000030?ooo`00
0?l0oooo00H0oooo20000?l00`3oool0003o0?ooo`080?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0403oool006l0oooo3@000000
0`000?l0000000000006000000030?l000000000000000L0000000<0003o
0000000000001P0000000`3o0000003o0000o`0;0000o`H0000000<0o`00
0000000000001`0000020?l000<000000P000?l>000000<0003o1`000000
103o000000000000000000030?l00003000000000?l0000000L0000000<0
o`000000000000000`0000060000o`L0000000<0o`000000000000001`00
00000`000?l0000000000007000000030?l000000000000000L0000000<0
003o0000000000001`0000000`3o0000000000000007000000030000o`00
0000000000L0000000<0o`000000000000001`0000040000o`D0000000<0
o`00000000000000100000040?l000@0000000D0o`000000o`000?l00000
0?l00008000000030?l000000000000000D000002`000?l9000000030000
o`000000000000D000002`3oool007`0oooo00@0003o0?ooo`3oool0oooo
6@000?l90?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1@3oool20?l000030?ooo`000?l0oooo0080oooo00<0003o0?ooo`000000
403oool20000o`@0oooo0P3o00060?ooo`@0o`001P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00L0003o00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`050?ooo`030000003oool0o`0000T0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool40000o`P0oooo
00<0o`000?ooo`3oool00P3oool20?l000030?ooo`000?l0oooo00D0oooo
0P000?l00`000000003o0000o`030?l000D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l000000?l0003o00l0003o
2`3oool007`0oooo10000?l60?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01@3o00040?ooo`060000o`3o
ool0oooo0000o`3oool000004P3oool40000o`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3o00000`3oool0o`000?ooo`070?ooo`03
0000o`3oool0oooo00L0oooo1`000?l30?ooo`030000o`3oool0oooo00D0
oooo00<000000?ooo`3o00002@3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool60000o`<0
oooo00<0003o0?ooo`3oool01P3oool50?l000@0oooo00@0003o0?ooo`3o
ool0oooo1P000?l40?ooo`<0o`000P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0@0?ooo`00O03oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo0`3o000:0?ooo`04
0000o`3oool0oooo0000oaL0oooo10000?l40?ooo`030000o`3oool0oooo
00H0oooo1P3o00040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool:0000o`040?ooo`000000oooo0?l000T0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`030?ooo`l0003o00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`D0o`001`3oool4
0000o`030?ooo`000?l0003o00X0oooo1P3o00050?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@
0?ooo`00O03oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o``0o`0000<0oooo0?l0003oool02`3oool30000oa/0oooo0`000?l00`3o
ool0003o0?ooo`070?ooo`030?l0003oool0oooo00<0oooo1@3o00080?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3ooolM0000
o`D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0o`000080o`00103oool00`3o0000oooo0?ooo`030?oo
o`80003o00D0oooo0000o`3oool0oooo0000o`020?ooo`80003o2@3oool0
0`3o0000oooo0?ooo`020?ooo`P0o`001P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo0140oooo001l0?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool0103ooolC0?l00080oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`0;0?ooo`<0003o7@3oool40000
o`H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?l000020?l0
00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?oo
o`030000003oool0o`0000T0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool0103oool50?l000L0oooo00<0o`000?ooo`3oool00`000?l00`3o
ool0003o0000o`030?ooo`050000o`3oool0oooo0?ooo`000?l02@3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo0180o`004@3oool0
07`0oooo4@3o00020?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo0`000?l0103oool0003o0?ooo`000?lP0?ooo`@0003o0P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo1P3o0009
0?ooo`030000o`3oool0oooo00H0oooo00<000000?ooo`3o00002@3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01`3oool70?l000<0oooo00<0003o0?ooo`3oool01P3oool3
0000o`<0oooo00<0003o0?ooo`3oool00`3oool20000o`<0oooo10000?l5
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0o`002`3oool0
07`0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00<0oooo1P000?l20?oo
o`050000o`3oool0oooo0?ooo`000?l08`3oool30000o`P0oooo00<0003o
0?ooo`3oool01`3oool70?l000<0oooo00<0003o0?ooo`3oool01P3oool0
0`000000o`000?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`D0o`002P3oool0
0`000?l0oooo0?ooo`020?ooo`<0003o103oool20000o`H0oooo00<0003o
0?ooo`3oool01P3oool60000o`P0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo001l0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01P3oool80000o`L0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0S0?ooo`@0003o103oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo2`3o00000`3oool000000?l0000:0?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00P3oool;0?l0
00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0000o`020000
o`D0oooo0P000?l80?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`000?l01P000?l00`3oool0003o0?ooo`080?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool04@3oool007`0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo50000?l00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool09P3oool60000o`L0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`050?oooad0o`001@3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo0`000?l60?ooo`80
003o2P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0
oooo4`000?l30?ooo`030000o`3oool0oooo0140oooo001l0?oooad0003o
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`0[0?ooo`D0003o0P3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00H0oooo00<000000?l0003oool02@3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`030?ooo`<0003o1`3oool20000o``0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00`3oool<0000o`/0oooo
001m0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00D0oooo0P000?l`0?ooo`@0003o203oool00`000?l0oooo0?oo
o`070?ooo`030000003o0000oooo00T0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0
o`000000o`000?l00`000?l80?ooo`80003o00<0oooo0?l0003oool02`3o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo0140oooo001m0?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01`3oool20?l000/0oooo00<0003o
0?ooo`3oool0203oool00`000?l0oooo0?ooo`0a0?ooo`D0003o0`3oool0
0`000?l0oooo0?ooo`070?ooo`030000003o0000oooo00T0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`040000o`3oool0
oooo0?ooo`L0003o2`3oool20000o`<0oooo00<0o`000?ooo`3oool0203o
ool@0?l000T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo0140oooo001m0?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0003o
0?ooo`3oool0=@3oool80000o`D0oooo00<000000?l0003oool02@3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo1@000?l?
0?ooo`<0003o1@3oool00`3o0000oooo0?ooo`040?ooo`@0o`000`3oool0
0`000?l0oooo0?ooo`090?ooo`h0o`001P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo0140oooo001m0?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?oo
obL0o`00303oool20000ocd0oooo9P000?lB0?ooo`80003o2@3oool00`3o
0000oooo0?ooo`030?l000L0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`070?ooo`040000o`3oool0oooo0?oooaP0o`002`3oool0
07d0oooo5`3o00050?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`040000o`3o0000o`00
0?l000T0oooo00<0o`000?ooo`000?l0@@3oool00`000000oooo0?ooo`0^
0?ooo`<0003o2@3oool40?l000X0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`00O@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool02@3oool010000?l0oooo0?ooo`3oool3
0?l000D0oooo00@0o`000?ooo`3oool0oooo0P000?lo0?ooo`030000003o
ool0oooo02`0oooo0P000?l30?ooo`030000o`3oool0oooo00@0oooo0P3o
00020?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`00O@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`05
0?ooo`<0o`000P3oool00`3o0000oooo0?ooo`030?ooo`80003o?@3oool0
0`000000oooo0?ooo`0Y0?ooo`<0003o1@3oool00`000?l0oooo0?ooo`02
0?ooo`80o`00103oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool04@3oool0
07d0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool20?l000P0oooo0P000?lk0?ooo`030000003oool0oooo
02L0oooo0P000?l80?ooo`030000o`3oool0oooo0080o`001P3oool00`3o
0000oooo0?ooo`060?ooob<0003o2@3oool00`000?l0oooo0?ooo`0A0?oo
o`00O@3ooolg0000o`D0oooo00<0003o0?ooo`3oool02@3oool30?l000L0
oooo0`000?li0?ooo`030000003oool0oooo02<0oooo10000?l00`3oool0
o`000?ooo`070?ooo`<0o`002@3oool00`3o0000oooo0?ooo`050000o`<0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000000o`000?l040000?l;0?ooo`00
O@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool60000o`/0oooo
00<0o`000?ooo`3oool00`3o00030?ooo`040000o`3oool0oooo0?ooo`80
003o=`3oool00`000000oooo0?ooo`0O0?ooo`@0003o1@3oool00`3o0000
oooo0?ooo`030?ooo`<0o`0000<0oooo0000o`3oool0203oool40000o`P0
oooo00<0003o0?ooo`3oool0203oool20?l000T0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo0140
oooo001m0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`D0003o
1P3oool00`3o0000oooo0?ooo`040?ooo`80o`0000<0oooo0000o`3oool0
103oool30000oc@0oooo00<000000?ooo`3oool07@3oool20000o`030?oo
o`000?l0oooo00L0oooo1@3o00040?ooo`030000o`3oool0oooo00<0oooo
10000?l00`3oool0o`000?ooo`090?ooo`030000o`3oool0oooo00P0oooo
0P3o00090?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0A0?ooo`00O@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`@0003o0P3o
ool00`3o0000oooo0?ooo`060?ooo`<0o`001P3oool0103o0000003o0000
o`000?la0?ooo`030000003oool0oooo01X0oooo0`000?l40?ooo`030000
o`3oool0oooo0080oooo103o00090?ooo`030000o`3oool0003o0080003o
1@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool04@3oool007d0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3o
ool30000o`P0oooo00<0003o0?ooo`3oool00`3o00030?ooo`040?l0003o
ool0oooo0?ooo`80003o;`3oool00`000000oooo0?ooo`0E0?ooo`D0003o
1`3oool00`000?l0oooo0?l000020?l000<0oooo00<0o`000?ooo`3oool0
1P3oool30000o`T0oooo00<0o`000?ooo`3oool01`3ooolb0?l000/0oooo
001m0?ooocD0o`001P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0003o0080003o1@3oool00`000?l0oooo0?ooo`030?ooo`<0o`001P3o
ool40000ob/0oooo00<000000?ooo`3oool0403oool50000o`@0oooo00<0
o`000?ooo`3oool00`3oool40?l000L0oooo00<0o`000?ooo`3oool00P3o
ool30000o`030?ooo`000?l0oooo00T0oooo00<0o`000?ooo`3oool01`3o
00000`3oool0003o0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo0140oooo001m0?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`02
0?ooo`L0o`002@3oool00`3o0000oooo0?ooo`030?ooo`<0003o00<0oooo
0000o`3oool01`3oool30?l000D0oooo00<0003o0?ooo`3oool010000?l0
0`3o0000oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo10000?l2
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3o0002
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000000o`000?l00P000?l5
0?ooo`030000o`3oool0oooo00H0oooo103o00080?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool04@3oool0
07d0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?l0
003o00000P3o00050?ooo`030?l0003oool0oooo00H0oooo0`000?l70?oo
o`030?l0003oool0oooo00<0o`000P3oool00`000?l0oooo0?ooo`040?oo
o`D0003o8P3oool00`000000oooo0?ooo`070?ooo`D0003o1P3oool00`00
0?l0oooo0?ooo`050?ooo`80o`001P3oool00`000?l0oooo0?ooo`020?oo
o`@0003o2@3oool00`000?l0oooo0?ooo`020?ooo`@0o`0000<0oooo0?l0
003oool02@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo0140oooo001m0?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo103o00000`3oool0
o`000?ooo`080?ooo`040000o`3oool0003o0000o`D0oooo00<0o`000?oo
o`3oool00`3oool50?l000@0oooo00<0o`000?ooo`3oool00P3oool70000
oa/0oooo00<000000?ooo`3oool00`3oool40000o`@0oooo00<0o`000?oo
o`3oool0103oool010000?l0oooo0?ooo`3oool50?l000L0oooo00<0003o
0?ooo`3oool00P000?l40?ooo`030?l0003oool0oooo00H0oooo1@3o0006
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0A0?ooo`00O@3ooolU0000
o`030?ooo`000?l0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`070?ooo`D0o`001@3oool00`000?l0oooo0?ooo`020?oo
o`@0003o00<0o`000?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool4
0?l000H0oooo00<0003o0?ooo`3oool00`3ooolQ0000o`030?ooo`000?l0
oooo00D0oooo00<0o`000?ooo`3oool00`3oool50?l000@0oooo00<0o`00
0?ooo`3oool0103oool40000o`H0oooo00<0o`000?ooo`3oool00P3oool4
0?l000030?ooo`000?l0oooo00P0oooo00<0o`000?ooo`3oool01P3ooolb
0000o`/0oooo001m0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo4P000?l30?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool00P3oool30?l00080oooo00<0003o0?ooo`3oool01P3oool50000
o`<0oooo00<0003o0?ooo`3oool0103oool60?l000030?ooo`000?l0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool20?l0
00D0oooo00<0003o0?ooo`3oool0103oool60?l00080oooo00<0003o0?oo
o`3oool0103oool00`3o0000003o0000o`040000o`80oooo00<0003o0?oo
o`3oool01@3oool50?l000D0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000003o0000o`060000o`030?ooo`000?l0oooo00T0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool04@3oool007d0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00@0oooo1P000?l70?ooo`030?l0003oool0oooo00D0
oooo103o00060?ooo`030?l0003oool0oooo00<0oooo10000?l60?ooo`03
0?l0003oool0oooo00<0oooo103o00040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<000000?l0003oool00`3oool:0?l000H0
oooo00<0003o0?ooo`3oool01@000?l00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo0080oooo1@3o00080?ooo`030000o`3oool0oooo00<0
oooo1@000?l90?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`060?ooo`80o`00203oool00`000?l0
oooo0?ooo`0A0?ooo`00O@3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`050000o`80oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`040?l00080oooo00<0o`000?ooo`3oool0
1@3oool010000?l0oooo0000o`000?l40?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0903o00020?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00P3oool50000o`D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`020?l000@0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`030000o`@0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo0140oooo001m0?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00D0oooo10000?l70?ooo`030000
o`3oool0oooo00@0oooo0`3o00070?ooo`040000o`3oool0oooo0?ooo`P0
003o0`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<000000?l0003oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l000000?l0003o0080003o0P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo103o00060?ooo`03
0?l0003oool0oooo00D0oooo10000?l80?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?l0000S0?l000/0
oooo001m0?ooobX0o`001P3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool010000?l30?ooo`030000
o`3oool0oooo00H0oooo1@3o00030?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00P3oool50000o`D0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`000000o`000?ooo`050?ooo`030000
o`3oool0oooo00D0003o1`3oool00`000?l0oooo0?ooo`050?ooo`H0o`00
0P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0003o00D0003o
0P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
3@3o00080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0A0?ooo`00O@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo0?ooo``0o`00
0`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo
1P000?l50?ooo`030?l0003oool0oooo00<0oooo1@3o00050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool02P000?l00`3oool0003o
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool0
oooo3@000?l40?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3o00070?ooo`040000o`3oool0oooo0?ooo`H0003o203oool00`00
0?l0oooo0?ooo`070?ooo`T0o`0000<0oooo0000o`3oool0203oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`0A0?ooo`00O@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool0103oool60?l000L0oooo00<0o`000?ooo`3o
ool01P3oool010000?l0oooo0?ooo`3oool40000o`030?ooo`3o0000oooo
00H0oooo00<0003o0?ooo`3oool01P3o00060?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3ooolC0000o`80oooo00<000000?l0
003oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00<0oooo1@3o00050?ooo`030?l0003oool0oooo00D0oooo10000?l50?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool60?l0
00T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0A0?ooo`00O@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`080?l000P0oooo00<0003o0?ooo`3o
ool01@3oool30000o`H0oooo00<0003o0?ooo`3oool01@3oool90?l000D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`04
0?l0003oool0oooo0?ooo`<0000000<0003o0000003oool00`3oool00`00
0000o`000?ooo`050?ooo`030000o`3oool0oooo00X0o`000P3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo1@000?l70?oo
o`030?l0003oool0oooo00@0oooo1`3o00050?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0A0?ooo`00O@3ooolL0000o`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00L0oooo1P3o00030?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`000?l00`000?l20?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?l000050?l000H0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`03
000000000?l0oooo00@0oooo00<000000?l0003o0000203o00050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
003o0000o`020000o`@0oooo00<0003o0?ooo`3oool01@3oool70?l000<0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo9`000?l;0?ooo`00V@3ooolC0000o`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`040?ooo`D0o`001P3oool00`3o0000oooo0?ooo`040?ooo`D0003o
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
7@3o00060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
0`3oool:0000o`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0
oooo1P3o00080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool;0000oc80oooo002/0?ooo`L0003o0`3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1`3o00080?ooo`030000o`3oool0oooo00X0003o0P3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`030?ooo`03000000000?l0oooo00@0oooo
00<000000?l0003oool01P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
00000?l0003o00<0003o0P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00<0oooo1P3o00050?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01`3oool70000ocd0oooo002c0?ooo``0003o00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`D0o`000`3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo1000
0?l50?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`03000000000?l0oooo00@0oooo00<0
00000?l0003oool0103oool:0000o`L0oooo00<0003o0?ooo`3oool01@3o
ool60?l00080oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`040?ooo``0003oA03oool00;l0oooo1P000?l30?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool00P3oool60?l000D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0000o`0V0000o`80oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0
oooo0?ooo`D0o`00203oool00`000?l0oooo0?ooo`050?ooo`030?l00000
0?l0003o00@0003oD03oool00<D0oooo1P000?l60?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3o00060?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
0`000000oooo0?l000060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool00P3oool60?l000@0oooo00<0o`000?ooo`3oool01P3oool0
10000?l0oooo0?ooo`3oool50000oeH0oooo003;0?ooo`D0003o00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`D0o`000P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<000000?ooo`3o00001P3oool00`000?l0oooo0?ooo`0:
0?l00080oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`H0003oF`3oool00=00oooo1P000?l20?ooo`030000o`3oool0oooo
00D0oooo0P3o00040?ooo`d0o`00103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`00
0000oooo0?l000090?l000D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l000000?l0003o00<0003oH@3oool00=H0
oooo1@000?l50?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool0103o0000oooo0?ooo`3ooolK0?l000H0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0003oIP3oool00=/0oooo1P000?l70?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000000
oooo0?l000060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool00`3oool50000of`0oooo003Q0?ooo`X0003o103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030000003oool0o`0000H0oooo
00@0003o0?ooo`3oool0oooo2P000?ma0?ooo`00j`3oool]0000og/0oooo
003o0?ooo``0oooo00<000000?ooo`3oool0Q@3oool00?l0oooo303oool0
0`000000oooo0?ooo`250?ooo`00o`3oool<0?ooo`030000003oool0oooo
08D0oooo003o0?ooo``0oooo00<000000?ooo`3oool0Q@3oool00?l0oooo
303oool00`000000oooo0?ooo`250?ooo`00o`3oool<0?ooo`030000003o
ool0oooo08D0oooo003o0?ooo``0oooo00<000000?ooo`3oool0Q@3oool0
0?l0oooo303oool00`000000oooo0?ooo`250?ooo`00o`3oool<0?ooo`03
0000003oool0oooo08D0oooo003o0?ooo``0oooo00<000000?ooo`3oool0
Q@3oool00?l0oooo303oool00`000000oooo0?ooo`250?ooo`00o`3oool<
0?ooo`030000003oool0oooo08D0oooo003o0?ooo``0oooo00<000000?oo
o`3oool0Q@3oool00?l0oooo303oool00`000000oooo0?ooo`250?ooo`00
o`3oool<0?ooo`030000003oool0oooo08D0oooo003o0?ooo``0oooo00<0
00000?ooo`3oool0Q@3oool00?l0oooo303oool00`000000oooo0?ooo`25
0?ooo`00o`3oool<0?ooo`030000003oool0oooo08D0oooo003o0?ooo``0
oooo00<000000?ooo`3oool0Q@3oool00?l0oooo303oool00`000000oooo
0?ooo`250?ooo`00o`3oool<0?ooo`030000003oool0oooo08D0oooo003o
0?ooo``0oooo00<000000?ooo`3oool0Q@3oool00?l0oooo303oool00`00
0000oooo0?ooo`250?ooo`00o`3oool<0?ooo`030000003oool0oooo08D0
oooo003o0?ooo`<0oooo100000050?ooo`030000003oool0oooo08D0oooo
003o0?ooo`<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`250?ooo`00o`3oool40?ooo`030000003oool0oooo00D0oooo0P000026
0?ooo`00o`3oool50?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0Q@3oool00?l0oooo0`3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo08D0oooo003o0?ooo`@0oooo0P00002>0?ooo`00
o`3ooonD0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(JoukowskiPlot := 
      Module[{}, \[IndentingNewLine]gr1\  = \ 
          CartesianMap[
            F1, {0.00001, 3.20001, 0.2}, {0.00001, 0.60001, 
              0.1}, \[IndentingNewLine]PlotStyle \[Rule] {Blue, Red}, 
            DisplayFunction \[Rule] Identity]; \ \ \n
        gr2\  = \ 
          CartesianMap[
            F2, {\(-3.20001\), \(-0.00001\), 0.2}, {\ 0.00001, 0.60001, 0.1}, 
            PlotStyle \[Rule] {Blue, Red}, 
            DisplayFunction \[Rule] Identity]; \ \ \n
        gr3\  = \ 
          CartesianMap[F3, {0.00001, 3.20001, 0.2}, {0.00001, 0.60001, 0.1}, 
            PlotStyle \[Rule] {Blue, Red}, 
            DisplayFunction \[Rule] Identity]; \ \ \n
        gr4\  = \ 
          CartesianMap[
            F4, {\(-3.20001\), \(-0.00001\), 0.2}, {\ 0.00001, 0.60001, 0.1}, 
            PlotStyle \[Rule] {Blue, Red}, 
            DisplayFunction \[Rule] Identity]; \ \ \n
        Show[gr1, gr2, gr3, 
          gr4, \ \ Ticks \[Rule] {Range[\(-2\), 2, 2], Range[\(-2\), 2, 1]}, 
          PlotRange \[Rule] {{\(-3.2\), 3.2}, {\(-0.75\), 2.05}}, 
          AspectRatio \[Rule] 2.8\/6.2, 
          DisplayFunction \[Rule] $DisplayFunction]; \ \
\[IndentingNewLine]Print["\<A Joukowski airfoil formed with the mapping\>", "\
\<\n\>", "\<f[z] = \>", F1[z]];\ \ \ ]\), "\[IndentingNewLine]", 
    \(\(For[k = 0, 
        k \[LessEqual] 
          6, \(k++\); \[IndentingNewLine]JoukowskiFun[\(-\(1\/10\)\), 
          k\/10]; \[IndentingNewLine]JoukowskiPlot;\ ];\)\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  For a fixed value ",
  StyleBox["dy",
    FontFamily->"Courier New"],
  ", increasing the parameter ",
  StyleBox["dx",
    FontFamily->"Courier New"],
  " will fatten out the airfoil. "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3oool?0?ooo`030000003oool0
oooo0880oooo003o0?ooo`l0oooo00<000000?ooo`3oool0PP3oool00?l0
oooo3`3oool00`000000oooo0?ooo`220?ooo`00o`3oool?0?ooo`030000
003oool0oooo0880oooo003o0?ooo`l0oooo00<000000?ooo`3oool0PP3o
ool00?l0oooo3`3oool00`000000oooo0?ooo`220?ooo`00o`3oool?0?oo
o`030000003oool0oooo0880oooo003o0?ooo`l0oooo00<000000?ooo`3o
ool0PP3oool00?l0oooo3`3oool00`000000oooo0?ooo`220?ooo`00o`3o
ool?0?ooo`030000003oool0oooo0880oooo003o0?ooo`l0oooo00<00000
0?ooo`3oool0PP3oool00?l0oooo3`3oool00`000000oooo0?ooo`220?oo
o`00o`3oool?0?ooo`030000003oool0oooo0880oooo003o0?ooo`l0oooo
00<000000?ooo`3oool0PP3oool00?l0oooo3`3oool00`000000oooo0?oo
o`220?ooo`00o`3oool?0?ooo`030000003oool0oooo0880oooo003o0?oo
o`l0oooo00<000000?ooo`3oool0PP3oool00?l0oooo3`3oool00`000000
oooo0?ooo`220?ooo`00o`3oool?0?ooo`030000003oool0oooo0880oooo
003o0?ooo`l0oooo00<000000?ooo`3oool0PP3oool00?l0oooo3`3oool0
0`000000oooo0?ooo`220?ooo`00o`3oool?0?ooo`030000003oool0oooo
0880oooo003o0?ooo`l0oooo00<000000?ooo`3oool0PP3oool00=<0oooo
8`000?lH0?ooo`030000003oool0oooo0880oooo00380?ooo`/0003o00<0
oooo0?l0003oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000003o0000
o`090000o`d0oooo00<000000?ooo`3oool0PP3oool00<80oooo1P000?l4
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00L0003o0P0000040?ooo`030000003oool0oooo0880oooo002m0?oo
o`D0003o00<0oooo0?l0003oool01`3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l000000000003o
00d0003oO@3oool00;T0oooo10000?l60?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3ooolN0?l000<0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l000000000oooo00D0
oooo00<000000000o`3oool01@3oool70000ogH0oooo002d0?ooo`D0003o
00<0oooo0000o`3oool0203oool00`3o0000oooo0?ooo`020?ooo``0o`00
1`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool00`3oool>0?l000<000000`3oool00`3o00000000
0?ooo`050?ooo`03000000000?l0oooo00P0oooo00@0o`000?ooo`3oool0
oooo1`000?m_0?ooo`00[`3oool50000o`L0oooo00<0003o0?ooo`3oool0
1@3oool60?l000<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01`3o00000`000000oooo0?ooo`040?ooo`030000
00000?l0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0000o`060000ofP0oooo002[0?ooo`@0003o0P3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00D0o`0000<0oooo0?l0003oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`060?ooo`P0o`0000<000000000o`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo20000?mP0?ooo`00Y@3oool6
0000o`H0oooo00<0o`000?ooo`3oool01P3oool40?l000H0oooo00<0o`00
0?ooo`3oool01@3oool010000?l0oooo0?ooo`3ooolT0000o`030?ooo`3o
0000oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`L0o`000`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool0103oool70000oeT0oooo002N
0?ooo`L0003o0P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo0080oooo0`3o00000`3oool0003o0?ooo`070?ooo`030?l0003oool0
oooo00@0oooo1@000?l40?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo30000?l60?ooo`030?l0003oool0oooo00D0oooo00<00000
0000o`3oool0103oool70?l000H0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo0?ooo`l0003oBP3o
ool009H0oooo20000?l:0?ooo`030000o`3oool0oooo00L0oooo1@3o0005
0?ooo`030000o`3oool0oooo00D0oooo1`000?l20?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0003o1`3oool0
0`000000003o0?ooo`070?ooo`040?l0003oool0oooo0?ooo`L0o`002@3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01P3oool80000od80oooo002=0?ooo`T0003o1`3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00<0oooo1@3o0009
0?ooo`030000o`3oool0oooo00D0003o00<0oooo0?l0003oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo2P3o0007
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0003o00D0003o00<0oooo
000000000?l0203oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
o`0000H0o`0000<0oooo0?l0003oool0203oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool?
0000oc<0oooo001m0?oooa00003o1@3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?l0003o00000`3o00040?oo
o`030?l0003oool0oooo00L0oooo0`000?l60?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3o00002`3o00000`3oool0003o0?ooo`060?oo
o`l0o`0000<0oooo0?l0003oool01`3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo1`000?l40?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool80?l000<0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01`3ooolA0000ob<0oooo001b0?ooo`/0
003o2P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool01@3oool40?l000X0oooo00<0o`000?ooo`3o
ool00`3oool30000o`030?ooo`000?l0oooo00H0oooo00<0o`000?ooo`3o
ool00`3oool40?l000H0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool60?l000<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo1`000?l60?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool70?l000L0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`030?oooaL0003o303oool007`0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3o00001@3o00030?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`000?l00`000?l40?ooo`030000o`3oool0oooo00D0oooo
1P3o00020?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`d0o`00
203oool00`000?l0oooo0?ooo`060?ooo`040?l0003oool0oooo0?ooo`P0
003o203oool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo0?oo
oa00o`0000<0oooo0000o`3oool0203oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00D0oooo10000?l80?oo
o`00O03oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool00P3oool80?l000X0oooo00<0003o0?ooo`3o
ool01P3oool30000o`P0oooo00<0003o0?ooo`3oool01@3o00000`3oool0
o`000?ooo`060?ooo`030000o`3oool0oooo00<0oooo5`000?l00`3oool0
003o0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool80?l000030?ooo`000?l0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0000o`060000o`030?ooo`3o0000oooo00P0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`L0
o`00103oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool007`0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`050?ooo`P0o`00
1`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo
10000?l20?ooo`030?l0003oool0oooo00H0oooo0`3o00060?ooo`030?l0
003oool0oooo00<0oooo20000?l00`3oool0o`000?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool80000o`030?oo
o`3o0000oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`D0o`001@3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00H0oooo1`000?l40?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`030?oooa00o`00
2P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`00O03o
ool00`000?l0oooo0?ooo`070?ooo`T0o`00103oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`000?l00P00
0?l60?ooo`030?l0003oool0oooo00<0oooo0`3o00000`3oool0003o0?oo
o`060?ooo`030?l000000?l0003o00<0003o0P3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo1P00
0?l30?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l000000?ooo`020?ooo`<0o`000P3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103o
ool70000o`L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?l0003o00001P3o
00000`3oool0o`000?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`00LP3ooolD
0?l00080oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00H0oooo10000?l:0?ooo`030?l0003oool0
oooo0080o`00103oool00`000?l0oooo0?ooo`040?ooo`80003o1`3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool00`3oool;0000o`030?l0003oool0
oooo00H0oooo00<0003o0000003oool01@3oool50?l000H0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0
oooo0?ooo`P0003o2@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool01P3ooolH0?l000T0oooo00<0
003o0?ooo`3oool01`3oool00780oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0000o`060000o`<0oooo00<0003o
0?ooo`3oool0203oool30?l000L0oooo00<0003o0?ooo`3oool00`000?l2
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o00007@3o0005
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool3
0000o`H0oooo00<0003o0000003oool01P3oool0103o0000oooo0?ooo`3o
ool80?l000P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`080?ooo`030?l000000?l0003o00H0003o00<0oooo0000o`3oool02@3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo``0o`00203o
ool00780oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool8
0000o`X0oooo00<0003o0?ooo`3oool01P3oool30?l000T0oooo0`000?l5
0?ooo`030?l0003oool0oooo0080oooo103o00050?ooo`030?l0003oool0
oooo00@0oooo0P000?l60?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103o00000`3oool0o`000?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@000?l00`3oool0003o00000007
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o00001P3o0000
0`3oool0o`000?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool01P3oool80000o`@0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00L0oooo001b0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`050?ooo`P0003o1`3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo103o00020?oo
o`030?l0003oool0oooo00D0oooo0`000?l60?ooo`H0o`000P3oool20000
o`D0oooo0P3o00050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo``0o`001P3oool00`3o
0000oooo0?ooo`050?ooo`H0003o103oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00H0oooo1`3o00040?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?oo
o`P0003o1P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00L0oooo001b0?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool01`3oool90000o`<0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`090?ooo`040000o`3o0000o`000?l0
00L0oooo00<0o`000?ooo`3oool00P3oool20000o`<0oooo00@0003o0?oo
o`3oool0oooo0P3o00020?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00P3ooolD0000o`<0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0o`000P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0000000<0oooo1`000?l6
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool8
0?l000H0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`08
0?ooo`040?l0003oool0oooo0?oooa00003o00<0oooo0?l0003oool02@3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01`3oool00780oooo00<0o`000?ooo`3oool00P3oool@
0000o`030?ooo`3o0000oooo00T0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`060?ooo`@0o`002P3oool00`3o0000oooo0?ooo`02
0000o`D0oooo00@0003o0?ooo`3o0000o`00103oool0103o0000oooo0?oo
o`3oool80000oa@0oooo2P000?l00`3oool0o`000?ooo`060?ooo`030000
o`3oool0oooo00@0oooo103o00060?ooo`030000o`3oool0000000L0oooo
00<0o`000?ooo`3oool01@000?l00`3oool0003o0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00@0003o0?ooo`3oool0oooo203o00090?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`070?oooaP0003o2@3oool00`000?l0oooo0?ooo`070?ooo`00
LP3oool50000o`H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00@0o`000?ooo`3oool0
oooo1@3o00030?ooo`030000o`3oool0oooo00P0oooo0`000?l70?ooo`80
o`001P3oool0103o0000oooo0000o`000?lV0?ooo`H0003o0P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0o`000P3oool00`00
0?l0oooo000000060?ooo`030?l0003oool0oooo00H0oooo10000?l70?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?l000070?l000030?ooo`000?l0oooo00T0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0000o`0:0000
o`P0oooo001b0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0
oooo103o00090?ooo`030000o`3oool0oooo00D0oooo0P000?l00`3oool0
o`000?ooo`060?ooo`030?l0003oool0003o00D0oooo0`000?l^0?ooo`D0
003o1P3oool00`3o0000oooo0?ooo`040?ooo`L0o`00103oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00H0003o00<0oooo0?l0003o
ool02@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo1`3o00050?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`00
LP3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`040?ooo`D0o`00
303oool00`000?l0oooo0?ooo`030?ooo`80003o103oool00`3o0000oooo
0?ooo`020?ooo`80o`000`3oool00`000?l0oooo0000o`020000ocH0oooo
1@000?l00`3oool0o`000?ooo`070?ooo`030000o`3oool000000080oooo
1@3o00090?ooo`030000o`3oool0oooo00H0oooo1`000?l40?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`030?ooo`P0o`001`3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00L0oooo001b0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`020?ooo`h0o`001@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00<0003o1`3oool0103o0000oooo0?l0003o00050?ooo`80003o
?P3oool30000o`H0oooo00@0003o0?ooo`3oool000001P3oool50?l000@0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`030?ooo`P0
003o1`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0
oooo00@0o`000?ooo`3oool0oooo403o00020?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00L0oooo001b0?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?l0003o00003@3o00070?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02P3oool20000o`X0oooo0P3o00050?ooo`80
003o@`3oool50000o`050?ooo`000?l0oooo0?ooo`0000001P3oool00`3o
0000oooo0?ooo`020?ooo`D0o`002@3oool00`3o0000oooo0?ooo`080?oo
o`040000o`3oool0oooo0?ooo`H0003o00<0oooo0?l0003oool02@3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool01P3oool@0?l000L0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`070?ooo`00LP3oool<0?l000X0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00H0oooo1@000?l90?ooo`80o`0000<0oooo0?l0003o00000P3oool20000
odX0oooo1@000?l50?ooo`030?l0003oool0oooo00L0oooo00<0003o0?l0
003o00000`3o00040?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool01`3oool40000o`L0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool01`3oool010000?l0oooo0?ooo`3ooolD0?l000P0oooo001b0?oo
o`030?l0003oool0oooo00<000001@3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`020?ooo`@0003o103oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`000?l00`3oool40000
04T0oooo00@000000000o`000?l0003o0P3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00<0oooo1@3o000:0?ooo`030000o`3oool0
oooo00L0oooo00@0o`000?ooo`3oool0oooo3P000?l40?ooo`030?l0003o
ool0oooo00@0oooo100000000`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00L0oooo001b0?ooo`050?l0003oool0
oooo0?ooo`0000001P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool50000o`T0oooo00<0
003o0?ooo`3oool00`3oool20?l000H0oooo00<0003o0?ooo`3oool00P3o
ool00`000000oooo0?ooo`1:0?ooo`040000003oool0oooo0?ooo`D0003o
1`3oool00`000?l0oooo0?ooo`070?ooo`H0o`00103oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
103oool80000o`<0oooo00D000000?ooo`3oool0oooo0000o`090?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo001b0?ooo`030?l0
00000000000000<000001@3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02@000?l00`3oool0o`00
0?ooo`0<0?ooo`050000o`3oool0oooo0?ooo`3o00001`3oool00`000?l0
oooo0?ooo`040?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool01P3oool50000o`030?ooo`000?l0oooo00T0oooo00<0o`000?ooo`3o
ool00`3oool70?l000P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`040?l0003oool0oooo0?ooo`h0003o0`3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`070?ooo`00K@3oool400000003
0?ooo`3o000000000080oooo00<000000?ooo`3oool0103oool00`000?l0
oooo0?ooo`080?ooo`l0003o2P3oool00`3o0000oooo0?ooo`0;0?ooo`04
0000o`3oool0o`000?l000L0oooo00<0003o0000000000000P0000040?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool02`3oool40000
o`L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`060?l0
0080oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00H0oooo00<000000000o`3oool01P3ooolB0000
o`L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?oo
o`00LP3ooolF0000o`030?ooo`3o0000oooo00T0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool0103oool010000000oooo0?ooo`0000190?oo
o`030000003oool0oooo00l0oooo10000?l30?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool01P3oool40?l000T0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`040?ooo`040000003oool0oooo
0000o`X0oooo00<0o`000?ooo`3oool0203oool010000?l0oooo0?ooo`3o
oolD0000o`P0oooo001b0?ooo`030?l0003oool0oooo008000001P3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`<0o`0000<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`800000BP3oool0
0`000000oooo0?ooo`0C0?ooo`@0003o2P3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0o`0000H0o`000P3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00D0oooo0P0000000`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo001b0?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool0103oool50?l000<0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`1C0?ooo`030000003oool0oooo01L0oooo1@000?l40?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3ooolA0?l0
00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`070?ooo`00LP3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`090?ooo`L0o`002@3oool20000o`D0oooo00<0003o0?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0L0?ooo`H0003o2@3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool00P3oool90?l000P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool01`3oool00780oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00D0oooo4@3o000@0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0E03oool00`000000oooo
0?ooo`0R0?ooo`@0003o1@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`0=0?l000H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00L0oooo001b0?oooal0o`00103o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00h0oooo00D0
003o0?ooo`3oool0oooo0000o`1F0?ooo`030000003oool0oooo02H0oooo
1P000?l:0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0080oooo
7P3o00080?ooo`00LP3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00h0oooo00D0003o0?ooo`3oool0oooo
0000o`1F0?ooo`030000003oool0oooo02`0oooo20000?l20?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo
001b0?ooo`030?l000000000000000P0000000<0003o0000000000002@00
00000`3o0000000000000009000000030000o`000000000000X0000000<0
o`000000000000003`00000010000?l00000000000000?n=000001P0003o
2`0000000`3o0000000000000008000000030000o`000000000000P00000
00<0o`00000000000000200000000`000?l000000?ooo`070?ooo`00LP3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo0100oooo0`000?l80?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0A03oool50000o`040?ooo`000?l0003o0000o`X0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00780oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0A0?ooo`80003o203oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo0480oooo0P000?l60?ooo`030000o`000000oooo00L0003o0`3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`00LP3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo;`000?mG
0?ooo`030000003oool0oooo03l0oooo0`000?l80?ooo`030000o`3oool0
oooo00L0oooo9P000?l80?ooo`00LP3ooolF0000o`030?ooo`3o0000oooo
00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0A0?oo
o`80003oEP3oool00`000000oooo0?ooo`0k0?ooo`040?l0003oool0003o
0000o`/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`070?ooo`00LP3oool00`3o0000oooo0?ooo`080?oo
o`80003o2P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0000o`1F0?oo
o`030000003oool0oooo03T0oooo10000?l=0?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00780
oooo0P3o00090?ooo`80003o2P3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0403oool010000?l0
oooo0?ooo`000?mE0?ooo`030000003oool0oooo03D0oooo10000?l20?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`070?ooo`00LP3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00l0
oooo00D0003o0?ooo`3oool0oooo0000o`1E0?ooo`030000003oool0oooo
0340oooo10000?l70?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?oo
o`00LP3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`1C0?ooo`030000003oool0oooo02l0oooo0P000?l;0?ooo`03
0?l0003oool0oooo00T0oooo803o00050?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool01`3oool00780oooo:P3o00060?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`1B0?ooo`030000003oool0oooo02`0oooo10000?l<0?ooo`040?l0
003oool0oooo0?ooo`P0o`000P3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool00`3ooolB0?l000P0
oooo001b0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00@0oooo
303o00090?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
DP3oool00`000000oooo0?ooo`0Y0?ooo`<0003o103oool00`000?l0oooo
0?ooo`090?ooo`@0o`002P3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00L0oooo001b0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool00`3o
ool60?l000<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`1A0?ooo`030000003oool0oooo02L0oooo0P000?l70?ooo`030000o`3o
ool0oooo00H0oooo0`3o00000`3oool0o`000?ooo`0;0?ooo`030000o`3o
ool0oooo00T0oooo0P3o000:0?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`00LP3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00T0oooo0`3o00090?ooo`030000o`3oool0oooo0540oooo00<00000
0?ooo`3oool09@3oool20000o`X0oooo00<0003o0?ooo`3oool00P3oool3
0?l000@0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo001b0?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool0303oool00`000?l0o`000?l000080?ooo`030000o`3oool0oooo
0500oooo00<000000?ooo`3oool08P3oool30000o`030?ooo`3o0000oooo
00T0oooo00<0003o0?ooo`3o00000P3o00070?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`070?ooo`00LP3ooolD0000o`<0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00`0
oooo00@0003o0?ooo`3oool0o`00203oool00`000?l0oooo0?ooo`1?0?oo
o`030000003oool0oooo01h0oooo10000?l40?ooo`030?l0003oool0oooo
00H0oooo103o000:0?ooo`030?l0003oool0oooo00T0oooo<@000?l80?oo
o`00LP3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0
oooo5P000?l50?ooo`030?l0003oool0oooo00`0oooo00D0003o0?ooo`3o
ool0oooo0?l000080?ooo`030000o`3oool0oooo04h0oooo00<000000?oo
o`3oool06`3oool30000o`P0oooo00<0o`000?ooo`3oool00P3oool40?l0
00<0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080000
o`030?ooo`000?l0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool01`3oool00780oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool01@3oool50000o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool00`3oool20?l000H0oooo00<0o`000000o`3oool0CP3oool00`000000
oooo0?ooo`0G0?ooo`@0003o00<0oooo0000o`3oool0203oool50?l000L0
oooo00<0003o0?ooo`3oool0203oool40000o`T0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`00
LP3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0:0?ooo`T0003o
103oool00`000?l0oooo0?ooo`060?ooo`80o`00103oool0103o0000oooo
0000o`000?m=0?ooo`030000003oool0oooo01@0oooo0`000?l50?ooo`03
0000o`3oool0oooo00@0oooo1@3o000:0?ooo`030000o`3oool0oooo00@0
oooo10000?l00`3oool0o`000?ooo`0;0?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00780oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`060?ooo`80003o0P3oool00`000?l0oooo0?ooo`080?ooo`80o`00
00<0oooo0?l0003oool00`3oool20000od/0oooo00<000000?ooo`3oool0
403oool40000o`T0oooo00<0003o0?ooo`3o00000`3o00040?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool010000?l50?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`070?ooo`00LP3oool50?l000H0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool0203oool30000o``0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`180?ooo`030000003o
ool0oooo00d0oooo0`000?l30?ooo`030?l0003oool0oooo00H0oooo0`3o
00090?ooo`030?l0003oool0oooo00H0oooo10000?l:0?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?l0
000Q0?l000P0oooo001b0?ooo`030?l0003oool0oooo0080oooo6P3o0003
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0000o`020000o`P0oooo00@0o`000?ooo`3o0000o`001P3o
ool20000odP0oooo00<000000?ooo`3oool02P3oool30000o`H0oooo00<0
o`000?ooo`3oool00`3oool30?l000030?ooo`000?l0oooo00T0oooo00<0
o`000?ooo`3oool00P3oool40000o`80oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`090?ooo`d0o`002P3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3o
ool00780oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00H0oooo2`3o00040?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool00P3oool20000o`H0oooo00D0o`00
0?ooo`3oool0oooo0?l000050?ooo`040000o`3oool0003o0000odH0oooo
00<000000?ooo`3oool01`3oool50000o`P0oooo00<0o`000?ooo`3o0000
0P3o00050?ooo`030000o`3oool0oooo00L0oooo00<0o`000000o`000?l0
0P000?l60?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2@3o00000`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00L0oooo001b0?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00D0oooo1@3o000<0?ooo`030000o`3oool0oooo00@0oooo0P00
0?l30?ooo`030?l0003oool0oooo00<0oooo0P3o00030?ooo`040000o`3o
ool0oooo0?ooo`80003oA03oool00`000000oooo0?ooo`040?ooo`<0003o
103oool00`000?l0oooo0?ooo`040?ooo`@0o`00203oool00`000?l0oooo
0?ooo`040?ooo`@0003o2P3oool00`000?l0oooo0?ooo`060?ooo`H0o`00
2@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00L0oooo001b0?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00T0oooo203o00040?ooo`030000o`3oool0oooo00L0oooo0P00
0?l00`3oool0o`000?ooo`060?ooo`80o`0000<0003o0?ooo`3oool0103o
ool20000o`030?l0003oool0oooo03l0oooo00<000000?ooo`3oool01000
0?l70?ooo`040000o`3oool0oooo0?ooo`<0o`000P3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00@0003o103oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0o`0000D0o`000`3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool01`3oool00780oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`050?ooo`<0o`0000<0
oooo0000o`3oool02P3oool30000o`P0oooo0`3o00050?ooo`040?l00000
0?l0003o0000oc`0oooo1P000?l20?ooo`030?l0003oool0oooo00H0oooo
103o00060?ooo`030?l0003oool0oooo00H0oooo0`000?l80?ooo`030?l0
003oool0oooo00H0oooo103o000:0?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo0080oooo4`000?l80?ooo`00LP3ooolE0000o`030?ooo`3o
0000oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`080?ooo`<0o`002P3oool00`3o0000oooo0?ooo`020000o`H0oooo00<0
003o0?ooo`3oool00`3o00020?ooo`040?l0003oool0oooo0?ooo`<0003o
=03oool60000o`80oooo00<000000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`<0o`0000<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`020?ooo`@0003o00<0oooo0000o`3oool0203oool00`3o0000oooo
0?ooo`020?ooo`@0o`000P3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool06@000?l60?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00780oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`/0003o0P3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3o00000P3o00060?ooo`030?l0003oool0oooo00<0oooo0P00
0?l30?ooo`030000o`3oool0oooo00@0oooo0`3o00060?ooo`<0003o:`3o
ool60000o`H0oooo00<0003o0?ooo`0000001@3oool00`3o0000oooo0?l0
00020?l000@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0000
o`020000o`D0oooo00<0003o0?ooo`3oool0203oool40?l000L0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`L0003o2@3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`00LP3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool01`3oool<0000o`030?ooo`3o0000oooo00X0oooo00<0003o
0?ooo`3oool00`3oool40?l00080oooo00<0o`000?ooo`3oool01@3oool4
0000o`L0oooo103o00040?ooo`030000o`3oool0oooo00L0003o7P3oool6
0000o`@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo00000003
0?ooo`@0o`001`3oool00`000?l0oooo0?ooo`040?ooo`@0003o203oool0
0`000?l0oooo0?ooo`040?ooo`D0o`002P3oool00`000?l0oooo0?ooo`07
0?ooo`P0003o103oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00L0oooo001b0?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00P0oooo1@000?l80?ooo`030000o`3oool0oooo
00L0oooo103o00080?ooo`@0003o1@3oool0103o0000oooo0?ooo`3oool2
0?l00080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0N
0000o`80oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`H0o`000P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
003o00@0003o0`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00@0o`00103oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00<0oooo10000?l00`3oool0o`000?ooo`0:0?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool0
0780oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool0103o
0000oooo0?ooo`3oool40000o`@0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`020?l000H0oooo00@0003o0?ooo`3oool0oooo0`00
0?l20?ooo`030?l0003oool0oooo00<0oooo103o00050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0o`0000D0o`0000<0
003o0?ooo`0000001P3oool00`3o0000oooo0?ooo`020?ooo`D0003o203o
ool00`3o0000oooo0?ooo`040?ooo`D0o`00203oool00`3o0000oooo0?oo
o`080?ooo`H0003o1@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0o`0000X0o`00203oool00780oooo303o000:
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`050?ooo`@0003o2`3oool00`3o0000oooo0?ooo`02
0?ooo`80o`000`3oool00`000?l0oooo0?ooo`050?ooo`<0003o1P3oool0
0`000?l0oooo0?ooo`060?l000H0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?l000H0oooo00<0003o
0?ooo`0000001P3oool00`3o0000oooo0000o`020000o`@0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?l000040?l000<0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`020?ooo`L0003o2P3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00D0oooo6`3o0009
0?ooo`030000o`3oool0oooo00L0oooo001b0?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?l0003o00003`3o00040?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool0203oool50000o`L0oooo00<0o`000?oo
o`3oool0103oool30?l000030000o`3oool0oooo00H0oooo00<0o`000?oo
o`000?l00P000?l30?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3o00001@3o00000`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool;0?l000@0oooo00<0o`000?oo
o`3oool01P3oool00`000?l000000?ooo`030?ooo`@0003o1`3oool00`00
0?l0oooo0?ooo`040?ooo`@0o`00203oool00`000?l0oooo0?ooo`080?oo
o`@0003o1P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00@0oooo303o00030?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00L0oooo001b0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`040?ooo`T0o`001P3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo0080oooo10000?l20?ooo`03
0?l0003oool0oooo00P0oooo0`3o00050?ooo`030?l0003oool0oooo00<0
oooo0P000?l00`3oool0003o0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo5P3o00070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool60000o`80oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?l000040?l000<0oooo00<0o`000?ooo`3oool01`3oool010000?l0
oooo0?ooo`3oool60000o`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`040?l000@0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?oo
o`00LP3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`P0
o`002P3oool00`000?l0oooo0?ooo`060?ooo`@0003o203oool010000?l0
oooo0?ooo`3oool30?l00080oooo00<0o`000?ooo`3oool01@3oool40000
o`@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`000?l01P000?l00`000000oooo0?ooo`050?ooo`030?l0003oool0oooo
0080oooo1@3o00080?ooo`030?l0003oool0oooo00H0oooo1@000?l60?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01@3oool60?l0
00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`070?ooo`00LP3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0o`0000D0o`000`3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00@0003o103oool00`000?l0
oooo0?ooo`040?ooo`<0o`001`3oool010000?l0oooo0?ooo`3oool:0000
o`030?ooo`000?l0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo30000?l60?oo
o`030000o`000000oooo00H0oooo00<0o`000?ooo`3o00000P3o00040?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool40000
o`030?ooo`000?l0oooo00P0oooo00<0o`000?ooo`3oool0203oool80?l0
00<0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`070?ooo`<0003o203oool00780oooo10000?l70?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00D0oooo103o000:0?ooo`03
0?l0003oool0oooo00@0oooo10000?l80?ooo`030?l0003oool0o`0000<0
o`000`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0
oooo7@000?l20?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l000000?ooo`040?ooo`@0o`001`3oool00`000?l0
oooo0?ooo`060?ooo`D0003o1@3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0o`0000L0o`0000<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo80000?l;0?ooo`00
MP3ooolA0000o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3o0000o`000080o`00
1P3oool00`3o0000oooo0?ooo`070?ooo`@0003o1@3oool00`3o0000oooo
0?ooo`030?ooo`H0o`001@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000000000000002000000@0oooo1P3o00020?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`000?l01P000?l00`3oool0o`00
0?ooo`070?ooo`030000o`3oool0oooo00@0oooo1P3o00080?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`080000o`030?l0003oool0oooo02P0oooo00270?oooa00003o1`3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo103o
00000`3oool0o`000?ooo`090?ooo`040000o`3oool0oooo0?ooo`<0003o
0P3oool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0oooo0?ooo`D0
o`001`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3o00001P3o00000`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo1@000?l80?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3o00000`3o00040?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`020?ooo`T0003o<`3oool009L0oooo20000?l:0?ooo`030000
o`3oool0oooo00H0oooo1@3o00060?ooo`030000o`3oool0oooo00D0oooo
0`000?l70?ooo`030000o`3oool0oooo00D0oooo2@3o00070?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`030?ooo`/0o`0000<000000?ooo`3oool0103oool00`000?l00000
0?ooo`060?ooo`030?l0003oool0003o0080003o103oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00@0oooo1@3o00080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0103oool80000oc`0oooo
002M0?ooo`030?l0003oool0003o00D0003o0`3oool00`000?l0oooo0?oo
o`080?ooo`040?l0003oool0oooo0?ooo`H0o`0000<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0000o`030000o`<0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o0000o`0001X0o`00
0P3oool00`000?l0oooo0?ooo`050?ooo`030?l000000000oooo00D0oooo
00<0003o0?ooo`3oool0103oool40000o`L0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?l000040?l000<0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`080?ooo`L0003oA03oool00:D0oooo1000
0?l:0?ooo`030?l0003oool0oooo00L0oooo0`3o00060?ooo`030?l0003o
ool0oooo00<0oooo1P000?l50?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l000000000oooo00D0oooo1`000?l20?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0103oool40?l000P0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0000o`070000od/0oooo002Y
0?ooo`H0003o0`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00<0o`000`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00P0003o1@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`040000o`3oool0oooo0?ooo`d0003o203oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0o`0000@0o`000`3oool00`3o0000oooo0?oo
o`070?ooo`040000o`3oool0oooo0?ooo`P0003oD`3oool00:l0oooo1@00
0?l80?ooo`030000o`3oool0oooo00@0oooo103o00070?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool02`000?l00`3oool0o`000?oo
o`060?ooo`030000o`3oool0oooo00D0oooo30000?l40?ooo`030?l0003o
ool0oooo00D0oooo00<000000000o`3oool01P3oool0103o0000oooo0?oo
o`3oool70?l000P0oooo00<0o`000?ooo`3oool01P3oool50000oe/0oooo
002d0?ooo`@0003o103oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0o`0000<0o`000`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103ooolA0000o`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`03000000000?l0oooo00@0oooo1P3o00060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool40000of00oooo002h
0?ooo`D0003o203oool00`3o0000oooo0?ooo`030?ooo`H0o`001@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000003o0000o`0000@0o`000`3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo1@000?mT0?ooo`00_@3oool50000
o`<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0<0?l0
00030?ooo`000?l0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00@0003o0?oo
o`3oool0oooo3@3o00000`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`000?l01P000?mY0?ooo`00`P3oool40000
o`P0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
obD0o`001@3oool00`3o0000oooo0?ooo`040?ooo`03000000000?l0oooo
00L0oooo00@0o`000?ooo`3oool0oooo1`000?m`0?ooo`00aP3oool40000
o`<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`03000000000?l0oooo
00D0oooo1P000?mg0?ooo`00bP3oool60000o`H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000000
003o0000o`050000ogd0oooo003@0?ooo`d0003o00<0oooo0000o`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool010000?l0oooo0?ooo`3oool<0000oh@0
oooo003M0?ooobH0003o2`3oool00`000000oooo0?ooo`220?ooo`00o`3o
ool?0?ooo`030000003oool0oooo0880oooo003o0?ooo`l0oooo00<00000
0?ooo`3oool0PP3oool00?l0oooo3`3oool00`000000oooo0?ooo`220?oo
o`00o`3oool?0?ooo`030000003oool0oooo0880oooo003o0?ooo`l0oooo
00<000000?ooo`3oool0PP3oool00?l0oooo3`3oool00`000000oooo0?oo
o`220?ooo`00o`3oool?0?ooo`030000003oool0oooo0880oooo003o0?oo
o`l0oooo00<000000?ooo`3oool0PP3oool00?l0oooo3`3oool00`000000
oooo0?ooo`220?ooo`00o`3oool?0?ooo`030000003oool0oooo0880oooo
003o0?ooo`l0oooo00<000000?ooo`3oool0PP3oool00?l0oooo3`3oool0
0`000000oooo0?ooo`220?ooo`00o`3oool?0?ooo`030000003oool0oooo
0880oooo003o0?ooo`l0oooo00<000000?ooo`3oool0PP3oool00?l0oooo
3`3oool00`000000oooo0?ooo`220?ooo`00o`3oool?0?ooo`030000003o
ool0oooo0880oooo003o0?ooo`l0oooo00<000000?ooo`3oool0PP3oool0
0?l0oooo3`3oool00`000000oooo0?ooo`220?ooo`00o`3oool?0?ooo`03
0000003oool0oooo0880oooo003o0?ooo`l0oooo00<000000?ooo`3oool0
PP3oool00?l0oooo3`3oool00`000000oooo0?ooo`220?ooo`00o`3oool?
0?ooo`030000003oool0oooo0880oooo003o0?ooo`H0oooo100000050?oo
o`030000003oool0oooo0880oooo003o0?ooo`H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`220?ooo`00o`3oool70?ooo`030000
003oool0oooo00D0oooo0P0000230?ooo`00o`3oool80?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0PP3oool00?l0oooo1P3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo0880oooo003o
0?ooo`L0oooo0P00002;0?ooo`00o`3ooonD0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(JoukowskiPlot := 
      Module[{}, \[IndentingNewLine]gr1\  = \ 
          CartesianMap[
            F1, {0.00001, 3.60001, 0.2}, {0.00001, 0.60001, 
              0.1}, \[IndentingNewLine]PlotStyle \[Rule] {Blue, Red}, 
            DisplayFunction \[Rule] Identity]; \ \ \n
        gr2\  = \ 
          CartesianMap[
            F2, {\(-3.60001\), \(-0.00001\), 0.2}, {\ 0.00001, 0.60001, 0.1}, 
            PlotStyle \[Rule] {Blue, Red}, 
            DisplayFunction \[Rule] Identity]; \ \ \n
        gr3\  = \ 
          CartesianMap[F3, {0.00001, 3.60001, 0.2}, {0.00001, 0.60001, 0.1}, 
            PlotStyle \[Rule] {Blue, Red}, 
            DisplayFunction \[Rule] Identity]; \ \ \n
        gr4\  = \ 
          CartesianMap[
            F4, {\(-3.60001\), \(-0.00001\), 0.2}, {\ 0.00001, 0.60001, 0.1}, 
            PlotStyle \[Rule] {Blue, Red}, 
            DisplayFunction \[Rule] Identity]; \ \ \n
        Show[gr1, gr2, gr3, 
          gr4, \ \ Ticks \[Rule] {Range[\(-4\), 2, 2], Range[\(-2\), 2, 1]}, 
          PlotRange \[Rule] {{\(-4.0\), 3.2}, {\(-1.55\), 2.1}}, 
          AspectRatio \[Rule] 2.55\/7.2, 
          DisplayFunction \[Rule] $DisplayFunction]; \ \
\[IndentingNewLine]Print["\<A Joukowski airfoil formed with the mapping\>", "\
\<\n\>", "\<f[z] = \>", F1[z]];\ \ \ ]\), "\[IndentingNewLine]", 
    \(\(For[k = 0, 
        k \[LessEqual] 
          5, \(k++\); \[IndentingNewLine]JoukowskiFun[\(-\(k\/10\)\), 
          1\/5]; \[IndentingNewLine]JoukowskiPlot;\ ];\)\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Increasing both parameters ",
  StyleBox["dx",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["dy",
    FontFamily->"Courier New"],
  " will bend and fatten out the airfoil. "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006C0000UB000`400?l0
0000o`00003oo`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3ooonD0?ooo`00
o`3ooonD0?ooo`00o`3ooonD0?ooo`00o`3oool?0?ooo`030000003oool0
oooo0880oooo003o0?ooo`l0oooo00<000000?ooo`3oool0PP3oool00?l0
oooo3`3oool00`000000oooo0?ooo`220?ooo`00o`3oool?0?ooo`030000
003oool0oooo0880oooo003o0?ooo`l0oooo00<000000?ooo`3oool0PP3o
ool00?l0oooo3`3oool00`000000oooo0?ooo`220?ooo`00o`3oool?0?oo
o`030000003oool0oooo0880oooo003o0?ooo`l0oooo00<000000?ooo`3o
ool0PP3oool00?l0oooo3`3oool00`000000oooo0?ooo`220?ooo`00o`3o
ool?0?ooo`030000003oool0oooo0880oooo003o0?ooo`l0oooo00<00000
0?ooo`3oool0PP3oool00?l0oooo3`3oool00`000000oooo0?ooo`220?oo
o`00o`3oool?0?ooo`030000003oool0oooo0880oooo003o0?ooo`l0oooo
00<000000?ooo`3oool0PP3oool00?l0oooo3`3oool00`000000oooo0?oo
o`220?ooo`00o`3oool?0?ooo`030000003oool0oooo0880oooo003o0?oo
o`l0oooo00<000000?ooo`3oool0PP3oool00?l0oooo3`3oool00`000000
oooo0?ooo`220?ooo`00o`3oool?0?ooo`030000003oool0oooo0880oooo
003o0?ooo`l0oooo00<000000?ooo`3oool0PP3oool00?l0oooo3`3oool0
0`000000oooo0?ooo`220?ooo`00o`3oool?0?ooo`030000003oool0oooo
0880oooo003o0?ooo`l0oooo00<000000?ooo`3oool0PP3oool00?l0oooo
3`3oool00`000000oooo0?ooo`220?ooo`00o`3oool?0?ooo`030000003o
ool0oooo0880oooo003o0?ooo`H0oooo1@0000040?ooo`030000003oool0
oooo0880oooo003o0?ooo`P0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`220?ooo`00o`3oool80?ooo`030000003oool0oooo00@0
oooo0P0000230?ooo`00c03ooolF0000oad0oooo100000040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0PP3oool00<@0oooo2000
0?l30?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0000o`0>0000oaH0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`220?ooo`00_@3oool70000o`<0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`L0003o3P3oool2000000H0oooo00<000000?ooo`3oool0PP3oool0
0;L0oooo1P000?l00`3oool0o`000?ooo`070?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`030?ooo`L0003o3`3oool00`000000oooo0?ooo`220?oo
o`00/P3oool50000o`L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`020?oooa<0o`0000<0oooo0?l0003oool01P3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00@0003o0?ooo`3o
ool0oooo1`000?l80?ooo`030000003oool0oooo0880oooo002^0?ooo`@0
003o0`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00<0
oooo203o00030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool;0?l000L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`070?ooo`030?l000000?l0003o00H0003o00<000000?ooo`3o
ool0PP3oool00:T0oooo1@000?l70?ooo`030000o`3oool0oooo00H0oooo
1P3o00030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3o00001`3o00090?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool70000ogh0oooo002S0?ooo`H0003o0`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0o`0000D0o`0000<0
oooo0?l0003oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00H0oooo1`3o00030?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000000003o0?oo
o`040?ooo`P0003oMP3oool009l0oooo10000?l90?ooo`030?l0003oool0
oooo00@0oooo1@3o00070?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`000?l050000?l00`3oool0o`000?ooo`070?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool0103oool60?l000H0oooo00<0o`00
0?ooo`3oool01`3oool00`000000003o0?ooo`080?ooo`040?l0003oool0
oooo0?oooa00003oIP3oool009P0oooo1`000?l30?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3o00000`3o00030?ooo`030000o`3oool0
oooo00H0oooo00@0o`000?ooo`3oool0oooo1P000?l60?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool;0000o`P0oooo00<0
o`000?ooo`3oool01P3oool010000?l0oooo0?ooo`3oool70?l000T0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00H0oooo40000?mF0?ooo`00TP3oool60000o`X0oooo00<0
003o0?ooo`3oool01`3oool30?l000P0oooo00<0003o0?ooo`3oool01@3o
ool40000o`@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool80000o`030?ooo`3o0000oooo00L0oooo00<0003o0?ooo`3oool01`3o
ool90?l000030?ooo`000?l0oooo00T0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00@0
003o0?ooo`3oool0oooo60000?ln0?ooo`00SP3oool40000o`D0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`@0o`0000<0
oooo0?l0003oool0203oool00`000?l0oooo0?ooo`050000o`030?ooo`3o
0000oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`L0003o0`3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo1`3o00040?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`040?ooo`l0003o;`3oool008L0oooo1`000?l9
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o00000`3o0005
0?ooo`030?l0003oool0oooo00L0oooo0`000?l60?ooo`030?l0003oool0
oooo00@0oooo5`3o00000`3oool0o`000?ooo`070?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool70000o`H0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`P0o`001`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool01`3oool90000o`80oooo00<0o`00
0?ooo`3oool08P3oool007L0oooo40000?l50?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01P3oool40?l000X0oooo00<0o`000?oo
o`3oool00`3oool30000o`030?ooo`000?l0oooo00H0oooo1`3o00000`3o
ool0003o0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool:0?l000P0oooo00<0o`000?ooo`3oool01`3oool01000
0?l0oooo0?ooo`3oool70000o`T0oooo00<0003o0?ooo`3oool01`3oool0
103o0000oooo0?ooo`3oool@0?l00080oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00H0oooo4@000?lF0?ooo`00LP3oool50000o`T0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo0080oooo103o00030?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`000?l00`000?l40?ooo`030000o`3oool0oooo00<0oooo0`3o0007
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?l0003o00001@3o00000`3oool0o`000?ooo`070?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`000?l010000?l40?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`06
0?ooo`T0o`00103oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
10000?l0oooo0?ooo`3oool>0000o`P0oooo001e0?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`09
0?ooo`@0o`001`3oool00`000?l0oooo0?ooo`070?ooo`<0003o203oool0
0`000?l0oooo0?ooo`030?l00080oooo0P3o00060?ooo`030000o`3oool0
oooo00@0oooo10000?l40?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`D0o`001@3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo10000?l0
0`000000oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?oooah0o`001P3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00`0oooo001e0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`P0o`002P3oool00`00
0?l0oooo0?ooo`030?ooo`@0003o0P3oool00`3o0000oooo0?ooo`060?oo
o`<0o`001P3oool0103o0000oooo0?ooo`3oool:0000o`040?l0003oool0
oooo0?ooo`l0003o1@3oool00`000?l0oooo0?ooo`060?ooo`040?l0003o
ool0oooo0?ooo`@0o`0000<0oooo0000o`3oool0203oool00`3o0000oooo
0?ooo`070?ooo`L0003o103oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
0P3ooolA0?l000T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00d0oooo001e0?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool90?l000L0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0000o`020000o`H0oooo00<0
o`000?ooo`3oool00`3oool30?l000030?ooo`000?l0oooo00D0oooo1@00
0?l30?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`040?l0003oool0oooo0?ooo`H0003o
203oool00`3o0000oooo0?ooo`050?ooo`@0o`001`3oool00`3o0000oooo
0?ooo`070?ooo`030000o`000000oooo00@0oooo1`000?l80?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o0000o`0000H0o`00
00<0oooo0?l0003oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00d0oooo001e0?ooo`030000o`3oool0oooo00P0oooo203o
00040?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203o
ool30000o`X0oooo00<0o`000?ooo`3o00000P3o00040?ooo`040000o`3o
ool0oooo0?ooo`<0003o00<0oooo0?l0003oool01@3oool20000o`D0oooo
0P3o00060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1P3oool60000o`80oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`080?l000T0oooo00<0003o0000003oool0203oool00`3o0000oooo
0?ooo`090000o`X0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo
403o00070?ooo`030?l0003oool0oooo00d0oooo001b0?ooo`h0o`0000<0
oooo0?l0003oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00@0oooo0`000?l20?ooo`030000o`3oool0oooo00L0oooo0`3o
00080?ooo`<0003o1@3oool00`3o0000oooo0?ooo`030?oooa80o`00103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo0`00
0?l90?ooo`030000o`3oool0oooo00H0oooo2@3o00020?ooo`030000o`00
0000oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0000
o`0=0000o`L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00@0
003o0?ooo`3oool0oooo2@3o000>0?ooo`00M@3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0000o`040000o`D0oooo00<0003o0?ooo`3oool01@3o
ool20?l00080oooo00<0o`000?ooo`3oool01@3oool20000o`L0oooo1P3o
00000`3oool0003o0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00@0
003o0?ooo`3oool0oooo1`3o00050?ooo`030000o`3oool0oooo00H0oooo
00<0o`000000o`000?l00`000?l30?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool50?l000L0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0080oooo
90000?l20?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3o00001@3o00080?ooo`00M@3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0103o
ool70000o`X0oooo00<0003o0?ooo`3oool00P3oool30?l000@0oooo00<0
o`000?ooo`3oool00`3oool20000o`80oooo00<0003o0?ooo`3oool00`3o
ool20?l000H0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
00080?ooo`030?l0003oool0oooo00<0oooo1`000?l60?ooo`030?l0003o
ool0oooo00L0oooo00@0003o0?ooo`000000oooo103o00030?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`050?ooo`d0003o2P3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
3@3oool007D0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0003o00@0003o1@3oool00`3o0000oooo0?oo
o`0:0?ooo`040000o`3oool0o`000?l000P0oooo00<0o`000?ooo`3oool0
0P000?l40?ooo`030000o`3oool0oooo00<0o`000P3oool00`3o0000oooo
0?ooo`020?ooo``0003o0P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?l0003o00000`3o00020?ooo`030?l0
003oool0oooo00L0oooo00@0003o0?ooo`3oool0oooo1@000?l00`3oool0
o`000?ooo`080?ooo`030000o`3oool0000000D0oooo1P3o00080?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`T0003o0P3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool03@3oool007D0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`050?ooo`H0003o2P3oool00`3o0000oooo0?ooo`0:0?ooo`80o`00
2P3oool00`3o0000003o0000o`070?ooo`80o`001@3oool00`3o0000oooo
0000o`020000o``0oooo20000?l00`3oool0o`000?ooo`060?ooo`030000
o`3oool0oooo00@0oooo0`3o00090?ooo`030000o`3oool0oooo00H0oooo
10000?l70?ooo`030000o`3oool0000000P0oooo00<0o`000?ooo`3oool0
203o00000`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`060?ooo`P0003o1@3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00d0oooo001e0?ooo`030000o`3oool0003o0140003o103o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo0`3o
00000`000?l0oooo0?ooo`080?ooo`80003o00<0o`000?ooo`3oool0103o
ool20?l00080003o0P3oool50000oaL0oooo10000?l50?ooo`030000o`3o
ool0oooo00H0oooo1P3o00030?ooo`030000o`3oool0oooo00L0oooo00@0
o`000?ooo`3oool0oooo0`000?l40?ooo`030000o`3oool0000000P0oooo
00<0o`000?ooo`3oool0203oool90?l00080oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00`3ooolB0000o`h0oooo
001b0?ooo`D0003o00<000000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00X0oooo00@0o`000?ooo`3oool0oooo
1@3o00040?ooo`030000o`3oool0oooo00D0oooo0P000?l30?ooo`030?l0
003oool0oooo0080oooo00@0o`000?ooo`3oool0oooo0`000?l00`3oool0
000000000002000001/0oooo1P000?l80?ooo`030?l0003oool0oooo00<0
oooo1@3o00080?ooo`030?l0003oool0oooo00@0oooo1@000?l00`3oool0
00000?ooo`060?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool01P3oool`0?l000<00000103oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0000o`050000o`P0oooo001e0?ooo`030000o`000000oooo00T0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`@0o`00
2@3oool00`000?l0oooo0?ooo`030?ooo`80003o1@3oool00`3o0000oooo
0?ooo`020?l000<0oooo0P000?l30?ooo`030000003oool0oooo0280oooo
1@000?l20?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o0000
0P3o00050?ooo`030?l0003oool0oooo00L0oooo1`000?l40?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0000000T0o`00
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool03@3oool007<0oooo0P0000000`000?l000000000
00090?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0103o
ool60?l000d0oooo00<0003o0?ooo`3oool00P000?l80?ooo`80o`00103o
ool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo02H0oooo0`00
0?l80?ooo`030000o`3oool0oooo00<0oooo0`3o00020?ooo`030?l0003o
ool0oooo00L0oooo00@0003o0?ooo`3oool000000`3oool80000o`L0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`070?ooo`040?l0003oool0oooo000000D0oooo00<0003o0?ooo`3o
ool01`3o00000`3oool0o`000?ooo`090?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool03@3oool006d0oooo100000020?ooo`040000
003oool0oooo0000o`/0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`040?l000H0oooo00<0o`000?ooo`3oool02P3oool30000o`X0
oooo0P3o00030?ooo`030000o`000000000000800000103oool00`000000
oooo0?ooo`0X0?ooo`<0003o1@3oool00`000?l0oooo0?ooo`060?ooo`@0
o`00203oool010000?l0oooo0?ooo`0000070?ooo`040?l0003oool0oooo
0?ooo`T0003o2P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`07
0?ooo`050?l0003oool0oooo0?ooo`000000103oool00`000?l0oooo0?oo
o`070?ooo`P0o`00103oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00d0oooo001d0?ooo`030000003oool0003o00/0oooo00<0o`00
0?ooo`3oool01@3oool70?l000X0oooo00<0o`000?ooo`3oool0203oool3
0000o`X0oooo0P3o00020?ooo`030?l0003oool0003o00L0oooo00@00000
0?ooo`3oool00000;03oool40000o`030?ooo`000?l0oooo00P0oooo00<0
o`000?ooo`3oool01P3o00020?ooo`040000o`3oool0oooo000000L0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0000o`050000o`@0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
000000020?ooo`050000003oool0oooo0?ooo`000?l02P3oool00`3o0000
oooo0?ooo`040?ooo`P0o`00203oool00`3o0000oooo0?ooo`0=0?ooo`00
M@3oool00`000000003o0?l0000B0?l000@0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`060?ooo`80003o0`3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo0080oooo0P3o00000`000?l0oooo
0?ooo`060?ooo`800000<@3oool40000o`L0oooo00<0o`000?ooo`3oool0
1P3oool50?l000030000003oool0oooo00D0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`050?ooo``0003o0`3oool00`000?l0oooo
0?ooo`080?ooo`040?l0003oool0oooo0?oooaT0003o00<0oooo0000o`3o
ool02@3oool00`3o0000oooo0?ooo`080?ooo`040000o`3oool0oooo0?oo
o`h0o`002P3oool00780oooo1@3o000;0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`030?ooo`<0
003o1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0?P3oool50000o`030?ooo`3o0000oooo00T0
oooo00@0003o0?ooo`3oool0oooo103o00030?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?oo
oa80003o1`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00D0oooo10000?l80?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`040?ooo`80o`00203oool007H0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000000o`000?l00`000?l90?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`140?ooo`80003o2P3oool01@000?l0oooo0?ooo`3oool00000
00<0oooo1@3o000:0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?oo
o`040000o`3oool0oooo0?ooo`@0003o0`3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool03P3oool0
07H0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00H0oooo1@000?l00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo0080o`001P3oool00`000?l0oooo0?ooo`170?oo
o`80003o1`3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<0o`000?ooo`3o00000`3o00060?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo10000?l;0?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool03P3oool007H0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo``0
003o1@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o0000o`0000P0
oooo00<0003o0?ooo`3oool0B@3oool30000o`@0oooo00<0003o0?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo1P3o000;0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo0080
oooo2`3o00020?ooo`030000o`3oool0oooo00P0oooo00<0o`000000o`00
0?l010000?l50?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool03P3oool007H0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0000o`060000o`@0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0<0?ooo`030?l000000?l0oooo00L0oooo00<0003o0?ooo`3oool0
C@3oool50000o`@0oooo00<000000?ooo`3oool00`3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3o0000o`0000X0o`002`3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00D0oooo1`3o00050?ooo`030?l0
003oool0oooo00<0oooo00<0o`000000o`3oool02P3oool00`3o0000oooo
0?ooo`040?oooa80003o3`3oool00780oooo4P000?l;000000030000o`00
0000000000X0000000<0o`000000000000002@0000030?l00080000000<0
003o0000000000001@0000000`000?l000000000001A000000H0003o1@00
00000`3o0000000000000009000000030000o`000000000000T00000803o
0003000000030000o`000000000000H0000000<0o`000000000000000P00
0?l010000000003o0?l0003o000:000000030?l000000000000000P00000
00<0003o0000000000002@0000000`3o000000000000o`060000o`P0oooo
001b0?ooo`050000003oool0oooo0?ooo`000?l02`3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
1P3oool30?l000D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`080?ooo`030000003oool0oooo04/0oooo00<000000000o`000?l0
1@000?l:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool01@3oool40000o`040?ooo`000000oooo0000o`80
oooo1@3o00040?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0>0?ooo`00LP3oool01@000000oooo
0?ooo`3oool0003o00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080oooo0`3o00090?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0203oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo00<0oooo00<0o`000?ooo`00
0?l00`000?l60?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool00`3oool20000o`030?ooo`000?l0003o00@0
003o203oool30?l000030?ooo`3o0000oooo00X0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0>0?ooo`00MP3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
2@3oool70?l000d0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`1F0?ooo`030000003oool0oooo00T0oooo1P000?l<0?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`080?ooo`040000o`3oool0oooo0?ooo`80003o0P3oool30000o`l0
oooo1P3o00070?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool03P3oool007H0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0o`0000T0o`000P3oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
EP3oool00`000000oooo0?ooo`0>0?ooo`@0003o2@3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
1@3oool70000o`80oooo0P000?l0103oool0003o0000o`000?l?0?ooo`03
0?l0003oool0oooo0080oooo303o00070?ooo`030?l0003oool0oooo00h0
oooo001f0?ooo`030000o`3oool0oooo00P0oooo403o000<0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`1F0?ooo`030000003oool0oooo0180oooo2@000?l<0?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool01@000?l70?ooo`80003o
0`3oool00`000?l0oooo0?ooo`020000o``0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`020?ooo`h0o`002P3oool00780oooo3`3o
00000`3oool0o`000?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool04@3oool20000o`80oooo00<0003o0?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0K0?oooa/0003o2`3oool00`000?l0oooo0?oo
o`030?ooo`040000o`3oool0oooo0?ooo`<0003o2P3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
103oool20?l000P0oooo001f0?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo01<0oooo0`000?mH0?ooo`030000003oool0oooo0400oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`<0003o203o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool03P3oool007H0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0503oool20000oeP0oooo00<000000?ooo`3oool0?P3oool2
0000o`L0oooo00<0003o0?ooo`3oool01P3oool50000o`<0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00h0oooo001f0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00d0oooo2@000?mH0?ooo`030000003oool0oooo03d0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`0;0?ooo`T0003o1`3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00h0oooo001f0?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l000000?l0003o00d0003o1P3oool20000oeP0
oooo00<000000?ooo`3oool0>`3oool20000o`X0oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`020?ooo`h0003o1P3oool00`3o0000
oooo0?ooo`0>0?ooo`00MP3oool00`000?l0oooo0?ooo`090?ooob00003o
4P3oool00`000?l0oooo0000o`1G0?ooo`030000003oool0oooo03X0oooo
00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool00P3ooolA0000o`P0oooo
001b0?oooa00003o00<0oooo0?l0003oool02P3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo0180oooo00@0003o0?ooo`3oool0003o
E`3oool00`000000oooo0?ooo`0h0?ooo`80003o3@3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0>0?ooo`00MP3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0B0?ooo`040000o`3oool0oooo0000oeL0oooo
00<000000?ooo`3oool0=P3oool20000o`l0oooo00<0003o0?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool03`3oool007H0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool04@3oool01@000?l0oooo0?ooo`3oool0003o05L0oooo
00<000000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00l0oooo001f0?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo03<0oooo0P00
0?l00`3o0000oooo0?ooo`0?0?oooa40o`00303oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00l0oooo001f0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo0380oooo00D0003o
0?ooo`3oool0oooo0?l0000;0?ooo`D0o`0000<0oooo0000o`3oool03@3o
oolK0?l00100oooo001b0?oooaX0o`00103oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo0300oooo0P000?l5
0?ooo`030?l0003oool0oooo00D0oooo0`3o00060?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0o`0000L0o`00203oool007H0oooo0P000?l;0?oo
o`030?l0003oool0oooo00H0oooo5`3o000<0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`0^0?oo
o`80003o1`3oool00`3o0000oooo0?ooo`020?ooo`<0o`002@3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0?0?ooo`00MP3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`030?ooo`P0o`00103oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3o
ool0;@3oool00`000?l0oooo0?ooo`080?ooo`040?l0003oool0o`000?l0
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool03`3oool007H0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool20?l00003
0?ooo`000?l0oooo00X0oooo00<0003o0?ooo`3oool0D@3oool00`000000
oooo0?ooo`0[0?ooo`80003o2`3oool20?l000h0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool03`3oool007H0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool03@3oool30?l000/0oooo00<0003o0?ooo`3oool0
D03oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00T0oooo
0`3o000@0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00l0oooo
001f0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool00P3o000:0?ooo`030000o`3oool0oooo04l0oooo00<0
00000?ooo`3oool0:03oool20000o`030?ooo`000?l0oooo00L0oooo0P3o
00030?ooo`030?l0003oool0oooo00d0oooo00@0003o0?ooo`3oool0oooo
;@000?l80?ooo`00LP3ooolB0000o`/0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`1?0?ooo`030000003o
ool0oooo02H0oooo0P000?l30?ooo`030000o`3oool0oooo00@0oooo0P3o
00060?ooo`030?l0003oool0oooo00X0oooo1P000?l:0?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0?0?ooo`00MP3oool00`000?l0oooo0?ooo`0:0?ooo`030?l000000?l0
003o0180003o1@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`1>
0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`80o`00203oool00`3o0000oooo0?ooo`06
0?ooo`@0003o0P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0?
0?ooo`00MP3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool01P3oool:0000o`X0oooo00<0003o0?oo
o`3oool01@3oool20?l000L0oooo00<0o`000000o`3oool0CP3oool00`00
0000oooo0?ooo`0S0?ooo`80003o1`3oool010000?l0oooo0?l0003o000:
0?ooo`030?l0003oool0oooo0080oooo10000?l60?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00l0oooo001f0?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo0080oooo1@000?l50?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo0?ooo`000?m>
0?ooo`030000003oool0oooo0240oooo0P000?l90?ooo`80o`00303oool0
0`3o0000oooo0?ooo`020000o`X0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool03`3oool007H0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool01`3oool20000o`80oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`020?ooo`040?l0003oool0oooo0?ooo`80003oC03oool0
0`000000oooo0?ooo`0N0?ooo`<0003o00<0o`000?ooo`3oool01P3oool2
0?l000030?ooo`000?l0oooo00/0oooo0`000?l<0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00l0oooo001f0?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00X0oooo0`000?l<0?ooo`80o`0000<0oooo0?l0
003oool01@3oool00`000?l0oooo0?ooo`190?ooo`030000003oool0oooo
01`0oooo0P000?l40?ooo`030?l0003oool0oooo0080oooo0`3o00040?oo
o`030000o`3oool0oooo00H0oooo0`000?l20?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool02@3ooolT0?l000P0oooo001b0?oooa80
o`002`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`000?l00P000?l;0?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool0B03oool00`000000oooo0?ooo`0J0?ooo`80
003o1P3oool00`3o0000oooo0?ooo`020?l000L0oooo00<0003o0?ooo`3o
ool00`3oool30000o`D0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
o`000?l000090?l000030?ooo`3o0000oooo00/0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0?0?ooo`00MP3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0o`0000d0o`002P3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo0P000?l80?ooo`040?l0
003oool0o`000?l000L0oooo0P000?m80?ooo`030000003oool0oooo01P0
oooo0P000?l80?ooo`<0o`002P3oool00`000?l0oooo0000o`020000o`P0
oooo00<0o`000?ooo`3oool01@3oool70?l000`0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00l0
oooo001f0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0;0?l000d0oooo00<0003o0?ooo`3oool0
103oool20000o`H0oooo00@0o`000?ooo`3oool0oooo0P3o00060?ooo`80
003oA`3oool00`000000oooo0?ooo`0F0?ooo`80003o00<0oooo0000o`3o
ool01@3oool40?l000/0oooo0P000?l<0?ooo`040?l0003oool0oooo0?oo
o`<0o`001P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0?0?oo
o`00MP3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02P3oool40?l000T0oooo00<0003o0?ooo`3o
ool01`3oool20000o`<0oooo00<0o`000?ooo`3oool0103oool20?l000<0
oooo0P000?l00`3oool0003o0000o`150?ooo`030000003oool0oooo01@0
oooo0P000?l30?ooo`030000o`3oool0oooo0080oooo0P3o00040?ooo`03
0?l0003oool0oooo00D0oooo0`000?l00`3oool0003o0?ooo`0;0?ooo`04
0?l0003oool0o`000?l000T0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool03`3oool007H0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00@0o`000?ooo`3o
ool0oooo1@3o00040?ooo`030000o`3oool0oooo00T0oooo0P000?l00`3o
0000oooo0?ooo`070?ooo`030?l0003oool0003o00D0oooo00<0003o0?oo
o`3oool0@P3oool00`000000oooo0?ooo`0A0?ooo`<0003o1P3oool01000
0?l0oooo0?l0003o00060?ooo`030?l0003oool0oooo0080oooo0`000?l4
0?ooo`030000o`3oool0oooo00P0oooo103o000<0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00l0oooo001f0?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00L0oooo1@3o000=0?ooo`80003o2@3oool20?l0
00H0oooo0P000?m20?ooo`030000003oool0oooo00h0oooo0`000?l90?oo
o`80o`002@3oool0103o0000oooo0000o`000?l70?ooo`030000o`3oool0
oooo00@0oooo103o00020?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000003o0000o`0O0000o`P0oooo001b0?oo
oaP0003o103oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3o00000`3o00080?ooo`030?l0003oool0oooo
0080003o1`3oool00`000?l0oooo0?l000070?ooo`80003o@03oool00`00
0000oooo0?ooo`0;0?ooo`<0003o0P3oool00`3o0000oooo0?ooo`050?oo
o`80o`0000<0003o0?ooo`3oool0203oool20000o`X0oooo00<0003o0?oo
o`3o00000`3o00070?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool00P3oool90000o`/0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0?0?ooo`00MP3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00D0oooo1`000?l:0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool00`3oool20?l000H0oooo00<0o`000?ooo`3o
ool00P3oool20000o`D0oooo00<0003o0?ooo`3oool00P3o00050?ooo`04
0?l0003oool0003o0000ocD0oooo1@0000040?ooo`030000003oool0oooo
00P0oooo0`000?l60?ooo`030?l0003oool0oooo0080oooo0P3o00020?oo
o`030000o`3oool0oooo00D0oooo0`000?l00`3oool0o`000?ooo`090?oo
o`80o`002`3oool00`3o0000oooo0?ooo`050?ooo`X0003o203oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool03`3oool007H0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00X0003o00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`050?ooo`<0o`000P3oool00`3o0000
oooo0?ooo`050?ooo`80003o0P3oool00`000?l0oooo0?ooo`030?ooo`80
o`000P3oool00`3o0000oooo0?ooo`020?ooo`80003o=@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo10000?l80?ooo`03
0?l0003oool0o`000080o`001@3oool00`000?l0oooo0?ooo`020?ooo`80
003o103oool00`3o0000oooo0?ooo`050?ooo`<0o`0000<0003o0?ooo`3o
ool02P3oool0103o0000oooo0?ooo`3oool40000o`D0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool03`3oool007H0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0
oooo10000?l90?ooo`030000o`3oool0oooo00P0oooo0`3o00090?ooo`80
003o203oool30?l000H0oooo0`000?lb0?ooo`030000003oool0oooo00@0
oooo0P0000040?ooo`80003o103oool00`000?l0oooo0?ooo`040?ooo`<0
o`00203oool00`000?l0oooo0?ooo`020000o`H0oooo00<0o`000?ooo`3o
ool00P3oool30?l000@0oooo00<0003o0?ooo`3oool02@3oool40000o`T0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool03`3oool007H0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00X0oooo00@0o`000?ooo`3oool0oooo1@000?l40?ooo`03
0000o`3oool0oooo00T0oooo00@0o`000?ooo`3o0000o`00203oool30000
o`L0oooo00@0o`000?ooo`3o0000o`001@3oool010000?l0oooo0000o`00
0?l`0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000?l00`00
0?l60?ooo`040000o`3oool0oooo0?ooo`<0o`000P3oool00`3o0000oooo
0?ooo`060?ooo`<0003o2@3oool0103o0000oooo0?l0003o00070?ooo`03
0000o`3oool0oooo00H0oooo0`000?l00`3oool0o`000?ooo`0;0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`050?ooo`h0o`00203oool00780oooo1P3o000:0?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`070?ooo`@0003o303oool0103o0000oooo0?ooo`3oool20?l000D0
oooo00@0003o0?ooo`3oool0oooo0P000?l50?ooo`040?l0003oool0oooo
0?ooo`80o`000P3oool00`000?l0oooo0?ooo`020?ooo`@0003o;03oool0
10000000oooo0?ooo`3oool50000o`80oooo00<0o`000?ooo`3oool01P3o
ool30?l000D0oooo00<0o`000?ooo`3oool00`3oool30000o`030?ooo`00
0?l0oooo00T0oooo0P3o000:0?ooo`030000o`3oool0oooo0080oooo0`00
0?l40?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3o
oolD0?l000@0oooo00<0o`000?ooo`3oool03`3oool007H0oooo00<0003o
0?ooo`3o00004@3o00040?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02P3oool50000o`L0oooo00<0o`000?ooo`3oool0103oool3
0?l00080oooo00<0003o0?ooo`3oool00`3oool30000o`030?ooo`3o0000
oooo00D0oooo0P3o00000`000?l0oooo0?ooo`050?ooo`030?l000000?l0
003o0080003o9P3oool70000o`80oooo00D000000?ooo`3oool0oooo0?l0
00050?ooo`<0o`0000<0003o0?ooo`3oool01P3oool00`3o0000oooo0000
o`020000o`D0oooo00<0003o0?ooo`3oool0103oool40?l000/0oooo00<0
003o0?ooo`000?l00P000?l70?ooo`030?l0003oool0oooo00X0oooo00@0
003o0?ooo`3oool0oooo2@3o000<0?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool03`3oool007H0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`050?ooo`T0o`001`3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo0080oooo0`000?l40?ooo`030?l0003o
ool0oooo00L0oooo0P3o00000`000?l0oooo0?ooo`060?ooo`<0003o1P3o
ool010000?l0o`000?l0003o00040?ooo`030?l0003oool0oooo00<0oooo
1@000?lK0?ooo`H0003o1P3oool010000?l0oooo0?ooo`0000040?ooo`03
0?l0003oool0o`000080o`000`3oool00`000?l0oooo0?ooo`040?ooo`@0
003o203oool00`000?l0oooo0?ooo`040?l000@0oooo00<0o`000?ooo`3o
ool01P3oool40000o`X0oooo00<0o`000?ooo`3oool01@3oool90?l000P0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00l0oooo001f0?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`P0o`00
2`3oool00`000?l0oooo0?ooo`060?ooo`<0003o00<0o`000?ooo`3oool0
2@3oool00`000?l0o`000?l000070?ooo`030?l0003oool0oooo00<0003o
0`3oool010000?l0oooo0?ooo`3oool60?l000D0oooo0P000?l20?oooa/0
003o103oool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0oooo0000
0080oooo103o00070?ooo`030000o`3oool0oooo00<0003o0P3oool00`3o
0000oooo0?ooo`070?ooo`<0o`00203oool00`3o0000oooo0?ooo`020?oo
o`@0003o0`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00@0o`001@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0?0?oo
o`00MP3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool02P3oool40?l000P0oooo00<0003o0?ooo`3o
ool02@3oool30000o`T0oooo00<0003o0?ooo`3oool00`3o00040?ooo`03
0?l0003oool0oooo00<0oooo0P000?l00`3oool0003o0?ooo`060?ooo`03
0?l0003oool0o`0000<0o`0000<0oooo0000o`3oool01@3oool20?l000D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool60?l00080
oooo00<0o`000?ooo`3oool01P3oool30000o`H0oooo00<0o`000?ooo`3o
ool00P3oool40?l000030?ooo`000?l0oooo00P0oooo00<0o`000000o`00
0?l00P000?l70?ooo`030000o`3oool0oooo00L0oooo1@3o00090?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00h0oooo001f0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0:0?ooo`040?l0003oool0oooo0?ooo`D0o`000`3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00@0003o103oool00`000?l0
oooo0?ooo`040?ooo`80o`0000<0oooo0?l0003oool01`3oool30000o`H0
oooo00<0o`000?ooo`3oool00`3oool60?l00080oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?l000040?l00004
0000o`3oool0oooo000000D0oooo00@0o`000?ooo`3oool0oooo1@000?l8
0?ooo`030?l0003oool0o`000080o`001@3oool00`000?l0oooo0?ooo`05
0?ooo`<0003o00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`03
0?ooo`@0o`000P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0B
0000o`P0oooo001b0?ooo`h0003o00<0oooo0?l0003oool02P3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00L0oooo103o000;0?oo
o`030?l0003oool0oooo00@0oooo0`000?l00`3oool0003o0?ooo`070?oo
o`80o`00203oool00`000?l0oooo0?ooo`030000o`80oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`H0o`000`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo2P3o00060?oo
o`030000o`3oool0000000@0oooo1@000?l40?ooo`030000o`3oool0oooo
00@0oooo103o00090?ooo`030000o`3oool0oooo00@0003o0`3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0o`0000<0o`001P3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00P0oooo40000?lJ0?oo
o`00P03oool90000o`@0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0o`0000<0o`001P3oool00`3o0000
oooo0?ooo`080?ooo`80003o2@3oool40?l000D0oooo00<0003o0?ooo`3o
ool00`3oool40000o`H0oooo00<0003o0?ooo`3oool0103oool0103o0000
oooo0?ooo`3ooolA0?l000030?ooo`000?l0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool010000?l0oooo0000003oool30000o`030?ooo`3o0000
oooo00L0oooo00<0003o0?ooo`3oool00`3o00030?ooo`030?l0003oool0
oooo00H0oooo10000?l70?ooo`030?l0003oool0oooo00H0oooo103o000;
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`000?l020000?lZ
0?ooo`00R@3oool90000o`L0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`030?ooo`@0o`000P3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0003o0080003o1@3oool00`3o0000oooo0?ooo`020?oo
o`<0o`000P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0003o
00<0003o0P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool40000
o`@0oooo00<0o`000?ooo`3oool01P3oool30?l000H0oooo00<0o`000?oo
o`3oool00P3oool40000o`030?ooo`000?l0oooo00T0oooo00<0o`000?oo
o`3oool00P3oool30?l000<0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`040?ooo`L0003o<`3oool00980oooo2@000?l:0?ooo`03
0000o`3oool0oooo00L0oooo103o00090?ooo`030000o`3oool0oooo0080
oooo0`000?l20?ooo`030?l0003oool0oooo00D0oooo103o00060?ooo`03
0?l0003oool0oooo00<0oooo2@000?l00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`020?ooo`/0003o00<0oooo0000003oool01@3oool0103o0000
oooo0?ooo`3oool40?l000030000o`3oool0oooo00L0oooo00@0o`000000
o`000?l0003o1@3oool00`000?l0oooo0?ooo`080?ooo`D0o`001P3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00@0003o>P3oool0
09/0oooo1P000?l40?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool0103o00040?ooo`030000o`3oool0oooo00H0oooo0`000?l80?oo
o`030000o`3oool0oooo00H0o`001`3oool00`000?l0oooo0?ooo`050?oo
oa/0003o0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool00000
00@0oooo1P3o00050?ooo`030000o`3oool0oooo00@0oooo0`000?l90?oo
o`030000o`3oool0oooo00@0oooo103o000:0?ooo`030000o`3oool0oooo
00H0oooo1P000?ln0?ooo`00X@3oool40000o`/0oooo00<0o`000?ooo`3o
ool0103oool30?l000030?ooo`000?l0oooo00P0oooo00<0o`000?ooo`00
0?l00P000?l50?ooo`030000o`3oool0oooo00D0oooo0`3o00050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`H0o`000P3oool00`3o0000
oooo0?ooo`060?ooo`040000o`3oool0oooo0?ooo`<0003o0P3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00@0o`00103oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0003o00D0003oA03oool00:D0
oooo10000?l70?ooo`030?l0003oool0oooo00L0oooo103o00070?ooo`03
0?l0003oool0oooo0080oooo0`000?l00`3oool0003o0?ooo`070?ooo`03
0?l0003oool0oooo00@0o`0000<0oooo0000o`3oool01P3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0o`0000D0
o`0000<0003o0000003oool01@3oool00`3o0000oooo0?ooo`060?ooo`@0
003o1@3oool00`3o0000oooo0?ooo`060?ooo`@0o`00203oool00`3o0000
oooo0?ooo`060?ooo`@0003oBP3oool00:T0oooo10000?l30?ooo`030?l0
003oool0oooo00L0oooo00@0003o0?ooo`3oool0oooo0`3o00040?ooo`03
0?l0003oool0oooo00D0oooo10000?l60?ooo`030?l0003oool0oooo00@0
oooo3@3o00030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?l000070?l000H0oooo00<0003o0000003o
ool01@3oool00`3o0000oooo0?ooo`020?ooo`D0003o2@3oool00`3o0000
oooo0?ooo`020?ooo`<0o`000P3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo0080oooo10000?m>0?ooo`00[@3oool40000o`T0oooo
00<0003o0?ooo`3oool0103oool40?l000T0oooo00<0003o0?ooo`3oool0
1`000?l60?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
0P3ooolD0?l000H0oooo00<0o`000?ooo`3oool01@3oool00`000?l00000
0?ooo`030?ooo`L0003o1@3oool00`000?l0oooo0?ooo`060?ooo`D0o`00
1@3oool00`000?l0oooo0?ooo`080?ooo`@0003oDP3oool00;40oooo1000
0?l50?ooo`030000o`3oool0oooo00L0oooo1@3o00040?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`000?l01P000?l70?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool60000o`<0oooo00<0o`000?ooo`3oool01P3oool010000?l0oooo0?oo
o`3oool60?l000T0oooo00<0003o0?ooo`3oool0103oool40000oeH0oooo
002e0?ooo`D0003o2P3oool00`3o0000oooo0?ooo`020?ooo`<0o`0000<0
oooo0000o`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`H0003o0P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0003o00L0003o1`3oool00`3o0000oooo0?ooo`060?ooo`@0o`001@3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00@0003oFP3o
ool00;T0oooo10000?l70?ooo`030?l0003oool0oooo00D0oooo103o0006
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool=
0000o`D0oooo00<0o`000000o`000?l03P000?l70?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool00P3oool40?l000030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool0103oool50000oeh0oooo002m0?oo
o`D0003o00<0oooo0?l0003oool0203oool00`000?l0oooo0?ooo`070?l0
00L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00L0003o1P3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool70?l0
00@0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0000o`040000
of<0oooo00320?ooo`D0003o1@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0o`0000D0o`0000<0oooo0000o`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo1P3o00030?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool0103oool40000ofP0oooo00370?ooo`@0003o00<0oooo0000o`3oool0
1`3oool00`3o0000oooo0?ooo`050?ooo`P0o`0000<0oooo0?l0003oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?l000050?l000030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0000o`040000of`0oooo003;0?ooo`@0003o1P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo8`3o00060?ooo`030000o`3o
ool0oooo00H0oooo00@0o`000?ooo`3oool0oooo1`000?ma0?ooo`00c`3o
ool70000o`L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool60000ogP0oooo003F0?ooo`H0003o00<0oooo
0000o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<000000000o`000?l010000?mn
0?ooo`00g03oool80000o`030?ooo`3o0000oooo00L0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`000?l01P000?n40?ooo`00i03ooolT0000o`H0
oooo00<000000?ooo`3oool0PP3oool00?l0oooo3`3oool00`000000oooo
0?ooo`220?ooo`00o`3oool?0?ooo`030000003oool0oooo0880oooo003o
0?ooo`l0oooo00<000000?ooo`3oool0PP3oool00?l0oooo3`3oool00`00
0000oooo0?ooo`220?ooo`00o`3oool?0?ooo`030000003oool0oooo0880
oooo003o0?ooo`l0oooo00<000000?ooo`3oool0PP3oool00?l0oooo3`3o
ool00`000000oooo0?ooo`220?ooo`00o`3oool60?ooo`@000001@3oool0
0`000000oooo0?ooo`220?ooo`00o`3oool60?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0PP3oool00?l0oooo1`3oool00`000000
oooo0?ooo`050?ooo`800000P`3oool00?l0oooo203oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0880oooo003o0?ooo`H0oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`220?ooo`00o`3o
ool70?ooo`800000R`3oool00?l0ooooU03oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{403, 149},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(JoukowskiPlot := 
      Module[{}, \[IndentingNewLine]gr1\  = \ 
          CartesianMap[
            F1, {0.00001, 3.60001, 0.2}, {0.00001, 0.60001, 
              0.1}, \[IndentingNewLine]PlotStyle \[Rule] {Blue, Red}, 
            DisplayFunction \[Rule] Identity]; \ \ \n
        gr2\  = \ 
          CartesianMap[
            F2, {\(-3.60001\), \(-0.00001\), 0.2}, {\ 0.00001, 0.60001, 0.1}, 
            PlotStyle \[Rule] {Blue, Red}, 
            DisplayFunction \[Rule] Identity]; \ \ \n
        gr3\  = \ 
          CartesianMap[F3, {0.00001, 3.60001, 0.2}, {0.00001, 0.60001, 0.1}, 
            PlotStyle \[Rule] {Blue, Red}, 
            DisplayFunction \[Rule] Identity]; \ \ \n
        gr4\  = \ 
          CartesianMap[
            F4, {\(-3.60001\), \(-0.00001\), 0.2}, {\ 0.00001, 0.60001, 0.1}, 
            PlotStyle \[Rule] {Blue, Red}, 
            DisplayFunction \[Rule] Identity]; \ \ \n
        Show[gr1, gr2, gr3, 
          gr4, \ \ Ticks \[Rule] {Range[\(-4\), 2, 2], Range[\(-2\), 2, 1]}, 
          PlotRange \[Rule] {{\(-4.0\), 3.2}, {\(-1.05\), 2.0}}, 
          AspectRatio \[Rule] 3.05\/7.2, 
          DisplayFunction \[Rule] $DisplayFunction]; \ \
\[IndentingNewLine]Print["\<A Joukowski airfoil formed with the mapping\>", "\
\<\n\>", "\<f[z] = \>", F1[z]];\ \ \ ]\), "\[IndentingNewLine]", 
    \(\(For[k = 0, 
        k \[LessEqual] 
          5, \(k++\); \[IndentingNewLine]JoukowskiFun[\(-\(k\/15\)\), 
          k\/15]; \[IndentingNewLine]JoukowskiPlot;\ ];\)\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the modified Joukowski airfoil when  ",
  Cell[BoxData[
      \(W\  = \ \(\(S\_2\) \((z)\)\  = \ z\^1.925\)\)]],
  "  is used to map the ",
  StyleBox["Z",
    FontFamily->"Courier"],
  " plane onto the ",
  StyleBox["W",
    FontFamily->"Courier"],
  " plane.  Refer to Figure 11.69 and discuss why the angle of the trailing \
edge of the modified Joukowski airfoil ",
  Cell[BoxData[
      \(A\_1\)]],
  " forms an angle of ",
  Cell[BoxData[
      \(0.15\)]],
  " radians.  "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.69",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/joukowskitransform/\
JoukowskiTransFigures/mat1169.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The images of the circles ",
  Cell[BoxData[
      \(C\_0\)]],
  " and ",
  Cell[BoxData[
      \(C\_1\)]],
  " under the modified Joukowski airfoil. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "\tThe image of the circle ",
  Cell[BoxData[
      \(C\_0\)]],
  " is the line ",
  Cell[BoxData[
      \(L\_0\)]],
  ", then two rays ",
  Cell[BoxData[
      \(R\_\(0, 1\)\)]],
  " and ",
  Cell[BoxData[
      \(R\_\(0, 2\)\)]],
  ", and then two arcs ",
  Cell[BoxData[
      \(A\_\(0, 1\)\)]],
  " and ",
  Cell[BoxData[
      \(A\_\(0, 2\)\)]],
  " in the respective ",
  StyleBox["Z",
    FontFamily->"Courier"],
  ",  ",
  StyleBox["W",
    FontFamily->"Courier"],
  ", and ",
  StyleBox["w",
    FontFamily->"Courier"],
  " planes.  The image of the circle ",
  Cell[BoxData[
      \(C\_1\)]],
  " is the circle ",
  Cell[BoxData[
      \(K\_1\)]],
  ", then the \"cardioid like\" curve ",
  Cell[BoxData[
      \(H\_1\)]],
  ", and then the modified Joukowski airfoil ",
  Cell[BoxData[
      \(A\_1\)]],
  ".  The details are left as an exercise for the reader in the book. \n\n",
  StyleBox[ButtonBox["Complex Analysis for Mathematics and Engineering",
    ButtonData:>{
      URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}]
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Ideal Fluid Flow",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/FluidFlowBib.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Joukowski Transformation and Airfoils",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/JoukowskiTransBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Potential",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexPotentialBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{974, 606},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 191811, 3947}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 117, 2, 33, "Text"],
Cell[2222, 66, 943, 25, 150, "Text"],
Cell[3168, 93, 419, 14, 36, "Text"],
Cell[3590, 109, 1206, 36, 224, "Text"],
Cell[4799, 147, 1720, 49, 349, "Text"],
Cell[6522, 198, 11970, 341, 160, "Text"],

Cell[CellGroupData[{
Cell[18517, 543, 101, 2, 33, "Text"],
Cell[18621, 547, 815, 13, 140, "Input"],
Cell[19439, 562, 785, 13, 130, "Input"],
Cell[20227, 577, 746, 12, 143, "Input"],
Cell[20976, 591, 1121, 20, 130, "Input"]
}, Closed]],
Cell[22112, 614, 465, 15, 30, "Text"],
Cell[22580, 631, 3844, 135, 138, "Text"],
Cell[26427, 768, 583, 21, 33, "Text"],
Cell[27013, 791, 4025, 139, 135, "Text"],
Cell[31041, 932, 583, 14, 74, "Text"],
Cell[31627, 948, 403, 14, 33, "Text"],
Cell[32033, 964, 414, 14, 33, "Text"],
Cell[32450, 980, 1346, 42, 253, "Text"],
Cell[33799, 1024, 3207, 79, 282, "Text"],
Cell[37009, 1105, 1962, 56, 115, "Text"],
Cell[38974, 1163, 993, 26, 292, "Text"],
Cell[39970, 1191, 1338, 39, 71, "Text"],
Cell[41311, 1232, 956, 29, 33, "Text"],
Cell[42270, 1263, 1650, 51, 93, "Text"],
Cell[43923, 1316, 394, 14, 33, "Text"],
Cell[44320, 1332, 956, 25, 112, "Text"],
Cell[45279, 1359, 384, 11, 33, "Text"],
Cell[45666, 1372, 381, 11, 33, "Text"],
Cell[46050, 1385, 188, 6, 33, "Text"],
Cell[46241, 1393, 912, 15, 254, "Input"],
Cell[47156, 1410, 297, 11, 33, "Text"],
Cell[47456, 1423, 40560, 668, 163, 40446, 664, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[88041, 2095, 109, 2, 33, "Text"],
Cell[88153, 2099, 1704, 34, 343, "Input"]
}, Closed]],
Cell[89872, 2136, 303, 11, 30, "Text"],
Cell[90178, 2149, 45773, 753, 163, 45659, 749, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[135976, 2906, 109, 2, 33, "Text"],
Cell[136088, 2910, 1703, 34, 343, "Input"]
}, Closed]],
Cell[137806, 2947, 299, 11, 30, "Text"],
Cell[138108, 2960, 46932, 772, 163, 46818, 768, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[185065, 3736, 109, 2, 33, "Text"],
Cell[185177, 3740, 1704, 34, 340, "Input"]
}, Closed]],
Cell[186896, 3777, 604, 21, 49, "Text"],
Cell[187503, 3800, 472, 17, 33, "Text"],

Cell[CellGroupData[{
Cell[188000, 3821, 101, 2, 33, "Text"],
Cell[188104, 3825, 1180, 47, 90, "Text"]
}, Closed]],
Cell[189299, 3875, 290, 7, 30, "Text"],
Cell[189592, 3884, 278, 6, 33, "Text"],
Cell[189873, 3892, 309, 7, 33, "Text"],
Cell[190185, 3901, 291, 7, 33, "Text"],
Cell[190479, 3910, 257, 5, 33, "Text"],
Cell[190739, 3917, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

