(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    889858,      16153]*)
(*NotebookOutlinePosition[    890964,      16192]*)
(*  CellTagsIndexPosition[    890886,      16186]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["11.9  The Schwarz-Christoffel Transformation",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tIn Chapter 10 we mentioned the Riemann mapping theorem:  If ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " is any simply connected domain in the plane (other than the entire plane \
itself), then there exists a one-to-one conformal mapping  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  that maps ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " onto the unit disk  ",
  Cell[BoxData[
      \(\(\(|\)\(w\)\(|\)\(\(<\)\(1\)\)\)\)]],
  ".  The Mobius transformation ",
  Cell[BoxData[
      \(w = \ \(S \((z)\) = \(\[ImaginaryI]\ \((1 + z)\)\)\/\(1 - z\)\)\)]],
  " is a one-to-one conformal mapping of the unit disk  ",
  Cell[BoxData[
      \(\(\(|\)\(z\)\(|\)\(\(<\)\(1\)\)\)\)]],
  "  onto the upper half-plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  ", and the inverse is ",
  Cell[BoxData[
      \(z = \ \(\(S\^\(-1\)\) \((w)\) = \(w - \[ImaginaryI]\)\/\(w + \
\[ImaginaryI]\)\)\)]],
  ".  Hence the Riemann mapping theorem could have been stated:  If ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " is any simply connected domain in the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  "-plane, then there exists a one-to-one conformal mapping  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  that maps the upper half-plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  " onto ",
  StyleBox["D",
    FontFamily->"Courier New"],
  ".  In this section we will introduce the Schwarz-Christoffel formula for \
constructing a conformal mapping from the upper half plane onto a region ",
  StyleBox["G",
    FontFamily->"Courier New"],
  " bounded by a polygonal curve.  At the end of this section we will \
introduce the remarkable mappings of the unit disk onto an equilateral \
triangle and a square. "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:80000[b000`400?l0
0000o`00003oo`3ooooo0?ooohX0oooo003o0?ooool0ooooRP3oool00?l0
ooooo`3ooon:0?ooo`00o`3ooooo0?ooohX0oooo003o0?ooool0ooooRP3o
ool00?l0ooooo`3ooon:0?ooo`00o`3ooooo0?ooohX0oooo002M0?ooo`03
0000003oool0oooo0740oooo1@00002V0?ooo`D00000_@3oool5000000D0
oooo002M0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0
Z03oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo00D0oooo
002F0?ooo`D000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo0:P0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?oo
o`050?ooo`00V03oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo06/0oooo100000040?ooo`030000003oool0oooo0:P0oooo00<00000
0?ooo`3oool0_`3oool00`000000oooo0?ooo`050?ooo`00TP3ooolG0000
ofX0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`2o0?oo
o`030000003oool0oooo00D0oooo002<0?ooo`H0003o0P0000040?ooo`03
0000003oool0oooo0080oooo00<0003o0?ooo`3oool02@3oool60000of<0
oooo0P00002Y0?ooo`800000`03oool2000000L0oooo00280?ooo`040?l0
00000?l0003o0000o``0oooo00<000000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0?0?ooo`<0003o00<0o`000?ooo`3oool0/P3oool00`000000
oooo0?ooo`1l0?ooo`030000003oool0oooo09l0oooo00250?ooo`<0003o
00<0o`000?ooo`3oool0303oool2000000@0oooo00<0003o0?ooo`3oool0
4P3oool00`3o0000003o0000o`2b0?ooo`030000003oool0oooo07`0oooo
00<000000?ooo`3oool0W`3oool00840oooo10000?l40?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04@3oool0103o0000oooo0?oo
o`3oool30000ojl0oooo00<000000?ooo`3oool0O03oool00`000000oooo
0?ooo`2O0?ooo`00O`3oool20000o`P0oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00@0oooo0`00
0?n/0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0BP3o
ool00`3o0000oooo0?ooo`1B0?ooo`00O@3oool20000o`X0oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo00L0oooo10000?m=0?ooo`@00000[`000?l400000200oooo0`00002K
0000o`@000000`3oool007/0oooo0P000?l<0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?l0003oool0403oool00`3o0000oooo0?ooo`0<0?oo
o`80003oC`3oool00`000000003o0000o`0b0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo0300oooo0P000?l00`00
0000oooo0?ooo`0U0?ooo`80003o:@3oool00`3o0000oooo0?ooo`0?0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo02L0oooo0P000?l70?oo
o`00N@3oool20000o`l0oooo00<0o`000?ooo`3oool01P3oool:0?l00003
0000o`3o0000o`0000X0o`001P3oool00`3o0000oooo0?ooo`0>0?ooo`80
003oCP3oool010000?l0oooo0000o`000?l`0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo02h0oooo0P000?l00`3o
ool0003o0?ooo`0W0?ooo`030000o`3oool0003o02P0oooo00<0o`000?oo
o`3oool03`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0V0?oo
o`030000o`3oool0003o00L0oooo001g0?ooo`80003o4@3oool00`3o0000
oooo0?l000060?l000X0oooo00<0003o0?ooo`3oool02P3oool30?l000<0
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`1<0?ooo`04
0000o`3oool0oooo0000obl0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0;@3oool010000?l0oooo0?ooo`000?lY
0?ooo`040000o`3oool0oooo0000obL0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0U0?ooo`040000o`3o
ool0oooo0000o`L0oooo001e0?ooo`80003o4P3oool30?l00140oooo00<0
003o0?ooo`3oool03@3oool50?l00180oooo0P000?m<0?ooo`040000o`3o
ool0oooo0?ooo`80003o;@3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo0140o`0000<0003o0?l0003o00003`3o00020?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0:`3oool20000o`<0oooo
00<0003o0?ooo`3oool09`3oool01@000?l0oooo0?ooo`3oool0003o02H0
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0T0?ooo`050000o`3oool0oooo0?ooo`000?l01`3oool007@0
oooo00<0003o0?ooo`000?l0403oool20?l00080oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00<0
o`003`3oool00`000?l0oooo0000o`1<0?ooo`030000o`3oool0oooo0080
oooo0P000?l[0?ooo`030?l0003oool0oooo00<0oooo203o00000`000?l0
o`000?l000080?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`060?ooo`80o`0000<0003o0?l0003o
00001@3o00060?ooo`030?l0003oool0oooo02T0oooo0P000?l40?ooo`03
0000o`3oool0oooo02P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0S0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00D0oooo001b0?ooo`80003o0P3oool00`000?l0oooo
0?ooo`0;0?ooo`<0o`00103oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00l0oooo00<0o`000?ooo`3oool00`3oool20?l000d0oooo
00<0003o0?ooo`3oool00P000?m:0?ooo`030000o`3oool0oooo00@0oooo
0P000?lY0?ooo`030?l0003oool0oooo00<0o`00203oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00D0oooo
0`3o00030?ooo`030?l0003oool0oooo02L0oooo0P000?l60?ooo`030000
o`3oool0oooo02P0oooo00<0003o0?ooo`3oool00`3oool20000ob<0oooo
00<0o`000?ooo`3oool02`3oool50?l000030000o`3o0000o`0001`0o`00
00<0003o0?l0003o00003`3oool00`3o0000oooo0?ooo`0Q0?ooo`80003o
1@3oool00`000?l0oooo0?ooo`050?ooo`00L03oool20000o`D0oooo00<0
003o0?ooo`3oool01`3oool30?l000L0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00D0oooo0P3o
000:0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0B03o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02D0oooo103o
000;0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool02@3oool30?l002T0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool0803oool0103o0000oooo0?ooo`3oool:0?l000D0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`040000
o`3oool0oooo0?ooo`T0o`001P3oool00`3o0000oooo0?ooo`0P0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool006l0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`<0o`00
2`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool0203oool20?l000L0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`180?ooo`030000o`3oool0oooo00D0oooo
0P000?lR0?ooo`<0o`000P3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00@0oooo10000?l00`3o0000003o0000o`0?0000o`040?l0
00000?l0003o0000o`H0oooo00<0003o0?ooo`3oool02`3oool60?l00280
oooo0P000?l70?ooo`030000o`3oool0oooo02X0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`0N0?ooo`D0o`003`3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool02P3oool:0?l001h0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`00KP3oool00`000?l0oooo0?ooo`070?ooo`040000
o`3oool0oooo0?ooo`80o`003P3oool00`3o0000oooo0?ooo`0;0?ooo`H0
003o3P3oool00`3o0000oooo0?ooo`0:0?ooo`80o`001@3oool00`000?l0
oooo0?ooo`060?ooo`80003oB03oool00`000?l0oooo0?ooo`070?ooo`80
003o7P3oool20?l000D0oooo00<0o`000?ooo`3oool02P3oool70000o`@0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`04
0?l0003oool0oooo0?ooo`L0003o3@3oool00`3o0000oooo0?ooo`030?oo
o`@0o`00703oool20000o`T0oooo00<0003o0?ooo`3oool0:P3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01P0oooo1@3o00020?oo
o`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool00P3oool40?l001T0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`050?ooo`00K@3oool00`000?l0oooo0?ooo`090?ooo`03
0000o`3o0000o`000100oooo00<0o`000?ooo`3oool00`3oool80000o`<0
oooo00<0003o0?ooo`3oool02@000?l50?ooo`030?l0003oool0oooo00`0
oooo0P3o00020?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3o
ool0AP3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo01P0
oooo0`3o00080?ooo`030?l0003oool0oooo00D0oooo1P000?l90?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`@0003o2@3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0203oool00`000?l0
oooo0?ooo`0[0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3o
ool04`3oool40?l000L0oooo00<0o`000?ooo`3oool03`3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`060?ooo`80o`005P3oool00`000?l0
oooo0?ooo`080?ooo`030000o`3oool0oooo00D0oooo001[0?ooo`80003o
303oool00`000?l0oooo0?ooo`0A0?ooo`030?l000000?l0003o0080003o
2`3oool00`000?l0oooo0?ooo`090?ooo`<0003o00<0oooo0?l0003oool0
403oool20?l000030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0
A@3oool00`000?l0oooo0?ooo`090?ooo`80003o5P3oool20?l000/0oooo
00<0o`000?ooo`3oool00P3oool30000o`D0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool010000?l0oooo0?ooo`3oool20000o`L0
oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`0E0?ooo`80
003o2`3oool00`000?l0oooo0?ooo`0[0?ooo`030000o`3oool0oooo00T0
oooo00<0003o0?ooo`3oool0403oool20?l000/0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`080?ooo`<0
o`004P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00D0
oooo001Z0?ooo`030000o`3oool0oooo00X0oooo0P3o00000`3oool0003o
0?ooo`0?0?ooo`80003o00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0<0?ooo`030000o`3o0000003o0140oooo00<0003o0?l0003o0000
303oool20000odH0oooo00<0003o0?ooo`3oool02P3oool20000oa80oooo
0P3o000=0?ooo`030?l0003oool0oooo0080003o203oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00H0o`0000<0003o0?l0003o0000
0`3o00030?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
0`3oool30000o`@0oooo00<0o`000?ooo`3oool02P3oool20?l001<0oooo
0P000?l<0?ooo`030000o`3oool0oooo02`0oooo00<0003o0?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0=0?ooo`80o`003@3oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo00T0oooo0`000?l00`3o0000003o
0000o`030000o`T0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0<0?ooo`80o`003`3oool00`000?l0oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00D0oooo001Y0?ooo`030000o`3oool0oooo00T0oooo0P3o
00030?ooo`030000o`3oool0oooo00X0oooo10000?l20?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0000
o`030000o`d0oooo00<0003o0?ooo`3oool00P3o000<0?ooo`030000o`3o
ool0oooo04<0oooo00<0003o0?ooo`3oool0303oool20000o`l0oooo00<0
o`000?ooo`3oool03P3oool00`3o0000003o0?ooo`090?ooo`030000o`3o
ool0oooo00D0oooo1@3o00060?ooo`030000o`3oool0oooo00<0oooo1P3o
00060?ooo`030000o`3oool0oooo00L0oooo0`000?l00`3o0000oooo0?oo
o`0=0?ooo`80o`003`3oool20000o`h0oooo00<0003o0?ooo`3oool0;03o
ool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo0P3o
000@0?ooo`030?l0003oool0oooo00d0oooo3@000?l30?ooo`030?l0003o
ool0oooo00<0oooo2P000?l@0?ooo`030?l0003oool0oooo00h0oooo0P3o
000<0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool01@3o
ool006P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00L0oooo0P000?l70?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`04
0?ooo`80003o2P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0o`000?ooo`0;0?ooo`030000o`3oool0o`0000@0o`000`3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00@0o`00
0?ooo`3oool0oooo0`3o00030?ooo`030000o`3oool0oooo00X0oooo00<0
o`000000o`000?l03`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00d0oooo00<0003o0?ooo`3oool0;@3oool00`000?l0oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00P0oooo0P3o000B0?ooo`030?l0003o
ool0oooo00T0oooo10000?l00`3oool0003o0?ooo`0=0?ooo`030?l0003o
ool0oooo00`0oooo1P000?l;0?ooo`030?l0003oool0oooo0100oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00D0oooo001W0?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`<0003o2@3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool01P3oool30000o`L0oooo00<0003o0?ooo`3oool0103oool2
0?l000/0oooo00<0003o0?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0=
0?ooo`80003o2P3oool00`3o0000oooo0?ooo`0=0?ooo`80003o00<0oooo
0?l0003oool02P3oool00`3o0000003o0?l000080?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`<0o`0000<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`02
0000o`h0oooo00<0o`000?ooo`3oool0203oool20000o`l0oooo00<0003o
0?ooo`3oool0;P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo0?ooo`04
0?ooo`D0003o1@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool00`3oool40000o`L0oooo00<0o`00
0?ooo`3oool04@3oool20?l000P0oooo00<0003o0?ooo`3oool0303oool0
0`000?l0oooo0?ooo`050?ooo`00IP3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00L0oooo00@0003o0?ooo`3oool0oooo0P000?l<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`090?ooo`80003o103oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0@P3oool0
0`000?l0oooo0?ooo`0?0?ooo`80003o1`3oool00`3o0000oooo0?ooo`0<
0?ooo`80003o103oool00`3o0000oooo0?ooo`060?ooo`80o`000P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0
o`000?l000T0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00D0oooo0P000?lA0?ooo`030000o`3o
ool0oooo02h0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?oo
o`030?ooo`80o`005P3oool00`3o0000oooo0000o`030000o`/0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00P0oooo1@000?l00`3oool0o`000?ooo`0E0?ooo`80o`001@3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00D0oooo001U
0?ooo`030?l0003oool0oooo00P0oooo0P3o000;0?ooo`<0003o3P3oool0
0`3o0000oooo0?ooo`090?ooo`<0o`0000@0003o0?l0003o0000o`002`3o
ool00`3o0000oooo0?ooo`0;0?ooo`80003o00<0oooo0000o`3oool02P3o
ool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo0480oooo00<0
003o0?ooo`3oool0403oool20000o`@0oooo00<0o`000?ooo`3oool02`3o
ool20000o`H0oooo00<0o`000?ooo`3oool0103oool20?l000@0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0000o`0<0000o`030?ooo`3o
0000oooo00L0oooo00@0003o0?ooo`3oool0oooo0`3o00060?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`020?ooo`80003o4P3oool00`000?l0oooo0?ooo`0_0?ooo`030000
o`3oool0oooo00h0oooo00D0003o0?ooo`3oool0oooo0?l0000G0?ooo`03
0000o`3o0000003o00l0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00d0oooo00@0003o0?l00000
0?l0003o5P3oool01@3o0000oooo0?ooo`3oool0003o0100oooo00<0003o
0?ooo`3oool01@3oool006@0oooo00<0003o0?ooo`3o0000203oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool00`3oool60?l000<0oooo00@0003o0?ooo`3oool0oooo1P3o0005
0?ooo`030?l0003oool0oooo00d0oooo0P000?l<0?ooo`80o`00203oool0
0`3o0000oooo0000o`130?ooo`030000o`3oool0oooo0180oooo00@0003o
0?ooo`3oool0o`003@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00<0o`001P3oool00`000?l0oooo0?ooo`040?ooo`80003o00<0
o`000000o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`040000o`3o
0000003o0000o`D0oooo00<0003o0?ooo`3oool01@3oool20?l000<0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0<0?ooo`040?l0
003oool0oooo0000oa@0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0
oooo0?ooo`0?0?ooo`030000o`3oool0o`0001H0oooo0P000?l00`3oool0
o`000?ooo`0?0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00<0
003o503oool00`3o0000oooo0000o`0A0?ooo`030000o`3oool0oooo00D0
oooo001S0?ooo`050000o`3oool0oooo0?ooo`3o00001P3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0003o00l0oooo1P3o00090?ooo`03
0000o`3oool0oooo00L0oooo1P3o000?0?ooo`040000o`3oool0003o0000
o``0oooo00<0o`000?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0
003o04<0oooo00<0003o0?ooo`3oool04P3oool20000o`d0oooo00<0003o
0?ooo`3oool02@3oool20?l000T0oooo00@0003o0?ooo`3oool0oooo0`00
0?l20?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`030000o`80oooo00<0003o0?ooo`3oool01`3o
ool30?l000X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000003o0000
o`0D0?ooo`030000o`3oool0oooo0300oooo00<0003o0?ooo`3oool0403o
ool20000oa@0oooo0P000?l30?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool0103oool20000oa<0oooo00<0
003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`050?ooo`00HP3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool02P3oool20000o`80oooo00<0003o0?ooo`3oool02`3oool3
0?l000h0oooo00<0003o0?ooo`3oool0303oool40?l000/0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`11
0?ooo`030000o`3oool0oooo0180oooo00<0o`000000o`000?l02P3oool0
0`000?l0oooo0?ooo`080?ooo`<0o`002P3oool40000o`D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo0`000?l:0?ooo`<0o`002P3oool20000o`X0oooo0P000?lE
0?ooo`030000o`3oool0oooo0340oooo00<0003o0?ooo`3oool03`3oool0
103o0000oooo0?ooo`000?lA0?ooo`80003o1P3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo01L0o`000P3oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo00H0oooo0P000?l@0?ooo`030000o`3o
ool0o`000140oooo00<0003o0?ooo`3oool01@3oool00640oooo00<0003o
0?ooo`3oool01@3oool0103o0000oooo0?ooo`3o000<0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool30?l000<0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo0080oooo0P3o00090?ooo`030000o`3oool0oooo00<0oooo0P00
0?l;0?ooo`040?l0003oool0oooo0?l000L0oooo00<0003o0?ooo`3oool0
@03oool00`000?l0oooo0?ooo`0A0?ooo`050?l0003oool0oooo0?ooo`00
0?l02@3oool00`000?l0oooo0?ooo`070?ooo`050?l0003oool0oooo0?oo
o`3o0000203oool30000o`P0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo0`000?l80?oo
o`040?l0003oool0oooo0?l000/0oooo00<0003o0?ooo`3oool01P3oool0
10000?l0oooo0?ooo`3o000D0?ooo`030000o`3oool0oooo0340oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00/0oooo0`000?l80?ooo`030?l0003oool0oooo00T0oooo103o
00000`000?l0o`000?l0000;0?ooo`030?l0003oool0oooo00T0oooo0P3o
00000`000?l0o`000?l000020?l000/0oooo00<0o`000?ooo`3oool0203o
ool20000o`d0oooo00D0003o0?ooo`3oool0oooo0?l0000@0?ooo`030000
o`3oool0oooo00D0oooo001P0?ooo`030000o`3oool0oooo00L0oooo0P3o
000;0?ooo`80003o1`3oool00`000?l0oooo0?ooo`030?ooo`<0o`001P3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0103oool20?l000H0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`090?ooo`80o`002@3oool00`000?l0oooo0?oo
o`100?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool00P3o
ool20000o`H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo0P000?l20?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool0103o00000`000?l0o`000?l0
00020?l00080oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?oo
o`3oool20000o`D0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00@0oooo0P000?l30?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool0<P3oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
203oool20000o``0oooo00<0o`000?ooo`3oool01@3oool30?l000D0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00<0oooo0`3o00070?ooo`030?l0003oool0oooo00/0oooo
0P000?l:0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`050?ooo`00G`3oool00`000?l0oooo0?oo
o`080?ooo`80o`002P3oool00`000?l0oooo0?ooo`070?ooo`040000o`3o
ool0oooo0?ooo`80o`002@3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool01P3oool20?l000@0oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`80o`00
2@3oool00`000?l0oooo0?ooo`100?ooo`030000o`3oool0oooo0100oooo
00<0o`000?ooo`3oool0103oool20000o`<0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080003o
1@3oool00`000?l0oooo0?ooo`030?ooo`D0o`00103oool00`000?l0oooo
0?ooo`020?ooo`@0o`001P3oool00`000?l0oooo0?ooo`030?ooo`80003o
0P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00P0oooo
00@0003o0?ooo`3oool0oooo0P000?l60?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool0<P3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool20000o`h0
oooo00<0o`000?ooo`3oool00P3oool30?l000P0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00H0
oooo0`3o00040?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool01@3oool20000o`H0oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`050?ooo`00GP3oool00`000?l0oooo0?ooo`080?ooo`040?l0
003oool0oooo0?l000P0oooo00<0003o0?ooo`3oool02@3oool00`000?l0
o`000?l0000<0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`090?ooo`80o`0000<0oooo0000o`3o
ool02P3oool20000o`L0oooo00@0o`000?ooo`3oool0o`002@3oool00`00
0?l0oooo0?ooo`100?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool01P3oool30000o`X0oooo00<0o`000?ooo`3oool01P3oool00`3o
0000003o0?ooo`060?ooo`040000o`3oool0oooo0?ooo`80o`000P3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0103o00000`3oool0003o0?ooo`070?ooo`030000o`3o0000
oooo00L0oooo00<0o`000?ooo`3oool01`3oool010000?l0oooo0000o`00
0?l80?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0<`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0?0?ooo`040?l0003o
ool0o`000?l000/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo0P3o00000`3oool0o`00
0?ooo`0@0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00D0oooo
001N0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`030?ooo`80003o2`3oool00`3o0000003o0?oo
o`0=0?ooo`030?l0003oool0oooo00L0oooo1`000?l90?ooo`030?l0003o
ool0oooo00/0oooo00<0o`000000o`3oool0303oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`0o0?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool0203oool30000o`P0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?l000080?ooo`030000o`3o0000o`0000D0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000000o`3oool01`3oool00`3o0000003o0?oo
o`080?ooo`030?l0003oool0oooo00H0oooo0P000?l:0?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3oool0<`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00P0oooo00D0003o0?ooo`3oool0oooo
0000o`0B0?ooo`80o`003@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool30?l00140oooo
00D0003o0?ooo`3oool0oooo0000o`0:0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool01@3oool005d0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`040?ooo`050?l0003oool0oooo0?ooo`00
0?l02`3oool20?l00080oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`070000o`<0oooo00@0003o0?ooo`3oool0oooo1`000?l20?oo
o`030?l0003oool0oooo00/0oooo00@0003o0?ooo`3o0000o`00303oool0
1@000?l0oooo0?ooo`3oool0o`0000H0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`0o0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`020000o`H0oooo00<0
o`000?ooo`3oool01@3oool010000?l0oooo0?ooo`3o00060?ooo`80o`00
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?l000060?ooo`030?l0003oool0oooo0080003o203oool00`3o0000oooo
0?ooo`030?ooo`80003o00<0oooo0000o`3oool02P3oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo03@0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0003o0140oooo
0`3o000>0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080o`00
403oool00`000?l0oooo0000o`0<0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool01@3oool005`0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0003o00/0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`80003o00<0
o`000000o`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3o
0000003o00d0oooo00D0003o0?ooo`3oool0oooo0?l0000<0?ooo`030000
o`3oool0o`0000P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`100?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`040?l0
003oool0oooo0?ooo`80o`000`3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo0080o`00103oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00D0o`000?ooo`3o
ool0oooo0000o`040?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0e0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0?0?oo
o`050?l0003oool0oooo0?ooo`3o00003@3oool00`000?l0oooo0?ooo`05
0?ooo`D0003o00<0o`000000o`000?l00`000?l70?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool00P3oool20?l000l0oooo0P000?l<
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool01@3oool0
05/0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?oo
o`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`070?ooo`80003o0P3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`000?l00P000?l90?oo
o`030000o`3oool0oooo00<0oooo0P3o000;0?ooo`030?l0003oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0o0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`040?ooo`80003o00<0oooo0?l0003oool01P3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0o`0000D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000003o0000o`090000o`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`3o0006
0?ooo`030000o`3oool0oooo00D0oooo00@0o`000?ooo`000?l0003o1@3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0=@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`000?l03P3oool20?l000@0oooo00<0
o`000?ooo`3oool02`3oool80000o`D0oooo00<0o`000?ooo`3oool00`3o
ool60000o`030?ooo`000?l0oooo00`0oooo00<0o`000?ooo`3oool0103o
ool20?l000d0oooo0P000?l=0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool01@3oool005/0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0o`0000T0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`80003o103oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool00P3oool30000o`H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`070?ooo`030?l000000?l0oooo00T0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0o0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0003o00@0003o00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0
003o0000o`<0oooo00<0003o0?ooo`3oool0103oool20?l000P0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0f0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3o
ool01@000?l0oooo0?ooo`3oool0003o00/0oooo0P3o00070?ooo`030?l0
003oool0oooo00P0oooo10000?l;0?ooo`030?l0003oool0oooo00T0oooo
0`000?l<0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
2@3oool010000?l0oooo0?ooo`000?l<0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool01@3oool005X0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`3o
00001`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo0080
oooo0P000?l70?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`060?ooo`80003o0`3oool00`000?l0
oooo0?ooo`070?ooo`80o`001P3oool0103o0000oooo0?ooo`000?l:0?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0?P3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0000o`020000o`<0oooo00<0003o0?oo
o`3oool01P3oool20?l000L0oooo0P000?l50?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`3oool3
0000o`L0oooo0`3o00070?ooo`030000o`3oool0oooo0080oooo0`000?l0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0f0?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00H0oooo0P3o00090?ooo`030?l0003oool0
oooo00@0oooo10000?l30?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`030000o`P0oooo00<0o`00
0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00D0oooo001I0?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool02@3oool01000
0?l0oooo0000o`000?l90?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`<0003o303oool0
0`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo03l0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool2
0000o`030?ooo`000?l0oooo00H0oooo00@0o`000?ooo`3oool0o`001P3o
ool20000o`D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`000?l0003o
103oool01@3o0000oooo0?ooo`3oool0o`0000L0oooo00@0003o0?ooo`00
0?l0003o103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0g0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool02P3oool0103o0000oooo0?ooo`3oool20000o`L0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00<0oooo0`000?l50?ooo`030?l0003oool0oooo00T0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`05
0?ooo`00F@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool0
o`0000`0oooo0P000?l;0?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`80003o303oool0
103o0000oooo0?ooo`3o00060?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0n0?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`020?ooo`040?l0003oool0oooo0?ooo`80003o
0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0g0?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool02`3oool0103o0000
oooo0000o`000?l:0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`070?ooo`<0003o00<0oooo0?l0
003oool0303oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00D0oooo001H0?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0o`0000/0oooo0P000?l00`3oool0003o0?ooo`0:0?ooo`03
0?l0003oool0oooo00@0oooo103o00000`000?l0o`000?l000020?l000D0
oooo00<0o`000?ooo`3oool02P3oool010000?l0oooo0?ooo`000?l<0?oo
o`80o`00203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo0P000?m00?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00@0003o0?ooo`000?l0003o1@3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0003o00@0oooo00<0003o0?ooo`3oool00P3oool5
0?l000030000o`3o0000o`000080o`00103oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0o`0000H0oooo00<0o`000?ooo`3oool00P3oool3
0000o`H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0>03oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?l000h0oooo00<0003o
0?l0003oool02`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02P3oool00`000?l0o`000?ooo`0=
0?ooo`80o`000P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`05
0?ooo`00F03oool30000o`H0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00D0003o0?oo
o`3oool0oooo0000o`0<0?ooo`H0o`00103oool00`000?l0oooo0?ooo`02
0?ooo`@0o`0000<0oooo0?l0003oool02`3oool01@000?l0oooo0?ooo`3o
ool0003o00/0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00@0oooo0`000?m10?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool0oooo
0P000?l20?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?l000<0oooo00@0003o0?ooo`3oool0
oooo0P3o00030?ooo`030000o`3oool0oooo00@0oooo00<0o`000000o`3o
ool01@3oool00`3o0000oooo0?ooo`020000o`<0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0i0?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`080?ooo`030000o`3o0000oooo00d0oooo0P000?l00`3oool0
o`000?ooo`0;0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0:0?ooo`040?l0003oool0003o0000
o`h0oooo00<0o`000000o`3oool02@3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01@3oool005L0
oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01`3oool30?l000X0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`080?ooo`80o`002@3oool00`00
0?l0oooo0?ooo`060?ooo`D0o`00203oool00`000?l0oooo0?ooo`030?oo
o`80003o203oool00`3o0000oooo0?l000090?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`000?m1
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0o`000?ooo`060?ooo`030000o`3oool0
o`0000D0oooo00<0003o0?l0003o00000P3oool01@3o0000oooo0?ooo`3o
ool0003o00<0oooo00D0o`000?ooo`3o0000o`000000o`060?ooo`040?l0
003oool0oooo0000o`H0oooo00<0o`000000o`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo03T0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000000o`000?l02`3oool20000o`@0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`030?ooo`X0
o`001@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool02P3oool20000o`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00D0oooo001G0?ooo`030000o`3oool0oooo0080oooo
0P000?l20?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1P3oool01@3o0000oooo0?ooo`3oool0o`0000L0oooo0P000?l60?ooo`03
0000o`3oool0oooo00D0oooo0`3o00000`3oool0o`000?ooo`080?ooo`03
0000o`3oool0oooo00L0oooo00@0o`000?ooo`3oool0oooo0P3o00060?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool01@3o
0000oooo0?ooo`3oool0o`0000T0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`020000o`@0oooo00<0003o0?ooo`3oool0?`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3o
ool0o`0000<0oooo0P3o00001@000?l0oooo0?ooo`3oool0o`0000<0oooo
00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3o0000oooo0080
oooo0P3o00030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo03X0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00D0o`000?ooo`3o
ool0oooo0000o`090?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool02@3oool00`3o0000003o0?l000040?l000@0oooo00<0o`000?oo
o`3oool00`3oool50?l000030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool00`3oool20000o`T0oooo00D0003o0?ooo`3oool0oooo0?l0000;
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`050?ooo`00EP3oool00`000?l0oooo0?ooo`050?oo
o`80003o2@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00<0oooo0P3o00040?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool00P3oool20?l000D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo0P3o00030?oo
o`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01`3oool20000o`H0oooo00<0003o0?ooo`3oool0?`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00@0o`000?ooo`000?l0003o0`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0o`000080oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool00`000?l0oooo
0?ooo`030?l000H0oooo00@0003o0?ooo`3oool0oooo0P000?l00`3oool0
o`000?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool0>P3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`050?ooo`<0o`0000<0oooo0000o`3o
ool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3o0000o`0000P0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool01@3oool005H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000003o
0000o`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool0103o0000oooo0?ooo`000?l:0?ooo`030000o`3oool0o`000080
o`001`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool20?l000030?ooo`000?l0oooo00T0
oooo00@0003o0?ooo`3oool0o`001`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00@0oooo0P000?l00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo03l0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`040?l0003oool0oooo
0?ooo`<0003o1`3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`3o00000P3oool010000?l0oooo0?ooo`3o00030?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool0103oool010000?l0oooo
0000o`000?l30?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0k0?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`080?ooo`040?l0003oool0oooo0?oo
o`<0o`00103oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00@0003o0?ooo`3oool0oooo0`3o00050?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo001F0?oo
o`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3oool0oooo0P000?l4
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0
0`3o0000003o0?ooo`0:0?ooo`030?l000000?l0oooo00T0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?l0003oool02P3oool00`000?l0o`000?ooo`08
0?ooo`030?l0003oool0oooo00L0oooo00@0003o0?ooo`3oool0oooo0P00
0?l30?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0?`3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool20000o`D0oooo00<0
o`000?ooo`3o00000`3oool01@000?l0oooo0?ooo`000?l0o`0000D0003o
00@0o`000?ooo`3oool0003o103oool00`3o0000oooo0?l000050?ooo`80
003o1P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0>`3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`060?ooo`050000o`3oool0oooo0?oo
o`000?l02`3oool0103o0000oooo0?l0003o00070?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`04
0?ooo`80o`000P3oool00`3o0000oooo0?ooo`090?ooo`80003o0P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00D0oooo001E0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool00`3oool010000?l0oooo0?ooo`000?l80?ooo`030?l0003oool0
oooo00L0oooo0P000?l00`3o0000oooo0?ooo`070?ooo`80o`000P3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0
oooo0?l000X0oooo00<0o`000000o`3oool0203oool00`3o0000oooo0?oo
o`070?ooo`040000o`3oool0oooo0000o`D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`0o0?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo0080003o0P3oool01@3o0000oooo
0?ooo`3oool0o`0000<0oooo0P000?l0203oool0o`000?ooo`3oool0003o
0?ooo`3o0000oooo0`000?l30?ooo`050?l0003oool0oooo0?ooo`3o0000
0P3oool20000o`80oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool0?03oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0003o00`0oooo0P3o00090?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`060?ooo`<0o`003@3oool20000o`T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool005D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`<0003o1`3oool00`3o0000oooo0?oo
o`070?ooo`050000o`3oool0oooo0?ooo`3o00001`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
0`3oool70000o`D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00@0o`000?ooo`3oool0
003o2@3oool00`3o0000oooo0?ooo`070?ooo`80003o1`3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo0400oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`/0o`000`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0o`000?ooo`040?ooo`040?l0003oool0003o0000
o`<0oooo00D0o`000?ooo`000?l0oooo0?l000020?ooo`050000o`3oool0
003o0?ooo`3o0000103oool00`3o0000003o0000o`040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?oo
o`3oool;0?l000D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`0m0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?l000090?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`070?ooo`<0o`003@3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo001D0?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool20000o`L0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`060?ooo`030?l000000?l0003o00<0003o0`3oool010000?l0oooo0?oo
o`3oool50000o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
0`3oool20?l000D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00D0oooo0P000?l80?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0?`3oool00`000?l0oooo
0?ooo`050?ooo`L0o`0000<0oooo0000o`3oool0103oool0103o0000oooo
0?ooo`3oool50?l000@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`80003o1@3oool0103o0000oooo0?ooo`000?l20?oo
o`050?l0003oool0003o0?ooo`3o00000P3oool010000?l0oooo0?ooo`3o
00050?ooo`030000o`3o0000oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`H0o`000P3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0o`0000D0o`00203oool00`000?l0oooo0?oo
o`0m0?ooo`030000o`3o0000o`0000@0o`000P3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool02@3o
ool20000o`030?ooo`000?l0oooo00P0oooo0P3o00030?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00P3o
000:0?ooo`030000o`3oool0003o00X0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`070?ooo`040?l0003oool0oooo0?ooo`D0o`00
00<0003o0?ooo`3oool01@3oool005@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0080003o103o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00D0
o`000?ooo`3oool0oooo0?l000080?ooo`030000o`3oool0oooo00<0oooo
0P000?l00`3oool0o`000?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00@0o`000000o`000?l0003o1@3oool00`000?l0oooo0?ooo`060?ooo`05
0?l0003oool0oooo0?ooo`3o00001P3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo0080oooo0P000?l20?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`100?oo
o`030000o`3oool0oooo0080oooo103o00060?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?l000040?l0
00D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020000
o`80oooo00D0003o0?ooo`3o0000oooo0000o`020?ooo`070?l0003oool0
003o0?ooo`3o0000oooo0000o`020?ooo`030?l0003oool0003o0080oooo
0P000?l20?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
0`3oool40?l00080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo0`3o00050?ooo`030000
o`3oool0oooo03h0oooo00<0003o0?ooo`3oool0103oool60?l000D0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
0P3oool40000o`040?l000000?l0003o0000o`D0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00D0
oooo0P000?l30?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`030?ooo`L0o`001@3oool00`000?l0
oooo0?ooo`050?ooo`00E03oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool20000o`030?oo
o`3o0000oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?l000090?ooo`040000o`3oool0oooo0?ooo`80003o0`3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3o
ool0oooo0`000?l20?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3o0000203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
0080003o103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0@03oool00`000?l0oooo0?ooo`020?l0
00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool60?l0
00030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool20000
o`<0oooo00@0o`000?ooo`000?l0oooo0P3o00001`000?l0o`000?ooo`3o
ool0003o0?ooo`3o00000`3oool20000o`@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0o`000?l000040?l000D0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00@0o`000?ooo`3oool0oooo0`3o00020?ooo`030000o`3oool0oooo03h0
oooo00<0003o0?ooo`3oool01P3oool0103o0000oooo0?ooo`3oool40?l0
00030?ooo`000?l0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`D0003o103oool0103o
0000oooo0?ooo`3oool60000o`P0oooo00<0o`000?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00<0o`000`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo001C0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o0000oooo
00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0003o00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo0P000?l;0?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000003o0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`100?ooo`030000o`3o0000oooo
00D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`80o`001@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo1@3o00000`3oool0o`000?ooo`040?ooo`<0003o0P3oool00`3o
0000oooo0000o`020?l000060000o`3o0000o`000000o`3oool0o`000P3o
ool30000o`D0oooo00<0o`000?ooo`3o0000103o00050?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool00`3o0000003o0?ooo`100?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool20?l000P0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080o`00203o
ool00`3o0000oooo0?ooo`040?ooo`80003o00<0oooo0000o`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`<0003o1`3oool00`3o0000oooo0?oo
o`060?ooo`80o`000P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool30?l000H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`00D`3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000003o0000o`070?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3o00002P3oool20000o`L0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00H0oooo0P000?l90?ooo`030?l0003oool0o`0000T0oooo00<0003o
0?ooo`3oool01@3oool20000o`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo0440oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P000?l4
0?ooo`@0o`000P3oool010000?l0oooo0?ooo`3oool20000o`0;0?ooo`3o
0000oooo0000o`3o0000003o0?l000000?l0oooo0?l0003oool00P000?l2
0?ooo`80003o00<0oooo0?l0003o00000`3o00040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0400oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0
o`000?l000D0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`070?ooo`030000o`3o0000oooo00X0oooo00@0o`000?ooo`3oool0oooo
0P000?l30?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`030000o`<0oooo00<0o`000?ooo`3oool0
2@3oool00`3o0000003o0?ooo`080?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0103oool20?l000030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`00DP3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020000o`@0oooo00<0
003o0?ooo`3oool0203oool0103o0000oooo0?ooo`3o00070?ooo`80003o
00<0oooo0000o`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo
0?ooo`000?l70?ooo`050?l0003oool0oooo0?ooo`3o00002@3oool00`00
0?l0oooo0?ooo`020?ooo`80003o0P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`100?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool20?l000@0oooo00<0003o0?oo
o`3oool00`3oool0103o0000oooo0?ooo`3oool30?l000D0oooo00D0003o
0?ooo`3o0000003o0?l000020000o`040?ooo`3o0000oooo0000o`D0oooo
0P3o00040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0@03oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00@0003o0?ooo`3oool0
oooo0`3o00020?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000003o0?ooo`0;0?ooo`030?l000000?l0003o00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00<0oooo0`000?l00`3o0000oooo0?ooo`090?ooo`03
0000o`3o0000oooo00P0oooo00<0003o0?ooo`3oool01`3oool0103o0000
oooo0?ooo`3oool30?l000<0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo001B0?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo0P000?l00`3oool0
003o0?ooo`090?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool20000o`@0
oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`04
0000o`3oool0003o0000o`D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0@@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0
003o00000P3o0000103oool0o`000000o`3oool20?l00080003o00D0o`00
0?ooo`000?l0o`000?ooo`040?l000030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`110?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`<0o`00203o
ool00`000?l0oooo0?ooo`080?ooo`040?l0003oool0oooo0000o`X0oooo
00<0003o0?l0003oool01`3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000003o
0?ooo`090?ooo`040000o`3oool0oooo0?l000T0oooo00<0003o0?ooo`3o
ool01`3oool30?l000H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo001B0?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00D0oooo0P000?l90?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00@0o`000?ooo`3oool0
oooo0`3o000010000?l0o`000?l0003o00020?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0
o`0000D0oooo00<0o`000?ooo`3oool01`3oool20000o`L0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0@@3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00P3oool30?l00080003o00<0o`00
0000o`3o00000P000?l30?l000@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo0440oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00@0o`00
0?ooo`3o0000o`001P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool01@3oool20000o`80oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool0103o0000oooo0000
o`000?l70?ooo`050000o`3oool0oooo0?ooo`3o00002@3oool00`000?l0
oooo0?ooo`050?ooo`<0o`002@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00540oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool010000?l0oooo
0000o`000?l60?ooo`030?l0003oool0oooo00D0oooo00@0o`000?ooo`3o
ool0003o1`3oool00`000?l0oooo0?ooo`040?ooo`<0o`000`3oool01000
0?l0oooo0?ooo`3oool50?l000@0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?l000070?ooo`030?l0003oool0oooo00@0oooo0P000?l0
0`3oool0003o0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo0440oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`80o`0000<0oooo0000o`000?l0<`000?l0
0`3oool0o`000?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0@P3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
103o0000oooo0?ooo`3oool20?l000<0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool00P3oool20?l000<0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00540oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool010000?l0oooo0?ooo`3oool20000o`<0oooo00<0
o`000?ooo`3oool01`3oool20?l000P0oooo00@0003o0?ooo`3oool0oooo
103o00050?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0
o`000`3oool00`000?l0oooo0?ooo`060?ooo`80o`002@3oool0103o0000
oooo0?ooo`3oool20000o`<0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`110?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`040?l0003oool0oooo0?ooo`X0003o0`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool6
0?l000030000o`3o0000003o00@0o`00103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00@0003o0?ooo`3oool0oooo2P00
0?l30?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0480oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool30?l000030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`<0o`00103oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00<0oooo0P000?l30?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`020?l000D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00500oooo0P3o00070?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00@0oooo0P000?l00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
o`0000P0oooo00<0003o0?l0003o00000`3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0oooo0P3o
00000`000?l0oooo0?ooo`060?ooo`040?l0003oool0oooo0000o`T0oooo
00<0o`000000o`000?l01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`80o`00@`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool40000o`80oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool010000?l0oooo
0?ooo`3oool30?l00080003o00<0o`000000o`000?l00P3o00020000o`<0
o`000`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00@0003o103oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0@`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o0000o`0000L0
oooo00<0o`000?ooo`3oool01P3oool010000?l0oooo0000o`000?l70?oo
o`030?l0003oool0oooo00@0oooo00<0o`000000o`3o00002P3o00000`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`000?l0203oool00`3o0000oooo0?ooo`050?ooo`<0o`00203oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`00D03oool00`000?l0
oooo0?l000020?l000<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`070?ooo`050000o`3oool0oooo0?oo
o`3o00001@3oool20?l000030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?l0003oool01@3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool0103o0000oooo0?ooo`3oool30?l000030?ooo`000?l0
oooo04<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo0080003o00<0oooo0?l0003oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`D0o`000P3oool0
2`000?l0oooo0?l000000?l0o`000000o`3o0000oooo0?l0003oool0003o
0080oooo1@3o00040?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo00H0o`000?ooo`000?l0003o0?ooo`000?l50?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool0A03oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0080o`001@3o
ool00`3o0000oooo0?ooo`070?ooo`80003o2@3oool00`3o0000oooo0?oo
o`030?l000030?ooo`000?l0oooo00@0oooo00<0o`000?ooo`3oool00`3o
ool010000?l0o`000?l0003o00030?ooo`030?l0003oool0oooo00L0oooo
0P000?l90?ooo`030?l0003oool0oooo00<0oooo0P3o00020?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00500oooo00<0003o0?ooo`3oool00P3oool40?l000L0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`000?l01`3oool00`000?l0oooo0?oo
o`030?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080o`00
0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3o0000203oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool40?l000@0oooo
00<0003o0?ooo`3oool0@P3oool00`000?l0oooo0?ooo`030?ooo`040?l0
003oool0oooo0?ooo`@0003o0`3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`020?ooo`D0o`0000<0oooo0000o`3oool00`3oool03@000?l0
oooo0?l0003oool0003o0?l000000?l0o`000000o`3oool0o`000?ooo`00
0?l0103oool00`000?l0oooo0?l000040?l000@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00@0o`000?ooo`3oool0oooo10000?l30?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool0A03oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00D0o`000?oo
o`3oool0oooo0?l000090?ooo`040000o`3oool0oooo0000o`P0oooo0`3o
00040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool010000?l0oooo0?ooo`3oool20?l000030?ooo`3o0000oooo00L0oooo
00@0003o0?ooo`3oool0003o2@3oool01@3o0000oooo0?ooo`3oool0o`00
00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`00D03oool00`000?l0oooo0?ooo`050?ooo`@0
o`00103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020000o`@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?l000040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?l000070?ooo`030000o`3oool0oooo0080
oooo0P000?l30?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0080
oooo103o00080?ooo`030000o`3oool0oooo0480oooo00<0003o0?ooo`3o
ool00P3oool0103o0000oooo0000o`000?l20?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103o00050?oo
o`080000o`3oool0003o0000o`3oool0o`000?ooo`000?l20?l000070000
o`3o0000o`000000o`3oool0o`000?ooo`020000o`030?ooo`000?l0oooo
00@0oooo0`3o00030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00P000?l00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo04D0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`80o`0000<0oooo0?l0
003oool0203oool01@000?l0oooo0?ooo`3oool0003o00L0oooo0P3o0006
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`040?ooo`80o`001`3oool01@000?l0oooo0?ooo`3o
ool0003o00X0oooo0`3o00060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool004l0oooo00<0003o
0?ooo`3oool01P3oool0103o0000oooo0?ooo`3oool30?l000030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00<0oooo0P000?l00`3oool0003o0?oo
o`070?ooo`80o`001P3oool00`000?l0oooo0?ooo`030?ooo`050?l0003o
ool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool010000?l0oooo
0000o`000?l50?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0o`000080
o`000`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0480
oooo00<0003o0?ooo`3oool00P3oool20000o`@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool40?l000<0oooo00<0o`000?ooo`3o
ool00`3oool20000o`80oooo00@0o`000?ooo`000?l0oooo0P3o00001`00
0?l0o`000?ooo`3oool0003o0?ooo`3o00000P3oool20000o`D0oooo00<0
o`000?ooo`3oool01@3o00030?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo0P000?l40?ooo`030000o`3oool0oooo04D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`070?ooo`80o`00203oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00@0oooo00@0o`000?ooo`3oool0o`001@3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`020?l000D0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`060?ooo`80o`00203oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
001?0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103o
ool30?l000D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo0P000?l90?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`3o0000003o0000
o`050000o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?l000080?ooo`80003o203oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`3o
ool30?l000L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`130?ooo`060000o`3oool0003o0000o`3oool0o`001@3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00`3oool01P3o0000oooo0?l0003o0000oooo0000o`D0oooo00@0o`00
0?ooo`3oool0oooo0P000?l01P3oool0003o0?ooo`3o0000oooo0000o`80
oooo00L0o`000?ooo`000?l0oooo0?l0003oool0003o0080oooo00@0o`00
0?ooo`000?l0oooo0P000?l30?ooo`030?l0003oool0oooo00<0oooo00H0
003o0?ooo`3o0000o`000?ooo`3o00050?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`06
0?l0003oool0003o0000o`3oool0003oB03oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool00P3o00050?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0o`0000D0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?oo
o`3oool0003o00H0oooo00<0003o0?ooo`3oool00`3oool20?l00080oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo001?0?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`070?l000L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0003o00L0oooo00@0o`000?ooo`3o0000o`00
1@3oool01P000?l0oooo0?ooo`3oool0003o0?l000<0oooo00H0003o0?oo
o`3oool0oooo0?l000000?l30?ooo`030000o`3oool0oooo00<0oooo00D0
o`000?ooo`3oool0oooo0?l000060?ooo`030000o`3oool0003o00P0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`L0o`00
00<0oooo0000o`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo04<0oooo0P000?l40?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00@0o`00103oool00`000?l0oooo0?ooo`030?ooo`030?l0
00000?l0003o00@0oooo00H0o`000?ooo`3oool0003o0?ooo`3o00020?oo
o`030000o`3oool0o`000080oooo00@0003o0?ooo`3oool0o`00103oool2
0000o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool4
0?l00080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool2
0000odP0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo0P3o0002
0?ooo`030000o`3oool0oooo00H0oooo0P000?l20?l000D0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`04
0?ooo`030?l000000?l0003o00L0oooo00@0003o0?ooo`3oool0oooo0P3o
00040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`00C`3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?l000020?l000@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0
oooo0?ooo`80003o103oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo0`000?l20?ooo`040?l0003oool0oooo0000o`80oooo
00<0o`000?ooo`3oool00`000?l50?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool20000o`80oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo
0`3o00000`3oool0o`000?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`140?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0003o0000
0P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool0103o0000oooo0000o`000?l20?ooo`06
0?l0003oool0oooo0000o`3oool0o`000P3oool01@000?l0oooo0000o`3o
ool0o`0000D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo0080o`0000<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`170?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0003o00T0oooo00<0
o`000000o`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?l0003oool0203oool00`000?l0oooo
0?l000070?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`00CP3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`<0o`0000<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00<0oooo0P000?l00`3oool0o`000?ooo`050?ooo`040?l0003o
ool0oooo0?ooo`80003o103oool0103o0000oooo0?ooo`000?l20?ooo`03
0?l0003oool0oooo0080oooo0P000?l30?ooo`030?l0003oool0oooo00@0
oooo00@0o`000?ooo`000?l0003o103oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00D0oooo00@0003o0?l0003o0000o`00103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`140?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`040?l0003oool0oooo0?ooo`80o`001@3oool00`3o0000oooo0?oo
o`030?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0?l000030?ooo`05
0?l0003oool0oooo0?ooo`000?l00P3oool01P3o0000oooo0?ooo`000?l0
oooo0?l00080oooo0P000?l30?ooo`070?l0003oool0oooo0?ooo`3o0000
oooo0000o`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00`3oool20?l000<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool0B03oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool20?l000P0
oooo00@0o`000?ooo`3oool0003o1P3oool00`3o0000oooo0?ooo`020?oo
o`@0003o00<0o`000000o`000?l00`000?l30?ooo`030?l0003oool0oooo
00@0oooo00@0003o0?ooo`3oool0o`00203oool20?l000P0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo001>0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo0`3o00050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool20000o`L0oooo00<0o`000000
o`000?l00P3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00@0003o
0?ooo`3oool0o`000`3oool01P000?l0oooo0?ooo`000?l0oooo0?l000L0
oooo0P000?l70?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool00`3oool30?l000L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0A03oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00P3oool40?l000030?ooo`000?l0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool010000?l0oooo0000o`000?l30?oo
o`030?l0003oool0o`0000<0oooo00D0003o0?ooo`000?l0003o0?l00005
0000o`040?l000000?l0oooo0000o`@0oooo00<0o`000?ooo`3o00000`3o
ool30000o`H0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`040?l000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo04P0oooo3`000?l70?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`060?ooo`040000o`3oool0o`000?l000D0oooo00D0o`000?ooo`3oool0
oooo0000o`060?ooo`030?l0003oool0oooo00<0003o0`3oool00`3o0000
oooo0?ooo`020?ooo`<0003o00<0oooo0?l0003oool01@3oool01@000?l0
oooo0?ooo`3oool0o`0000D0oooo0P3o00000`3oool0003o0?ooo`070?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0003o00`0003o1`3oool004h0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`030?l00080oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`040?l0003oool0003o0000o`D0oooo00<0003o0?l0
003oool00P3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00@0003o
0?ooo`3oool0o`000`3oool01@000?l0oooo0?ooo`3oool0o`0000H0oooo
0P000?l00`3oool0o`000?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool00`3o00020?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0A@3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o0000
0P3o00050?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3oool20000o`H0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool0o`000080oooo00@0003o0?ooo`3oool0o`000`3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo0P000?l40?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool01P3o
0000oooo0?l0003o0000oooo0000o`@0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`190?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool90000o`L0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo0P3o
00030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103o
ool01@3o0000003o0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0
oooo0000o`030?ooo`030?l000000?l0oooo00@0oooo00<0003o0?ooo`3o
ool00P3oool0103o0000oooo0?ooo`3oool20?l000@0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo2P000?l50?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool004h0oooo00<0003o0000000000000`0000020?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo103o00060?ooo`03
0000o`3oool0oooo00H0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`030000o`3oool0o`0000<0oooo00@0003o0?ooo`3oool0o`000P3oool0
10000?l0oooo0?ooo`3o00020?ooo`070000o`3oool0oooo0?ooo`3o0000
oooo0000o`040?ooo`050000o`3oool0oooo0?ooo`3o0000203oool00`00
0?l0oooo0?ooo`040?ooo`@0o`001P3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`030?ooo`80000000<0003o000000000000A@3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo0P3o00030?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`020000o`030?ooo`000?l0oooo00<0oooo0P3o00001@3o
ool0o`000?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000
o`020?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo
0?l000040?ooo`030000o`3oool0oooo0080003o0P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000003o0?ooo`030?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool0B@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0103o0000003o
0000o`000?l40?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`040?ooo`<0o`001P3oool20000o`80
oooo0P000?l01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0o`000?oo
o`3oool0oooo0000o`030?ooo`030?l0003oool0003o0080oooo0P000?l6
0?ooo`<0o`001P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00@0003o0?ooo`3oool0oooo0`000?l00`3oool0o`000?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`00CP3oool010000?l0oooo0?ooo`00
00040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3o00001@3o00080?ooo`030?l0003oool0oooo00<0oooo0P00
0?l00`3oool0003o0?ooo`020?ooo`070?l0003oool0oooo0?ooo`000?l0
oooo0?l000020?ooo`060000o`3oool0oooo0?l0003oool0003o0`3oool0
1P3o0000oooo0?ooo`3oool0003o0?ooo`80003o1@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3o0000o`0000@0o`0000<0oooo0?l0003oool0
1`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo04H0oooo00<0003o0?ooo`3oool00P3oool01P3o0000oooo
0?ooo`3o0000oooo0000o`<0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`030?ooo`80003o103oool010000?l0oooo0?ooo`3o0004
0?ooo`80o`0000D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3o
ool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?l000030?ooo`050?l0
003oool0oooo0?ooo`000?l0103oool20000o`@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o0000o`000080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1:0?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`040?l0003oool0oooo0?ooo`L0003o1@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01P3oool20000o`<0oooo00@0o`000?ooo`3oool0003o0`3oool0
1@3o0000oooo0?ooo`3oool0003o0080oooo00@0o`000?ooo`3oool0oooo
0P000?l80?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`030?ooo`L0003o103oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`00CP3oool010000?l0oooo0?oo
o`0000040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool010000?l0o`000?l0003o00040?ooo`03
0?l0003oool0oooo00H0oooo0P000?l40?ooo`050?l0003oool0oooo0?oo
o`000?l00`3o00001@000?l0o`000?l0003o0000003o00<0oooo00<0o`00
0?ooo`3oool00P3oool20000o`P0oooo00<0o`000?ooo`3oool00P3oool3
0?l000030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo04H0oooo00<0003o0?ooo`3oool00P3oool30?l00080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0
oooo0?ooo`80003o00<0oooo0?l0003oool0103oool00`000?l0oooo0?l0
00050?ooo`030000o`3o0000oooo0080oooo00D0o`000?ooo`3oool0oooo
0000o`030?ooo`060?l0003oool0oooo0?ooo`3o0000003o1@3oool00`3o
0000oooo0000o`050?ooo`040?l0003oool0003o0000o`80oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0o`00103oool00`000?l0oooo0?ooo`1:0?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0oooo0`00
0?l00`3oool0o`000?ooo`070?ooo`030000o`3oool0oooo00H0oooo00@0
o`000?ooo`3o0000o`001P3oool20000o`@0oooo00@0o`000?ooo`3oool0
003o0P3oool0103o0000oooo0?ooo`000?l20?ooo`030?l0003oool0oooo
0080oooo0P000?l60?ooo`80o`0000<0oooo0?l0003oool01`3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0003o0080003o0`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00D0oooo00190?ooo`@0000000D0oooo0000o`3oool0oooo000000040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool010000?l0oooo0?ooo`3oool30?l000030?ooo`3o0000
oooo00L0oooo00@0003o0?ooo`000?l0003o0`3oool0103o0000oooo0?oo
o`000?l20?l000030?ooo`000?l0oooo0080o`0000@0003o0?ooo`3oool0
o`000`3oool20000o`030?ooo`000?l0oooo00L0oooo00<0o`000?ooo`3o
00000P3o00030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo04L0oooo00H0003o0?ooo`3o0000o`000?ooo`3o0004
0?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool30000o`<0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0o`0000<0o`000`3oool010000?l0oooo0?ooo`3oool40?l000030?oo
o`000?l0oooo00D0oooo00<0o`000?ooo`3oool0103oool0103o0000oooo
0?ooo`3oool20000o`D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`060?l0003oool0o`000?l0003oool0003oC@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00@0oooo0`000?l70?ooo`030000o`3oool0oooo00H0oooo00D0o`00
0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0003o00@0oooo00@0
o`000?ooo`3oool0003o0P3oool0103o0000oooo0?ooo`000?l20?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`000?l0103oool01@3o0000
oooo0?ooo`3oool0o`0000P0oooo00<0003o0?ooo`3oool01@3oool30000
o`H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`00CP3oool010000?l0oooo0?ooo`0000040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`<0o`001P3oool00`00
0?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?ooo`80o`0000T0oooo
0000o`3o0000oooo0000o`3oool0o`000000o`3oool00P3o00030?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool30?l000H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0B03oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?oo
o`3oool00P3oool0103o0000oooo0?ooo`3oool20000o`H0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0000o`040?ooo`030000o`3oool0
oooo00<0oooo103o00000`000?l0o`000?l000020?l000D0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?l000040?ooo`030?l0003oool0
oooo00<0oooo0`000?l20?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o04h0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0003o00H0003o203oool00`3o0000oooo0?oo
o`030?ooo`80o`0000<0oooo0000o`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0003o0080oooo00H0o`000?ooo`3oool0003o
0?ooo`3o00040?ooo`040000o`3oool0oooo0000o`80oooo0P3o00050?oo
o`030?l0003oool0oooo00D0oooo20000?l00`3oool0o`000?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool004h0oooo00@0003o0?ooo`0000000000103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?l000030?l0
0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?l0
00090?ooo`000?l0o`000?ooo`000?l0oooo0?l000000?l0oooo0080o`00
0P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0o`00
00<0oooo0?l0003oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000000003o0?ooo`190?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`000080
oooo00@0003o0?ooo`3oool0003o1@3oool00`3o0000oooo0?ooo`020?l0
00<0oooo00@0003o0?ooo`3oool0003o1@3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool0
10000?l0oooo0?ooo`000?l30?ooo`040?l0003oool0oooo0?l000D0oooo
00L0003o0?ooo`3oool0oooo0000o`3oool0o`0000@0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
04`0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo10000?l50?oo
o`030?l0003oool0oooo00D0oooo0P3o00040?ooo`80003o0`3oool00`3o
0000003o0?l000030?l000040000o`3oool0oooo0?l00080oooo0P000?l4
0?ooo`80o`00203oool00`3o0000oooo0?ooo`020?ooo`@0003o1`3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01@3oool004h0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool20?l0
00D0oooo0`3o00060?ooo`80003o0P3oool02@3o0000oooo0000o`3o0000
003o0?l000000?l0oooo0?l000020?ooo`80003o1P3oool30?l000H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`190?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool00`000?l0oooo0?ooo`020?ooo`80003o0`3oool00`000?l0
oooo0?ooo`040?ooo`80o`001P3oool30000o`D0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0
oooo0`000?l50?ooo`030?l0003oool0o`0000D0oooo00<0003o0?ooo`3o
ool00P3oool20000o`@0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`030000o`3oool0oooo04d0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00@0003o0?ooo`3oool0oooo0`000?l00`3oool0o`000?ooo`07
0?ooo`040000o`3oool0o`000?l000@0oooo00<0003o0?ooo`3oool00P3o
00001@000?l0oooo0?l0003oool0003o0080o`000P3oool00`000?l0oooo
0?ooo`020?ooo`80o`0000<0003o0?ooo`3oool01`3oool00`3o0000oooo
0000o`020000o`<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool01@3oool004h0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0o`0000D0o`0000d0oooo0?l000000?l0003o
0?ooo`3o0000003o0?l000000?l0o`000000o`3o0000oooo0080003o203o
00000`3oool0003o0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0B@3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00H0
003o0?ooo`000?l0003o0?ooo`3o00040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool30000o`<0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo0`000?l70?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020000o`030?ooo`000?l0oooo00<0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1=0?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0
oooo10000?l60?ooo`040000o`3oool0oooo0?ooo`80o`000`3oool02P00
0?l0o`000?ooo`3o0000003o0?ooo`3o0000oooo0000o`3oool20?l00004
0000o`3oool0oooo0?ooo`80o`000`3oool00`000?l0oooo0?ooo`040?oo
o`@0003o1`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`050?ooo`00CP3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool30?l000030?ooo`000?l0003o0080
o`000P000?l00`3o0000003o0000o`040?l000L0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo04X0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?oo
o`3o00001@3oool010000?l0oooo0?ooo`3oool20?l000030?ooo`3o0000
oooo00D0oooo00@0003o0?ooo`3oool0003o0P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0003o
0P3oool00`000?l0oooo0?ooo`030?ooo`80o`0000<0oooo0?l0003o0000
0P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
0P000?l30?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
CP3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00<0003o0P3oool00`000?l0oooo
0?ooo`040?ooo`0C0?l0003oool0oooo0?l000000?l0oooo0?l000000?l0
oooo0?l0003oool0003o0?l0003oool0003o0?ooo`3o0000oooo0?l00006
0?ooo`030000o`3oool0oooo00<0003o0P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00D0oooo001>0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0o`000P000?l00`3o
0000003o0?l000020?l000<0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0BP3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0003o103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0o`0000@0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`80003o00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l000000?l0003o
00@0oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`030?l0003oool0
003o00@0oooo00<0o`000?ooo`3oool00`3oool30000o`80oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1>0?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool30000o`L0oooo0P3o00020?ooo`090000o`3oool0
o`000000o`3o0000003o0?ooo`3o0000003o0080oooo0P3o00070?ooo`<0
003o1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo001:0?ooo`@00000
CP000?l00`3o0000003o0000o`1>0000o`@00000B@3oool00`000?l0oooo
0?ooo`020?ooo`030?l000000?l0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
0P3o00000`3oool0003o0?ooo`060?ooo`030?l000000?l0003o00T0003o
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?l000070?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool01P000?l0oooo
0?ooo`3oool0003o0?l000@0oooo00<0003o0?ooo`3oool0C`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo1@000?l30?ooo`<0o`000P3oool01`00
0?l0o`000000o`3o0000003o0?l000000?l00P3oool00`3o0000oooo0?l0
00030?ooo`D0003o203oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo001>
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`040?l0003oool0oooo0?ooo`<0o`0000@0003o0?l000000?l0003o
0P3o00030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo04`0oooo00<0003o0?ooo`000?l0
0P000?l01@3o0000oooo0?ooo`3oool0003o00D0oooo00L0o`000?ooo`3o
ool0oooo0?l0003oool0003o00L0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
o`0000<0oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3o
ool0o`0000<0003o00<0oooo0000o`3oool0D@3oool00`000?l0oooo0?oo
o`030?ooo`80o`001@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`020?ooo`H0003o0P3o00000`3oool0003o0000
o`020?l000040000o`3oool0o`000?l000H0003o103oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool004h0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo103o
00020000o`030?l000000?l0003o0080o`000P000?l40?l000L0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo04`0oooo0P00
0?l30?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool0103o0000oooo0?l0003o00030?ooo`030000o`3oool0oooo00<0oooo
00@0003o0?ooo`3o0000o`001@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool20?l00003
0000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0oooo0P3o00000`3o
ool0o`000?ooo`030?ooo`030000o`3oool0oooo0080oooo00@0o`000?oo
o`3oool0oooo0P000?mB0?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080003o0`3o0006
0000o`80oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool01@3oool004h0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0o`0000L0o`000P000?l02@3o
ool0o`000000o`3o0000003o0?l000000?l0o`000?ooo`020000o`P0o`00
00<0oooo0000o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo04d0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00@0o`000?ooo`3o
ool0oooo0P3o00030?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1A0?oo
o`030000o`3o0000o`0004X0o`000P000?m;0?l000030000o`3oool0oooo
00D0oooo001>0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool20000o`H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`<0o`001P3oool20000o`80
oooo00T0o`000?ooo`000?l0o`000000o`3o0000003o0?ooo`3o00000P3o
ool20000o`H0oooo0`3o00050?ooo`80o`001`3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo0P000?l60?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo04d0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`070000o`3oool0oooo0?ooo`3o0000
oooo0?l000060?ooo`040000o`3oool0oooo0000o`D0oooo0P3o00000`3o
ool0o`000?ooo`060?ooo`030000o`3oool0oooo00@0oooo00@0o`000?oo
o`3oool0o`001@3oool01@000?l0oooo0?ooo`3oool0003o00L0oooo0P3o
00020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`1A0?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`040?l0003oool0oooo0?ooo`<0003o
00@0o`000000o`3o0000o`000P000?l30?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0
oooo001>0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`3o00020?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o00002@3oool0003o
0?l0003oool0003o0?l0003oool0003o0?ooo`020?l00080oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?l00080oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`1>0?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?l000030?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`000?l01`3oool40?l000D0oooo00<0003o
0?ooo`3oool00`3oool40?l000L0oooo00<0003o0?ooo`000?l01`3oool0
1P3o0000oooo0?ooo`3o0000oooo0000o`@0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`1B0?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`@0003o00@0oooo0?l0003oool0
003o0P3o00000`3oool0o`000?ooo`040000o`L0oooo0P000?l70?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool01@3oool004h0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool40?l000D0oooo
00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3oool20?l00009
0?ooo`000?l0o`000?ooo`000?l0oooo0?l000000?l0oooo0080o`000`3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo103o
00060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo04l0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`060?ooo`040?l0003oool0oooo0?ooo`D0o`00
00<0003o0?l0003o00000`3o00020?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`030?l0
003oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`1E0?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`<0
003o00<0o`000?ooo`3oool00P3o00001`3oool0003o0000o`3o0000003o
0?l0003oool00P3o00020?ooo`040?l000000?l0003o0000o`@0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo001>
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0
oooo0?ooo`<0o`0000<0oooo0?l0003oool01`3oool010000?l0oooo0000
o`000?l30?ooo`040?l0003oool0oooo0000o`80o`0000<0oooo0000o`3o
ool00P3o000010000?l0oooo0?ooo`3o00030?ooo`80003o00<0oooo0000
o`3oool01`3oool00`3o0000oooo0?l000020?l000<0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0C`3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080o`0000<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0003o
00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00@0oooo0P000?l00`3oool0003o0?ooo`040?oo
o`030?l0003oool0oooo0080oooo00@0003o0?ooo`3o0000o`000P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo05<0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0003o0080003o103oool2
0?l0000;0?ooo`000?l0003o0?l000000?l0o`000000o`3oool0o`000000
o`3oool00P3o00040?ooo`<0003o00<0oooo0000o`3oool01`3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00D0oooo001>0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`040000o`3o0000o`000?l000@0oooo00<0o`000?oo
o`3oool01P3oool20000o`@0oooo00H0o`000?ooo`3oool0oooo0000o`3o
ool20?l000050000o`3o0000o`000?ooo`000?l00`3oool00`3o0000oooo
0?ooo`020?ooo`80003o203oool00`3o0000oooo0?ooo`020?ooo`<0o`00
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
D03oool00`000?l0oooo0?ooo`020?ooo`80o`000`3oool00`000?l0oooo
0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool20000o`D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo0080oooo0P000?l30?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0o`0000<0oooo00<0003o0?ooo`3oool0E03oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00<0oooo10000?l60?ooo`<0o`0000`0003o0?ooo`3o
0000oooo0000o`3o0000003o0?ooo`3o0000oooo0000o`3oool20?l000H0
oooo10000?l50?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool004h0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0o`00203oool00`3o0000oooo
0?ooo`030?ooo`80003o00<0oooo0000o`3oool00P3oool01`3o0000oooo
0?ooo`3oool0003o0?ooo`3o00000P3oool01P000?l0oooo0?ooo`3o0000
oooo0000o`<0oooo00H0o`000?ooo`3oool0oooo0000o`3oool20000o`D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0o`000?l000040?l00003
0?ooo`3o0000oooo00L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`1@0?ooo`070000o`3oool0oooo0?oo
o`3o0000oooo0?l000040?ooo`030000o`3oool0oooo00<0oooo00@0o`00
0?ooo`3oool0003o1@3oool01@000?l0oooo0?ooo`3oool0o`0000T0oooo
00<0003o0?ooo`3oool01`3oool0103o0000oooo0?ooo`000?l60?ooo`04
0000o`3oool0oooo0?l000D0oooo00<0003o0?ooo`3oool00`3oool20?l0
00<0oooo00<0003o0?ooo`3oool0E03oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00<0003o0P3oool00`000?l0oooo0?ooo`030?ooo`80o`000P3oool03@00
0?l0oooo0?ooo`3o0000003o0?ooo`3o0000oooo0000o`3oool0o`000?oo
o`000?l00P3oool20?l000@0oooo00@0003o0?ooo`3oool0oooo0`000?l2
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool01@3oool004h0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`<0o`001P3oool00`000?l0oooo0?ooo`060?ooo`050?l0003oool0oooo
0?ooo`000?l00`3oool010000?l0oooo0?ooo`3o00030?ooo`040000o`3o
ool0oooo0?l00080oooo00@0003o0?ooo`3oool0o`000P3oool01@000?l0
oooo0?ooo`3oool0o`000080oooo00D0003o0?ooo`3oool0oooo0000o`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool3
0?l000L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`1A0?ooo`030000o`3o0000o`000080oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`80003o1`3oool2
0000o`030?ooo`3o0000oooo00P0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0000o`080?ooo`80003o1@3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo0080o`0000<0003o0?ooo`3oool0E@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?ooo`3o
ool70000o`H0oooo00<0003o0?ooo`3oool00P3o00040?ooo`0:0000o`3o
0000o`000?ooo`000?l0oooo0?l0003oool0003o0?ooo`80o`0000<0003o
0?ooo`3oool00P3oool20?l00080oooo00<0003o0?ooo`3oool0103oool7
0000o`<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool01@3oool004h0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`040?l000030?ooo`3o0000oooo
00H0oooo00<0003o0?ooo`3oool01P3oool0103o0000oooo0000o`000?l5
0?ooo`030000o`3o0000oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00020?ooo`040000o`3oool0oooo0?l000<0oooo00H0003o0?ooo`3oool0
oooo0?l000000?l50?ooo`80003o00<0oooo0?l0003oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0o`0000<0o`000P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
0580oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o00002@3oool0103o
0000003o0000o`000?l70?ooo`030000o`3oool0oooo00@0oooo0`000?l0
0`3o0000003o0?ooo`080?ooo`030?l000000?l0oooo00<0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo05D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo10000?l5
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?l0003o00001@3oool0
0`000?l0oooo0?ooo`020?l0000:0000o`3o0000o`000?l000000?l0o`00
0?ooo`3o0000oooo0000o`D0oooo0P3o00000`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo0080oooo10000?l70?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`00CP3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`060?ooo`<0o`001@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo0P000?l70?ooo`030?l000000?l0003o0080
oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`040000o`3oool0oooo
0?l000<0oooo00H0003o0?ooo`3oool0003o0?ooo`3o00070?ooo`80003o
1`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo
0`3o00070?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo05<0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`040000
o`3oool0oooo0000o`<0oooo0P3o00070?ooo`040?l0003oool0oooo0?oo
o`H0003o00<0oooo0000o`3oool01@000?l40?ooo`030?l0003oool0oooo
00D0oooo0P3o00020?ooo`040000o`3oool0oooo0000o`H0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1F0?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`030?ooo`<0003o203oool00`3o0000oooo0?ooo`05
0?ooo`030?l000000?l0oooo00<0oooo0P000?l20?ooo`040?l0003oool0
003o0?ooo`<0o`0000@0oooo0000o`3oool0o`000P3oool20000o`@0oooo
00<0003o0?l0003oool01P3oool00`3o0000oooo0?ooo`060?ooo`<0003o
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool004h0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool30?l000030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`030?ooo`80003o00<0oooo0?l0003oool01@3oool0103o0000oooo0?oo
o`3oool20000o`@0oooo00@0o`000?ooo`3oool0003o0P3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0003o0080oooo00<0o`000?ooo`3o
ool0103oool0103o0000oooo0000o`000?l40?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01@3oool010000?l0o`000?l0003o0004
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo05@0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`80003o1P3oool0
0`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo1@000?l8
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0000o`050?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool0E`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`000?l00`000?l2
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool2
0?l00080oooo00@0003o0?ooo`3oool0003o0`3oool0103o0000oooo0?oo
o`000?l20?ooo`040?l0003oool0oooo0000o`80oooo00D0o`000?ooo`3o
ool0oooo0000o`020?ooo`030000o`3oool0oooo0080o`001@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0003o00<0oooo0?l0
003oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo001?0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0o`000080o`00103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00H0oooo00@0003o0?ooo`3oool0oooo0P000?l40?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool20000
o`<0oooo00@0o`000?ooo`3oool0003o0P3oool0103o0000oooo0?ooo`3o
ool30000o`@0oooo00<0o`000?ooo`3oool00`3oool0103o0000oooo0?oo
o`3oool20000o`80oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo0080oooo0`3o00000`3oool0o`00
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`1D0?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`80o`00
0`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo
00@0o`000?ooo`3oool0oooo0P3o00070?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1G0?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool30000o`L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`020?l000@0oooo00<0003o0?ooo`000?l0103oool0103o0000
oooo0?ooo`000?l20?ooo`040?l0003oool0oooo0000o`80oooo00<0o`00
0?ooo`3oool00P3oool20000o`D0oooo0P3o00020?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool30000o`H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`00C`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3o00001P3o00070?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0000o`060?oo
o`050?l0003oool0oooo0?ooo`3o00001@3oool00`000?l0oooo0?ooo`02
0000o`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000003o0000
o`020?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo
0?l000060?ooo`80003o2@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo1`3o00020?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1E0?ooo`030000
o`3oool0oooo0080oooo00@0o`000?ooo`3oool0oooo0P000?l00`3oool0
003o0?ooo`070?ooo`80o`0000<0oooo0?l0003oool02P3oool00`000?l0
oooo0?ooo`090?ooo`040?l0003oool0oooo0?l000P0oooo00@0003o0?oo
o`000?l0003o0`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo05P0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool7
0000o`030?ooo`3o0000oooo00L0oooo00<0003o0?ooo`3oool01P3oool3
0?l000L0oooo0P000?l30?ooo`040?l0003oool0oooo0000o`<0oooo00@0
o`000?ooo`3oool0003o0`3oool0103o0000oooo0?ooo`3oool20000o`L0
oooo0`3o00080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`00
0?l01P000?l70?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo001?0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool30?l000D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo0P000?l80?ooo`030?l0
003oool0o`0000H0oooo00<0003o0?ooo`3oool00P3oool00`3o0000003o
0000o`050000o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool0103o0000oooo0?ooo`3o00080?ooo`80003o1`3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool30?l000H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`1E0?ooo`030000o`3oool0oooo00<0oooo00<0o`000000o`00
0?l0103oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02@3oool30?l000P0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?l000050?ooo`030000o`3oool0oooo05P0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool50000o`L0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`<0
o`00203oool30000o`030?ooo`3o0000oooo0080oooo00D0003o0?ooo`3o
ool0oooo0?l000030?ooo`060000o`3oool0oooo0?ooo`3o0000oooo0`00
0?l90?ooo`80o`001`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo10000?l40?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo001?0?ooo`030000o`3oool0oooo00H0oooo00@0o`00
0?ooo`3oool0oooo0`3o00000`3oool0003o0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`030?ooo`80003o00<0oooo0000o`3oool0203oool20?l000D0oooo00<0
003o0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`80o`00
203oool00`000?l0oooo0?ooo`020000o`D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3o00000P3o00030?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool0EP3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool40?l000T0oooo
00<0003o0?ooo`3oool0203oool30?l000P0oooo00<0003o0?ooo`3oool0
103oool00`000?l0o`000?ooo`030?ooo`030000o`3oool0oooo05T0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo1P000?l40?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`040?l0
003oool0oooo0?l000H0oooo0P000?l30?ooo`030000o`3o0000oooo0080
oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`060000o`3oool0oooo
0?ooo`3o0000003o0`3oool20000o`H0oooo00@0o`000?ooo`3oool0o`00
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00@0003o0?ooo`3oool0oooo1P000?l50?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`00
C`3oool00`000?l0oooo0?ooo`060?ooo`@0o`00103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`020000o`@0oooo00<0003o0?ooo`3oool0
1@3oool0103o0000oooo0?ooo`3o00030?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo00<0oooo00@0003o0?ooo`3oool0oooo103o00070?oo
o`030000o`3oool0oooo0080oooo0P000?l20?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo0080oooo103o00070?ooo`030000o`3oool0oooo
05L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0o`000?ooo`060?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool20?l0
00L0oooo00<0003o0?ooo`3oool01@3oool30?l00080oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l000000?l0oooo
00<0oooo00<0003o0?ooo`3oool0F@3oool00`000?l0oooo0?ooo`040?oo
o`040?l0003oool0oooo0?ooo`T0003o00<0oooo0?l0003oool01`3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00@0003o
0?ooo`3oool0oooo0P3o00040?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool00`3oool00`3o0000003o0000o`020?ooo`050000o`3o
ool0oooo0?ooo`3o00000`3oool01P000?l0oooo0?ooo`3oool0003o0?l0
00D0oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`3oool2
0?l000<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool02P000?l2
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0500oooo00<0003o0?ooo`3oool00`3oool30?l000P0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`000?l01`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo0080oooo00@0o`000?ooo`3oool0003o1@3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o00040?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?l0
00070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`<0o`001@3oool00`000?l0oooo0?oo
o`1H0?ooo`040000o`3oool0003o0000o`80oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
1@3o00020?ooo`030000o`3oool0oooo00D0o`001P3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
0P000?l00`3oool0003o0?ooo`1K0?ooo`/0003o0`3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0oooo0?l000H0
oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`030?l0003oool0oooo
00<0003o0`3oool0103o0000oooo0?ooo`3oool40000o`030?ooo`3o0000
oooo00D0oooo00D0003o0?ooo`3oool0oooo0?l000060?ooo`030?l0003o
ool0003o00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3o
ool:0000o`L0oooo001@0?ooo`030000o`3oool0o`0000<0o`000P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`04
0?ooo`030?l000000?l0oooo00D0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?l0003oool01@3oool01@3o0000oooo0?ooo`3oool0003o00T0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`040?l000030?ooo`000?l0oooo05X0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`3o0000
2`3oool30?l000030000o`3o0000o`0000`0oooo00D0o`000?ooo`3oool0
oooo0000o`070?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0F`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool20?l000P0
oooo00<0o`000?ooo`000?l01P3oool00`3o0000oooo0?ooo`030?ooo`@0
003o00H0o`000000o`000?l0003o0?ooo`000?l40?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3o0000203oool20?l000P0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo001@0?ooo`80o`001`3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`80003o00<0o`000?oo
o`3oool01`3oool010000?l0oooo0?ooo`3o00080?ooo`030000o`3o0000
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0000o`090?ooo`040?l0003oool0003o0000o`D0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool20?l005/0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`040000o`3o
ool0oooo0?l000h0oooo00<0003o0?ooo`3oool0303oool0103o0000oooo
0?ooo`000?l80?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0F`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool20?l00003
0?ooo`000?l0oooo00P0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01`3oool010000?l0oooo0?l0003o00050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`00D@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`060?ooo`040000o`3oool0oooo0?ooo`80003o0`3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3o0000oooo00L0oooo00<0003o
0?ooo`3oool00P3o00020?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?l000030?ooo`000?l0
oooo00L0oooo00<0o`000000o`3oool01`3oool00`3o0000oooo0?ooo`02
0?ooo`80003o0`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo05/0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3o0000oooo00h0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000003o0?ooo`070?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0G03oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00@0o`00
0?ooo`3oool0oooo0P3o00030?ooo`030000o`3oool0oooo00H0oooo00@0
003o0?ooo`3o0000o`00103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P3o00000`3oool0003o
0?ooo`060?ooo`030000o`3oool0oooo0080oooo0P3o00030?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`00D@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0003o0000o`H0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000003o0?ooo`070?ooo`030000
o`3oool0oooo0080oooo103o00040?ooo`030000o`3oool0oooo0080oooo
103o00040?ooo`030000o`3oool0oooo00H0oooo00<0003o0?l0003oool0
1`3oool00`3o0000oooo0?ooo`040?ooo`<0003o203oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`1K0?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`3o0000003o0000o`0>0?ooo`030000
o`3oool0oooo00`0oooo00<0003o0?ooo`3o00001`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo05`0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`<0o`00
1P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo
00D0o`000?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`05
0?l0003oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo0`3o00090?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00580
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool20000o`P0
oooo00<0o`000?ooo`3oool01@3oool0103o0000oooo0?ooo`000?l60?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o00000`3o00000`00
0?l0o`000?l000020?l000030?ooo`3o0000oooo00H0oooo00<0003o0?oo
o`3oool00`3oool20000o`80oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`070?ooo`80003o1`3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`1M0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o00d0oooo00<0003o
0?ooo`3oool02P3oool20000o`<0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo05d0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`80o`002@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo00@0oooo0`3o00060?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
o`0000H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`07
0?ooo`80o`001`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo001B0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`000?l02@3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo00@0003o0?oo
o`3oool0003o1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1M
0?ooo`030000o`3oool0oooo00D0oooo00D0o`000?ooo`3oool0oooo0?l0
00050?ooo`80003o2`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo05d0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`80o`000P3o
ool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo0000o`P0oooo
0P3o00050?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`040?ooo`80o`00203oool010000?l0oooo
0?ooo`000?l90?ooo`030?l0003oool0oooo0080o`001@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo001B0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`040?l0003oool0oooo0?ooo`80
003o0`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool0103oool20000o`80oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?ooo`000?l70?oo
o`040?l0003oool0oooo0?l000X0oooo00@0003o0?ooo`3oool0oooo0P00
0?l30?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo05h0oooo00<0
003o0?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0o`0000L0oooo
0P000?l90?ooo`030000o`3oool0oooo00L0oooo0P000?l70?ooo`050?l0
003oool0oooo0?ooo`3o00001P3oool00`000?l0oooo0?ooo`1N0?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool00P3o00040?ooo`030?l0003oool0oooo00P0oooo0P000?l90?ooo`03
0?l0003oool0o`000080o`000P3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00@0003o0?ooo`3oool0oooo0P3o00000`3o
ool0o`000?ooo`080?ooo`030000o`3oool0003o00T0oooo00<0o`000?oo
o`3oool00P3oool20?l000<0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`00DP3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000003o0000o`060?ooo`030000o`3oool0oooo00H0
oooo00@0o`000?ooo`3oool0o`002@3oool20000o`P0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00H0oooo0P000?l90?ooo`030?l0003oool0o`0000T0oooo00<0003o0?oo
o`3oool0103oool20000o`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
05l0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?l0000:0?oo
o`D0003o103oool00`000?l0oooo0?ooo`020?ooo`D0003o2@3oool0103o
0000oooo0?ooo`3o00060?ooo`030000o`3oool0oooo05l0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?l00007
0?ooo`030?l0003oool0oooo00L0oooo0P000?l80?ooo`030?l0003oool0
oooo00<0oooo0P3o00000`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00@0003o0?l0003o0000o`00103oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0000o`080?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo001C0?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`80003o203oool0
0`000?l0oooo0?ooo`070?ooo`80o`002`3oool20000o`H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo0P000?l;0?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool01P3oool20000o`L0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0600oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0>0?ooo`T0003o3`3oool2
0?l000L0oooo00<0003o0?ooo`3oool0G`3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`80o`00203oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo0080003o1P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3o0000o`0000T0o`0000<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`040?ooo`80003o00<0oooo0000o`3oool01`3oool0
0`3o0000oooo0?ooo`060?ooo`80o`00203oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`00D`3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool20000
o`80oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`<0o`002@3oool00`000?l0oooo0?ooo`020000o`@0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
0080oooo0P000?l20?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3o0000203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
0080003o103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool0H@3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0o`0001<0oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?l000050?ooo`030000o`3oool0oooo0600oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool00`3oool20?l000030?ooo`000?l0oooo
00P0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`80003o103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3o00000P3o00050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo001C0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`050?l0003oool0oooo
0?ooo`3o0000203oool00`000?l0oooo0?ooo`020?ooo`@0003o00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l000000?l0
003o0080003o103oool00`000?l0oooo0?ooo`060?ooo`050?l0003oool0
oooo0?ooo`3o00001P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0H@3oool00`000?l0oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`3o00004P3oool00`000?l0
oooo0?ooo`0?0?ooo`80o`000`3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo0600oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
00000P3o00030?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`050?ooo`050000o`3oool0oooo0?oo
o`3o00001`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01P3oool0103o0000oooo0?ooo`000?l7
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`030?ooo`80o`000P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`00E03oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo0`000?l60?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000003o0000o`020000o`@0oooo00<0003o0?ooo`3oool00P3oool40000
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`040?ooo`<0003o203oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo06<0oooo00@0003o0?oo
o`3oool0o`001@3oool20?l00100oooo00<0003o0?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`040?ooo`040?l0003oool0oooo0000of<0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo0P3o00070?ooo`030000o`3oool0oooo00P0oooo00@0
o`000?ooo`3oool0003o2@3oool00`000?l0oooo0?l000080?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0003o00T0oooo00@0003o0?ooo`3oool0
o`002@3oool00`000?l0oooo0?ooo`060?ooo`<0o`00203oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool005@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`80003o2@3oool00`3o0000oooo0?ooo`060?ooo`050000
o`3oool0oooo0?ooo`3o00001`3oool20?l000@0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`020?ooo`T0003o103oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool01@3oool0103o0000oooo0?ooo`000?l90?ooo`030?l0003oool0oooo
00L0oooo0P000?l70?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool0H`3oool00`000?l0o`000?l000080?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`060?oo
o`80o`0000<0003o0?ooo`3oool0H@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool30?l0
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0000o`0:0?oo
o`030000o`3o0000oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0203oool010000?l0oooo0?ooo`3o00090?ooo`030000o`3oool0
oooo00L0oooo0`3o00060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`00E@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00@0003o0?oo
o`3oool0003o203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
o`0000X0oooo00@0o`000?ooo`3oool0003o2@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`020?l000T0oooo00<0o`000000o`3oool02@3o
ool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0oooo0000o`D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`1U0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`80o`002P3oool00`000?l0oooo0?ooo`1R0?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool010000?l0oooo
0?ooo`3oool30?l00080oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000000o`00
0?l01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool20000o`030?l0003oool0oooo00T0
oooo00<0003o0?l0003oool0203oool00`000?l0oooo0?ooo`070?ooo`04
0?l0003oool0oooo0?ooo`<0o`000`3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool005D0
oooo00<0003o0?ooo`3oool01P3oool0103o0000oooo0?ooo`3oool20000
o`<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030?l000000?l0oooo00X0oooo00<0o`000000o`3oool02@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0203oool00`000?l0o`000?ooo`0:0?ooo`030000o`3o0000oooo
00P0oooo00<0o`000?ooo`3oool01`3oool010000?l0oooo0?ooo`3oool2
0000o`<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`1V
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool0H`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo103o00060?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01P3oool20000o`030?ooo`3o0000oooo00P0oooo00@0o`00
0?ooo`3oool0oooo0`000?l30?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`80003o0`3o
ool00`3o0000oooo0?ooo`080?ooo`030?l000000?l0003o00L0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`@0o`00203o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo001F
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000000o`000?l01P3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00@0o`00
0?ooo`3oool0003o2P3oool010000?l0oooo0?l0003o00080?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`070?ooo`030?l0003oool0003o00X0oooo00@0003o0?ooo`3oool0
o`001`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00@0
oooo0P000?l00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo06L0
oooo00<0003o0?ooo`3oool02@3oool20?l000/0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo06<0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`<0
o`0000<0oooo0000o`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool20?l000L0
oooo00<0o`000?ooo`3oool0103oool40000o`L0oooo00<0o`000?ooo`3o
ool01@3oool50000o`D0oooo00<0o`000?ooo`3oool01P3oool20?l000<0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?l0003o00000P3o00040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool005L0oooo
00<0003o0?ooo`3oool0103oool20000o`T0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool01`3oool010000?l0oooo0?ooo`3oool20?l000H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00@0oooo0`3o00020?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool20000o`H0
oooo00<0003o0?ooo`3oool0J@3oool00`000?l0oooo0?ooo`0:0?ooo`80
o`002@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool0I03oool00`000?l0oooo0?ooo`060?ooo`D0
o`00103oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0000o`060000o`030?l000000?l0003o00D0003o00<0oooo0000o`3o
ool0203oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool40?l000P0
oooo00<0003o0?ooo`3oool01@3oool005L0oooo00<0003o0?ooo`3oool0
0P3oool20000o`80oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
0P3o00030?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1`3oool0103o0000oooo0?ooo`3oool20?l000H0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo0080003o103oool00`000?l0oooo0?ooo`1Y0?ooo`03
0000o`3oool0oooo00`0oooo0P3o00070?ooo`030000o`3oool0oooo00H0
oooo0P3o000=0?ooo`030000o`3oool0oooo06@0oooo00<0003o0?l0003o
00001`3o00090?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool02@3oool01@000?l0oooo0?ooo`3oool0003o00P0oooo00<0o`000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?oo
o`040?l0003oool0oooo0?ooo`80o`00203oool010000?l0oooo0?ooo`00
0?l:0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01P3o
ool90?l000030000o`3oool0oooo00D0oooo001H0?ooo`040000o`3oool0
oooo0000o`@0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`060?ooo`040?l0003oool0oooo0?l000P0oooo0P000?l50?ooo`030000
o`3oool0oooo00H0oooo103o00090?ooo`030000o`3oool0oooo00L0oooo
103o00080?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool01@3o0000oooo0?ooo`3oool0o`0000T0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0000
ofd0oooo00<0003o0?ooo`3oool03@3oool40?l000<0oooo00@0003o0?oo
o`3oool0oooo1@3o000>0?ooo`030000o`3oool0oooo06D0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0000o`0:
0?ooo`80o`0000<0oooo0?l0003oool02@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool0
103o0000oooo0?l0003o000;0?ooo`80003o2`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`00F03oool30000o`H0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`80o`002`3oool0
1@000?l0oooo0?ooo`3oool0003o00`0oooo1P3o00040?ooo`030000o`3o
ool0oooo0080oooo1P3o000<0?ooo`040000o`3oool0oooo0?ooo`80003o
2@3oool30?l000T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`040?ooo`<0003oKP3oool00`000?l0oooo0?ooo`0@0?ooo`<0o`00
00@0003o0?l0003o0000o`004P3oool00`000?l0oooo0?ooo`1V0?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02`3oool20?l000T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo001H0?ooo`80003o1`3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00H0oooo0`3o000;0?ooo`040000
o`3oool0oooo0000o`/0oooo00<0o`000?ooo`3oool0103oool40?l00003
0000o`3o0000o`000080o`001@3oool00`3o0000oooo0?ooo`0:0?ooo`04
0000o`3oool0oooo0000o``0oooo0P3o00080?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool20000ofh0oooo00<0003o0?oo
o`3oool04`3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo
06H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool20000
o`d0oooo00@0o`000?ooo`3o0000o`001`3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool3
0?l000d0oooo0P000?l:0?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo001I0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`040?ooo`050?l0003oool0oooo
0?ooo`3o00002`3oool20000o``0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo0P000?l;
0?ooo`80o`000P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`1_
0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`1W0?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00H0oooo00@0003o0?ooo`3oool0003o303oool01@3o0000oooo0?oo
o`3oool0o`0000H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00@0oooo0P3o00030?ooo`030?l0
003oool0oooo00P0oooo0P000?l20?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool005X0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`090?ooo`<0003o2P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0203oool30000o`/0oooo00<0
o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`1_0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`1W0?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00<0oooo0P000?l40?ooo`80003o2@3oool00`3o0000oooo0?oo
o`030?ooo`<0o`000`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00P0oooo00@0003o0?ooo`3oool0oooo0P3o00050?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool20000o`D0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool005X0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`040000o`3o
ool0oooo0?l000L0oooo00<0o`000?ooo`3oool01`3oool010000?l0oooo
0?ooo`3oool20000o`P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo0P000?l30?ooo`03
0000o`3oool0oooo00H0oooo0P3o00070?ooo`050?l0003oool0oooo0?oo
o`000?l02P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
0740oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?oo
o`030000o`3oool0oooo06P0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo00D0o`000?oo
o`3oool0oooo0000o`080?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01`3oool30?l000030000o`3o0000oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000003o0?l000020?l000L0oooo00<0o`00
0?ooo`3oool01@3oool20000o`P0oooo00D0003o0?ooo`3oool0oooo0?l0
000;0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`050?ooo`00F`3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o0000203oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo0P000?l5
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`030?ooo`80003o1P3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00L0oooo00@0o`000?ooo`3oool0003o2P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0740oooo00<0
003o0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo06P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00P0oooo00@0o`000?ooo`3oool0003o
2P3oool20000o`D0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?l0000A0?l000030?ooo`000?l0oooo00X0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`090?ooo`040000o`3oool0oooo0?l000X0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00D0oooo001L0?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`80o`00
1@3oool00`000?l0oooo0?ooo`060?ooo`80003o0`3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00@0o`000?ooo`3oool0
oooo0P000?l80?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool02@3oool00`3o0000003o0?ooo`090?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool0L`3oool00`000?l0oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0J@3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000003o0?ooo`0<0?ooo`050000o`3oool0oooo0?oo
o`3o0000303oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02@3oool0103o0000oooo0?ooo`3oool2
0000o`d0oooo00<0003o0?l0003oool02P3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01@3oool0
05d0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`80o`0000<0003o0?ooo`3oool02P3oool01@3o0000oooo0?ooo`3oool0
003o00/0oooo0`000?l00`3o0000003o0000o`090?ooo`030000o`3oool0
oooo00P0oooo00<0003o0?l000000?l00P000?l;0?ooo`050000o`3oool0
oooo0?ooo`3o0000303oool00`000?l0o`000?l000080?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0M03oool00`000?l0oooo0?oo
o`0?0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool0JP3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool0203oool00`000?l0o`000?ooo`0=0?ooo`80003o00<0
oooo0?l0003oool02`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool00`3o0000003o0000
o`0?0?ooo`030?l000000?l0oooo00T0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00D0oooo001M
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool0
1@3o0000oooo0?ooo`3oool0003o00`0oooo00@0o`000?ooo`3oool0003o
3@3oool0103o0000oooo0?ooo`3oool50000o`@0oooo00<0003o0?ooo`3o
ool00P3oool60000o`80oooo00<0o`000?ooo`3oool02`3oool010000?l0
oooo0?l0003o000<0?ooo`050000o`3oool0oooo0?ooo`3o00001P3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo07D0oooo00<0003o
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0
oooo06X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool0o`003`3o
ool00`000?l0o`000?ooo`0;0?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`80003o00<0
o`000?ooo`3oool03@3oool0103o0000oooo0?ooo`000?l90?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`050?ooo`00GP3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l000000?l0oooo00d0oooo00<0o`000?ooo`3oool01P3o
ool90000o`P0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0:0?ooo`80003o1@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0MP3oool00`000?l0oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0J`3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool01P3oool010000?l0oooo0?ooo`3oool20?l000d0oooo
00<0o`000?ooo`000?l00P000?l80?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`80003o
0P3oool00`3o0000oooo0?ooo`0;0?ooo`80o`00103oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`050?ooo`00G`3oool00`000?l0oooo0?oo
o`070?ooo`040?l0003oool0oooo0?l000L0oooo00<0003o0?ooo`3oool0
2P3oool00`000?l0o`000?l0000<0?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`80o`00
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`040?l0
003oool0oooo0?l000X0oooo00<0003o0?ooo`3oool0M`3oool00`000?l0
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3o
ool0J`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool30000o`D0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00@0oooo0P000?l50?ooo`030?l0003oool0oooo00T0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`050?ooo`00H03oool00`000?l0oooo0?ooo`070?ooo`80o`00
2@3oool20000o`T0oooo00@0003o0?ooo`3oool0oooo0P3o00090?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`070?ooo`80o`000`3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo00P0oooo0P3o000:0?ooo`030000o`3oool0oooo07T0
oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo06`0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool01P3oool20?l000T0oooo00<0o`000?ooo`3oool01P3oool30000o`80
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`04
0000o`3oool0oooo0?ooo`<0003o1`3oool00`3o0000oooo0?ooo`070?oo
o`80o`002@3oool01@000?l0oooo0?ooo`3oool0003o00`0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`050?ooo`00H03oool00`00
0?l0oooo0?ooo`070?ooo`80o`002`3oool20000o`L0oooo00<0003o0?oo
o`3oool00`3oool20?l000L0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00D0oooo0P3o00050?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool02@3oool20?l0
00T0oooo00<0003o0?ooo`3oool0NP3oool00`000?l0oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0K03oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00D0003o0?oo
o`3oool0oooo0000o`0;0?ooo`030?l0003oool0oooo00H0oooo00<0o`00
0?ooo`3oool02@3oool60000o`P0oooo00<0o`000?ooo`3oool01`3oool6
0000o`/0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:
0?ooo`040000o`3oool0oooo0000o``0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`050?ooo`00H@3oool00`000?l0oooo0?ooo`05
0?ooo`040?l0003oool0oooo0?l000`0oooo0P000?l40?ooo`030000o`3o
ool0oooo00H0oooo0`3o00040?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`020?ooo`<0o`00203o
ool00`000?l0oooo0?ooo`030?ooo`80003o2`3oool0103o0000oooo0?oo
o`3o00070?ooo`030000o`3oool0oooo07`0oooo00<0003o0?ooo`3oool0
303oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo06d0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0003o00d0oooo0P3o00050?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool00P3oool80000o`030?l000000?l0003o00L0003o
0`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00<0oooo
0P3o000>0?ooo`80003o303oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00D0oooo001R0?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0;0?ooo`050000o`3o
ool0oooo0?ooo`000?l02`3oool40?l000h0oooo00<0003o0?ooo`3oool0
303oool40?l000/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`1n0?ooo`030000o`3oool0oooo00/0oooo
00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`1^0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0>0?ooo`80o`000`3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0;0?ooo`040?l0003oool0oooo0?ooo`80o`00403oool20000o``0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`00
H`3oool01@000?l0oooo0?ooo`3oool0o`0000H0oooo00<0o`000?ooo`3o
ool02`3oool30000o`l0oooo103o000;0?ooo`030000o`3oool0oooo00X0
oooo0`3o000?0?ooo`040000o`3oool0oooo0000o`/0oooo0P3o00060?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0OP3oool00`00
0?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?oo
o`3oool0KP3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00T0oooo0P000?l00`3oool0003o0000o`0@0?ooo`<0o`003P3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool0303oool30?l00100oooo0P000?l20?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?oo
o`00I03oool00`000?l0oooo0?l000080?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool03@3oool0103o0000oooo0?ooo`3oool60?l0
00D0oooo00<0003o0?ooo`3oool00P3oool80?l00080oooo00<0o`000?oo
o`3oool03@3oool30000o`/0oooo00<0o`000?ooo`3oool01`3oool0103o
0000oooo0?ooo`000?n20?ooo`030000o`3oool0oooo00X0oooo00<0003o
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`1_0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`03
0?ooo`80003o403oool20?l000d0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo0P3o000A
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00D0oooo001U0?oo
o`030?l0003oool0oooo00P0oooo0P3o000;0?ooo`030000o`3oool0003o
00h0oooo00<0o`000?ooo`3oool01`3oool50?l000030000o`3o0000o`00
0080o`002P3oool00`3o0000oooo0?ooo`0=0?ooo`80003o2`3oool00`3o
0000oooo0?ooo`090?ooo`030?l000000?l0oooo0880oooo00<0003o0?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo
06l0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`040?l000T0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00P0oooo0`3o00000`3o
ool0o`000?ooo`0?0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00D0oooo001V0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`020000o``0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0
oooo0P000?l00`3oool0003o0?ooo`090?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool0P`3oool00`000?l0oooo0?ooo`090?ooo`03
0000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0L03oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0203oool20000o``0oooo00<0o`000?ooo`3oool0103oool40?l000D0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00@0oooo103o00050?ooo`030?l0003oool0oooo00/0
oooo0P000?l90?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`050?ooo`00I`3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
0`3oool20000o`X0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00P0oooo0`000?l40?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`240?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`1`0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0:0?ooo`80003o
2@3oool00`3o0000oooo0?ooo`090?ooo`<0o`0000<0oooo0000o`3oool0
303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0o`0000<0o`00
2@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00D0oooo001X0?ooo`030000o`3oool0oooo00T0oooo0P3o
00050?ooo`030000o`3oool0oooo00H0oooo0`000?l70?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`050?ooo`<0003o203oool00`000?l0oooo0?ooo`030?ooo`80o`002`3o
ool20000ohP0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo0740oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00d0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0<0?ooo`030?l00000
0?l0o`0000<0o`002@3oool00`3o0000oooo0?ooo`060?ooo`D0o`0000<0
003o0?l0003oool03@3oool00`3o0000oooo0?ooo`070?ooo`80003o3P3o
ool01@000?l0oooo0?ooo`3oool0o`000100oooo00<0003o0?ooo`3oool0
1@3oool006T0oooo00<0003o0?ooo`3oool02P3oool01@3o0000oooo0?oo
o`3oool0003o00`0oooo0P000?l40?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`020?ooo`80003o
303oool01@000?l0oooo0?ooo`3oool0o`0000`0oooo00<0003o0?ooo`3o
ool0R@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool0LP3oool00`000?l0oooo0?ooo`0?0?ooo`04
0?l0003oool0oooo0000oa40oooo0P000?l60?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool00P3ooolB0?l000D0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000oooo0?ooo`050?ooo`80003o4@3oool00`00
0?l0oooo0?l0000A0?ooo`030000o`3oool0oooo00D0oooo001Z0?ooo`03
0000o`3oool0oooo00X0oooo0P3o00000`3oool0003o0?ooo`0=0?ooo`@0
003o00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0003o0080003o3P3oool010000?l0oooo0?ooo`3o000<0?oo
o`030000o`3oool0oooo08X0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0780oooo00<0003o0?oo
o`3oool0403oool20000oa@0oooo0P000?l30?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool00P3oool20000
oa@0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`050?oo
o`00J`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo0140
oooo00@0o`000000o`000?l0003o303oool00`000?l0oooo0?ooo`090?oo
o`@0003o00<0o`000000o`3oool04@3oool00`000?l0o`000?ooo`0:0?oo
o`80003oSP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool0L`3oool00`000?l0oooo0?ooo`0?0?oo
o`030000o`3oool0o`0001H0oooo0P000?l00`3oool0o`000?ooo`0?0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0080003o5@3oool00`3o
0000oooo0000o`0A0?ooo`030000o`3oool0oooo00D0oooo001/0?ooo`80
003o2`3oool00`000?l0o`000?l0000@0?ooo`030?l0003oool0oooo0080
oooo2@000?l30?ooo`040000o`3oool0oooo0?ooo`P0003o1@3oool00`3o
0000oooo0?ooo`0>0?ooo`80o`0000<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`2>0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`1c0?ooo`030000o`3oool0oooo
00h0oooo00D0003o0?ooo`3oool0oooo0?l0000G0?ooo`040000o`3o0000
003o0000o`h0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00h0oooo00<0o`000000o`000?l05P3o
ool01@3o0000oooo0?ooo`3oool0003o0100oooo00<0003o0?ooo`3oool0
1@3oool006h0oooo00<0003o0?ooo`3oool01`3oool010000?l0oooo0?oo
o`3oool20?l000h0oooo00<0o`000?ooo`3oool02`3oool70000o`d0oooo
00<0o`000?ooo`3oool0303oool20?l000<0oooo00<0003o0?ooo`3oool0
1P3oool20000oi80oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo07@0oooo00<0003o0?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`030?ooo`80o`005@3oool0103o0000oooo
0?ooo`3oool40000o`X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo10000?l00`3o0000
oooo0?ooo`0D0?ooo`80o`001@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00D0oooo001_0?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool00`3oool20?l000`0oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00X0oooo
0P3o00050?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
T`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0M@3oool00`000?l0oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool04P3oool00`3o0000oooo
0?ooo`050?ooo`<0003o1P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool01@3oool40000o`D0oooo
00<0o`000?ooo`3oool04@3oool20?l000P0oooo00<0003o0?ooo`3oool0
303oool00`000?l0oooo0?ooo`050?ooo`00L03oool20000o`D0oooo00<0
003o0?ooo`3oool01P3oool20?l000T0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00L0oooo0P3o
00080?ooo`030000o`3oool0oooo0080oooo0P000?nF0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`1e0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0203o
ool20?l00180oooo00<0o`000?ooo`3oool0203oool80000o`d0oooo00<0
o`000?ooo`3oool0303oool80000o`T0oooo00<0o`000?ooo`3oool03`3o
ool20?l000/0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?oo
o`050?ooo`00LP3oool01@000?l0oooo0?ooo`3oool0003o00/0oooo103o
00050?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`030?ooo`@0o`002`3oool010000?l0oooo0?oo
o`000?nI0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`1f0?ooo`030000o`3oool0oooo00X0oooo
00<0003o0?ooo`3oool02`3oool20?l00100oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0000o`0<0000o`030?l000000?l0003o00d0003o
403oool00`3o0000oooo0?ooo`0=0?ooo`80o`003P3oool00`000?l0oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00D0oooo001c0?ooo`80003o00<0
oooo0000o`3oool03P3oool40?l000030?ooo`3o0000oooo0100oooo00<0
003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`030?l000l0oooo0`00
0?nJ0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`1f0?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool03P3oool40?l000/0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`090?ooo`<0o`004@3o
ool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00D0oooo001e
0?ooo`80003o4`3oool20?l00140oooo00<0003o0?ooo`3oool0403oool2
0?l00180oooo0P000?nL0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1g0?ooo`030000o`3oool0
oooo00P0oooo00<0003o0?ooo`3oool04`3oool30?l000P0oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`06
0?ooo`<0o`005@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0
oooo00D0oooo001g0?ooo`80003o4@3oool00`3o0000oooo0?l000020?l0
00h0oooo00<0003o0?ooo`3oool02`3oool60?l00140oooo0P000?nN0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`1g0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool05`3oool40?l000@0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`030?ooo`<0o`006@3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo001i0?ooo`80
003o3`3oool00`3o0000oooo0?ooo`020?ooo`/0o`000`3oool00`000?l0
oooo0?ooo`0;0?l000D0oooo00<0o`000?ooo`3oool03@3oool20000oj40
oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0oooo
07P0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0L0?oo
o`D0o`004@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`030?l0
01d0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`00N`3oool20000o``0oooo00<0o`000?ooo`3oool03P3oool30?l00004
0000o`3o0000o`000?l000l0oooo00<0o`000?ooo`3oool02`3oool20000
oj@0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`1i
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0803oool0
0`3o0000oooo0?l000040?l000`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00P0oooo2P3o000Q
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
07d0oooo0P000?l:0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`070?ooo`<0003oYP3oool01000
0?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo07T0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003oool0
oooo00@0oooo303o00000`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00/0oooo0P3o00000`000?l0o`000?l000070?l000P0oooo00<0o`00
0?ooo`3oool08@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo001o0?ooo`<0003o1`3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool01@3oool20000
oi/0oooo0P00000=0?ooo`050000o`3oool0003o0?ooo`000?l0O03oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0280oooo00<0o`00
0?ooo`3oool0403oool00`000?l0o`000?l0000J0?l00080oooo00<0003o
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool01@3oool00880oooo0P000?l50?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`030?ooo`80003oW@3oool2000000D0oooo0P0000060?oo
o`050000o`3oool0003o0?ooo`000?l0O03oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo02<0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool01@3oool008@0oooo10000?l00`3o
0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo0180oooo00<0o`000000
o`000?l00P000?nN0?ooo`030000003oool0000000@0oooo00@000000?oo
o`3oool000001P3oool30000ogd0oooo00D0003o0?ooo`3oool0oooo0000
o`0V0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool0903oool01@000?l0oooo0?ooo`3oool0003o00L0oooo
00280?ooo`030?l000000?l0003o00<0003o3`3oool00`000?l0oooo0?oo
o`0?0?ooo`<0003o00<0o`000?ooo`3oool0WP3oool01@000000oooo0000
003oool0000000H0oooo00<000000?ooo`3oool01@3oool30000ogd0oooo
00@0003o0?ooo`3oool0003o9`3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo02D0oooo00@0003o0?ooo`3o
ool0003o1`3oool008h0oooo0`000?l50?ooo`D000000P3oool00`000?l0
oooo0?ooo`0:0?ooo`D0003oY@3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool01@3oool00`000?l000000?ooo`1e0?oo
o`D000000P3oool00`000?l0oooo0000o`0X0?ooo`030?l0003oool0oooo
00l0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool09P3oool00`00
0?l0oooo0000o`070?ooo`00T@3oool;0000o`030?ooo`000?l0oooo00/0
003o[P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
0080oooo0P000?lY0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00l0oooo00<0o`000?ooo`3oool09`3oool20000o`L0oooo002H0?ooo`04
0000003oool0oooo0?ooo`<0003o^@3oool00`000000oooo0?ooo`020?oo
o`800000203oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
0080ooooV`000?l70?ooo`00V03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0;T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0W`3oool009P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`2i0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`2O0?ooo`00U`3oool2000000@0oooo00<0
00000?ooo`3oool0^@3oool:000007d0oooo0P0000040?ooo`030000003o
ool0oooo09l0oooo003o0?ooonL0oooo00<000000?ooo`3oool0W`3oool0
0001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{648, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\tTo proceed further, we must review the rotational effect of a conformal \
mapping ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  " at a point ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  If the contour ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " has the parameterization  ",
  Cell[BoxData[
      \(z \((t)\)\  = \ x \((t)\) + \[ImaginaryI]\ y \((t)\)\)]],
  ",  then a vector ",
  Cell[BoxData[
      \(\[ScriptCapitalT]\)]],
  " tangent to ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " at the point ",
  Cell[BoxData[
      \(z\_0 = z \((t\_0)\)\)]],
  " is  \n\n\t\t\t",
  Cell[BoxData[
      \(\[ScriptCapitalT]\ \  = \ \ \(z' \((t\_0)\)\ \  = \ \ x' \((t\_0)\)\  \
+ \ \[ImaginaryI]\ y' \((t\_0)\)\)\)]],
  ".  \n\nThe image of ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a contour ",
  StyleBox["K",
    FontFamily->"Courier New"],
  " given by  ",
  Cell[BoxData[
      RowBox[{\(w \((t)\)\), " ", "=", " ", 
        RowBox[{
          RowBox[{"u", 
            RowBox[{"(", 
              RowBox[{\(x \((t)\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(y \((t)\)\)}], ")"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "v", 
            RowBox[{"(", 
              RowBox[{\(x \((t)\)\), 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], \(y \((t)\)\)}], ")"}]}]}]}]]],
  ",  and a vector ",
  StyleBox["T",
    FontFamily->"Courier New"],
  " tangent to ",
  StyleBox["K",
    FontFamily->"Courier New"],
  " at the point  ",
  Cell[BoxData[
      \(w\_0 = f \((z\_0)\)\)]],
  "  is \n\n\t\t\t",
  Cell[BoxData[
      \(T\  = \ \ \(w' \((t\_0)\)\  = \ f' \((z\_0)\) z' \((t\_0)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "If the angle of inclination of  ",
  Cell[BoxData[
      \(\[ScriptCapitalT]\)]],
  "  is  ",
  Cell[BoxData[
      \(\[Beta] = Arg\ z' \((t\_0)\)\)]],
  ",  then the angle of inclination of ",
  StyleBox["T",
    FontFamily->"Courier New"],
  " is  \n\n\t\t\t",
  Cell[BoxData[
      \(Arg\ T\ \  = \ \ \(Arg \((f' \((z\_0)\) 
                z' \((t\_0)\))\)\ \  = \ \ Arg\ f' \((z\_0)\)\ \  + \ \ \
\[Beta]\)\)]],
  ".  \n\nHence the angle of inclination of the tangent  ",
  Cell[BoxData[
      \(\[ScriptCapitalT]\)]],
  "  to ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " at ",
  Cell[BoxData[
      \(z\_0\)]],
  " is rotated through the angle  ",
  Cell[BoxData[
      \(Arg\ f' \((z\_0)\)\)]],
  "  to obtain the angle of inclination of the tangent ",
  StyleBox["T",
    FontFamily->"Courier New"],
  " to ",
  StyleBox["K",
    FontFamily->"Courier New"],
  " at the point ",
  Cell[BoxData[
      \(w\_0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tMany applications involving conformal mappings require the construction \
of a one-to-one conformal mapping from the upper half plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  onto a domain ",
  StyleBox["G",
    FontFamily->"Courier New"],
  " in the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  "-plane where the boundary consists of straight line segments.  Let's \
consider the case where ",
  StyleBox["G",
    FontFamily->"Courier New"],
  " is the interior of a polygon ",
  StyleBox["P",
    FontFamily->"Courier New"],
  " with vertices  ",
  Cell[BoxData[
      RowBox[{\(w\_1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_n\)}]]],
  "  specified in the positive sense (counterclockwise).  We want to find a \
function  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  with the property  \n\n",
  StyleBox["(11-38)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{\(w\_k = \(f \((x\_n)\)\ \ for\ \ k = 1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(n - 1\)}]]],
  ",  and  ",
  Cell[BoxData[
      \(w\_n = f \((\[Infinity])\)\)]],
  "\n\n\t\t\twhere\n\n\t\t\t",
  Cell[BoxData[
      \(\(x\_1 < x\_2 <  ... \) < x\_\(n - 1\) < \[Infinity]\)]],
  ".  \n\nTwo German mathematicians ",
  StyleBox[ButtonBox["Herman Amandus Schwarz",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Schwarz.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " (1843-1921) and ",
  StyleBox[ButtonBox["Elwin Bruno Christoffel",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Christoffel.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontVariations->{"Underline"->True}],
  " (1829-1900) independently discovered a method for finding f, and that is \
our next theorem."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Theorem 11.6 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Schwarz-Christoffel Formula",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/Schwarz-ChristoffelMapping.html"], 
      None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let ",
  StyleBox["P",
    FontFamily->"Courier New"],
  " be a polygon in the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane with vertices  ",
  Cell[BoxData[
      RowBox[{
        StyleBox[\(w\_1\),
          FontSize->14], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[\(w\_2\),
          FontSize->14], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[\(w\_n\),
          FontSize->14]}]]],
  "  and exterior angles  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["\[Alpha]",
            FontSize->14], "1"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["\[Alpha]",
            FontSize->14], "2"], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        SubscriptBox[
          StyleBox["\[Alpha]",
            FontSize->14], "n"]}]]],
  ",  where  ",
  Cell[BoxData[
      RowBox[{\(-\[Pi]\), "<", 
        SubscriptBox[
          StyleBox["\[Alpha]",
            FontSize->14], "k"], "<", "\[Pi]"}]]],
  ".  There exists a one-to-one conformal mapping  ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  "  from the upper half plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  onto ",
  StyleBox["G",
    FontFamily->"Courier New"],
  " that satisfies the boundary conditions  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(w\_k\), "=", 
          RowBox[{
            RowBox[{"f", \((x\_k)\), "   ", 
              StyleBox["for",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "   ", "k"}], "=", "1"}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "2", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "...", 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          RowBox[{"n", "-", 
            RowBox[{"1", "    ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", \(w\_n\)}]}], 
          "=", \(f \((\[Infinity])\)\)}]}], "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["where",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "   ", 
              SubscriptBox[
                StyleBox["x",
                  FontSize->14], "1"]}], "<", 
            SubscriptBox[
              StyleBox["x",
                FontSize->14], "2"], "<"}], "..."}], "<", 
        SubscriptBox[
          StyleBox["x",
            FontSize->14], \(n - 1\)], "<", \(\(\[Infinity]\)\(.\)\)}]}]],
  "  \n\nThe derivative ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " is   \n\n",
  StyleBox["(11-39)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      \(f' \((z)\)\  = \ \ \(A \(\((z - 
                      x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - \
x\_2)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\) ... \) \((z - x\_\(n - 1\))\)\^\(\(-\
\[Alpha]\_\(n - 1\)\)/\[Pi]\)\)]],
  "  \n\nand the function ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " can be expressed as an indefinite integral,  \n\n",
  StyleBox["(11-40)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{\(f \((z)\)\), " ", "=", " ", 
        RowBox[{"B", " ", "+", " ", 
          RowBox[{"A", 
            RowBox[{
              StyleBox["\[Integral]",
                
                FontSize->
                  18], \(\(\((z - 
                        x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \(\((z - 
                        x\_2)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\) \
\[CenterEllipsis] \(\((z - 
                        x\_\(n - 1\))\)\^\(\(-\[Alpha]\_\(n - 1\)\)/\[Pi]\)\) \
\[DifferentialD]z\)}]}]}]}]]],
  " \n\nwhere ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " are suitably chosen constants.  Two of the points  ",
  Cell[BoxData[
      RowBox[{"{", 
        SubscriptBox[
          StyleBox["x",
            FontSize->14], "k"], "}"}]]],
  "  may be chosen arbitrarily, and the constants ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " determine the size and position of ",
  StyleBox["P",
    FontFamily->"Courier New"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.70",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/schwarzchristoffel/\
SchwarzChristoffelFigures/mat1170.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  A Schwarz-Christoffel mapping with ",
  Cell[BoxData[
      \(n = 5\)]],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "+", 
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "+", 
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "+", 
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "4"]}], ">", "\[Pi]"}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.71",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/schwarzchristoffel/\
SchwarzChristoffelFigures/mat1171.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  A Schwarz-Christoffel mapping with ",
  Cell[BoxData[
      \(n = 5\)]],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "+", 
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "+", 
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "+", 
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "4"]}], "\[LessEqual]", "\[Pi]"}]]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 11.6 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  "\tEquation ",
  StyleBox["(11-40)",
    FontColor->RGBColor[0, 0, 1]],
  " gives a representation for f in terms of an indefinite integral.  Note \
that these integrals do not represent elementary functions unless the image \
is an infinite region.  Also, the integral will involve a multivalued \
function, and we must select a specific branch to fit the boundary values \
specified in the problem.  Table 11.2 is useful for our purposes."
}], "Text"],

Cell["\<\
\tThe following table of integrals is useful for hand computations and are \
compatible with the versions used in the textbook.  Occasionally they have \
been adjusted by a constant of integration which could be changed for \
indefinite integrands.  Also, depending on which quadrant you use it might be \
necessary to use various combinations of the branches of the multivalued \
terms. \
\>", "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[BoxData[{
      \(\ \ \[Integral]\(1\/\((1 - z\^2)\)\^\(1\/2\)\) \[DifferentialD]z\ \  \
= \ \ Arcsin\ z\), "\n", 
      \(\ \ \[Integral]\(1\/\((z\^2 - 1)\)\^\(1\/2\)\) \[DifferentialD]z\ \  \
= \ \ Log \((z + \((z\^2 - 1)\)\^\(1\/2\))\)\  - \ \(\[ImaginaryI]\ \
\[Pi]\)\/2\), "\n", 
      \(\ \ \[Integral]\(1\/\((z\^2 - 1)\)\^\(1\/2\)\) \[DifferentialD]z\ \  \
= \ \ \[ImaginaryI]\ Arcsin\ z\)}], "Input"],
  "\n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{"          ", 
        RowBox[{
          RowBox[{"\[Integral]", " ", 
            RowBox[{
              FractionBox[
                SuperscriptBox["1", 
                  StyleBox["1",
                    FontColor->GrayLevel[1]]], \(z\^2 + 
                  1\)], \(\[DifferentialD]z\)}]}], "  ", "=", 
          "  ", \(Arctan\ z\)}], "\[IndentingNewLine]"}], "\n", 
      RowBox[{"          ", 
        RowBox[{
          RowBox[{"\[Integral]", " ", 
            RowBox[{
              FractionBox[
                SuperscriptBox["1", 
                  StyleBox["1",
                    FontColor->GrayLevel[1]]], \(z\^2 + 
                  1\)], \(\[DifferentialD]z\)}]}], "  ", "=", 
          "  ", \(\(\[ImaginaryI]\/2\) 
            Log \((\(\[ImaginaryI] + z\)\/\(\[ImaginaryI] - z\))\)\)}]}]}], 
    "Input"],
  "\n\t\t\t\n\t\t\t",
  Cell[BoxData[{
      \(\[Integral]\(1\/\(z \((z\^2 - 1)\)\^\(1\/2\)\)\) \[DifferentialD]z\ \ \
 = \ \ \(-\ Arcsin\) \((1\/z)\)\), "\n", 
      \(\[Integral]\(1\/\(z \((z\^2 - 1)\)\^\(1\/2\)\)\) \[DifferentialD]z\ \ \
 = \ \ \[ImaginaryI]\ Log \((1\/z\  + \ \((1\/z\^2 - 1)\)\^\(1\/2\))\)\)}], 
    "Input"],
  "\n\t\t\t\n\t\t\t",
  Cell[BoxData[{
      \(\ \ \[Integral]\(1\/\(z \((z + 1)\)\^\(1\/2\)\)\) \[DifferentialD]z\ \
\  = \ \ \(-\ 2\)\ Arctanh \((\((z + 1)\)\^\(1\/2\))\)\), "\n", 
      \(\ \ \[Integral]\(1\/\(z \((z + 1)\)\^\(1\/2\)\)\) \[DifferentialD]z\ \
\  = \ \ Log \((\(1 - \((z + 1)\)\^\(1\/2\)\)\/\(1 + \((z + 1)\)\^\(1\/2\)\))\
\)\)}], "Input"],
  "\n\t\t\t\n\t\t\t",
  Cell[BoxData[{
      \(\ \[Integral]\(\((1 - 
                    z\^2)\)\^\(1\/2\)\) \[DifferentialD]z\ \  = \ \ 1\/2\ z\ \
\((1 - z\^2)\)\^\(1\/2\)\ \  + \ \ \(1\/2\) Arcsin\ z\), "\n", 
      \(\ \[Integral]\(\((1 - 
                    z\^2)\)\^\(1\/2\)\) \[DifferentialD]z\ \  = \ \ \(\
\[ImaginaryI]\/2\) 
            z\ \((z\^2 - 1)\)\^\(1\/2\)\ \  - \ \ \[ImaginaryI]\/2\ Log \((z\ \
 + \((z\^2 - 1)\)\^\(1\/2\))\)\)}], "Input"]
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox["Table 11.2",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Indefinite integrals."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Exploration",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
\tThe following table of integrals is useful for hand computations and are \
compatible with the versions used in the textbook.  Occasionally they have \
been adjusted by a constant of integration which could be changed for \
indefinite integrands.  Also, depending on which quadrant you use it might be \
necessary to use various combinations of the branches of the multivalued \
terms. \
\>", "Text"],

Cell[BoxData[{
    \(\(f[z_] = ArcSin[z];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", \*"\"\<\[Integral]\!\(1\/\((1 - z\^2)\
\)\^\(1\/2\)\)\[DifferentialD]z  \[Equal]  ArcSin[z]\>\""];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[z_] = 
        Log[z + \((z\^2 - 1)\)\^\(1\/2\)] - \(\[ImaginaryI]\ \[Pi]\)\/2;\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", \*"\"\<\[Integral]\!\(1\/\((z\^2 - 1)\
\)\^\(1\/2\)\)\[DifferentialD]z  \[Equal]  Log[z+\!\(\((z\^2 - 1)\)\^\(1\/2\)\
\)]-\!\(\(\[ImaginaryI]\\\ \[Pi]\)\/2\)\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", 
        Together[\(f'\)[z]]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[z_] = \[ImaginaryI]\ ArcSin[z];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", \*"\"\<\[Integral]\!\(1\/\((z\^2 - 1)\
\)\^\(1\/2\)\)\[DifferentialD]z  \[Equal]  \[ImaginaryI] \
ArcSin[z]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[z] = \!\(\(\((\(-\[ImaginaryI]\))\)\\\ \
\[ImaginaryI]\)\/\(\(\\\ \)\(\(\@\(-1\)\) \@\(1 - z\^2\)\)\)\)\>\""\ ];\)\), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[z] = \!\(1\/\(\(\\\ \)\(\@\(z\^2 - 1\)\)\)\)\>\""\ ];\
\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[z_] = ArcTan[z];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", \*"\"\<\[Integral]\!\(1\/\(z\^2 + 1\)\
\)\[DifferentialD]z  \[Equal]  ArcTan[z]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[z_] = \(\[ImaginaryI]\/2\) 
          Log[\(\[ImaginaryI] + z\)\/\(\[ImaginaryI] - z\)];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", \*"\"\<\[Integral]\!\(1\/\(z\^2 + 1\)\
\)\[DifferentialD]z  \[Equal]  \!\(\[ImaginaryI]\/2\)Log[\!\(\(\[ImaginaryI] \
+ z\)\/\(\[ImaginaryI] - z\)\)]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", 
        Together[\(f'\)[z]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", 
        Numerator[Together[\(f'\)[z]]]\/ComplexExpand[Denominator[Together[\(\
f'\)[z]]]]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[z_] = \ \(-ArcSin[1\/z]\);\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", \*"\"\<\[Integral]\!\(1\/\(z \((z\^2 \
- 1)\)\^\(1\/2\)\)\)\[DifferentialD]z  \[Equal]  - \
ArcSin[\!\(1\/z\)]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", 
        Numerator[\(f'\)[z]]\/Map[PowerExpand, Denominator[\(f'\)[z]]]\ \
];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[
          z_] = \[ImaginaryI]\ Log[
            1\/z\  + \ \((1\/z\^2 - 1)\)\^\(1\/2\)];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", \*"\"\<\[Integral]\!\(1\/\(z \((z\^2 \
- 1)\)\^\(1\/2\)\)\)\[DifferentialD]z  \[Equal]  \[ImaginaryI] Log[\!\(1\/z\) \
+ \!\(\((1\/z\^2 - 1)\)\^\(1\/2\)\)]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", 
        Numerator[Together[\(f'\)[z]]]\/Map[PowerExpand, \
Denominator[Together[\(f'\)[z]]]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[z] = \!\(1\/\(z\\\ \@\(z\^2 - 1\)\)\)\>\""\ ];\)\), "\
\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[
          z_] = \(-\ 
            2\)\ ArcTanh[\((z + 1)\)\^\(1\/2\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", \*"\"\<\[Integral]\!\(1\/\(z \((z + \
1)\)\^\(1\/2\)\)\)\[DifferentialD]z  \[Equal]  -2 ArcTanh[\!\(\((z + \
1)\)\^\(1\/2\)\)]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[z_] = \ 
        Log[\(1 - \((z + 1)\)\^\(1\/2\)\)\/\(1 + \((z + \
1)\)\^\(1\/2\)\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", \*"\"\<\[Integral]\!\(1\/\(z \((z + \
1)\)\^\(1\/2\)\)\)\[DifferentialD]z  \[Equal]  Log[\!\(\(1 - \((z + 1)\)\^\(1\
\/2\)\)\/\(1 + \((z + 1)\)\^\(1\/2\)\)\)]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", 
        Together[\(f'\)[z]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", 
        Numerator[Together[\(f'\)[z]]]\/FullSimplify[Denominator[Together[\(f'\
\)[z]]]]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[z_] = \ 
        1\/2\ z\ \((1 - z\^2)\)\^\(1\/2\) + \(1\/2\) 
            ArcSin[z];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", \*"\"\<\[Integral]\!\(\((1 - \
z\^2)\)\^\(1\/2\)\)\[DifferentialD]z  \[Equal]  \!\(1\/2\) z \!\(\((1 - z\^2)\
\)\^\(1\/2\)\)+\!\(1\/2\)ArcSin[z]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", 
        Together[\(f'\)[z]]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[
          z_] = \ \(\[ImaginaryI]\/2\) 
            z\ \((z\^2 - 1)\)\^\(1\/2\) - \[ImaginaryI]\/2\ Log[
              z\  + \((z\^2 - 1)\)\^\(1\/2\)];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", \*"\"\<\[Integral]\!\(\((1 - \
z\^2)\)\^\(1\/2\)\)\[DifferentialD]z  \[Equal]\!\(\[ImaginaryI]\/2\)z \
\!\(\((z\^2 - 1)\)\^\(1\/2\)\)-\!\(\[ImaginaryI]\/2\) Log[z +\!\(\((z\^2 - 1)\
\)\^\(1\/2\)\)]\>\""];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<\n\>", "\< f[z] = \>", f[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", 
        FullSimplify[Together[\(f'\)[z]]]\ ];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f'[z] = \!\(\@\(1 - z\^2\)\)\>\""\ ];\)\), "\
\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.26.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Schwarz-Christoffel formula to verify that  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ Arcsin\ z\)\)]],
  "  maps the upper half plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  onto the semi infinite strip  ",
  Cell[BoxData[
      RowBox[{\(\(-\[Pi]\)\/2 < u < \[Pi]\/2\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(v > 0\)}]]],
  "  shown in Figure 11.72."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005V0000[b000`400?l0
0000o`00003oo`3ooomW0?ooo`00o`3ooomW0?ooo`00o`3ooomW0?ooo`00
o`3ooomW0?ooo`00o`3ooomW0?ooo`00o`3ooomW0?ooo`00o`3ooomW0?oo
o`00o`3ooomW0?ooo`00P03oool400000380oooo0`00001Q0?ooo`<00000
;P3oool4000001L0oooo00200?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0H@3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo01P0oooo00210?ooo`030000003oool0oooo0300oooo1@00001O
0?ooo`D00000;`3oool00`000000oooo0?ooo`0G0?ooo`00PP3oool00`00
0000oooo0?ooo`0_0?ooo`040000003oool0oooo00000600oooo00@00000
0?ooo`3oool00000<@3oool00`000000oooo0?ooo`0F0?ooo`00P03oool0
10000000oooo0?ooo`00000a0?ooo`030000003oool000000640oooo00<0
00000?ooo`000000;`3oool010000000oooo0?ooo`00000G0?ooo`00P@3o
ool2000003<0oooo0P00001R0?ooo`800000<03oool2000001P0oooo003o
0?ooofL0oooo001g0?ooo`@000000`3oool8000002@0oooo100000040?oo
o`P00000F`3oool4000000030?ooo`000000000000800000:`3oool80000
01D0oooo003o0?ooofL0oooo003o0?ooofL0oooo003o0?ooofL0oooo001o
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo05`0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0503oool00800oooo00@000000?oo
o`3oool00000<03oool010000000oooo0?ooo`00001P0?ooo`040000003o
ool0oooo000002l0oooo00@000000?ooo`3oool000005`3oool00840oooo
00<000000?ooo`000000<@3oool00`000000oooo0000001Q0?ooo`030000
003oool000000300oooo00<000000?ooo`0000005`3oool00840oooo00<0
00000?ooo`000000<@3oool00`000000oooo0000001Q0?ooo`030000003o
ool000000300oooo00<000000?ooo`0000005`3oool00800oooo1@00000_
0?ooo`D00000;@3oool00`000000oooo0?ooo`0_0?ooo`D00000;P3oool5
000001H0oooo003V0?ooo`030000003oool0oooo07d0oooo003V0?ooo`03
0000003oool0oooo07d0oooo001j0?ooo`/00000a0000?l;00000180oooo
001o0?ooo`040000o`3oool0oooo0?ooo`80003o:@3oool00`3o0000oooo
0?ooo`020?ooo`030000003oool0oooo00h0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?ooo`050000
003oool0oooo0?ooo`3o0000:P3oool01@000?l0oooo0?ooo`3oool0003o
01P0oooo001o0?ooo`04000000000?l0oooo0000ob/0oooo00<0o`000?oo
o`3oool00P3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo
00l0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03P3oool01@00
0000oooo0?ooo`3oool0o`0002/0oooo00@0003o0?ooo`000?l00000603o
ool00800oooo0P000?l]0?ooo`030?l0003oool0oooo0180oooo00<0003o
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0B
0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool0603oool0
07l0oooo00@0003o0?ooo`3oool0003o;03oool00`3o0000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0Y0?ooo`030000o`3oool0
003o01T0oooo001o0?ooo`050000o`3oool0oooo0?ooo`000?l0:`3oool0
0`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00l0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0X
0?ooo`050000o`3oool0oooo0?ooo`000?l0603oool007l0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0X0?ooo`030?l0003oool0
oooo0180oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo02L0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0F0?ooo`00O`3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02L0oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0>0?oo
o`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool09`3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01H0oooo001o0?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool09P3oool00`3o0000
oooo0?ooo`0B0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0V0?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool05P3oool007l0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0U0?ooo`030?l0
003oool0oooo0180oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo02D0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0F0?ooo`00O`3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02@0oooo00<0
o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0903o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01H0oooo001o
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0903oool0
0`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00l0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0S
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool05P3oool0
07l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0S0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool03`3oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo
0280oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0F0?oo
o`00O`3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo0280
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0>0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3o
ool08@3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo01H0
oooo001o0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0
8@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00l0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00l0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0
5P3oool007l0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0P0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo0200oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0F0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo01l0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0?
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0180oooo00<0o`00
0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo01H0oooo001o0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?oo
o`3oool07P3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo
00/0oooo9`3o000=0?ooo`030000o`3oool0oooo0180oooo00<0o`000?oo
o`3oool07P3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo
01H0oooo001o0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3o
ool07P3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0080
oooo2@3o00030?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool03@3oool0103o0000oooo0?ooo`3oool;0?l00080oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo
00h0oooo00<0003o0?ooo`3oool05P3oool007l0oooo00<0003o0?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo00l0
oooo1`3o000<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0<0?ooo`H0o`00403oool00`3o0000
oooo0?ooo`0M0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3o
ool05P3oool007l0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo
0?ooo`0L0?ooo`030?l0003oool0oooo00T0oooo1P3o00020?ooo`030000
o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00@0003o0?ooo`3oool0
oooo1@3o000;0?ooo`030?l0003oool0oooo01`0oooo00<0003o0?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0F0?ooo`00O`3oool00`000?l0oooo
0?ooo`0A0?ooo`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool0
0`3oool50?l000P0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`060?ooo`<0o`00203oool00`3o0000oooo
0?ooo`0K0?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool0
5P3oool007l0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?oo
o`0K0?ooo`030?l0003oool0oooo00<0o`003@3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo0`3o
00040?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`0F0?ooo`00O`3oool00`000?l0oooo0?ooo`0C
0?ooo`030000o`3oool0oooo01X0oooo0`3o000A0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool5
0?l001`0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0F
0?ooo`00O`3oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo
01L0oooo0P3o00000`3oool0o`000?ooo`0A0?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool04@3oool30?l0
01T0oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`0F0?oo
o`00O`3oool00`000?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo01@0
oooo0P3o00030?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0@0?ooo`04
0?l0003oool0oooo0?ooo`80o`005P3oool00`000?l0oooo0?ooo`0E0?oo
o`030000o`3oool0oooo01H0oooo001o0?ooo`030000o`3oool0oooo01H0
oooo00<0003o0?ooo`3oool04@3oool20?l000H0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo0100oooo00<0o`000?ooo`3oool00`3oool20?l001<0
oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`0F0?ooo`00
O`3oool00`000?l0oooo0?ooo`0G0?ooo`030000o`3oool0oooo00h0oooo
0P3o00080?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
003oool0oooo00H0oooo0P3o000@0?ooo`030000o`3oool0oooo01L0oooo
00<0003o0?ooo`3oool05P3oool007l0oooo00<0003o0?ooo`3oool0603o
ool00`000?l0oooo0?ooo`0;0?ooo`80o`002P3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`080?ooo`80o`003@3o
ool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo01H0oooo001o
0?ooo`030000o`3oool0oooo01T0oooo00<0003o0?ooo`3oool0203oool2
0?l000d0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00l0oooo00<0o`00
0?ooo`3oool02`3oool20?l000X0oooo00<0003o0?ooo`3oool06@3oool0
0`000?l0oooo0?ooo`0F0?ooo`00O`3oool00`000?l0oooo0?ooo`0J0?oo
o`030000o`3oool0oooo00D0oooo0P3o000?0?ooo`030?l0003oool0oooo
00l0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00d0oooo0P3o00070?oo
o`030000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool05P3oool007l0
oooo00<0003o0?ooo`3oool06P3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00l0oooo00<0o`000?ooo`3oool03`3oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool05P3oool007l0oooo
00<0003o0?ooo`3oool06`3oool010000?l0oooo0?ooo`3oool20?l001<0
oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo0080oooo5@000?l40?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool06`3oool00`000?l0
oooo0?ooo`0F0?ooo`00O`3oool00`000?l0oooo0?ooo`0L0?ooo`030000
o`3oool0o`0001D0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`060?ooo`/0003o2P3oool00`000?l0oooo0?ooo`080?ooo`/0003o
203oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0180oooo
0P3o00000`3oool0003o0?ooo`0M0?ooo`030000o`3oool0oooo01H0oooo
001o0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool05@3o
ool00`3o0000oooo0?ooo`0>0?ooo`040000o`3oool0oooo0?ooo`D0003o
1P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0103oool40000o`@0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo01d0oooo
00<0003o0?ooo`3oool05P3oool007l0oooo00<0003o0?ooo`3oool0703o
ool00`3o0000oooo0000o`0F0?ooo`030?l0003oool0oooo00h0oooo1000
0?l;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`080?ooo`D0003o403oool00`3o0000oooo0?oo
o`0D0?ooo`030000o`3oool0o`0001h0oooo00<0003o0?ooo`3oool05P3o
ool007l0oooo00<0003o0?ooo`3oool06`3oool01@3o0000oooo0?ooo`3o
ool0003o01D0oooo00<0o`000?ooo`3oool02`3oool40000o`h0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo0`000?l>0?ooo`030?l0003oool0oooo01<0oooo00D0
003o0?ooo`3oool0oooo0?l0000M0?ooo`030000o`3oool0oooo01H0oooo
001o0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo00H0oooo1000
0?l40?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00@0
003o0?ooo`3oool0oooo10000?l90?ooo`030?l0003oool0oooo01@0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0J0?ooo`030000
o`3oool0oooo01H0oooo001o0?ooo`030000o`3oool0oooo01T0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003o
ool0oooo0080oooo10000?l80?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool01@3oool30000o`H0oooo00<0
o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo01T0oooo00<0003o0?ooo`3oool05P3oool007l0oooo00<0003o
0?ooo`3oool0603oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo01<0oooo00@0o`000?ooo`000?l0003o303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00P0oooo0`00
0?l20?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo01H0oooo001o
0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`0B0?ooo`80003o3P3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo0`000?lD
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool05`3oool0
0`000?l0oooo0?ooo`0F0?ooo`00O`3oool00`000?l0oooo0?ooo`0G0?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool03`3oool20000
o`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l000000?l0003o
0140oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0F0?oo
o`030000o`3oool0oooo01H0oooo001o0?ooo`030000o`3oool0oooo01H0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`80
003o0`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool03@3oool0103o0000
oooo0?ooo`3oool20000o`h0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01H0oooo001o0?ooo`03
0000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`090?ooo`80003o1@3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`030?ooo`80003o303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3o
ool05P3oool007l0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00H0oooo0P000?l80?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo01@0oooo00<0003o0?ooo`3oool05P3oool007l0oooo00<0
003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`070?ooo`80003o1`3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo01@0oooo00<0
003o0?ooo`3oool05P3oool007l0oooo00<0003o0?l0003o00000`3o000@
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool02`3oool0103o0000oooo0?ooo`3ooolC0?l000@0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo00h0oooo1@3o00000`000?l0oooo0?oo
o`0F0?ooo`00O`3oool00`000?l0oooo0?ooo`030?ooo`H0o`002P3oool0
0`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo0080003o3@3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00D0oooo2P3o0009
0?ooo`030000o`3oool0oooo00L0oooo2P3o00070?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool02`3oool20000o`<0oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`080?ooo`H0o`001@3oool0
0`000?l0oooo0?ooo`0F0?ooo`00O`3oool00`000?l0oooo0?ooo`090?oo
o`<0o`001P3oool00`3o0000oooo0?ooo`0D0?ooo`80003o403oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00@0o`001`3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool0103oool50?l000030?ooo`000?l0oooo00h0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0000o`0E0?ooo`030?l0003oool0oooo
00@0oooo0`3o000;0?ooo`030000o`3oool0oooo01H0oooo001o0?ooo`03
0000o`3oool0oooo00`0oooo0P3o00040?ooo`030?l0003oool0oooo01@0
oooo0P000?l@0?ooo`030?l0003oool0oooo00/0oooo103o000;0?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`090?ooo`@0o`00303oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool00P3oool20?l000h0
oooo00<0003o0?ooo`3oool05P3oool007l0oooo00<0003o0?ooo`3oool0
3P3oool20?l000030?ooo`3o0000oooo01D0oooo00@0003o0?ooo`3oool0
003o403oool00`3o0000oooo0?ooo`080?ooo`80o`0000<0oooo0000o`3o
ool0303oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`020?l000X0
oooo00<0o`000?ooo`3oool03P3oool010000?l0oooo0000o`000?lE0?oo
o`040?l0003oool0o`000?l00100oooo00<0003o0?ooo`3oool05P3oool0
07l0oooo00<0003o0?ooo`3oool0403oool20?l001D0oooo00D0003o0?oo
o`3oool0oooo0000o`0@0?ooo`030?l0003oool0oooo00D0oooo0`3o0003
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool00P3oool30?l000H0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0180oooo0P3o000B
0?ooo`030000o`3oool0oooo01H0oooo001o0?ooo`030000o`3oool0oooo
0100oooo00@0o`000?ooo`3o0000o`004P3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool00P3oool2
0?l000L0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`060?ooo`80o`00103oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool03`3oool2
0?l000030?ooo`3o0000oooo0140oooo00<0003o0?ooo`3oool05P3oool0
07l0oooo00<0003o0?ooo`3oool0403oool0103o0000oooo0?ooo`3oool2
0?l000l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo0080o`002@3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo0P3o0000
0`3oool0o`000?ooo`0?0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool0303oool20?l000<0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0F0?ooo`00O`3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00`0oooo0`3o000;0?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool02P3oool20?l000l0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?oo
o`3oool03`3oool00`000?l0oooo0?ooo`0F0?ooo`00O`3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo00D0oooo0P3o000:0?ooo`03
0000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool02`3oool30?l000`0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`0:0?ooo`040?l0003oool0o`000?l000`0oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0F0?oo
o`00O`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00P0oooo0P3o00020?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?ooo`80o`002@3oool00`00
0?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00D0oooo0P3o00090?oo
o`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool05P3oool007l0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`090?ooo`80
o`001@3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00D0
oooo0P3o00050?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00@0oooo0P3o00060?ooo`030000o`3oool0oooo00`0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`090?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool05P3oool007l0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`050?l0
003oool0oooo0?ooo`000?l03`3oool00`000?l0oooo0?ooo`030?ooo`80
o`001`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool00`3oool;0000o`H0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00H0
oooo0P3o00040?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool05P3oool007l0oooo00<0003o0?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`0=0?ooo`80o`0000<0003o0?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`020?l000T0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`090?ooo`L0003o1@3oool00`000?l0oooo
0?ooo`030?ooo`P0003o2P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00P0oooo0P3o00000`3oool0003o0?ooo`0@0?ooo`040000
o`3oool0o`000?l000h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`0F0?ooo`00O`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`000?l0o`00
0?l0000<0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
20000?l00`3oool0o`000?ooo`090?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`000?l01P000?l20?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02`3oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0F0?ooo`00O`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3o00003`3oool20?l000030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool02@3oool40000o`T0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00H0oooo10000?l;0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?l0003oool0403oool00`3o0000003o0?ooo`0@0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool05P3oool007l0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0>0?ooo`050000o`3oool0
oooo0?ooo`3o00003@3oool01@3o0000oooo0?ooo`3oool0003o00d0oooo
00<0o`000?ooo`3oool0103oool40000o`030?ooo`000?l0oooo00X0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00@0003o0?ooo`000?l0003o203oool00`3o0000
oooo0?ooo`0;0?ooo`040000o`3oool0oooo0?l000l0oooo00@0o`000?oo
o`3oool0003o403oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo01H0oooo001o0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`030?ooo`80o`002P3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo00@0o`000?oo
o`3oool0oooo0`000?l50?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool00P3oool20000o`H0oooo00<0o`00
0?ooo`3oool02`3oool010000?l0oooo0?ooo`3oool20?l000/0oooo0P3o
00040?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0F0?ooo`00O`3oool80000o`H0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo0P3o00060?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0000o`000?l02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
000000@000000`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool0103oool30000o`80oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo00@0oooo20000?lH0?ooo`00O`3oool00`00
0?l0oooo0?ooo`050?ooo`D0003o00<0oooo0?l0003oool03P3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`090?ooo`80003o2`3oool00`00
0?l0oooo0?ooo`090?ooo`050?l0003oool0oooo0?ooo`0000001@3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool01`3oool20000o`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0000o`04
0000o`L0oooo00<0003o0?ooo`3oool05P3oool007l0oooo00<0003o0?oo
o`3oool02P3oool010000?l0o`000000o`000?l<0?ooo`030000o`3oool0
oooo00T0oooo00D0o`000?ooo`3oool0oooo0?l0000:0?ooo`030000o`3o
ool0oooo00L0oooo0P000?l00`3oool0o`000?ooo`0:0?ooo`030000o`3o
ool0oooo00T0oooo00D0o`000?ooo`3oool0oooo000000050?ooo`030000
o`000000000000P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`090?ooo`80003o2`3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00<0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`0;0?ooo`80003o00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0F0?ooo`00O`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00<0003o203oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0o`0000`0oooo00<0003o0?ooo`3oool0103oool20000o`@0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`050?l0003o
ool0oooo0?ooo`0000001@3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`030000o`L0oooo00<0003o0?ooo`3oool02@3oool01@3o0000oooo
0?ooo`3oool0o`0000`0oooo00<0003o0?ooo`3oool01`3oool30000o`80
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0F0?ooo`00
O`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo
0P000?l50?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
303oool010000?l0oooo0?ooo`3oool20000o`H0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`080?ooo`050?l0003oool0oooo0?oo
o`0000001@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?oo
o`80003o103oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0o`00
00h0oooo00<0003o0?ooo`3oool0103oool20000o`D0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0F0?ooo`00O`3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo0P000?l30?ooo`03
0000o`3oool0oooo00d0oooo0P3o000=0?ooo`040000o`3oool0003o0000
o`T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo008000002`3o00050?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?oo
o`80003o0P3oool00`000?l0oooo0?ooo`0;0?ooo`<0o`003P3oool00`00
0?l0oooo0?ooo`020?ooo`80003o1`3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo01H0oooo001o0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool0203oool30000o`l0oooo00@0o`000?ooo`3o
ool0o`003@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0103oool90?l000D0oooo00<0003o0?oo
o`3oool00`3oool:0?l000D0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`080?ooo`80003o3@3oool01@3o0000oooo0?ooo`3oool0
o`0000h0oooo00@0003o0?ooo`000?l0003o2P3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo01H0oooo001o0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0000o`0;0?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3o00000`3o00040?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`030?ooo`<0o`000P3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00@0003o
0?ooo`000?l0003o2P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo00/0oooo0P000?l<0?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool05P3oool007l0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0:0?ooo`040000o`3oool0003o0000o`/0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`80003o0P3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00L0oooo0`3o
00080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`<0o`002@3oool00`3o0000oooo0?oo
o`090?ooo`050000o`3oool0oooo0?ooo`000?l0203oool00`3o0000oooo
0?ooo`050?ooo`030?l0003oool0oooo00P0oooo0P000?l00`3oool0003o
0?ooo`0;0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
5P3oool007l0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0:0?ooo`040000o`3oool0oooo0?ooo`80003o203oool00`3o0000oooo
0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00@0oooo
0`3o00000`3oool0003o0?ooo`080?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0o`000080o`001P3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00<0oooo0P000?l50?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool20000o`<0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo01H0oooo
001o0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`040?ooo`80003o1@3oool00`3o0000oooo0?oo
o`080?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00<0o`001@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo0080oooo0`3o00020?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool01P3oool01@000?l0oooo0?ooo`3oool0o`0000X0oooo
00<0o`000?ooo`3oool00`3oool20000o`H0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo01H0oooo
001o0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool02@3oool0103o0000oooo0?ooo`000?l80?ooo`030000
o`3oool0oooo00P0oooo0`3o00080?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool30?l000X0oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?l0000<0?ooo`050?l0
003oool0oooo0?ooo`000?l0203oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool05P3oool007l0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00P0oooo0P000?l00`3oool0o`000?ooo`0<0?ooo`030?l0
00000?l0oooo00T0oooo00<0003o0?ooo`3oool01@3oool20?l000030?oo
o`3o0000oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`070?ooo`<0o`001`3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00@0o`000?ooo`3oool0
003o2P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool05P3oool007l0oooo00<0003o0?l0003o0000
1`3o00000`3oool0o`000?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02`3oool20000o`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool00`3oool20?l000<0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00L0oooo00@0o`000?ooo`3oool0oooo0P3o00040?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`000?l03@3oool00`3o0000
003o0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
0000203o00000`000?l0oooo0?ooo`0F0?ooo`00O`3oool00`000?l0oooo
0?ooo`070?ooo`<0o`002P3oool00`000?l0oooo0?ooo`090?ooo`040?l0
003oool0003o0000o`X0oooo00@0003o0?ooo`3oool0o`002`3oool00`00
0?l0oooo0?ooo`020?l000H0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool00`3oool20?l00080oooo00<0003o0?oo
o`3oool02@3oool0103o0000oooo0?ooo`000?l;0?ooo`030000o`3oool0
o`0000/0oooo00<0003o0?ooo`3oool0203oool30?l000T0oooo00<0003o
0?ooo`3oool05P3oool007l0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?l000030?l000D0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o0000o`00
00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?oo
oaD0003o203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo0P3o000;0?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool01`3oool010000?l0oooo0?ooo`3o000<0?ooo`030000o`3oool0
oooo00<0oooo103o00020?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool05P3oool007l0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`040?ooo`@0o`0000<0oooo0000o`3oool02P3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`060?ooo`80o`0000<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0003o
00D0003o00<0oooo0?l0003oool01`3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0003o00D0003o00<0oooo0000o`3oool0203oool00`3o
0000oooo0?ooo`070?ooo`030000o`3o0000o`0000P0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`030?l0
00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0F0?oo
o`00O`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?l0003oool02@3oool00`3o0000oooo0?ooo`050?ooo`80
003o0`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo0P3o00020?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool01@3oool30000o`L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo0`000?l70?ooo`03
0?l0003oool0oooo00L0oooo00@0003o0?ooo`3oool0oooo0P3o00060?oo
o`030?l0003oool0oooo00D0oooo0P000?l30?ooo`80003o1P3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3o0000oooo00P0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`0F0?ooo`00O`3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00@0003o0?ooo`3o
0000o`001`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0003o
00T0oooo00@0o`000?ooo`3oool0oooo0P3o00050?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool00`3oool20000o`030?ooo`000?l0
oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`000?l00P000?l4
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool2
0?l000<0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0000o`08
0?ooo`030?l0003oool0oooo00L0oooo0P3o00000`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool05P3oool0
07l0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo0080oooo0P3o00040?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?l000080?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`000?l00P000?l40?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool00P3oool40000o`X0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?l0000<0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool0103oool20?l000<0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo01H0oooo001o0?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`040?ooo`80o`000P3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0003o00X0oooo0P3o00090?ooo`030000o`3oool0oooo00H0
oooo0`000?l70?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool0103o0000003o0000o`000?l60?oo
o`030000o`3oool0oooo00L0oooo0P3o000;0?ooo`030000o`3oool0003o
00X0oooo00@0o`000?ooo`3oool0oooo0P3o00050?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0F
0?ooo`00O`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool01P3oool20?l000/0oooo00D0003o0?oo
o`3oool0oooo0000o`080?ooo`030?l0003oool0o`0000X0oooo00<0003o
0?ooo`3oool00P3oool30000o`030?ooo`3o0000oooo00L0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`040?l0003oool0oooo0?ooo`80003o103oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0o`0000T0oooo00D0003o0?ooo`3oool0oooo
0000o`090?ooo`040?l0003oool0o`000?l000L0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo01H0
oooo001o0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`080?ooo`<0o`002@3oool01@000?l0oooo
0?ooo`3oool0003o00L0oooo00D0o`000?ooo`3oool0oooo0?l000090?oo
o`030000o`3oool0oooo0080003o1@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`80003o00<0oooo0000
o`3oool02@3oool0103o0000oooo0?ooo`3o00070?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool01`3oool20?l000X0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo01H0oooo001o0?ooo`L0003o0P3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00L0oooo00D0o`000?ooo`3oool0oooo0?l00007
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00L0oooo0P000?l7
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo0P000?l90?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo0P3o00000`3oool0o`000?ooo`090?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01`000?lH0?ooo`00QP3oool20000
o`030?l000000?l0003o0080003o1@3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo0080oooo0P3o00040?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool00P3o00070?ooo`030?l0003oool0oooo
00@0oooo0`000?l90?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool00P3ooolH0?l000@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`040000o`3oool0003o0000o`H0oooo00<0o`00
0?ooo`3oool0103oool20?l00080oooo00<0003o0?ooo`3oool01P3oool0
10000?l0oooo0?ooo`3oool20?l000@0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`030?ooo`@0003o00<0o`000000o`000?l07`3o
ool008d0oooo0`000?l00`3oool0003o0?ooo`080?ooo`030?l0003oool0
oooo00D0oooo0P3o00000`3oool0003o0?ooo`080?ooo`030000o`3o0000
oooo00P0oooo00<0o`000?ooo`3oool00P3oool20000o`<0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`H0o`000`3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool00P3oool50?l000L0oooo00<0o`000?ooo`3oool01P3oool0
10000?l0oooo0?ooo`3oool20000o`<0oooo00<0o`000?ooo`3oool01`3o
ool00`3o0000003o0?ooo`090?ooo`030000o`3o0000o`0000L0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0000o`020000obH0oooo002@
0?ooo`<0003o203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00P0oooo00<0o`000000o`3oool02@3oool0103o0000oooo0?ooo`00
0?l50?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P3o
ool20?l00080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool010000?l0oooo0?l0003o00050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0103oool20000o`030?ooo`3o0000oooo00P0oooo
00<0003o0?l0003oool02@3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo0`000?lY0?ooo`00T`3oool30000o`@0oooo00<0
o`000?ooo`3oool0203oool00`000?l0o`000?ooo`070?ooo`040?l0003o
ool0oooo0000o`X0oooo0P000?l70?ooo`030000o`3oool0oooo00D0oooo
1@3o00040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00@0003o0?ooo`3oool0oooo1@3o00080?ooo`030000o`3oool0oooo00H0
oooo0P000?l80?ooo`040000o`3oool0oooo0?l000P0oooo00<0o`000?oo
o`000?l02@3oool00`3o0000oooo0?ooo`020?ooo`<0003o;03oool009H0
oooo0`000?l00`3oool0o`000?ooo`080?ooo`040000o`3oool0oooo0?l0
00H0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?oo
o`80003o00<0oooo0?l0003oool01P3oool00`000?l0oooo0?ooo`020?oo
o`D0o`001`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo103o00040?ooo`030000o`3oool0oooo
00H0oooo00@0o`000?ooo`3oool0003o1P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00@0oooo00@0o`000?ooo`3oool0003o2@3o
ool00`3o0000oooo0000o`020000obl0oooo002I0?ooo`030?l000000?l0
oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
1@000?l0oooo0?ooo`3oool0o`0000L0oooo00<0003o0?ooo`3oool00P3o
00040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo0080oooo0P3o00020?ooo`030000o`3oool0oooo00H0oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?l0003oool0<@3oool009/0oooo0P00
0?l50?ooo`030000o`3oool0oooo00@0oooo00@0o`000?ooo`3oool0o`00
1`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool01@3oool20?l000H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool20?l000P0oooo
00<0o`000?ooo`3oool00`3oool20000o`030?ooo`000?l0oooo00L0oooo
00@0o`000?ooo`3oool0o`001P3oool00`000?l0oooo0?ooo`030?ooo`80
003o=03oool009d0oooo0P000?l20?ooo`030000o`3oool0oooo00H0oooo
0P3o00090?ooo`040000o`3oool0003o0000o`H0oooo00<0o`000?ooo`3o
ool00`3oool20?l000030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0003o00X0
003o00<0oooo0?l0003oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?l0003o00001P3oool00`3o0000
oooo0?ooo`050?ooo`80003o2@3oool20?l000L0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0d0?ooo`00W`3oool30000o`P0oooo
0`3o00090?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
0P3o00030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0000o`060000o`D0oooo00<0003o0?ooo`3oool0
0`3oool80000o`030?ooo`000?l0oooo00H0oooo00<0o`000?ooo`3oool0
103oool010000?l0oooo0?ooo`3oool20?l000<0oooo00<0o`000?ooo`3o
ool01P3oool20000o`P0oooo0`3o00080?ooo`040000o`3oool0003o0000
ocL0oooo002P0?ooo`80003o1`3oool01@3o0000oooo0?ooo`3oool0o`00
00L0oooo00<0003o0?ooo`000?l0203oool30?l000D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`@0003o1@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool30000o`D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0o`0000P0oooo00@0003o0?oo
o`3oool0003o1P3oool01@3o0000oooo0?ooo`3oool0o`0000P0oooo00<0
003o0?ooo`3oool0=`3oool00:80oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00@0003o
0?ooo`3oool0003o1`3oool30?l000H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000003o0000o`020000o`80oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0000o`040000o`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool20?l000L0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool20000ocX0oooo002S
0?ooo`80003o0P3oool00`3o0000oooo0?ooo`050?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`030?ooo`040?l0003o
ool0oooo0?l000L0oooo00<0003o0?ooo`3oool00P3oool40000o`H0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`<0003o103oool00`000?l0oooo0?ooo`050?ooo`040?l0
003oool0o`000?l000D0oooo00<0003o0?ooo`3oool00`3oool010000?l0
oooo0?ooo`3o00060?ooo`040?l0003oool0oooo0?ooo`80003o?03oool0
0:D0oooo00<0003o0?ooo`3o0000203oool00`3o0000oooo0000o`060?oo
o`030000o`3oool0oooo0080o`00103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo0080003o0`3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool0103o0000oooo0?ooo`3oool20000o`030?ooo`000?l0
oooo00H0oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00L0oooo00<0003o0?ooo`3o00001`3oool00`3o0000oooo0000
o`0n0?ooo`00YP3oool00`3o0000oooo0?ooo`070?ooo`80003o203oool0
0`000?l0o`000?ooo`050?ooo`030?l0003oool0oooo00D0oooo0P000?l5
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo0`000?l50?ooo`030?l0003oool0oooo00@0oooo0P3o0000
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool0?@3oool00:L0oooo0P000?l60?ooo`040000o`3oool0oooo
0?l000L0oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`02
0?ooo`<0003o1`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3o0000303o00060?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0000o`00
0?l30?ooo`030?l0003oool0oooo00D0oooo00<0003o0?l0003oool01`3o
ool00`3o0000oooo0000o`070?ooo`030000o`3oool0oooo03h0oooo002Y
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`80o`0000<0oooo0000o`3oool01P3oool0
0`3o0000oooo0?ooo`020000o`<0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0o`0000D0o`001@3oool0
0`000?l0oooo0?ooo`040?ooo`H0o`0000<0oooo0000o`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo0P000?l0
0`3o0000oooo0?ooo`060?ooo`040000o`3oool0o`000?l000@0oooo0P3o
00030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0?`3o
ool00:X0oooo00@0003o0?ooo`3oool0003o1P3oool0103o0000oooo0?oo
o`3o00040?ooo`030000o`3oool0oooo00D0oooo0P000?l50?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3o00050?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`030?ooo`H0o`0000<0oooo0?l0003oool01@3oool00`000?l0oooo
0?ooo`040?ooo`80003o1P3oool00`000?l0oooo0?ooo`020?ooo`80o`00
00<0oooo0?l0003oool01@3oool01@000?l0oooo0?ooo`3oool0003o0480
oooo002[0?ooo`030000o`3oool0003o00L0oooo0P3o00060?ooo`030000
o`3oool0oooo0080oooo0P000?l00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00<0oooo0`3o00040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool20?l000H0oooo
00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`000?l40?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool30000od<0
oooo002/0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`020000o`<0oooo00<0o`000?ooo`3oool0
103oool010000?l0oooo0?ooo`3oool40?l000D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0o`000080o`000P3oool00`000?l0oooo0?ooo`040?ooo`04
0?l0003oool0oooo0?ooo`80003o0P3oool00`000?l0oooo0?ooo`050?oo
o`80o`001`3oool00`000?l0oooo0?ooo`130?ooo`00[@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0o`0000L0oooo0P000?l50?ooo`03
0?l0003oool0oooo00@0oooo00@0003o0?l0003o0000o`000`3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?oo
o`<0o`001@3oool00`3o0000oooo0?ooo`040?ooo`80003o1`3oool0103o
0000oooo0?ooo`3o00050?ooo`030000o`3oool0oooo04@0oooo002^0?oo
o`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l00004
0?ooo`80003o00<0oooo0000o`3oool01@3oool00`3o0000oooo0?ooo`02
0?ooo`80o`0000<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`040000o`3oool0
o`000?l000<0oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0000
o`000?l50?ooo`050?l0003oool0oooo0?ooo`3o00000`3oool00`000?l0
oooo0?ooo`150?ooo`00[`3oool010000?l0oooo0?ooo`3o00050?ooo`04
0?l0003oool0oooo0000o`<0oooo00<0003o0?ooo`3oool01@3oool40?l0
0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0003o01@0003o00<0oooo0000o`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`040000o`3oool0oooo0?ooo`@0o`001P3oool0
10000?l0oooo0?ooo`3oool20000o`80oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0000o`180?ooo`00/03oool00`000?l0o`000?ooo`05
0?ooo`030?l0003oool0003o00D0oooo00<0003o0?ooo`3oool00P3oool3
0?l000D0oooo00<0003o0?ooo`3oool0103oool00`3o0000003o0000o`05
0000o`@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo0080oooo0`000?l40?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool30?l000@0oooo00<0003o
0?ooo`3oool0103oool00`000?l0o`000?ooo`060?ooo`030?l0003oool0
oooo04L0oooo002a0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool010000?l0oooo0?l0003o00030?ooo`030?l0003oool0
oooo00<0oooo00@0003o0?ooo`3oool0oooo0`000?l50?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`000?l00`00
0?l00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00P3o00020?ooo`030000o`3oool0oooo00@0oooo00<0
o`000000o`3oool01@3oool00`000?l0oooo0?ooo`180?ooo`00/P3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0o`0000L0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`040000o`3oool0
003o0000o`80oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo1000
0?l20?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool20?l000H0oooo00@0o`000?ooo`3oool0003o103oool00`000?l0oooo
0?ooo`190?ooo`00/`3oool00`000?l0oooo0?ooo`020000o`<0oooo00<0
o`000?ooo`3oool00P3oool20?l000030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool20000o`@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00P3oool40000o`@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0o`000?l000040?ooo`040?l0003o
ool0oooo0?ooo`80003o00<0oooo0000o`3oool0B`3oool00;@0oooo0P00
0?l60?ooo`040?l0003oool0o`000?l000<0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0000o`020000o`030?ooo`000?l0oooo00@0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020000o`030?ooo`3o0000oooo00D0oooo
00D0003o0?ooo`3oool0oooo0?l000020?ooo`030?l0003oool0oooo00@0
oooo0P000?m<0?ooo`00]@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool20000o`D0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oooaT0o`00
103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
0P000?l50?ooo`030000o`3oool0oooo00<0oooo0P3o00070?ooo`030000
o`3oool0oooo04/0oooo002f0?ooo`030000o`3oool0oooo00<0oooo0P3o
00060?ooo`030000o`3oool0oooo0080003o00<0oooo0?l0003oool0103o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0o`000080o`0000<0
oooo0000o`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?l0
00040?l000@0oooo00<0003o0?ooo`3oool0103oool0103o0000003o0000
o`000?l20?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool20000odh0oooo002g0?ooo`050000o`3oool0oooo0?ooo`3o0000
0P3oool00`3o0000oooo0?ooo`030?ooo`<0003o0`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00@0o`00103oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
1@3o00000`3oool0003o0?ooo`040?ooo`030?l0003oool0oooo0080oooo
0P000?l60?ooo`030?l0003oool0o`0000<0oooo00<0003o0?ooo`3oool0
CP3oool00;P0oooo00<0003o0?l0003o0000103oool00`3o0000oooo0?oo
o`030000o`H0oooo00@0o`000?ooo`3oool0oooo103o00030?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
0`3o00040?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`000?l0
003o0`3oool0103o0000oooo0?ooo`3oool20?l000030000o`3oool0oooo
04l0oooo002h0?ooo`030?l000000?l0oooo00@0oooo00<0o`000?ooo`00
0?l00`3oool00`000?l0oooo0?ooo`030?ooo`@0o`000P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3o00000`3oool0
o`000?ooo`040?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo04l0oooo002j0?ooo`03
0000o`3oool0oooo0080oooo0P000?l40?ooo`030000o`3oool0oooo0080
oooo0P3o00050?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0000o`0B0000o`D0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`80o`00103oool00`000?l0
oooo0?ooo`030?ooo`80003o1@3oool00`000?l0oooo0?ooo`1@0?ooo`00
^`3oool010000?l0oooo0?ooo`000?l20?ooo`030?l0003oool0oooo0080
oooo00@0003o0?ooo`3o0000o`000P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00<0oooo00<0o`000000o`000?l010000?l30?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`H0003o1@3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0o`000080o`0000<0oooo0000o`3oool0103oool00`3o
0000oooo0000o`030?ooo`030000o`3oool0oooo0540oooo002k0?ooo`<0
003o0`3oool00`3o0000oooo0?ooo`020?ooo`80o`00103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0003o00<0003o103oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00H0o`000000o`000?l0003o0?ooo`000?l50?ooo`030?l0003oool0
oooo0080oooo0P3o00050?ooo`030?l0003oool0oooo0080003o00<0oooo
0000o`3oool0DP3oool00;/0oooo0P000?l50?ooo`060?l0003oool0o`00
0?l0003oool0003o103oool00`3o0000oooo0?ooo`020?ooo`<0003o0`3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?oo
o`3oool30000o`@0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo
0?l0003o00020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0DP3oool00;`0oooo00<0003o0?ooo`3oool00`3oool20?l000<0oooo
00<0003o0?ooo`3oool00`3oool01P3o0000003o0000o`000?l0oooo0000
o`D0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0000o`030000o`D0oooo00@0003o0?ooo`3oool0oooo0P3o
00050?ooo`030000o`3oool0oooo05<0oooo002m0?ooo`070000o`3oool0
oooo0?ooo`3o0000oooo0?l000040?ooo`030000o`3oool0oooo00<0003o
1@3oool00`000?l0oooo0?ooo`020?ooo`060?l0003oool0oooo0?ooo`00
0?l0oooo4@3o00000`3oool0003o0?ooo`030?ooo`050?l0003oool0oooo
0?ooo`000?l01@3oool01P3o0000003o0000o`000?l0oooo0000o`D0oooo
0`3o00030?ooo`030000o`3oool0oooo05<0oooo002m0?ooo`040000o`3o
ool0o`000?l00080oooo00<0o`000?ooo`3oool00P3oool30000o`80oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`H0o`00
0`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
00@0o`000?ooo`3oool0oooo1`3o00030?ooo`030000o`3oool0oooo00<0
oooo00@0o`000?ooo`3oool0oooo0P000?l40?ooo`070?l0003oool0oooo
0?ooo`3o0000oooo0000o`1F0?ooo`00_P3oool00`3o0000oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0003o103oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0o`0000<0o`00103oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`040000o`3oool0oooo0?ooo`@0o`0000<0oooo0000o`3oool0
0`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0003o00<0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`1E0?ooo`00_`3o
ool00`000?l0oooo0?ooo`020?ooo`030?l000000?l0003o0080oooo00<0
003o0?ooo`3oool00P3oool70?l000<0oooo00<0o`000?ooo`3oool00P3o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o
00000`3oool50?l000030?ooo`3o0000oooo0080oooo00@0003o0?ooo`3o
ool0oooo0P000?l00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
05H0oooo00300?ooo`030000o`3oool0oooo0080003o00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?l000D0oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0?ooo`80o`00
0`3oool00`000?l0oooo0?ooo`030?ooo`80003o0`3oool00`000?l0oooo
0?ooo`1F0?ooo`00`03oool00`000?l0oooo0000o`020?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3o00000P3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool05@00
0?l20?ooo`030?l0003oool0oooo00<0oooo00H0003o0?ooo`3oool0oooo
0?l0003oool20?l000030?ooo`000?l0oooo00<0oooo00<0o`000?ooo`3o
ool00`000?mI0?ooo`00`@3oool00`000?l0oooo0?ooo`020?ooo`040?l0
003oool0oooo0?ooo`80o`000`3oool00`3o0000oooo0?ooo`030?ooo`L0
003o00<0oooo0000o`0000000`3oool01@3o0000oooo0?ooo`3oool0003o
00@0oooo00H0o`000?ooo`3oool0oooo0000o`3oool60000o`030?ooo`00
0?l0oooo00<0oooo00@0o`000?ooo`3oool0oooo0P3o00030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0E`3oool00<40oooo00<0
003o0?ooo`3oool00P3oool40?l000030?ooo`000?l0oooo0080oooo00<0
o`000?ooo`3oool00P3oool20000o`<0oooo00<0o`000?ooo`3oool00P3o
ool01@000?l000000?ooo`3oool0o`0000<0oooo00D0003o000000000000
oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool30000
o`80oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?l000030?l0
00@0oooo00<0003o0?ooo`3oool0F03oool00<80oooo00<0003o0?ooo`3o
ool00`3o00030?ooo`030000o`3oool0oooo0080oooo00H0o`000000o`00
0?l0003o0?ooo`000?l30?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`000000oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`00
0?l0003o0?l000040?ooo`040000o`3oool0oooo0?ooo`<0o`000P3oool0
0`000?l0oooo0?ooo`1I0?ooo`00``3oool20?l00080oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0000o`020000o`@0oooo00D0003o0?oo
o`3oool0oooo0?l000030?oooa40o`0000<0oooo0000o`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo0`000?l00`3oool0003o0?oo
o`030?ooo`030?l0003oool0oooo0080o`0000<0003o0?ooo`3oool0F@3o
ool00<<0oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`3o
ool20000o`<0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`D0o`00
00H0oooo0000o`00000000000?ooo`3o00030?ooo`050000o`3oool0oooo
0?ooo`3o00000`3oool80?l000030?ooo`000?l0oooo0080oooo00@0o`00
0?ooo`3oool0oooo0`000?l20?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool0FP3oool00<@0oooo00<0003o0?ooo`3oool00P3oool4
0000o`@0oooo00@0o`000?ooo`3oool0oooo0`3o00020?ooo`050?l0003o
ool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0003o00<0
oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`040?l0003oool0oooo
0?ooo`<0o`000P3oool01@3o0000oooo0?ooo`3oool0003o0080oooo0P00
0?l00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo05X0oooo0034
0?ooo`030000o`3oool0oooo0080003o00D0o`000?ooo`3oool0oooo0000
o`030?ooo`@0o`0000<0oooo0000o`3oool00P3oool01@3o0000oooo0?oo
o`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`05
0?l0003oool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0
003o0080oooo0P3o00040?ooo`030000o`3oool0oooo0080oooo0P000?l2
0?ooo`030000o`3oool0oooo05/0oooo00350?ooo`80003o0`3oool00`3o
0000oooo0?ooo`060?l000<0oooo00D0003o0?ooo`3oool0oooo0?l00003
0?ooo`030000o`3oool0003o00h0003o0`3oool01@3o0000oooo0?ooo`3o
ool0003o00<0oooo1P3o00030?ooo`030?l0003oool0oooo0080003oGP3o
ool00<D0oooo00<0003o0?ooo`3oool00P3oool30?l000030?ooo`000?l0
oooo0080oooo00<0o`000?ooo`3oool00P3oool90000o`H0oooo00<00000
0?ooo`3oool01@3oool70000o`030?ooo`000?l0oooo0080oooo00H0o`00
0?ooo`3oool0oooo0000o`3oool20?l000030?ooo`3o0000oooo0080oooo
00<0003o0?ooo`3oool0G03oool00<H0oooo00<0003o0?ooo`3oool00P3o
00030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P00
0?l>0?ooo`030000003oool0oooo00`0oooo0P000?l30?ooo`050?l0003o
ool0oooo0?ooo`000?l00`3oool20?l00080oooo00<0003o0?ooo`3oool0
G@3oool00<H0oooo00<0003o0?ooo`3o00000P3oool0103o0000oooo0?oo
o`000?l20?ooo`D0003o403oool00`000000oooo0?ooo`0>0?ooo`D0003o
00<0oooo0000o`3oool00`3oool01@3o0000oooo0?l0003o0000003o05l0
oooo00360?ooo`030000o`3o0000oooo0080oooo00@0o`000?ooo`3oool0
oooo0P000?lE0?ooo`030000003oool0oooo01<0oooo0`000?l20?ooo`06
0?l0003oool0oooo0?ooo`000?l0o`00G`3oool00<L0oooo00<0003o0?oo
o`3oool00P3oool30000oaL0oooo00<000000?ooo`3oool05P3oool20000
o`050?l0003oool0oooo0?ooo`000?l0H03oool00<L0oooo00<0003o0?oo
o`3oool00P000?lJ0?ooo`030000003oool0oooo01P0oooo0P000?l00`3o
ool0003o0?ooo`1P0?ooo`00b03oool20000oa`0oooo00<000000?ooo`3o
ool06P3oool20000of40oooo003V0?ooo`030000003oool0oooo07d0oooo
003V0?ooo`030000003oool0oooo07d0oooo003V0?ooo`030000003oool0
oooo07d0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{358, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.72",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/schwarzchristoffel/\
SchwarzChristoffelFigures/mat1172.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The region with ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \(-\(\[Pi]\/2\)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \[Pi]\/2\)}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(\[Pi]\/2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(\[Pi]\/2\)}]}]]],
  "."
}], "Text"],

Cell[TextData[{
  "Solution.  If we choose  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 1\)}]]],
  ",  and  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \(-\(\[Pi]\/2\)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \[Pi]\/2\)}]]],
  ",  then the exterior angles are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(\[Pi]\/2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(\[Pi]\/2\)}]}]]],
  ",  and Equation ",
  StyleBox["(11-39)",
    FontColor->RGBColor[0, 0, 1]],
  " for ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " becomes  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z - \
\((\(-1\))\))\)\^\(\(-\((\[Pi]\/2)\)\)/\[Pi]\)\) \((z - \
1)\)\^\(\(-\((\[Pi]\/2)\)\)/\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(-\(1\/2\)\)\) \((z - 1)\)\^\(-\(1\/2\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \((z\^2 - \
1)\)\^\(-\(1\/2\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ 1\/\((z\^2 - 1)\)\^\
\(1\/2\)\)\)\)}]],
  " "
}], "Text"],

Cell[TextData[{
  "Then, using Table 11.2, the indefinite integral becomes \n\n\t\t\t",
  Cell[BoxData[{
      \(f \((z)\)\ \  = \ \ \[Integral]\(1\/\((z\^2 - 1)\)\^\(1\/2\)\) \
\[DifferentialD]z\ \  + \ \ B\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\[Cross]\[ImaginaryI]\ \
Arcsin\ z\ \  + \ \ B\)\)\)}],
    AspectRatioFixed->True],
  "  \n\nUsing the image values  ",
  Cell[BoxData[
      \(f \((\(-1\))\)\  = \ \(-\(\[Pi]\/2\)\)\)]],
  "  and  ",
  Cell[BoxData[
      \(f \((1)\)\  = \ \[Pi]\/2\)]],
  ", we obtain the system   \n\n\t\t\t",
  Cell[BoxData[{
      \(\(-\(\[Pi]\/2\)\)\ \  = \ \ A\[Cross]\[ImaginaryI]\ Arcsin\ \((\(-\
\[Pi]\)\/2)\)\ \  + \ \ B\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \[Pi]\/2\ \  = \ \ A\[Cross]\[ImaginaryI]\ Arcsin \((\[Pi]\/2)\)\ \
\  + \ \ B\)}]],
  " \n\nand simplifies to be \n\n\t\t\t",
  Cell[BoxData[{
      \(\(-\(\[Pi]\/2\)\)\ \  = \ \ \(-\(\[Pi]\/2\)\) 
            A\ \  + \ \ B\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \[Pi]\/2\ \  = \ \ \(\[Pi]\/2\) \[ImaginaryI]\ A\ \  + \ \ \
B\)}]],
  " \n\nwhich we can solve to obtain  ",
  Cell[BoxData[
      RowBox[{"B", "=", 
        RowBox[{
          RowBox[{"0", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "A"}], 
          "=", \(-\[ImaginaryI]\)}]}]]],
  ".  Hence the required function is \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\  = \ Arcsin\ z\)]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.26.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the formula ",
  Cell[BoxData[
      \(\(f'\)[z] = \(\(\ \)\(A\)\)\/\@\(z\^2\  - \ 1\)\)],
    AspectRatioFixed->True],
  " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[A, B, f, f1, z];\)\ \), "\n", 
    \(\(f1[z_]\  = \(\(\ \)\(A\)\)\/\@\(z\^2\  - \ 1\);\)\ \), "\n", 
    \(\(f[z_]\  = \ 
        B\  + \ \[Integral]\(\(\(\ \)\(A\)\)\/\@\(z\^2\  - \ 1\)\) \
\[DifferentialD]z;\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = B + \[Integral] \>", 
        f1[z], "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Remark.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "   No matter how tempting the integrand  ",
  Cell[BoxData[
      \(B + A\ Log[z + \@\(\(-1\) + z\^2\)]\)]],
  "  may seem, the logarithm does not have the proper branch cut for this \
problem, and we must use the familiar integrand  ",
  Cell[BoxData[
      \(B\  + \ A\ \ ArcSin[z]\)]],
  ".  Switching the order of terms in the square root will solve this \
problem."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[eq1, eq2, f, f1, F];\)\ \), "\n", 
    \(\(f1[z_]\  = \ A\/\@\(1\  - \ z\^2\);\)\ \), "\n", 
    \(\(F[z_]\  = \ 
        B\  + \ \[Integral]\(A\/\@\(1\  - \ z\^2\)\) \[DifferentialD]z;\)\ \
\), "\n", 
    \(\(Print["\<f'[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = B + \[Integral] \>", 
        f1[z], "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(eq1\  = \ F[\(-1\)]\  \[Equal] \(\(\ \)\(-\[Pi]\)\)\/2;\)\ \), "\n", 
    \(\(eq2\  = \ F[1]\  \[Equal] \ \ \[Pi]\/2;\)\ \), "\n", 
    \(\(solset\  = \ Solve[{eq1, eq2}, {A, B}];\)\ \), "\n", 
    \(\(f[z_]\  = \ 
        ReplaceAll[F[z], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \), "\n", 
    \(\(Print[eq1];\)\ \), "\n", 
    \(\(Print[eq2];\)\ \), "\n", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = B + A ArcSin[z]\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[
        f, {\(-2\), 2, 0.25}, {0.000001, 4.000001, 
          0.25}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-\[Pi]\)\/2, \[Pi]\
\/2, \[Pi]\/4], Range[0, 2, 1]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Red}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<is the semi infinite strip \!\(\(-\[Pi]\)\/2\)< u < \!\(\
\[Pi]\/2\), v > 0,\>\""];\)\ \), "\n", 
    \(\(Print["\<where  w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that  w = Arcsin(z)  maps the upper half plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  onto the semi infinite strip  ",
  Cell[BoxData[
      \(\(-\[Pi]\)\/2 < u < \[Pi]\/2, \ v > 0\)]],
  "."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.27.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Schwarz Christoffel formula to verify that  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ \((z\^2 - 1)\)\^\(1\/2\)\)\)]],
  "  maps the upper half plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  onto the upper half plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  "  slit along the line segment from  ",
  Cell[BoxData[
      \(\(\(w = \(0\ \ to\ \ w\_2 = \[ImaginaryI]\)\)\(\ \)\)\)]],
  ".  ",
  " (Use the principal square root throughout.)"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  If we choose  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_3 = 1\)}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \(-d\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_3 = d\)}]]],
  ",  then the formula\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(g' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\ \((z - x\_3)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z - \
\((\(-1\))\))\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - \
0)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\ \((z - 1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\)\
\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \
\((z)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\ \((z - \
1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\)\)}]],
  "\n\nwill determine a mapping ",
  Cell[BoxData[
      \(w\  = \ g \((z)\)\)]],
  " from the upper half-plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  onto the portion of the upper half-plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  "  that lies outside the triangle with vertices  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \(-d\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_3 = d\)}]]],
  "  as indicated in Figure 11.73(a).  If we let ",
  Cell[BoxData[
      \(d \[Rule] 0\)]],
  ",  then  ",
  Cell[BoxData[
      \(w\_1 \[Rule] \(0\ \ and\ \ w\_3 \[Rule] 0\)\)]],
  ", and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "\[Rule]", \(\[Pi]\/2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "\[Rule]", \(-\[Pi]\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "3"], "\[Rule]", \(\[Pi]\/2\)}]}]]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007l0000Nb000`400?l0
0000o`00003oo`3oooom0?ooo`00o`3oooom0?ooo`00o`3oooom0?ooo`00
o`3oooom0?ooo`00o`3oooom0?ooo`00o`3oooom0?ooo`00o`3oooom0?oo
o`00YP3oool400000440oooo1@0000220?ooo`D00000@03oool400000440
oooo002V0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
Q03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0480oooo
002W0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0Q03o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0440oooo002P
0?ooo`@00000103oool00`000000oooo0?ooo`0j0?ooo`@00000103oool0
0`000000oooo0?ooo`240?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool0@03oool00:H0oooo00@000000?ooo`3oool00000@`3oool0
0`000000oooo0?ooo`240?ooo`030000003oool0oooo0400oooo00@00000
0?ooo`3oool00000@@3oool00:L0oooo0P0000130?ooo`800000Q@3oool2
000004<0oooo0P0000120?ooo`00o`3oooom0?ooo`00o`3oooom0?ooo`00
o`3oooom0?ooo`00o`3oooom0?ooo`00o`3oooom0?ooo`00o`3oooom0?oo
o`00P`3ooonY0000o`<0000000@0003o0?l0000000000000ZP000?lO0?oo
o`00RP3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00T0
oooo00@000000?ooo`3oool0003o3`3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`00
0000oooo0000o`0E0?ooo`030?l0003oool0oooo02L0oooo1`000?lZ0?oo
o`030000o`3oool0oooo01<0oooo00<0o`000000003oool03`3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool0303oool0103o0000oooo0?ooo`00000<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0903oool008X0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`090?ooo`040000003oool0oooo
0000o`l0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00h0oooo00<000000?ooo`000?l05@3oool0
0`3o0000oooo0?ooo`0X0?ooo`<0003o0P3oool00`3o0000oooo0?ooo`0X
0?ooo`030000o`3oool0oooo01<0oooo00<0o`000000003oool03`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool0303oool0103o0000oooo0?ooo`00000<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0903oool008X0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04P3oool2
0?l002T0oooo00@0003o0?ooo`3oool0003o0`3oool00`3o0000oooo0?oo
o`0W0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0903oool008X0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04P3oool0
0`3o0000oooo0?ooo`0W0?ooo`050000o`3oool0oooo0?ooo`000?l0103o
ool00`3o0000oooo0?ooo`0V0?ooo`030000o`3oool0oooo01<0oooo00<0
o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0903o
ool008X0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0V0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0U
0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0903oool008X0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04P3oool00`3o
0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo
01<0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0903oool008X0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0T0?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`0T0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0903oool008<0oooo
A@3o00000`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0T0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0S0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`060?ooodl0o`007`3oool008X0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool03@3ooolM0?l000H0oooo00<0
003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0R0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool00P3o
oolF0?l000T0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0T0?ooo`00RP3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool02@3oool=0?l000l0oooo00<0o`000?ooo`3oool08P3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool08P3oool00`000?l0oooo0?ooo`0?0?ooo`P0o`003P3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0903oool008X0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0103oool60?l0
00T0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool08@3oool00`00
0?l0oooo0?ooo`030?ooo``0o`000`3oool00`3o0000oooo0?ooo`0@0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0T0?ooo`00RP3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0:0?ooo`X0
o`008P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool07P3oool80?l000l0oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0903oool008X0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
4P3oool70?l001`0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo01T0oooo103o00020?ooo`030000
o`3oool0oooo0180oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0903oool008X0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?oo
o`040?ooo`@0o`005`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool05@3oool30?l000L0oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0T0?ooo`00P`3ooolV0000o`l0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`08
0?ooo`80o`00503oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool04@3oool30?l000X0oooo00<0003o
0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=
0?ooobH0003o7`3oool008X0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?oooal0003o00<0oooo0000o`3oool03`3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0180oooo00<0o`000?oo
o`3oool02P3oool30?l00100oooo00<0003o0?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo0P3o000=0?oo
o`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo01d0003o00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
02@0oooo002:0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0
oooo2`000?l60?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`0=0?ooo`80o`003@3oool00`000?l0
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool02`3oool20?l000l0oooo00<0003o0?ooo`3oool04P3oool00`3o0000
oooo0?ooo`0=0?oooaH0003o3@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0T0?ooo`00RP3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00L0oooo4P000?l60?ooo`030000
o`3oool0oooo0180oooo00<0o`000?ooo`3oool0403oool20?l000/0oooo
00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00T0oooo0P3o000B0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool01@3oool80000o`80oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo02@0oooo002:0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`090?ooo`L0003o503oool00`3o0000oooo0?ooo`0B0?ooo`80o`00203o
ool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool01P3oool20?l001@0oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0000o`050000o`X0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo02@0oooo002:0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0?
0?ooo`H0003o3`3oool00`3o0000oooo0?ooo`0D0?ooo`80o`001@3oool0
0`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo0100oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0
oooo00T0oooo2P000?l@0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0T
0?ooo`00RP3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0>0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`030?ooo`H0003o2@3oool00`3o0000oooo0?ooo`0F0?oo
o`050?l0003oool0oooo0?ooo`000?l04P3oool00`000?l0oooo0?ooo`0A
0?ooo`040?l0003oool0oooo0?ooo`80o`005`3oool00`000?l0oooo0?oo
o`060?ooo`<0003o203oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0T0?ooo`00P`3oool:0?l000`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo00T0oooo1@000?l30?ooo`030?l0003oool0
oooo01P0oooo0P3o00000`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0
oooo0180oooo00<0o`000?ooo`3o00006@3oool010000?l0oooo0?ooo`3o
ool50000o`/0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00X0oooo2P3o
000O0?ooo`00RP3oool00`000?l0oooo0?ooo`0V0?l000@0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool03P3oool40000oa/0oooo00<0003o
0?l0003oool04P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0
oooo01L0oooo1@000?lA0?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00<0oooo9P3o00020?ooo`030?l0003oool0oooo02@0oooo002:0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`080?oooa@0o`0000<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0140oooo00@0o`000000
o`000?l0003o5`3oool010000?l0oooo0?ooo`3o000B0?ooo`030000o`3o
ool0oooo0140oooo0P3o00000`3oool0o`000?ooo`0D0?ooo`<0003o0P3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?l0000C0?l000X0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo02@0oooo002:0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00d0oooo2P3o00070?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo0?ooo`020?ooo`<0003o4`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo00l0oooo0`000?l50?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`050?ooo`X0o`003P3oool0
0`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0T0?ooo`00RP3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00L0oooo2P3o000>0?ooo`030000o`3oool0oooo0140oooo00<0o`000?oo
o`3oool01@3oool30000o`l0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`0<0?ooo`80003o203oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00d0oooo2P3o00080?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0903oool008X0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00P0
o`001P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00T0
oooo0P000?l<0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0
oooo00<0o`000?ooo`3oool02P3oool20000o`/0oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`050?ooo`P0o`000P3oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0903oool008X0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00T0oooo1P3o00000`000?l0oooo0?ooo`0@0?ooo`030?l0
003oool0oooo00/0oooo0P000?l90?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool20000o`d0oooo
00<0003o0?ooo`3oool0403oool00`3o0000oooo0?l000050?l000X0oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo02@0oooo002:0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0?0?ooo`D0o`003P3oool00`3o0000oooo0?oo
o`0=0?ooo`80003o1P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`090?ooo`030?l0003oool0oooo00@0oooo0P000?l?0?ooo`030000o`3o
ool0oooo00d0oooo1@3o000@0?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0T0?ooo`00P`3ooolL0000o`T0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`030?ooo`H0o`001`3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool01`3oool6
0?l000<0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`070?oooa`0003o7`3oool008T0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`040?oooa@0003o103oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`@0o`000`3oool00`3o
0000oooo0?ooo`0A0?ooo`80003o00<0oooo0000o`3oool03@3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool02`3oool00`3o0000oooo0?ooo`020000oa<0oooo00@0003o0?oo
o`3oool0oooo1@3o000:0?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00<0oooo4`000?l50?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0903oool008T0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00T0oooo4`000?l00`3o
ool0003o0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool03@3oool40?l001D0oooo0P000?l>0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030?l000000?l0oooo01@0oooo00@0003o0?ooo`3o0000o`003`3oool0
0`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`000?l04`000?l90?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0T0?ooo`00R@3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`X0003o1`3oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0100oooo0`3o000C0?oo
o`80003o3`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool03@3oool00`000?l0o`000?ooo`0C0?oo
o`<0o`004@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00D0oooo2P000?l>0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
02@0oooo00290?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool01P3oool80000oa00oooo00<0003o0?ooo`3o
ool03`3oool0103o0000oooo0?ooo`3oool30?l000l0oooo00@0003o0?oo
o`3oool0003o3P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool02`3oool20000o`80oooo00<0o`00
0?ooo`3oool03P3oool30?l00080oooo00<0003o0?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0>0?ooo`P0003o203oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo02@0oooo00290?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000003o0000o`030000o`/0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`040?ooo`80o`003@3oool01000
0?l0oooo0?ooo`3oool20000o`d0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0<0?ooo`80o`001@3oool0
0`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00T0oooo1P000?l?
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0903oool008T0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00<0oooo1@000?l60?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool01P3oool20?l000X0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool02@3oool20?l000P0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`020?ooo`L0003o1@3oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0903oool008<0oooo2P3o000;0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool0203oool60000oa80oooo00<0o`000?ooo`3oool0203oool20?l000P0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool20?l000X0oooo00<0003o0?ooo`3oool03@3oool70000o``0
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0:0?ooo`X0o`007`3oool008T0oooo00@0003o0?ooo`3oool0
oooo6`3o000>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0>0?ooo`H0003o303oool00`3o0000
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool20?l000`0
oooo00<0003o0?ooo`3oool02@3oool40000o`<0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool0303ooolL0?l00080oooo00<0o`000?ooo`3o
ool0903oool008T0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3o0000o`000180o`002P3oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
0`3oool50000o`L0oooo00<0o`000?ooo`3oool0303oool20?l000@0oooo
00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00@0o`000?ooo`3oool0
oooo0P3o000?0?ooo`030000o`3oool0oooo00@0oooo10000?l70?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0:0?oooa<0o`003P3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo02@0oooo00290?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00<0oooo2@3o00000`3oool0003o0?ooo`0>0?ooo`030?l0
003oool0oooo00h0oooo00<0003o0?ooo`3oool0203oool40000o`<0oooo
00<0o`000?ooo`3oool03P3oool20?l000030?ooo`000?l0oooo00X0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`0:0?ooo`<0o`004@3oool010000?l0oooo0?ooo`3oool30000o`/0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0o`0000T0o`000`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0T0?ooo`00R@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`X0o`001`3oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00d0oooo0P000?l00`3oool0o`000?ooo`0A0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`060?ooo`030?l000000?l0003o00P0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`0:0?ooo`<0o`004P3oool010000?l0oooo
0000o`000?l>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool01P3oool:0?l000d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0903oool008T0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`060?ooo`P0o`003`3oool00`000?l0oooo
0?ooo`0?0?ooo`<0003o4@3oool00`000?l0o`000?l0000<0?ooo`030000
o`3oool0oooo00P0oooo00@0o`000?ooo`3oool0oooo1@3o00000`000?l0
oooo0000o`040000o`<0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`090?ooo`80o`000P3oool00`3o0000oooo0?ooo`0?0?ooo`<0
003o403oool00`3o0000oooo0?ooo`0>0?ooo`P0o`00203oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo02@0
oooo00290?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool03@3oool60?l000X0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`020000o`h0oooo00D0003o0?ooo`3oool0
oooo0?l0000<0?ooo`030000o`3oool0oooo00L0oooo103o00050?ooo`03
0000o`3oool0oooo00@0oooo0`000?l00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000
oooo0?ooo`0<0?ooo`80003o0P3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00T0oooo1@3o00000`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0903oool008<0oooo0`000?l30?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`030?ooo`D0o`001@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
003oool0oooo0080oooo0`000?l:0?ooo`030000o`3oool0oooo00<0oooo
0P3o000:0?ooo`030000o`3oool0oooo00@0oooo103o00080?ooo`030000
o`3oool0oooo00H0oooo00@0o`000?ooo`000?l0003o1P3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3o
ool0203oool30000o`@0oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`030?ooo`D0o`001@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool00`3oool20000oal0oooo00260?oooaT0003o203oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`090?ooo`D0o`0000<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`060?ooo`80003o203oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00P0oooo00@0003o0?ooo`3oool0
oooo0P3o00040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool0103o0000oooo0?ooo`3oool20000o`<0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo0P000?l80?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3o00000`3o000:0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00H0oooo6P000?lQ0?ooo`00R@3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00@0oooo4`000?l40?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>0?ooo`D0
o`00303oool00`3o0000oooo0?ooo`080?ooo`<0003o103oool00`000?l0
oooo0?ooo`070?ooo`80o`002@3oool00`000?l0o`000?l000060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`<0003o2P3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo0080oooo0`000?l:0?ooo`030000o`3oool0oooo00/0
oooo1@3o000>0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`020?oooa<0003o1P3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo02<0oooo00290?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`080?ooo`T0003o2P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool00`3oool40?l000L0oooo
00<0o`000?ooo`3oool0303oool20000o`030?ooo`000?l0oooo00/0oooo
00<0o`000?ooo`3oool01P3oool00`3o0000003o0?ooo`070?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`80003o2@3oool00`3o0000oooo0?ooo`090?ooo`030?l0
003oool0oooo0080003o3@3oool00`000?l0oooo0?ooo`060?ooo`D0o`00
0`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool02@3oool90000o`X0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo02<0oooo
00290?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo2`00
0?l?0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool01`3o
ool40?l000<0oooo00<0o`000?ooo`3oool03P3oool20000o`d0oooo00<0
o`000?ooo`3oool0103oool00`3o0000oooo0000o`080?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`040000o`3oool0003o0000o`H0oooo00<0o`000?ooo`3oool0
2P3oool00`3o0000003o0000o`0?0?ooo`030000o`3oool0oooo0080oooo
103o00090?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`090000o`@0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool08`3oool008T0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool90000o`L0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0;0?ooo`<0o`004@3oool010000?l0oooo0000
o`000?l<0?ooo`030?l0003oool0oooo0080oooo00D0o`000?ooo`3oool0
oooo0000o`070?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`80
003o00<0o`000?ooo`3oool03`3oool010000?l0o`000?l0003o000=0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool01@3oool:0000
o`d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool08`3oool008T0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`060?ooo`P0003o3`3oool00`000?l0oooo0?ooo`0=0?ooo`<0
o`003`3oool01@000?l0oooo0?ooo`3oool0003o00`0oooo00@0o`000?oo
o`3o0000o`001@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0o`00303o
ool010000?l0oooo0?ooo`3o000>0?ooo`@0o`00403oool00`3o0000oooo
0?ooo`0=0?ooo`P0003o203oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo02<0oooo00290?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0000o`030000o`X0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`020?l000`0oooo00<0003o0?ooo`3oool00`3o
ool20000o`X0oooo0P3o00080?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0o`000?oo
o`0:0?ooo`80003o103oool00`3o0000oooo0?ooo`080?ooo`<0o`000`3o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00P0oooo1P00
0?l?0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool08`3oool008<0oooo4P3o00020?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool00`3oool5
0000o`D0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`03
0?ooo`<0o`002@3oool00`000?l0oooo0?ooo`050?ooo`80003o203oool2
0?l000P0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030?l000000?l0oooo00P0oooo0P000?l7
0?ooo`030?l0003oool0oooo00D0oooo0P3o00070?ooo`030000o`3oool0
oooo00d0oooo00@0o`000?ooo`3oool0oooo1`000?l50?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00@0003o0?ooo`3oool0oooo
4P3o000O0?ooo`00R@3oool00`000?l0oooo0?ooo`090?oooa<0o`003@3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0203oool60000o`l0oooo00<0o`000?ooo`3oool01P3o
ool30?l000D0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`040?ooo`040?l0003oool0oooo0?l000P0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`040?l0
003oool0oooo0000o`L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`030?ooo`80o`002@3oool00`000?l0oooo0?ooo`0;0?ooo`H0
003o303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303ooolC0?l000/0oooo00<0o`000?ooo`3o
ool08`3oool008T0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0o`0000P0o`00103oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
3@3oool50000o`/0oooo00<0o`000?ooo`3oool02@3oool30?l00080oooo
00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool00P3o000;0?ooo`030000
o`3oool0oooo00P0oooo0`000?l30?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00<0oooo2P3o000>0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool08`3oool008T0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00P0oooo4@3o
00030?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`020?ooo`@0003o1`3oool00`3o0000oooo0?oo
o`0<0?ooo`80o`003@3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0003o0`3o00020?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool30?l000h0oooo
00<0003o0?ooo`3oool0103oool30000o`H0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0180o`00
2@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool08`3oool008T0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool02P3oool50?l000d0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`060?ooo`@0003o0`3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3o0000o`0000`0oooo0P000?l00`3o0000oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3o
ool010000?l0o`000000o`000?l20?ooo`030000o`3oool0oooo00D0o`00
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo
00@0003o0?ooo`000?l0003o303oool30?l000l0oooo00@0003o0?ooo`3o
ool0oooo0`000?l90?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool01`3oool80?l000`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool08`3oool008T0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`070?l000H0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`<0003o00<0o`000?ooo`3o
ool0303oool010000?l0oooo0?ooo`3oool20?l000/0oooo00<0o`000000
o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`060000o`3oool0003o
0000o`3oool0o`00103oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080o`0000<0oooo0000o`3oool0103oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00X0oooo0P3o00020?ooo`030?l0003o
ool0oooo00d0oooo10000?l=0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool00P3oool50?l000D0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0S0?ooo`00R03oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00L0oooo2@3o000<0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0000o`000?l00P000?l;0?ooo`030000o`3oool0oooo00<0oooo0P3o0009
0?ooo`030?l0003oool0003o00L0oooo00<0o`000?ooo`3oool0103oool2
0000o`@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?l0003oool0103oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0003o00T0oooo0P3o00050?ooo`030?l0003o
ool0oooo00T0oooo1@000?l?0?ooo`030?l0003oool0oooo00X0oooo1`3o
000:0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool08`3oool008<0oooo2@000?l;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00@0o`000?ooo`3oool0oooo1`3o
00050?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool00P3o
ool30000o`P0oooo00<0003o0?ooo`3oool01@3oool20?l000H0oooo00D0
o`000?ooo`3oool0oooo0000o`070?ooo`040?l0003oool0oooo0?ooo`80
003o00<0oooo0000o`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o
00<0oooo00<0o`000?ooo`3oool00`3oool010000?l0oooo0?l0003o0002
0?ooo`030?l0003oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo0000
o`060?ooo`80o`001`3oool00`3o0000oooo0?ooo`060?ooo`<0003o103o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00<0oooo1`3o
00020?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool02P3oool90000oal0oooo00280?ooo`040000o`3oool0
oooo0?oooa80003o203oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`080?ooo`@0o`0000<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`050?ooo`80003o1@3oool00`000?l0oooo0?ooo`080?ooo`80o`000`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`000?l0103oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`070000o`3oool0oooo0?oo
o`3o0000oooo0?l000070?ooo`80003o1@3oool010000?l0oooo0?ooo`3o
ool20?l000X0oooo00<0o`000?ooo`3oool00`3oool20000o`L0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?l000030?l000T0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool01P3ooolB0000o`80oooo00<0
o`000?ooo`3oool08`3oool008P0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`040?oooa<0003o103oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool5
0?l000/0oooo00<0o`000?ooo`3oool0203oool30000o`80oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?l000070?ooo`80003o1P3oool0
0`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o00000`3o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00@0003o0?ooo`3oool0o`00303oool00`3o0000oooo0?ooo`030000o`X0
oooo00<0003o0?ooo`3oool02@3oool50?l000h0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00<0
oooo4P000?l50?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool08`3oool008P0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00P0oooo2@000?l:0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`020?ooo`@0o`001`3oool00`3o0000oooo0?ooo`0;0?ooo`<0003o
3@3oool20?l000T0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?l000050?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool010000?l0
oooo0?ooo`3o00040?ooo`030000o`3oool0oooo0080oooo00@0o`000?oo
o`3o0000o`000`3oool20000o`T0oooo0P3o000=0?ooo`<0003o3@3oool0
0`000?l0oooo0?ooo`050?ooo`@0o`000`3oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02@3oool9
0000o`T0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo02<0oooo00280?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo0080oooo2@000?l00`3oool0003o0?ooo`0=0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool01P3oool40?l0
00<0oooo00<0o`000?ooo`3oool0303oool010000?l0oooo0000o`000?l;
0?ooo`<0o`002@3oool010000?l0oooo0000o`000?l30?ooo`030?l0003o
ool0oooo0080oooo00@0003o0?ooo`3oool0oooo0`3o00030000o`050?l0
003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`03
0?l0003oool0003o00T0oooo0P3o00000`000?l0oooo0?ooo`0:0?ooo`80
003o00<0oooo0?l0003oool03@3oool010000?l0oooo0?ooo`3oool40?l0
00L0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0003o00T0003o0`3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0S0?ooo`00R03oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`X0003o1@3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00X0oooo0`3o000?0?ooo`040000o`3oool0oooo0?oo
o`<0003o203oool0103o0000oooo0?ooo`3o00090?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?l000060?ooo`000?l0oooo0?ooo`3o0000003o0P3oool01@000?l0oooo
0?ooo`3oool0o`0000H0oooo00<0003o0?ooo`3oool01`3oool01@3o0000
oooo0?ooo`3oool0003o00P0oooo0`000?l30?ooo`030?l0003oool0oooo
00d0oooo0`3o000<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool01@3oool90000o`d0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool08`3oool008P0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`070?ooo`L0003o3P3oool00`000?l0
oooo0?ooo`0<0?ooo`@0o`002`3oool00`000?l0oooo0?ooo`050?ooo`80
003o1@3oool00`3o0000oooo0?ooo`020?ooo`80o`001`3oool20000o`H0
oooo00D0o`000?ooo`3oool0oooo0000o`020?l000040?ooo`3o0000oooo
0000o`80oooo00@0o`000?ooo`000?l0003o0`3oool00`3o0000oooo0?oo
o`030?ooo`80003o00<0oooo0?l0003oool01@3oool20?l000@0oooo00<0
003o0?ooo`3oool0103oool20000o`H0oooo00<0o`000?ooo`3oool02P3o
ool30?l000030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool80000o`L0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0S0?ooo`00P`3oool20?l000<0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0003o00<0003o2P3oool00`000?l0oooo0?ooo`0<
0?ooo`040?l0003oool0oooo0?ooo`<0o`001`3oool00`000?l0oooo0?oo
o`080?ooo`80003o0P3oool00`3o0000oooo0?ooo`050?ooo`030?l0003o
ool0oooo00<0oooo00@0003o0?ooo`3oool0003o1@3oool01P3o0000oooo
0?ooo`3o0000oooo0000o`80oooo00D0o`000?ooo`000?l0oooo0?l00003
0?ooo`<0003o00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3o
ool0o`0000D0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?oo
o`3oool20000o`T0oooo00<0o`000?ooo`3oool01@3oool40?l000<0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`080?ooo`D0003o
3P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo0080oooo0P3o000O0?ooo`00Q@3ooolI0?l000L0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool00`3oool70000o`80oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`050?ooo`<0o`00103o
ool00`000?l0oooo0?ooo`0:0?ooo`80003o00<0o`000?ooo`3oool01P3o
ool20?l000<0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`80o`00
0`00000010000?l0oooo0?ooo`3o00020000o`040?l0003oool0oooo0000
o`<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo0080o`002@3oool30000o`/0oooo00@0o`000?oo
o`3oool0oooo103o00080?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool01`000?l50?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00L0oooo603o000Q0?ooo`00R03oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00@0oooo2@3o000=0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0:0?oo
o`L0003o2P3oool00`3o0000oooo0?ooo`080?ooo`<0o`0000<0oooo0000
o`3oool0303oool00`3o0000003o0000o`090?ooo`030?l0003oool0003o
00D0oooo00<0003o0?ooo`3oool00P3oool20?l000080000003oool0oooo
0?ooo`000?l0oooo0?l000000?l20?l000030?ooo`000?l0oooo0080oooo
00<0o`000?ooo`000?l00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0o`0000X0oooo0P000?l=0?ooo`@0o`00303oool00`000?l0oooo
0?ooo`090?ooo`H0003o303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool:0?l000D0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0S0?ooo`00R03o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3o00004@3o000:0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`030?ooo`@0003o1P3o
ool00`3o0000oooo0?ooo`0;0?ooo`<0o`00303oool00`3o0000oooo0?oo
o`020000o`P0oooo0P3o00060?ooo`040000o`3oool0oooo0?l00080oooo
0P3o00020?ooo`80003o0`3o000010000000003o0?ooo`3oool20?l000<0
oooo0P000?l70?ooo`80o`002@3oool20000o`80oooo00<0003o0?ooo`3o
ool0203oool20?l000030?ooo`3o0000oooo00d0oooo00<0003o0?ooo`3o
ool01@3oool40000o`<0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00P0oooo4`3o000>0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool08`3oool008P0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool00P3oool90?l000030?oo
o`000?l0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`070?ooo`@0003o00<0oooo0?l0003oool03P3oool00`000?l0oooo
0?l000030?l000P0oooo00<0o`000?ooo`3oool00P3oool20000o`D0oooo
00<0003o0?ooo`3oool00P3o00050?ooo`80003o0`3oool010000000oooo
0?l0003oool60000o`030?ooo`3o0000o`0000D0oooo00<0003o0?ooo`3o
ool0103oool20?l00080oooo00<0o`000?ooo`3oool0103oool20000o`@0
oooo00<0003o0?ooo`3oool01@3oool30?l000<0oooo00<0o`000?ooo`3o
ool0303oool010000?l0oooo0?ooo`3oool40000o`L0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0o`00
00P0o`00103oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0R0?oo
o`00R03oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`P0
o`001`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo0P000?l>0?ooo`030000o`3oool0oooo00@0oooo0P3o00050?ooo`03
0?l0003oool0oooo00D0oooo0P000?l20?ooo`030000o`3oool0oooo00<0
oooo0P3o00040?ooo`050?l000000?l0oooo0?ooo`0000000P3oool20?l0
0080oooo00<0o`000?ooo`3oool00P3o00050?ooo`030000o`3oool0003o
00@0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`80003o1`3oool010000?l0oooo0?ooo`3oool30?l000L0oooo00<0o`00
0?ooo`3oool02`3oool40000o`/0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`070?ooo`L0o`003@3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0R0?ooo`00R03oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00D0oooo103o00030?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0103o
0000003o0000o`000?l;0?ooo`030000o`3oool0oooo00H0oooo0P3o0003
0?ooo`030?l0003oool0oooo00L0oooo0`000?l70?ooo`040?l0003oool0
oooo0?l00080oooo0P000?l01@000000oooo0?ooo`000?l0oooo00H0o`00
00@0oooo0?l0003oool0oooo0P000?l20?ooo`050000o`3oool0oooo0?oo
o`3o00001P3oool0103o0000oooo0000o`000?l90?ooo`040000o`3oool0
o`000?l000X0oooo00<0o`000?ooo`3oool02@3oool30000o`l0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`030?ooo`@0o`001@3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo0280oooo00280?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool02@3oool60?l000`0oooo00<0003o
0?ooo`3oool0303oool0103o0000oooo0?ooo`3oool40000o`H0oooo00<0
003o0?ooo`3oool02@3oool30?l000/0oooo0`000?l70?ooo`80o`001@3o
ool40000o`<0oooo00<0o`000?ooo`3oool00P3oool30000o`D0oooo00<0
003o0?l0003o00001`3oool20000o`/0oooo0P3o000<0?ooo`030?l0003o
ool0oooo00H0oooo0`000?l30?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool02P3oool70?l000T0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0R0?ooo`00P`3ooolA
0000o`80oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`070?l000D0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`050?ooo`@0003o0P3oool00`000?l0oooo0?ooo`0;
0?ooo`80o`002P3oool00`000?l0oooo0?ooo`020000o`D0oooo00@0o`00
0?ooo`3o0000o`001@3oool:0000o`030?ooo`3o0000oooo00@0oooo0P3o
00070?ooo`80003o00<0oooo0?l0003oool01`3oool30?l000030?ooo`00
0?l0oooo00`0oooo00@0o`000?ooo`3oool0oooo10000?l60?ooo`030000
o`3oool0oooo00`0oooo00@0o`000?ooo`3oool0oooo2@3o00020?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00@0003o0?ooo`3o
ool0oooo4@000?lO0?ooo`00U03ooolB0000o`h0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00L0
oooo103o00000`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0
oooo10000?l;0?ooo`030?l0003oool0oooo00<0o`001P3oool00`000?l0
oooo0?ooo`030?ooo`80003o0`3oool0103o0000oooo0?ooo`3oool20?l0
0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`040?l0003oool0oooo0?ooo`80o`000P3oool010000?l0oooo0?ooo`3o
ool30000o`<0oooo00<0o`000?ooo`3oool0103oool20?l000@0oooo00<0
003o0?ooo`3oool02`3oool40000o`X0oooo00<0003o0?ooo`3oool02@3o
ool70?l000/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo4P000?l`0?ooo`00Y@3oool;
0000o`<0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00/0oooo1`3o00080?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool00P000?l90?ooo`030?l0003oool0
oooo00<0oooo0`3o00030?ooo`030000o`3oool0oooo00D0oooo0P000?l0
0`3oool0o`000?ooo`040?ooo`@0o`00103oool00`3o0000oooo0?ooo`03
0?ooo`@0o`00103oool010000?l0oooo0000o`000?l70?ooo`040?l0003o
ool0oooo0?ooo`80o`001`3oool00`000?l0oooo0?ooo`060?ooo`@0003o
00<0oooo0?l0003oool0303oool00`000?l0oooo0?ooo`040?ooo`@0o`00
0`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`030?ooo`T0003o
00<0o`000?ooo`3oool0?`3oool00;00oooo20000?l:0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`040?ooo`L0o`0000<0oooo0?l0003oool0303oool00`000?l0oooo0?oo
o`020?ooo`80003o1`3oool00`3o0000oooo0?ooo`060?ooo`<0o`002P3o
ool20000o`L0oooo00<0003o0?ooo`3o00002@3o00000`3oool0o`000?oo
o`040?ooo`<0003o2@3oool0103o0000oooo0?l0003o00090?ooo`030000
o`3oool0oooo0080oooo10000?l50?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3o0000103o00070?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`080?ooo`T0003o
B`3oool00;P0oooo2@000?l00`3oool0003o0?ooo`0=0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool40?l000/0oooo00<0
003o0?ooo`3oool0103oool30000o`<0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0o`000?l000080?ooo`040?l0003oool0003o0000o`D0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`040?l0
003oool0oooo0?ooo`80003o0`3oool00`000?l0oooo0?ooo`060?ooo`80
o`00303oool010000?l0oooo0000o`000?l90?ooo`030?l0003oool0oooo
00T0oooo103o000=0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0000o`080000oe@0oooo00310?ooo`X0
003o1@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00@0o`000?ooo`3oool0oooo103o00060?ooo`030000o`3oool0oooo
00P0oooo10000?l;0?ooo`030000o`3oool0oooo0080o`001@3oool00`3o
0000oooo0?ooo`020?ooo`D0003o1P3oool00`3o0000oooo0?ooo`040?oo
o`040?l0003oool0003o0000o`D0oooo00<0003o0?ooo`3oool0103oool2
0?l000030?ooo`3o0000oooo00X0oooo0`000?l;0?ooo`030?l0003oool0
oooo00D0oooo103o00020?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`T0003oG@3oool0
0</0oooo20000?l<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool01@3oool40?l00080oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0000o`030000o`L0oooo00<0003o0?ooo`3oool00P3oool30?l0
0080oooo00<0o`000?ooo`3oool01P3oool@0000o`L0oooo00@0003o0?oo
o`3oool0oooo0`3o00040?ooo`030?l0003oool0oooo00D0oooo0`000?l0
0`3oool0003o0?ooo`0;0?ooo`040?l0003oool0oooo0?ooo`@0o`001P3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo2@00
0?mV0?ooo`00d`3oool70000o`@0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`090?ooo`@0o`002`3oool00`3o0000oooo0?ooo`03
0?ooo`<0003o0`3oool00`000?l0oooo0?ooo`060?ooo`<0o`00203oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool010000?l0oooo0?l0003o00070?ooo`040?l0003o
ool0oooo0?ooo`@0003o103oool00`000?l0oooo0?ooo`0:0?ooo`@0o`00
2`3oool00`000?l0oooo0?ooo`0;0?ooo`040?l0003oool0oooo0?ooo`T0
003oK`3oool00=X0oooo1@000?l>0?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool00P3o00080?ooo`030?l0003oool0oooo00L0oooo
10000?l:0?ooo`@0o`001@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool40?l000X0oooo
0`000?l80?ooo`030000o`3oool0oooo00H0oooo103o00000`3oool0o`00
0?ooo`0<0?ooo`030000o`3oool0oooo00T0oooo1P000?mh0?ooo`00gP3o
ool60000o`T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`020?ooo`80o`001P3oool00`3o0000oooo0?ooo`0:0?ooo`80003o203o
ool00`3o0000oooo0?ooo`020?ooo`@0o`0000<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0o`0000<0o`000`3o
ool00`000?l0oooo0?ooo`050?ooo`<0003o00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`020?ooo`<0o`001@3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00D0oooo10000?mn0?ooo`00i03oool7
0000o`030?ooo`3o0000oooo00`0oooo00<0003o0?ooo`3oool0103oool3
0?l000<0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`02
0000o`H0oooo00<0o`000?ooo`3oool01P3ooolB0?l000L0oooo00<0003o
0?ooo`3oool00P3oool30000o`<0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`020?l000P0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0000o`040000oh80oooo003[0?ooo`@0003o2`3oool00`00
0?l0oooo0?ooo`070?ooo`@0o`002`3oool00`000?l0oooo0?ooo`020?oo
o`@0003o0P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0003o0080003o1P3oool00`3o0000oooo0?ooo`090?oo
o`<0o`002`3oool00`3o0000oooo0?ooo`090?ooo`@0003oQ`3oool00>l0
oooo10000?l70?ooo`030000o`3oool0oooo00X0oooo1@3o00060?ooo`03
0000o`3oool0oooo00L0oooo1P000?l50?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`@0
003o2@3oool00`3o0000oooo0?ooo`060?ooo`<0o`0000<0oooo0000o`3o
ool02`3oool00`3o0000oooo0?ooo`050?ooo`@0003oR`3oool00?<0oooo
10000?l20?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
0`3oool40?l00080oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`020?ooo`@0003o00<0oooo0000o`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`030?l000000?l0003o00<0003o0`3oool00`000?l0oooo
0?ooo`080?ooo`040?l0003oool0oooo0?ooo`@0o`00103oool00`000?l0
oooo0?ooo`0:0?ooo`040?l0003oool0oooo0?ooo`@0003oS`3oool00?L0
oooo10000?l;0?ooo`030?l0003oool0oooo00L0oooo0`3o000:0?ooo`03
0?l0003oool0oooo00H0oooo4`000?l80?ooo`030000o`3oool0oooo00L0
oooo1@3o00090?ooo`030000o`3oool0oooo00T0oooo10000?nC0?ooo`00
n`3oool40000o`L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0o`00
0?l000020?l000H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool010000?l0oooo0?ooo`3oool50?l00080oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`050?ooo`@0003oU`3oool00?l0oooo
1P000?l00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo
103o00020?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00@0003o0?l0003o0000o`001`3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0003o00D0003oV`3oool00?l0oooo1P3oool50000o`L0oooo
00<0003o0?ooo`3oool01`3oool60?l000D0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo
103o000:0?ooo`030?l0003oool0oooo00D0oooo1P000?nQ0?ooo`00o`3o
ool;0?ooo`@0003o0`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo0080oooo1`3o00070?ooo`030?l0003oool0oooo00H0oooo1`3o
00030?ooo`030000o`3oool0oooo00P0oooo00@0o`000?ooo`3oool0oooo
10000?nW0?ooo`00o`3oool?0?ooo`@0003o2P3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0o`0000l0o`0000<0oooo0?l0003oool01`3o
ool00`000?l0oooo0?ooo`090?ooo`<0003oZ`3oool00?l0oooo4P3oool4
0000o`L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`040?ooo`@0003o00<0o`000?ooo`3oool0Z`3oool0
0?l0oooo5P3oool50000o`030?ooo`3o0000oooo00T0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool010000?nb0?ooo`00o`3ooolK0?ooo`H0
003o1@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0o`000?ooo`3oool0103oool60000okH0oooo003o0?ooob40oooo
30000?l30?ooo`030?l0003oool0oooo0080oooo30000?nl0?ooo`00o`3o
ool]0?ooo`P0003ob03oool00?l0oooo<03oool00`000000oooo0?ooo`3:
0?ooo`00o`3oool`0?ooo`030000003oool0oooo0<X0oooo003o0?oooc00
oooo00<000000?ooo`3oool0bP3oool00?l0oooo<03oool00`000000oooo
0?ooo`3:0?ooo`00o`3oool`0?ooo`030000003oool0oooo0<X0oooo0000
\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{508, 123},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.73",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/schwarzchristoffel/\
SchwarzChristoffelFigures/mat1173.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "   The region with ",
  Cell[BoxData[
      RowBox[{\(w\_1 \[Rule] 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_3 \[Rule] 0\)}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "\[Rule]", \(\[Pi]\/2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "\[Rule]", \(-\[Pi]\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "3"], "\[Rule]", \(\[Pi]\/2\)}]}]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe limiting formula for the derivative ",
  Cell[BoxData[
      \(g' \((z)\)\)]],
  " becomes    \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z + 
                  1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \
\((z)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\ \((z - \
1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(\(-\(\[Pi]\/2\)\)/\[Pi]\)\) \((z)\)\^\(\(-\((\(-\
\[Pi]\))\)\)/\[Pi]\)\ \((z - 1)\)\^\(\(-\(\[Pi]\/2\)\)/\[Pi]\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(-\(1\/2\)\)\) \((z)\)\^1\ \((z - \
1)\)\^\(-\(1\/2\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ z \((z\^2 - \
1)\)\^\(-\(1\/2\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ z\/\((z\^2 - 1)\)\^\
\(1\/2\)\)\)\)}]],
  "\n\nwhich will determine a mapping ",
  Cell[BoxData[
      \(w\  = \ f \((z)\)\)]],
  " from the upper half-plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  onto the upper half plane  ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  "  slit along the line segment from  ",
  Cell[BoxData[
      \(\(\(w = \(0\ \ to\ \ w\_2 = \[ImaginaryI]\)\)\(\ \)\)\)]],
  " as indicated in Figure 11.73(b).  An easy integration reveals that ",
  Cell[BoxData[
      \(f \((z)\)\)]],
  " is given by  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\ \  = \ \ A\ \(\[Integral]\(z\/\((z\^2 - 1)\)\^\(1\/2\)\
\) \[DifferentialD]z\)\ \  + \ \ B\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ \((z\^2 - \
1)\)\^\(1\/2\)\ \  + \ \ B\)\)\)}],
    AspectRatioFixed->True],
  "  \n\nand the boundary values  ",
  Cell[BoxData[
      \(f \((\(\[PlusMinus]1\))\) = \(0\ \ and\ \ f \((0)\) = \[ImaginaryI]\)\
\)]],
  "  lead to system of equations \n\n\t\t\t",
  Cell[BoxData[
      \(A\ \((\((\(\[PlusMinus]1\))\)\^2 - 1)\)\^\(1\/2\)\  + \ B\  = \ 0\)],
    AspectRatioFixed->True],
  "   and   ",
  Cell[BoxData[
      \(A\ \((0 - 1)\)\^\(1\/2\)\  + \ B\  = \ \[ImaginaryI]\)],
    AspectRatioFixed->True],
  "\n\nthe solution is easily found to be ",
  Cell[BoxData[
      \(A = \(1\ \ and\ \ B = 0\)\)]],
  " and the desired function  is  \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\  = \ \((z\^2 - 1)\)\^\(1\/2\)\)],
    AspectRatioFixed->True],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.27.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the formula ",
  Cell[BoxData[
      \(\(f'\)[
          z] = \(\(\ \)\(A\ z\)\)\/\(\@\(z\  + \ 1\)\ \@\(z\  - \ 1\)\)\)],
    AspectRatioFixed->True],
  " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f1, A, B, z, F];\)\ \), "\n", 
    \(\(f1[
          z_]\  = \(\(\ \)\(A\ z\)\)\/\(\@\(z\  + \ 1\)\ \@\(z\  - \ 1\)\);\)\
\ \), "\n", 
    \(\(f[z_]\  = \ 
        B\  + \ \[Integral]\(\(\(\ \)\(A\ z\)\)\/\(\@\(z\  + \ 1\)\ \@\(z\  - \
\ 1\)\)\) \[DifferentialD]z;\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = B + \[Integral] \>", 
        f1[z], "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
This is one, formula for the integral.   However, we will use the following \
form of the integral to continue the computations.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[f1, F];\)\ \), "\n", 
    \(\(f1[z_]\  = \ \(A\ z\)\/\@\(z\^2\  - \ 1\);\)\ \), "\n", 
    \(\(F[z_]\  = \ 
        B\  + \ \[Integral]\(\(A\ z\)\/\@\(z\^2\  - \ 1\)\) \
\[DifferentialD]z;\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = B + \[Integral] \>", 
        f1[z], "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(eq1\  = \ F[1] \[Equal] 0;\)\ \), "\n", 
    \(\(eq2\  = \ F[0] \[Equal] \[ImaginaryI];\)\ \), "\n", 
    \(solset\  = \ Solve[{eq1, eq2}, {A, B}]\), "\n", 
    \(\(f[z_]\  = \ 
        ReplaceAll[F[z], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \), "\n", 
    \(\(Print[eq1];\)\ \), "\n", 
    \(\(Print[eq2];\)\ \), "\n", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<f[z] = B + A \!\(\@\(z\^2 - 1\)\)\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph conformal mapping  w = f(z).  We will need to use two branches \
of f(z) to form the graph."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f1, f2, z];\)\ \), "\n", 
    \(\(f1[z_]\  = \ \ \ \@\(z\^2\  - \ 1\);\)\ \), "\n", 
    \(\(f2[z_]\  = \ \[ImaginaryI]\ \@\(1\  - \ z\^2\);\)\ \), "\n", 
    \(\(gr1\  = \ 
        CartesianMap[f1, {0, 3, 0.2}, {0.00001, 1.00001, 0.1}, 
          PlotRange \[Rule] {{\(-2\), 2}, {0, 1.5}}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(gr2\  = \ 
        CartesianMap[f2, {\(-3\), 0, 0.2}, {0.00001, 1.00001, 0.1}, 
          PlotRange \[Rule] {{\(-2\), 2}, {0, 1.5}}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \), "\n", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{\(-2.5\), 2.5}, {0, 1.5}}, 
        AxesLabel \[Rule] {"\<u\>", "\<v\>"}, \[IndentingNewLine]Ticks \
\[Rule] {Range[\(-2\), 2, 1], Range[0, 2, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<is upper half plane Im[w] > 0 slit\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<along the line segment from w = 0 to \!\(w\_2\) = \
\[ImaginaryI],\>\""];\)\ \), "\n", 
    \(\(Print["\<where  w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that  ",
  Cell[BoxData[
      \(w = \@\(z\^2 - 1\)\)]],
  "  maps the upper half plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  onto the upper half plane  ",
  Cell[BoxData[
      \(Im[w] > 0\)]],
  "  slit along the line segment from  ",
  Cell[BoxData[
      \(\(\(w = \(0\ \ to\ \ w\_2 = \[ImaginaryI]\)\)\(\ \)\)\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.28.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ \(\(\(1\/\[Pi]\) 
              Arcsin\ z\)\(\ \)\(+\)\(\ \)\(\(\[ImaginaryI]\/\[Pi]\) Arcsin 
               1\/z\)\(\ \)\(+\)\(\ \)\(\(1\  + \ \[ImaginaryI]\)\/2\)\(\ \
\)\)\)\)]],
  "  maps the upper half plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  onto the right angle channel in the first quadrant, which is bounded by \
the coordinate axes and the rays  ",
  Cell[BoxData[
      RowBox[{\(x \[GreaterEqual] 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(y = 1\ \ and\ \ y \[GreaterEqual] 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x = 1\)}]]],
  ", as depicted in Figure 11.74(b).",
  " "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Solution.  If we choose  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_3 = 1\)}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = d\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_3 = 1 + \[ImaginaryI]\)}]]],
  ",  then the formula  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(g' \((z)\)\ \  = \ \ \(A\_1\) \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\ \((z - x\_3)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(A\_1\) \(\((z - \
\((\(-1\))\))\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - \
0)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\ \((z - 1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\)\
\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(A\_1\) \(\((z + 
                  1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \
\((z)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\ \((z - \
1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\)\)}]],
  "\n\nwill determine a mapping ",
  Cell[BoxData[
      \(w\  = \ g \((z)\)\)]],
  " of the upper half-plane onto the domain indicated in Figure 11.74(a).  \
With  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["\[Alpha]",
            FontSize->14], "1"], "=", \(\[Pi]\/2\)}]]],
  ",  we let ",
  Cell[BoxData[
      \(d \[Rule] \[Infinity]\)]],
  ",  then  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["\[Alpha]",
            FontSize->14], "2"], "\[Rule]", "\[Pi]"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["\[Alpha]",
            FontSize->14], "3"], "\[Rule]", \(-\(\[Pi]\/2\)\)}]]],
  ".  "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004`0000[b000`400?l0
0000o`00003oo`3ooola0?ooo`00o`3ooola0?ooo`00o`3ooola0?ooo`00
o`3ooola0?ooo`00o`3ooola0?ooo`00o`3ooola0?ooo`00o`3ooola0?oo
o`00o`3ooola0?ooo`00o`3ooola0?ooo`00o`3ooola0?ooo`00o`3ooola
0?ooo`00o`3ooola0?ooo`00o`3ooola0?ooo`00o`3ooola0?ooo`00[@3o
ool2000000@0oooo0P0000040?ooo`800000;03oool5000002X0oooo1@00
00020?ooo`800000103oool2000000/0oooo002/0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool00000;@3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
00002P3oool00:`0oooo00@000000?ooo`3oool000002`3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`080?ooo`00[03oool010000000oooo
0?ooo`0000090?ooo`800000;P3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo00P0oooo0P00000;0?ooo`00[03oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00X0
oooo002]0?ooo`8000002P3oool3000002`0oooo0P00000]0?ooo`800000
2P3oool3000000X0oooo003o0?oooc40oooo003o0?oooc40oooo003o0?oo
oc40oooo003o0?oooc40oooo001o0?ooo`03000000000?l0000000800000
V`000?lA0?ooo`00O`3oool01@000000oooo0000o`3oool0003o0300oooo
00<000000?ooo`3oool0603oool00`3o0000oooo0?ooo`0G0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool03`3oool007l0oooo00<0
00000?ooo`3oool00P000?m;0?ooo`030?l0003oool0oooo05h0oooo001o
0?ooo`030000003oool0oooo0080003oB`3oool00`3o0000oooo0?ooo`1N
0?ooo`00O`3oool00`000000oooo0000o`020?ooo`030000o`3oool0oooo
04P0oooo00<0o`000?ooo`3oool0GP3oool007l0oooo00<000000?ooo`00
0?l00P3oool00`000?l0oooo0?ooo`180?ooo`030?l0003oool0oooo05h0
oooo001o0?ooo`03000000000?l0oooo00<0oooo00<0003o0?ooo`3oool0
A`3oool00`3o0000oooo0?ooo`1N0?ooo`00O`3oool00`000000003o0?oo
o`040?ooo`030000o`3oool0oooo04H0oooo00<0o`000?ooo`3oool0GP3o
ool007l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`15
0?ooo`030?l0003oool0oooo05h0oooo001o0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool0A03oool00`3o0000oooo0?ooo`1N0?oo
o`00O`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo04<0
oooo00<0o`000?ooo`3oool0GP3oool007l0oooo00<0003o0?ooo`3oool0
203oool00`000?l0oooo0?ooo`120?ooo`030?l0003oool0oooo05h0oooo
001o0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0@@3o
ool00`3o0000oooo0?ooo`1N0?ooo`00O`3oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0oooo0400oooo00<0o`000?ooo`3oool0GP3oool0
07l0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`100?oo
o`030?l0003oool0oooo05h0oooo001o0?ooo`030000o`3oool0oooo00/0
oooo00<0003o0?ooo`3oool0?`3oool00`3o0000oooo0?ooo`1N0?ooo`00
O`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo03h0oooo
00<0o`000?ooo`3oool0GP3oool007l0oooo00<0003o0?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0l0?ooo`030?l0003oool0oooo05l0oooo001o
0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0>`3oool0
0`3o0000oooo0?ooo`1O0?ooo`00O`3oool00`000?l0oooo0?ooo`0?0?oo
o`030000o`3oool0oooo03X0oooo00<0o`000?ooo`3oool0G`3oool007l0
oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0i0?ooo`03
0?l0003oool0oooo05l0oooo001o0?ooo`030000o`3oool0oooo0140oooo
00<0003o0?ooo`3oool0>03oool00`3o0000oooo0?ooo`1O0?ooo`00O`3o
ool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo01d0oooo6@3o
00000`3oool0o`000?ooo`1P0?ooo`00O`3oool00`000?l0oooo0?ooo`0C
0?ooo`030000o`3oool0oooo01P0oooo103o000I0?ooo`T0o`00FP3oool0
07l0oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0D0?oo
o`@0o`007@3oool00`3o0000oooo0?ooo`060?ooo`@0o`00EP3oool007l0
oooo00<0003o0?ooo`3oool0503oool00`000?l0oooo0?ooo`0@0?ooo`<0
o`008@3oool00`3o0000oooo0?ooo`0:0?ooo`80o`00E03oool007l0oooo
00<0003o0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0=0?ooo`80o`00
903oool00`3o0000oooo0?ooo`0<0?ooo`@0o`00D03oool007l0oooo00<0
003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`090?ooo`<0o`009P3o
ool00`3o0000oooo0?ooo`0@0?ooo`@0o`00C03oool007l0oooo00<0003o
0?ooo`3oool05`3oool00`000?l0oooo0?ooo`050?ooo`<0o`00:@3oool0
0`3o0000oooo0?ooo`0D0?ooo`80o`00BP3oool007l0oooo00<0003o0?oo
o`3oool0603oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
02X0oooo00<0o`000?ooo`3oool05P3oool20?l004P0oooo001o0?ooo`03
0000o`3oool0oooo01P0oooo00@0003o0?ooo`3oool0oooo0P3o000]0?oo
o`030?l0003oool0oooo01P0oooo0P3o00160?ooo`00O`3oool00`000?l0
oooo0?ooo`0I0?ooo`030000o`3oool0o`0002l0oooo00<0o`000?ooo`3o
ool06P3oool20?l004@0oooo001o0?ooo`030000o`3oool0oooo01X0oooo
00<0o`000?ooo`3oool0;@3oool00`3o0000oooo0?ooo`0M0?ooo`80o`00
@P3oool007l0oooo00<0003o0?ooo`3oool0603oool20?l000030?ooo`00
0?l0oooo02d0oooo00<0o`000?ooo`3oool07`3oool20?l00400oooo001o
0?ooo`030000o`3oool0oooo01L0oooo00D0o`000?ooo`3oool0oooo0000
o`0^0?ooo`030?l0003oool0oooo0240oooo00<0o`000?ooo`3oool0?@3o
ool007l0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo02/0oooo00<0o`000?ooo`3oool08P3oool0
0`3o0000oooo0?ooo`0l0?ooo`00O`3oool00`000?l0oooo0?ooo`0E0?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0:P3oool00`3o
0000oooo0?ooo`0S0?ooo`80o`00?03oool007l0oooo00<0003o0?ooo`3o
ool0503oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo02X0
oooo00<0o`000?ooo`3oool09@3oool00`3o0000oooo0?ooo`0i0?ooo`00
O`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0:@3oool00`3o0000oooo0?ooo`0V0?ooo`030?l0
003oool0oooo03P0oooo001o0?ooo`030000o`3oool0oooo01<0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0W0?ooo`030?l0003o
ool0oooo02P0oooo00<0o`000?ooo`3oool0=`3oool007l0oooo00<0003o
0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo0140oooo4@000?l40?ooo`030?l0003oool0oooo02T0oooo00<0o`00
0?ooo`3oool0=P3oool007l0oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo10000?lA0?oo
o`L0003o:P3oool00`3o0000oooo0?ooo`0e0?ooo`00O`3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool01`3oool50000oaT0oooo00<0o`000?ooo`3oool00`000?lX0?ooo`03
0?l0003oool0oooo03@0oooo001o0?ooo`030000o`3oool0oooo0100oooo
00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`050?ooo`80003o
7@3oool00`3o0000oooo0?ooo`040?ooo`<0003o9P3oool00`3o0000oooo
0?ooo`0c0?ooo`00O`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool00P3oool20000oal0oooo00<0
o`000?ooo`3oool01`3oool30000ob@0oooo00<0o`000?ooo`3oool0<P3o
ool007l0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo0080003o8@3oool00`3o0000oooo0?ooo`0:
0?ooo`80003o8P3oool00`3o0000oooo0?ooo`0b0?ooo`00O`3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0180oooo0P000?lS0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0803oool00`3o
0000oooo0?ooo`0a0?ooo`00O`3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo0100oooo0`000?lS0?ooo`030?l0003oool0oooo00h0
oooo0P000?lQ0?ooo`030?l0003oool0oooo0300oooo001o0?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0403oool01@000?l0oooo
0?ooo`3oool0003o0280oooo00<0o`000?ooo`3oool0403oool20000ob00
oooo00<0o`000?ooo`3oool0;`3oool007l0oooo00<0003o0?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0803oool00`3o0000oooo0?ooo`0B0?ooo`80003o
7P3oool00`3o0000oooo0?ooo`0_0?ooo`00O`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00h0oooo0P000?l60?ooo`030000o`3o
ool0oooo01l0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?oo
o`0L0?ooo`030?l0003oool0oooo02h0oooo001^0?ooo`800000103oool2
000000@0oooo0P0000030?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo01h0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0K
0?ooo`030?l0003oool0oooo02h0oooo001]0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo01L0oooo00<0
003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0]0?ooo`00K@3oool0
10000000oooo0?ooo`00000;0?ooo`050000003oool0oooo0000o`000000
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00T0oooo
00<0003o0?ooo`3oool0403oool30?l000X0oooo00<0o`000?ooo`3oool0
603oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo02d0oooo
001]0?ooo`040000003oool0oooo000000T0oooo0P0000030?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00H0oooo2@3o00030?ooo`L0o`00
0P3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo01X0oooo
00<0o`000?ooo`3oool0;03oool006d0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00@0oooo0P3o000C0?ooo`D0o`006P3oool00`000?l0oooo
0?ooo`0J0?ooo`030?l0003oool0oooo02`0oooo001^0?ooo`8000002P3o
ool300000080oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3o00000`3o
000G0?ooo`030?l0003oool0oooo0080o`006@3oool00`000?l0oooo0?oo
o`0I0?ooo`030?l0003oool0oooo01H0oooo1@000?lA0?ooo`00O`3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool03`3oool20?l001/0oooo00<0o`000?ooo`3oool00P3oool2
0?l001P0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0>
0?ooo`P0003o5P3oool007l0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00h0oooo0P3o00000`3o
ool0003o0?ooo`0I0?ooo`030?l0003oool0oooo00D0oooo0P3o000G0?oo
o`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool00P3oool;0000
oah0oooo001o0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0=0?ooo`80o`000`3oool00`000?l0
oooo0?ooo`0H0?ooo`030?l0003oool0oooo00L0oooo0P3o000E0?ooo`03
0000o`3oool0oooo01P0oooo00<0o`000000o`000?l00P000?lY0?ooo`00
O`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0303oool20?l000H0oooo00<0003o0?ooo`3oool0
5`3oool00`3o0000oooo0?ooo`090?ooo`80o`00503oool00`000?l0oooo
0?ooo`0C0?ooo`@0003o00<0o`000?ooo`3oool0:`3oool007l0oooo00<0
003o0?l0003o0000103o00040?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool02P3oool20?l000P0oooo00<0003o0?ooo`3oool05P3o
ool00`3o0000oooo0?ooo`0<0?ooo`80o`004`3oool00`000?l0oooo0?oo
o`0>0?ooo`@0003o1@3oool00`3o0000oooo0?ooo`0Z0?ooo`00O`3oool0
0`000?l0oooo0?ooo`040?ooo`D0o`002@3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool05@3oool0
0`3o0000oooo0?ooo`0>0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool02`3oool20000o`T0oooo00<0o`000?ooo`3oool0:P3oool0
07l0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?l000080?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00l0oooo00<0o`000?oo
o`3oool0403oool00`000?l0oooo0?ooo`070?ooo`@0003o2`3oool00`3o
0000oooo0?ooo`0Z0?ooo`00O`3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo0080o`001@3oool00`000?l0oooo0?ooo`080?ooo`80
o`003@3oool00`000?l0oooo0?ooo`050?ooo``0003o103oool00`3o0000
oooo0?ooo`0@0?ooo`80o`004@3oool00`000?l0oooo0?ooo`020?ooo`@0
003o3`3oool00`3o0000oooo0?ooo`0Z0?ooo`00O`3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo0080oooo0P3o00030?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool03@3oool010000?l0oooo
0?ooo`3oool40000o``0oooo0`000?l00`3o0000oooo0?ooo`0C0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool00P000?lC0?ooo`03
0?l0003oool0oooo02X0oooo001o0?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0103oool20?l000030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool03`3oool30000oa<0oooo0`000?lD0?ooo`030?l0
003oool0oooo00h0oooo0P000?lE0?ooo`030?l0003oool0oooo02X0oooo
001o0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0o`000?l000070?ooo`030?l0003oool0oooo00`0oooo1@00
0?lE0?ooo`030?l0003oool0oooo00@0003o403oool00`3o0000oooo0?oo
o`0;0?ooo`@0003o5P3oool00`3o0000oooo0?ooo`0Z0?ooo`00O`3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool00P3o00040?ooo`030?l0003oool0oooo00/0oooo0P000?l4
0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0103oool2
0000o`l0oooo00<0o`000?ooo`3oool0203oool20000o`<0oooo00<0003o
0?ooo`3oool0503oool00`3o0000oooo0?ooo`0Z0?ooo`00O`3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool00`3oool0103o0000oooo0?ooo`3o000<0?ooo`80003o1`3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00L0oooo0P000?l>
0?ooo`030?l0003oool0oooo00D0oooo0P000?l60?ooo`030000o`3oool0
oooo01<0oooo00<0o`000?ooo`3oool0:P3oool007l0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo0P3o000;0?ooo`80003o2@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo00T0oooo0P000?l=0?ooo`030?l0003oool0oooo
0080oooo0P000?l80?ooo`030000o`3oool0oooo01<0oooo00<0o`000?oo
o`3oool0:P3oool007l0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
0000203oool20000o`/0oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00D0o`000?ooo`3o
ool0oooo0000o`0:0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?oo
o`3oool0:P3oool007l0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00@0o`000?ooo`3o
ool0o`001P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00D0oooo0`3o00080?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000003o0000o`0<0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool0:`3oool007l0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?ooo`3oool20000
o`l0oooo203o00020?ooo`T0o`00403oool00`000?l0oooo0?ooo`080?oo
o`80003o00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo02/0oooo001o0?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`000?l03P3oool30?l00003
0000o`3oool0oooo00l0oooo0`3o000?0?ooo`030000o`3oool0oooo00H0
oooo00@0003o0?ooo`3oool0o`003@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo02/0oooo001o0?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool02P3oool30?l000<0
oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`030?l000d0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0[0?ooo`00O`3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0o`0000T0oooo0P3o00060?ooo`030000
o`3oool0oooo00l0oooo00<0o`000?ooo`3oool00`3oool20?l000`0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0[0?ooo`00O`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`050000o`3oool0oooo0?ooo`3o00001P3oool20?l000T0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`060?ooo`80o`00
2`3oool010000?l0oooo0000o`000?l70?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0/0?ooo`00
O`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool20?l000/0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`080?ooo`80o`002P3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0/0?ooo`00O`3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00@0o`000?ooo`3o0000o`003@3oool010000?l0oooo0?ooo`3oool70000
o`D0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0003o00T0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo02`0oooo001o0?ooo`H0
003o00<0o`000000o`000?l00`3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`0;0?ooo`H0003o1`3oool40000o`030?ooo`3o0000oooo00`0
oooo0P3o00050?ooo`050000o`3oool0oooo0?ooo`000?l0203oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool0;@3oool007l0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`020000o`030?ooo`000?l0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0o`0000T0
oooo0`000?l20?ooo`030000o`3oool0oooo00`0oooo1@000?l<0?ooo`03
0?l0003oool0oooo0080003o103oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0]0?ooo`00O`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo0080oooo0P000?l50?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool0103o0000oooo0?ooo`3o00070?ooo`80
003o1P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080
oooo0P000?l;0?ooo`030?l000000?l0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool0;P3oool007l0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`<0003o0P3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`80003o203oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00@0oooo0P000?l90?ooo`030000
o`3o0000oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
;P3oool007l0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`040000o`3oool0oooo0?ooo`80003o00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00@0o`000?ooo`000?l0003o2P3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00H0oooo0P000?l60?ooo`040000o`3oool0oooo0?l0
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0;`3oool007l0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000000o`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`80o`001`3oool20000o``0oooo2`3o00030?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool01@000?l0
oooo0?ooo`3oool0o`0000L0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0<03oool007l0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00`000?l50?ooo`030?l0003oool0oooo00D0oooo0P000?l00`3oool0
o`000?ooo`060?ooo`D0o`0000<0003o0?ooo`3oool0203oool40?l000/0
oooo00@0003o0?ooo`3oool0003o1@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0340oooo001o0?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`040?l0003oool0oooo0?ooo`<0003o0`3oool00`3o
0000oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`3o0000103oool3
0?l000D0oooo00<0003o0?ooo`3oool02P3oool0103o0000oooo0?l0003o
000:0?ooo`80003o1`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo0380oooo001o0?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00P000?l00`3oool0o`000?oo
o`040?ooo`80003o1@3oool0103o0000oooo0?l0003o00080?ooo`030000
o`3oool0oooo00X0oooo00@0o`000?ooo`3oool0oooo0`3o00070?ooo`03
0000o`3oool0003o00L0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0b0?ooo`00O`3oool00`000?l0oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool01@3o0000
oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`050?ooo`80o`002P3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00@0oooo0`3o00040?ooo`040000o`3oool0oooo
0000o`H0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0c0?ooo`00O`3oool00`000?l0oooo0?ooo`020?oo
o`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3o
ool0003o00D0oooo00<0o`000?ooo`000?l00`3oool00`000?l0oooo0?oo
o`050?ooo`<0o`002@3oool;0000o`<0oooo00<0o`000?ooo`3oool01`3o
ool0103o0000oooo0?ooo`000?l40?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0d0?ooo`00O`3oool00`000?l0oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo00L0o`000?ooo`3oool0oooo0000o`3oool0003o00H0oooo0P3o0002
0?ooo`030?l0003oool0oooo00<0oooo10000?l20?ooo`030000o`3oool0
oooo00H0oooo1@000?l90?ooo`030?l000000?l0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo03D0oooo001o0?ooo`030000o`3o0000o`00
00@0o`000P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00<0oooo0P3o00050?ooo`030?l0003oool0oooo0080003o1P3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0080003o1`3oool0
0`000?l0o`000?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0e
0?ooo`00O`3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0o`00
0000o`3o00000P3o00000`3oool0o`000?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0000o`03
0?ooo`030?l0003oool0oooo00@0oooo10000?l80?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool00P3oool20000o`@0oooo00<0003o
0?ooo`3oool00P3o00050?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000003o0?l000070?l000<0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0f0?ooo`00O`3oool01@00
0?l0oooo0?ooo`3oool0o`0000<0oooo00@0003o0?ooo`3oool0oooo0P3o
00020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool01`000?l0oooo0?ooo`3oool0003o0?ooo`3o00001@3oool20000o`80
oooo00<0o`000?ooo`3oool01`3oool70?l000@0oooo00<0o`000?ooo`3o
ool0103oool20000o`030?ooo`000?l0oooo00@0oooo0P3o00040?ooo`03
0000o`3oool0oooo00<0oooo00H0o`000?ooo`3o0000o`000?ooo`000?l4
0?ooo`040?l0003oool0oooo0?ooo`<0o`0000<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0g0?ooo`00O`3oool01@000?l0oooo0?ooo`3o
ool0o`0000<0oooo00H0003o0?ooo`3oool0oooo0?l0003oool20?l00005
0000o`3oool0oooo0?ooo`3o00001@3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo0P000?l40?ooo`030?l0003oool0oooo
00<0oooo103o00000`000?l0oooo0?ooo`040?ooo`@0o`002@3oool20000
o`L0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`3oool3
0?l000<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3o0000o`0000P0oooo00<0o`000?ooo`3oool0>03oool0
07l0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`040000o`3oool0
oooo0?l000@0oooo00D0003o0?l0003oool0oooo0?l000040?ooo`030000
o`3oool0oooo0080oooo00<0o`000000o`3oool00P3oool00`000?l0oooo
0?ooo`050?ooo`D0o`00103oool00`000?l0oooo0?ooo`070?ooo`H0o`00
103oool00`000?l0oooo0000o`060?ooo`030?l0003oool0oooo0080oooo
00H0003o0?ooo`3o0000o`000?ooo`3o00040?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?l0
00@0oooo0P3o000k0?ooo`00O`3oool01@000?l0oooo0?ooo`3oool0o`00
00<0oooo00@0003o0?ooo`3oool0o`000`3oool00`000?l0oooo0?ooo`02
0?l000@0oooo00@0003o0?ooo`3oool0oooo0P3o00020?ooo`030000o`3o
ool0003o00L0oooo0P3o00080?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool00`3oool20?l00080oooo00@0003o0?ooo`3oool0003o
1P3oool01P3o0000oooo0?ooo`3oool0o`000000o`<0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`3o000m
0?ooo`00O`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00@0003o
0?ooo`3oool0o`000`3oool010000?l0oooo0?ooo`3oool30?l000030?oo
o`000?l0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`030?ooo`<0o`0000<0oooo0?l0003oool01P3oool90000o`030?oo
o`3o0000oooo00L0oooo0P3o00040?ooo`80003o1@3oool00`3o0000oooo
0?l000020?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?l0000n0?ooo`00O`3oool01@000?l0oooo
0?ooo`3oool0o`000080oooo00D0003o0?ooo`3oool0oooo0?l000030?oo
o`040000o`3oool0oooo0?l000<0oooo00D0003o0?ooo`3oool0oooo0?l0
00050?ooo`030000o`3oool0003o0080oooo0P3o00050?ooo`030?l00000
0?l0003o00@0003o00<0oooo0000o`3oool01P3oool30000o`P0oooo00<0
003o0?l0003oool0103oool00`000?l0oooo0?ooo`020?ooo`80o`000`3o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00@0003o0?ooo`3oool0
o`00103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo03d0
oooo001o0?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool010000?l0
oooo0?ooo`3o00030?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool0
1@000?l0oooo0?l0003oool0o`0000@0oooo0P000?l20?ooo`030000o`3o
ool0o`0000H0oooo0P000?l80?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`000?l00P000?l50?ooo`040000o`3oool0o`000?l000@0oooo
00H0003o0?ooo`3oool0o`000?ooo`3o00040?ooo`040000o`3oool0oooo
0?l000@0oooo00@0003o0?ooo`3oool0o`00103oool00`000?l0oooo0?oo
o`030?ooo`80o`0000<0oooo0?l0003oool0?@3oool007l0oooo10000?l0
103o0000003o0000o`000?l20?ooo`050?l0003oool0oooo0?ooo`000?l0
0P3oool0103o0000oooo0?ooo`000?l30?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`80
003o00<0oooo0?l0003oool01`3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo0080oooo0`000?l00`3oool0003o0?ooo`030?ooo`80
o`000`3oool00`000?l0o`000?ooo`020?ooo`050?l0003oool0oooo0?oo
o`000?l00`3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00D0o`00
0?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo0080oooo00<0
o`000?ooo`3oool0>`3oool007l0oooo00D0003o0?ooo`3oool0oooo0?l0
00020?ooo`<0003o00@0o`000?ooo`3oool0003o0P3oool0103o0000oooo
0?ooo`000?l40?ooo`<0o`0000<0oooo0000o`3oool0103oool00`3o0000
oooo0000o`020?ooo`80003o103oool00`3o0000oooo0?ooo`0>0?l000L0
oooo0P000?l60?ooo`050?l0003oool0oooo0?l000000?l0103oool01@3o
0000oooo0?ooo`3oool0003o0080oooo00D0o`000?ooo`3oool0oooo0000
o`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo
0?ooo`030?ooo`030?l0003oool0oooo03/0oooo001o0?ooo`050000o`3o
ool0oooo0?ooo`3o00000P3oool010000?l0oooo0?ooo`3o00040000o`05
0?ooo`3o0000oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo0P3o00030?ooo`80003o1P3oool30?l000D0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?l000020?l000@0oooo00@0003o
0?ooo`000?l0003o1@3oool20?l00080oooo00D0003o0?ooo`3oool0oooo
0?l000030?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool30000o`04
0?l0003oool0oooo0000o`@0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`0k0?ooo`00N@3oool5000000050?ooo`000?l0oooo0?oo
o`3o00000P3oool01`000?l0oooo0?ooo`3oool0o`000?ooo`000?l00P3o
ool0103o0000003o0?ooo`000?l30?ooo`070?l0003oool0oooo0?ooo`00
0?l0oooo0?l000020?ooo`030?l0003oool0oooo0080oooo0P000?l40?oo
o`@0o`001`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
0080oooo0P3o00000`3oool0003o0?ooo`030?ooo`80003o0`3oool00`3o
0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool0
1@000?l0oooo0?ooo`000?l0o`0000<0003o0P3oool00`3o0000003o0000
o`020000o`030?ooo`3o0000o`0000L0oooo00<0o`000?ooo`3oool0>`3o
ool007/0oooo00D000000?ooo`3oool0oooo0000o`020?ooo`040?l0003o
ool0oooo0000o`80oooo00@0o`000?ooo`3oool0003o0P3oool0103o0000
oooo0000o`000?l20?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool0
0`3o0000oooo0?l000030?ooo`80003o0P3oool010000?l0oooo0?l0003o
00030?ooo`030?l0003oool0003o00d0003o1P3oool30?l000D0oooo00D0
003o0?ooo`3o0000oooo0?l000040?ooo`040000o`3oool0oooo0?l000<0
oooo0P000?l01@3oool0o`000?ooo`3oool0003o0080oooo00D0o`000?oo
o`3oool0003o0?ooo`020?l000P0oooo00<0o`000?ooo`3oool0>`3oool0
07/0oooo00P000000?ooo`3oool0oooo0000o`000000oooo0?l00080oooo
00H0003o0?ooo`3oool0o`000?ooo`000?l20?ooo`080?l0003oool0oooo
0000o`3oool0003o0?ooo`3o00020?ooo`040000o`3oool0oooo0?ooo`80
o`000`3oool00`000?l0oooo0?ooo`020?ooo`80o`000`3oool40000o`H0
oooo00<0003o0?ooo`3oool0103oool00`3o0000003o0000o`030000o`04
0?ooo`000?l0oooo0?ooo`80o`00103oool01@000?l0oooo0?ooo`3oool0
o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000030000o`80oooo00@0
o`000?ooo`3oool0003o0P3oool01P3o0000oooo0?ooo`000?l0oooo0?l0
03H0003o4@3oool007/0oooo00D000000?ooo`3oool0oooo0000o`020?oo
o`040?l0003oool0oooo0000o`80oooo00<0o`000?ooo`000?l00P3oool0
103o0000oooo0?ooo`000?l20?ooo`050?l0003oool0oooo0?ooo`000?l0
0P3oool00`3o0000oooo0?ooo`020?l000040000o`3oool0oooo0?ooo`80
o`0000<0oooo0000o`3oool00P000?l30?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`80
003o103oool20?l000040?ooo`3o0000oooo0000o`<0oooo00P0o`000?oo
o`3oool0oooo0000o`3oool0003o0?l00080oooo00L0003o0?ooo`3oool0
oooo0?l0003oool0003o0080oooo00<0o`000?ooo`000?l00P3oool00`3o
0000003o0?ooo`150?ooo`00N`3oool01@000000oooo0?ooo`3oool0003o
00D0o`0000H0003o0?ooo`3oool0o`000?ooo`000?l20?ooo`030?l0003o
ool0003o0080oooo00<0o`000?ooo`000?l00P000?l20?ooo`040?l0003o
ool0oooo0?ooo`80003o0P3oool20?l000<0oooo0P000?l50?oooa40o`00
103oool30000o`@0oooo0P3o00020?ooo`050000o`3oool0oooo0?ooo`3o
00000P3oool20000o`050?ooo`3o0000oooo0?ooo`000?l00`3oool00`3o
0000oooo0000o`020?ooo`070?l0003oool0003o0?ooo`3o0000oooo0000
o`160?ooo`00NP3oool2000000<0oooo00H0003o0?ooo`3oool0o`000?oo
o`000?l40?l000040?ooo`000?l0oooo0?l00080oooo00@0003o0?ooo`3o
ool0o`000P3oool20000o`80oooo00@0o`000?ooo`3oool0003o0P3oool2
0?l000<0oooo0`000?l40?ooo`80o`0000<0oooo0?l0003oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080o`000P3oool0
0`000?l0oooo0?ooo`020000o`80oooo0P3o00030?ooo`080000o`3oool0
oooo0?ooo`3o0000003o0?ooo`000?l20?ooo`040?l0003oool0oooo0000
o`80oooo00<0o`000?ooo`000?l00P3oool01`3o0000oooo0000o`3oool0
o`000?ooo`000?l0AP3oool007l0oooo00H0003o0?ooo`3oool0o`000?oo
o`000?l20?ooo`030?l0003oool0003o00<0o`0000D0oooo0000o`3oool0
oooo0?l000020?ooo`060000o`3oool0oooo0000o`3o0000oooo0P000?l3
0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool010000?l0oooo0?l0
003o00030?ooo`030?l0003oool0oooo00T0003o00<0o`000?ooo`3oool0
0`3oool20?l000D0oooo00D0003o0?l0003oool0oooo0?l000030?ooo`05
0000o`3oool0oooo0000o`3o00000P3oool00`000?l0oooo0?l000020?oo
o`060000o`3oool0oooo0?l0003oool0003o103o00001P000?l0o`000?l0
003o0000003o0?l004D0oooo001o0?ooo`060000o`3oool0oooo0?l0003o
ool0003o0P3oool02P3o0000oooo0000o`3oool0o`000?ooo`3o0000003o
0?ooo`3o00030?ooo`040000o`3oool0oooo0?l00080003o103oool00`3o
0000oooo0?l000020000o`<0oooo0`3o00030?ooo`D0003o0`3oool00`00
0?l0oooo0?ooo`030?ooo`D0003o0P3oool00`000?l0o`000?l000030?oo
o`030?l000000?l0003o0080oooo00@0o`000?ooo`3oool0oooo0P000?l0
1@3oool0o`000?ooo`3oool0003o0080oooo00@0o`000?ooo`3oool0003o
0`3o00002P3oool0003o0?ooo`3o0000oooo0000o`3oool0o`000?ooo`00
0?m60?ooo`00O`3oool01P000?l0oooo0?ooo`3o0000oooo0000o`80oooo
00P0o`000?ooo`000?l0oooo0?l0003oool0003o0?ooo`80o`000P3oool0
1@000?l0oooo0?ooo`3o0000oooo0080003o0P3oool20?l000030?ooo`00
0?l0003o0080o`0000<0oooo0?l0003o00000P3oool010000?l0oooo0000
o`000?l20?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`020?ooo`80003o0`3oool30?l000<0oooo
00P0003o0?ooo`3oool0o`000?ooo`000?l0oooo0000o`80oooo00@0o`00
0?ooo`3oool0003o0P3oool20?l0000>0000o`3oool0oooo0?l0003oool0
003o0?ooo`3o0000oooo0000o`3oool0o`000?ooo`000?m60?ooo`00O`3o
ool020000?l0oooo0?ooo`3o0000oooo0000o`3oool0o`000P3oool02P00
0?l0oooo0?l0003oool0003o0?ooo`3o0000oooo0?l000000?l20?ooo`07
0?l0003oool0oooo0000o`3oool0003o0?l000020?ooo`040000o`3oool0
oooo0?ooo`80o`000`3oool30000o`@0oooo3`3o00030?ooo`<0003o0`3o
ool20?l000<0oooo0P000?l00`3oool0o`000?ooo`020?ooo`040000o`3o
ool0oooo0?l00080oooo00<0003o0?l0003o00000P3oool03@000?l0oooo
0?l0003oool0003o0?ooo`3o0000oooo0000o`3oool0o`000?ooo`000?l0
AP3oool007l0oooo0`000?l02@3o0000003o0000o`000?l0o`000?ooo`00
0?l0oooo0?l000020?ooo`030000o`3oool0o`000080oooo00<0003o0?l0
003o00000P3oool01@000?l0oooo0?ooo`3o0000oooo0080003o0`3oool0
103o0000oooo0?l0003oool20000o`040?ooo`000?l0oooo0?ooo`@0o`00
1@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0o`00
0P3oool20000o`030?l0003oool0oooo0080o`000`3oool010000?l0oooo
0?l0003o00020?ooo`030000o`3oool0o`000080o`000180003o0?ooo`3o
ool0o`000?ooo`000?l0oooo0?l0003oool0003o0?ooo`3o0000oooo0000
o`3oool0o`000?ooo`000?m60?ooo`00O`3oool00`000000oooo0?ooo`04
0?ooo`070?l000000?l0003o0?ooo`3o0000oooo0000o`020?ooo`030?l0
003oool0003o0080oooo00<0o`000?ooo`000?l00P3oool0103o0000oooo
0?ooo`000?l20?ooo`80o`000P3oool20000o`<0oooo0`3o00040?ooo``0
003o103oool010000?l0oooo0?l0003o00020?ooo`80003o0`3oool01@3o
0000oooo0000o`3oool0003o0080oooo00H0o`000?ooo`3oool0003o0?oo
o`3o00020?ooo`050000o`3oool0o`000?ooo`000?l00P3oool0103o0000
003o0?ooo`3o00030000o`040?l000000?l0003o0000odD0oooo001o0?oo
o`030000003oool0oooo00L0oooo00H0003o0?l000000?l0003o0?ooo`3o
00020?ooo`080000o`3oool0o`000?ooo`3o0000003o0?ooo`3o00020?oo
o`040000o`3oool0003o0?l000<0oooo00@0003o0?l0003oool0oooo0P3o
00020?ooo`D0003o00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0003o00@0003o0`3oool30?l000030?ooo`00
0?l0oooo0080oooo00@0o`000?ooo`3oool0003o0`3oool00`3o0000oooo
0000o`020?ooo`050?l0003oool0003o0?ooo`3o00000P3oool20000o`0:
0?l000000?l0003o0?l0003oool0003o0?ooo`3o0000oooo0000odH0oooo
001o0?ooo`030000003oool0oooo00/0oooo00H0003o0?l0003oool0003o
0?ooo`3o00020?ooo`030000o`3oool0o`000080oooo00H0003o0?ooo`3o
ool0o`000000o`3oool20000o`80oooo0P3o00030?ooo`80003o103oool;
0?l000@0oooo00@0003o0?ooo`000?l0003o0P3oool30?l000050?ooo`00
0?l0003o0000o`3oool00P3o0000103oool0003o0?ooo`3oool20?l00004
0?ooo`000?l0oooo0?l00080oooo00<0003o0?ooo`3o00000P000?l01`3o
ool0o`000000o`3oool0o`000?ooo`000?l00P3oool00`3o0000003o0?oo
o`150?ooo`00O`3oool00`000000oooo0?ooo`0<0?ooo`<0003o00T0oooo
0?l0003oool0003o0?ooo`3o0000oooo0?l000000?l00P3oool0103o0000
oooo0?ooo`000?l20?ooo`80o`0000<0oooo0?l000000?l00P000?l00`3o
ool0003o0?ooo`040?l000@0oooo00<0003o0?ooo`3oool00P3oool70?l0
0080oooo0P000?l00`3o0000oooo0?ooo`020?l000030?ooo`000?l0oooo
0080oooo00P0o`000?ooo`000?l0o`000?ooo`3o0000oooo0000o`80oooo
0180o`000000o`000?l0003o0?l0003oool0003o0?ooo`3o0000oooo0000
o`3oool0o`000?ooo`000?l0oooo0?l000000?m60?ooo`00O`3oool00`00
0000oooo0?ooo`0?0?ooo`050?l000000?l0oooo0000o`3o00000`3oool0
0`000?l0o`000?l000020?ooo`80003o0P3o00020?ooo`80003o0`3oool3
0?l000<0oooo00<0o`000000o`000?l02P000?l20?ooo`030000o`3oool0
o`0000<0o`000P000?l30?ooo`040?l0003oool0003o0000o`80oooo0P3o
000030000?l0oooo0?ooo`3o0000oooo0000o`3oool0o`000?ooo`000?l0
oooo0?l00080oooo00`0003o0?l0003oool0003o0?ooo`3o0000oooo0000
o`3oool0o`000000o`3o00150?ooo`00O`3oool00`000000oooo0?ooo`0A
0?ooo`030000o`3oool0o`000080oooo00X0003o0?ooo`3o0000o`000?oo
o`000?l0oooo0?l000000?l0oooo0P000?l20?ooo`<0o`0000<0oooo0000
o`000?l010000?l01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool010000?l20?ooo`80o`000P3oool30000o`050?ooo`3o0000
oooo0?ooo`000?l00P3o00020?ooo`040000o`3oool0o`000?ooo`80003o
00/0o`000?ooo`3oool0003o0?ooo`3o0000oooo0000o`3o0000oooo0000
o`030?l000040000o`3o0000o`000000odH0oooo001o0?ooo`030000003o
ool0oooo0180oooo00L0o`000?ooo`3oool0003o0?ooo`3o0000oooo0080
003o00D0oooo0?l0003oool0oooo0000o`020?ooo`<0o`0000D0oooo0000
o`000?l0oooo0000o`020?ooo`d0o`000`3oool01P000?l0oooo0000o`00
0?l0o`000?ooo`80o`0000<0oooo0000o`000?l00P3oool04P3o0000oooo
0?l000000?l0oooo0?l0003oool0003o0?ooo`000?l0o`000?ooo`000?l0
oooo0?l0003oool0003o0?ooo`80o`0000/0003o0?l0003o0000oooo0000
o`3o0000oooo0000o`3oool0o`000000o`160?ooo`00O`3oool00`000000
oooo0?ooo`0C0?ooo`80003o00D0oooo0?l0003oool0003o0?ooo`020?l0
0080oooo00@0003o0?ooo`3o0000o`000P3oool20000o`<0oooo0`3o0002
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?l0
00030?l000<0oooo0P000?l20?ooo`80o`0000@0oooo0000o`3oool0oooo
0P3o0000203oool0003o0?ooo`3o0000oooo0000o`3oool0o`000P3oool0
10000?l0o`000?ooo`000?l30?l0000;0000o`3oool0o`000?ooo`000?l0
o`000?ooo`000?l0oooo0?l000000?l0AP3oool007l0oooo00<000000?oo
o`3oool0503oool01P000?l0o`000000o`000?l0oooo0?l00080oooo00T0
o`000000o`3oool0o`000?ooo`000?l0oooo0000o`3oool0103o00000`3o
ool0003o0000o`0@0000o`040?ooo`3o0000o`000?l00080oooo0`000?l0
0`3oool0o`000?ooo`020000o`80oooo01`0o`000?ooo`000?l0003o0?l0
003oool0003o0?ooo`3o0000oooo0000o`3oool0o`000?ooo`000?l0oooo
0?l000000?l0oooo0?l0003oool0003o0?ooo`3o0000003o0?ooo`3o0000
003oAP3oool007l0oooo00<000000?ooo`3oool05P3oool20000o`070?l0
003oool0oooo0?ooo`000?l0oooo0?l000020?ooo`80003o00@0oooo0?l0
003o0000o`000P3oool20000oa00oooo10000?l30?l00080oooo00<0003o
0?ooo`3oool00P3o00001@3oool0003o0000o`3oool0o`000080003o00D0
oooo0?l0003oool0003o0?ooo`020?l000070000o`3oool0o`000000o`3o
ool0o`000000o`020?ooo`040?l000000?l0003o0?l00080003o00<0o`00
0000o`000?l0A@3oool007l0oooo00<000000?ooo`3oool0603oool0103o
0000oooo0?ooo`000?l20?l000040?ooo`000?l0003o0000o`80o`000P3o
ool00`3o0000003o0000o`0F0?ooo`80003o00@0oooo0?l0003o0000oooo
0P000?l02@3oool0o`000?l0003oool0003o0?ooo`000?l0o`000000o`02
0?ooo`090?l000000?l0o`000?l0003oool0003o0?ooo`3o0000003o0080
oooo00/0o`000000o`000?l0o`000000o`3oool0o`000000o`3oool0o`00
0000o`160?ooo`00O`3oool00`000000oooo0?ooo`0I0?ooo`80003o00@0
oooo0?l0003o0000003o0P3oool0103o0000003o0?ooo`3oool20000oaX0
oooo0P000?l01@3oool0o`000?l0003oool0003o0080oooo00P0o`000?oo
o`000?l0oooo0?l0003oool0003o0?ooo`80o`0000@0003o0?ooo`3o0000
003o0P3oool03P3o0000003o0000o`3o0000003o0?ooo`3o0000003o0?oo
o`3o0000003o0?ooo`3o0000003oAP3oool007l0oooo00<000000?ooo`3o
ool06@3oool01@000?l0o`000?l0003oool0003o00<0o`0000@0oooo0000
o`000?l0003o7@3oool20000o`80oooo00<0o`000?ooo`000?l00P3oool0
3@3o0000003o0000o`3oool0o`000?ooo`000?l0oooo0?l0003oool0003o
0?l0003oool00P000?l03`3o0000003o0?ooo`3o0000oooo0000o`3o0000
003o0?ooo`3o0000003o0?ooo`3o0000003o0?l000150?ooo`00O`3oool0
0`000000oooo0?ooo`0J0?ooo`<0003o0`3o00020000ob80oooo0P000?l2
0?l0000<0?ooo`000?l0003o0000o`3o0000oooo0000o`3oool0o`000?oo
o`000?l0o`000P3oool030000?l0o`000000o`3oool0o`000?ooo`000?l0
o`000?ooo`000?l0o`000000o`80o`0000@0003o0?l0003o0000003oAP3o
ool007l0oooo00<000000?ooo`3oool06`3oool00`000?l0o`000?ooo`02
0000obH0oooo0P000?l20?l00080003o00T0oooo0?l0003o0000003o0?oo
o`3o0000003o0?ooo`3o00000P000?l01P3o0000oooo0000o`3oool0o`00
0000o`80o`0000T0003o0?ooo`3o0000003o0?l0003oool0003o0?l00000
0?l0AP3oool007l0oooo00<000000?ooo`3oool0703oool20000obX0oooo
0P000?l00`3o0000oooo0000o`020?l0000;0?ooo`000?l0o`000?ooo`00
0?l0oooo0?l0003oool0003o0?l000000?l00`3o00002`000?l0o`000000
o`3oool0o`000000o`3o0000oooo0000o`3o0000003o04H0oooo001o0?oo
o`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0:P3oool01000
0?l0oooo0?l0003o00020000o`050?l000000?l0003o0?l000000?l00P3o
ool03P3o0000003o0?l0003o0000003o0?l0003oool0003o0?l000000?l0
oooo0?l000000?l0o`000P000?l00`3o0000003o0000o`150?ooo`00O`3o
ool00`000000oooo0?ooo`1:0?ooo`0<0000o`3oool0o`000?l000000?l0
oooo0?l000000?l0o`000?ooo`000?l0oooo0P3o00001`000?l0o`000000
o`3o0000oooo0000o`3o00000P000?l00`3o0000oooo0?ooo`1:0?ooo`00
O`3oool00`000000oooo0?ooo`1;0?ooo`80003o00H0o`000?ooo`000?l0
o`000?ooo`000?l20?l000090000o`3oool0o`000000o`3o0000oooo0000
o`3o0000003o0500oooo001o0?ooo`030000003oool0oooo04`0oooo00D0
003o0?ooo`3o0000003o0?ooo`020?l000080000o`3o0000o`000000o`3o
0000oooo0000o`3o001C0?ooo`00O`3oool00`000000oooo0?ooo`1=0?oo
o`040000o`3oool0o`000000o`80o`0000<0oooo0000o`3o00000P000?l0
0`3o0000oooo0?ooo`1C0?ooo`00O`3oool00`000000oooo0?ooo`1>0?oo
o`80003o00H0o`000000o`000?l0o`000000o`3o001H0?ooo`00O`3oool0
0`000000oooo0?ooo`1?0?ooo`030000o`3oool0o`000080003o00<0o`00
0?ooo`3oool0E`3oool007l0oooo00<000000?ooo`3oool0D03oool01000
0?l0oooo0?l000000?mJ0?ooo`00O`3oool00`000000oooo0?ooo`1A0?oo
o`030000o`3oool0oooo05X0oooo001o0?ooo`030000003oool0oooo0:h0
oooo001o0?ooo`030000003oool0oooo0:h0oooo001o0?ooo`030000003o
ool0oooo0:h0oooo001o0?ooo`030000003oool0oooo0:h0oooo003o0?oo
oc40oooo003o0?oooc40oooo003o0?oooc40oooo003o0?oooc40oooo003o
0?oooc40oooo003o0?oooc40oooo003o0?oooc40oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{304, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.74",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/schwarzchristoffel/\
SchwarzChristoffelFigures/mat1174.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The region with ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \(\(\[Rule]\)\(\[Infinity]\)\)\),
         
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_3 = 1 + \[ImaginaryI]\)}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(\[Pi]\/2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "\[Rule]", "\[Pi]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "3"], "\[Rule]", \(-\(\[Pi]\/2\)\)}]}]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe limiting formula for the derivative ",
  Cell[BoxData[
      \(g' \((z)\)\)]],
  " becomes   \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ \(A\_1\) \(\((z + 
                  1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \
\((z)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\ \((z - \
1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(A\_1\) \(\((z + 
                  1)\)\^\(\(-\(\[Pi]\/2\)\)/\[Pi]\)\) \((z)\)\^\(\(-\[Pi]\)/\
\[Pi]\)\ \((z - 1)\)\^\(\(-\((\(-\(\[Pi]\/2\)\))\)\)/\[Pi]\)\)\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(A\_1\) \(\((z + 
                  1)\)\^\(-\(1\/2\)\)\) \((z)\)\^\(-1\)\ \((z - \
1)\)\^\(1\/2\)\)\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\_1\ \(1\/z\) \((z \
- 1)\)\^\(1\/2\)\/\((z + 1)\)\^\(1\/2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\_1\ \(\(\((z - \
1)\)\^\(1\/2\)\) \((z - 1)\)\^\(1\/2\)\)\/\(z \(\((z + 1)\)\^\(1\/2\)\) \((z \
- 1)\)\^\(1\/2\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\_1\ \(z - 1\)\/\(z \
\((z\^2 - 1)\)\^\(1\/2\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ \(z - 1\)\/\(z \((1 \
- z\^2)\)\^\(1\/2\)\)\)\)\)}]],
  "\n\nwhere  ",
  Cell[BoxData[
      \(A\  = \ \(-\[ImaginaryI]\)\ A\_1\)]],
  ", which will determine a mapping ",
  Cell[BoxData[
      \(w\  = \ f \((z)\)\)]],
  " from the upper half plane onto the channel as indicated in Figure \
11.74(b).  "
}], "Text"],

Cell[TextData[{
  "\tUsing integrals in Table 11.2, we obtain \n\n\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\ \  = \ \ A\ \(\[Integral]\(\(z - 
                      1\)\/\(z \((1 - z\^2)\)\^\(1\/2\)\)\) \[DifferentialD]z\
\)\ \  + \ \ B\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ \(\[Integral]\(z\/\(z \
\((1 - z\^2)\)\^\(1\/2\)\)\) \[DifferentialD]z\)\ \  - \ \ \ A\ \(\[Integral]\
\(1\/\(z \((1 - z\^2)\)\^\(1\/2\)\)\) \[DifferentialD]z\)\ \  + \ 
          B\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ \
\(\[Integral]\(1\/\((1 - z\^2)\)\^\(1\/2\)\) \[DifferentialD]z\)\ \  - \ \ \ \
A\ \[ImaginaryI] \(\[Integral]\(1\/\(z \((z\^2 - 1)\)\^\(1\/2\)\)\) \
\[DifferentialD]z\)\ \  + \ B\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \((Arcsin\ z\  + \ \
\[ImaginaryI]\ Arcsin \((1\/z)\))\)\ \  + \ \ B\)\)\)}],
    AspectRatioFixed->True],
  "   "
}], "Text"],

Cell[TextData[{
  "\tIf we use the principal branch of the inverse sine function, then the \
boundary values  ",
  Cell[BoxData[
      \(f \((\(-1\))\) = \(0\ \ and\ \ f \((1)\) = 1 + \[ImaginaryI]\)\)]],
  "  lead to the system  \n\n\t\t\t",
  Cell[BoxData[
      \(A \((\(-\(\[Pi]\/2\)\) - \(\[ImaginaryI]\ \[Pi]\)\/2)\) + B = 0\)]],
  "   and   ",
  Cell[BoxData[
      \(A \((\[Pi]\/2 + \(\[ImaginaryI]\ \[Pi]\)\/2)\) + B = 
        1 + \[ImaginaryI]\)]],
  ",  \n\nwhich we can solve to obtain ",
  Cell[BoxData[
      \(A = \(1\/\[Pi]\ \ and\ \ B = \(1 + \[ImaginaryI]\)\/2\)\)]],
  ".  Hence the required solution is \n \n\t\t\t",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ \(\(\(1\/\[Pi]\) 
              Arcsin\ z\)\(\ \)\(+\)\(\ \)\(\(\[ImaginaryI]\/\[Pi]\) Arcsin 
               1\/z\)\(\ \)\(+\)\(\ \)\(\(1\  + \ \[ImaginaryI]\)\/2\)\(\ \
\)\)\)\)]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.28.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the formula ",
  Cell[BoxData[
      \(\(f'\)[z] = \(A\ \((z\  - \ 1)\)\)\/\(z\ \@\((z\^2\  - \ 1)\)\)\)],
    AspectRatioFixed->True],
  " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f1, A, B, z, F];\)\ \), "\n", 
    \(\(f1[
          z_]\  = \ \(A\ \((z\  - \ 1)\)\)\/\(z\ \@\((z\^2\  - \ 1)\)\);\)\ \
\), "\n", 
    \(\(f[z_]\  = \ 
        B\  + \ \[Integral]\(\(A\ \((z\  - \ 
                        1)\)\)\/\(z\ \@\((z\^2\  - \ 1)\)\)\) \
\[DifferentialD]z;\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = B + \[Integral] \>", 
        f1[z], "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
This is one, formula for the integral.   However, we will use the following \
form of the integral to continue the computations.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(F[z_]\  = \ 
        A\ \((ArcSin[z]\  + \ \[ImaginaryI]\ ArcSin[1\/z])\)\  + \ 
          B;\)\ \), "\n", 
    \(\(Print["\<F[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(eq1\  = \ F[\(-1\)]\  \[Equal] \ 0;\)\ \), "\n", 
    \(\(eq2\  = \ F[1]\ \  \[Equal] \ 1 + \[ImaginaryI];\)\ \), "\n", 
    \(\(solset\  = \ 
        Solve[{F[\(-1\)] \[Equal] 0, F[1] \[Equal] 1 + \[ImaginaryI]}, {A, 
            B}];\)\ \), "\n", 
    \(\(f[z_]\  = \ 
        ReplaceAll[F[z], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \), "\n", 
    \(\(Print[eq1];\)\ \), "\n", 
    \(\(Print[eq2];\)\ \), "\n", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<f[z] = B + A (ArcSin[z] + \[ImaginaryI] \
ArcSin[\!\(1\/z\)])\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[f, {\(-4\), 4, 0.5}, {0.00001, 4.00001, 0.2}, 
        PlotRange \[Rule] {{0, 1.5}, {0, 
              1.35}}, \[IndentingNewLine]Ticks \[Rule] {Range[0, 2, 0.5], 
            Range[0, 2, 0.5]}, AxesLabel \[Rule] {"\<u\>", "\<v\>"}, 
        PlotStyle \[Rule] {Blue, Red}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<is the channel in the right half plane bounded by the\>"];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<coordinate axes and rays x \[GreaterEqual] 0, y = 1 and y \
\[GreaterEqual] 1, x = 1.\>"];\)\ \), "\n", 
    \(\(Print["\<where  w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We see that  ",
  Cell[BoxData[
      \(\(\(w = \(1\/\[Pi]\) ArcSin[z] + \(\[ImaginaryI]\/\[Pi]\) 
            ArcSin[1\/z] + \(1\  + \ \[ImaginaryI]\)\/2\)\(\ \)\)\)]],
  "  maps the upper half plane  ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  onto the channel in the right half plane bounded by the coordinate axes \
and rays  ",
  Cell[BoxData[
      \(x \[GreaterEqual] 0, y = 1\ \ and\ \ y \[GreaterEqual] 1, x = 1\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(w\ \  = \ \ \(f \((z)\)\ \  = \ \ \(1\/\[Pi]\) \((z\^2 - 1)\)\^\(1\/2\
\)\  + \ \(1\/\[Pi]\) 
              Log \((z + \((z\^2 - 1)\)\^\(1\/2\))\)\  - \ \
\[ImaginaryI]\)\)]],
  "  maps the upper half-plane onto the domain indicated in Figure 11.77.  \n\
Hint: Set  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 1\)}]]],
  "  and   ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \(-\[ImaginaryI]\)\)}]]],
  ". "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006m0000[b000`400?l0
0000o`00003oo`3ooonn0?ooo`00o`3ooonn0?ooo`00o`3ooonn0?ooo`00
o`3ooonn0?ooo`00o`3ooonn0?ooo`00o`3ooonn0?ooo`00o`3ooonn0?oo
o`00o`3ooonn0?ooo`00o`3oool30?ooo`D00000]P3oool00?l0oooo1@3o
ool00`000000oooo0?ooo`2f0?ooo`00o`3oool50?ooo`030000003oool0
oooo00<0oooo00<000000000o`000000U@000?lK0?ooo`00o03oool40000
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000o`120?oo
o`030?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool0603oool00`3o
0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01T0oooo003o0?ooo`D0
oooo00<000000?ooo`3oool00`3oool010000000oooo0000o`000?m10?oo
o`030?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool0603oool00`3o
0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01T0oooo003o0?ooo`@0
oooo0P0000050?ooo`05000000000?l0oooo0?ooo`000?l0@03oool00`3o
0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?oo
o`3oool05@3oool00`000?l0oooo0?ooo`0I0?ooo`00o`3oool;0?ooo`03
000000000?l0oooo0080oooo00<0003o0?ooo`3oool0?@3oool00`3o0000
oooo0?ooo`0L0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`0I0?ooo`00o`3oool;0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0?03oool00`3o0000oooo
0?ooo`0L0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0
5@3oool00`000?l0oooo0?ooo`0I0?ooo`00o`3oool;0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool0>`3oool00`3o0000oooo0?oo
o`0L0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool05@3o
ool00`000?l0oooo0?ooo`0I0?ooo`00o`3oool;0?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool0>P3oool00`3o0000oooo0?ooo`0L
0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool05@3oool0
0`000?l0oooo0?ooo`0I0?ooo`00o`3oool;0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool0>@3oool00`3o0000oooo0?ooo`0L0?oo
o`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool05@3oool00`00
0?l0oooo0?ooo`0I0?ooo`00o`3oool;0?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool0>03oool00`3o0000oooo0?ooo`0M0?ooo`03
0000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool03@3oool90?l001/0
oooo003o0?ooo`/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo
0?ooo`0h0?ooo`030?l0003oool0oooo01d0oooo00<0003o0?ooo`3oool0
3`3ooolH0?l000P0oooo00<0003o0?ooo`3oool06@3oool00?l0oooo2`3o
ool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo03L0oooo00<0
o`000?ooo`3oool06P3ooolE0?l000P0oooo00<0o`000?ooo`3oool05@3o
ool00`000?l0oooo0?ooo`0I0?ooo`00o`3oool;0?ooo`030000o`3oool0
oooo00T0oooo00<0003o0?ooo`3oool0=P3oool00`3o0000oooo0?ooo`0<
0?ooo`h0o`000`3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0
oooo01D0oooo00<0003o0?ooo`3oool06@3oool00?l0oooo2`3oool00`00
0?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo03D0oooo00<0o`000?oo
o`3oool00`3oool90?l00140oooo00<0003o0?ooo`3oool05`3oool00`3o
0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01T0oooo003o0?ooo`/0
oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0c0?ooo`L0
o`006P3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo01D0
oooo00<0003o0?ooo`3oool06@3oool00?l0oooo2`3oool00`000?l0oooo
0?ooo`0<0?ooo`030000o`3oool0oooo02h0oooo103o00000`3oool0o`00
0?ooo`0N0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0
5@3oool00`000?l0oooo0?ooo`0I0?ooo`00o`3oool;0?ooo`030000o`3o
ool0oooo00d0oooo00<0003o0?ooo`3oool0:03oool50?l000H0oooo00<0
o`000?ooo`3oool0703oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003o
ool0oooo01D0oooo00<0003o0?ooo`3oool06@3oool00?l0oooo2`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo0280oooo1@3o000;
0?ooo`030?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool05`3oool0
0`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01T0oooo003o0?oo
o`/0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0M0?oo
o`@0o`00403oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo
01L0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0I0?oo
o`00o`3oool;0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3o
ool06P3oool20?l001@0oooo00<0o`000?ooo`3oool0703oool00`000?l0
oooo0?ooo`0G0?ooo`030?l0003oool0oooo0080oooo50000?lK0?ooo`00
o`3oool;0?ooo`030000o`3oool0oooo0140oooo00<0003o0?ooo`3oool0
5`3oool20?l001H0oooo00<0o`000?ooo`3oool0703oool00`000?l0oooo
0?ooo`0?0?ooo`d0003o4`3oool00`000?l0oooo0?ooo`0I0?ooo`00o`3o
ool;0?ooo`030000o`3oool0oooo0180oooo00<0003o0?ooo`3oool0503o
ool20?l001T0oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?oo
o`080?ooo`L0003o2@3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3o
ool0oooo01T0oooo003o0?ooo`/0oooo00<0003o0?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`0A0?ooo`80o`006`3oool00`3o0000oooo0?ooo`0I
0?ooo`d0003o403oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0
oooo01T0oooo003o0?ooo`/0oooo00<0003o0?ooo`3oool0503oool00`00
0?l0oooo0?ooo`0>0?ooo`80o`007@3oool00`3o0000oooo0?ooo`0D0?oo
o`D0003o0`3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo
01@0oooo00<0003o0?ooo`3oool06@3oool00?l0oooo2`3oool00`000?l0
oooo0?ooo`0E0?ooo`030000o`3oool0oooo00/0oooo0P3o000O0?ooo`03
0?l0003oool0oooo0100oooo10000?l80?ooo`030000o`3oool0oooo01L0
oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0I0?ooo`00
o`3oool;0?ooo`030000o`3oool0oooo01H0oooo00<0003o0?ooo`3oool0
203oool20?l00280oooo00<0o`000?ooo`3oool02@3oool60000o``0oooo
00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0D0?ooo`030000
o`3oool0oooo01T0oooo003o0?ooo`/0oooo00<0003o0?ooo`3oool05`3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0280oooo00<0
o`000?ooo`3oool0103oool50000oa80oooo00<0003o0?ooo`3oool05`3o
ool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01P0oooo003o
0?ooo`/0oooo00<0003o0?ooo`3oool0603oool00`000?l0oooo0?ooo`03
0?ooo`80o`009@3oool00`3o0000oooo0?ooo`040000oaL0oooo00<0003o
0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0
oooo01P0oooo003o0?ooo`/0oooo00<0003o0?ooo`3oool06@3oool00`00
0?l0oooo0?ooo`020?l002H0oooo10000?lK0?ooo`030000o`3oool0oooo
01L0oooo00<0o`000?ooo`3oool03@3oool90?l001X0oooo003o0?ooo`/0
oooo00<0003o0?ooo`3oool06P3oool00`000?l0o`000?ooo`0S0?ooo`@0
003o0P3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo01L0
oooo00<0o`000?ooo`3oool00P3oool;0?l000P0oooo00<0003o0?ooo`3o
ool0603oool00?l0oooo2`3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0
00000?l0oooo0200oooo0`000?l60?ooo`030?l0003oool0oooo01X0oooo
00<0003o0?ooo`3oool03`3oool=0?l001<0oooo00<0003o0?ooo`3oool0
603oool00?l0oooo2`3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003o
ool0003o01l0oooo0P000?l90?ooo`030?l0003oool0oooo01/0oooo00<0
003o0?ooo`3oool0203oool60?l000P0oooo00<0o`000?ooo`3oool05@3o
ool00`000?l0oooo0?ooo`0H0?ooo`00o`3oool;0?ooo`030000o`3oool0
oooo01P0oooo00D0o`000?ooo`3oool0oooo0000o`0K0?ooo`<0003o303o
ool00`3o0000oooo0?ooo`0J0?ooo`040000o`3oool0oooo0?ooo`L0o`00
3`3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo01P0oooo
003o0?ooo`/0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo01D0oooo0`000?l?0?ooo`030?l0003o
ool0oooo01P0oooo1P3o000F0?ooo`030?l0003oool0oooo01@0oooo00<0
003o0?ooo`3oool0603oool00?l0oooo2`3oool00`000?l0oooo0?ooo`0F
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool2
0000oa80oooo00<0o`000?ooo`3oool04`3oool50?l00080oooo00<0003o
0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0
oooo01P0oooo003o0?ooo`/0oooo00<0003o0?ooo`3oool05@3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00l0oooo0P000?lD0?oo
o`030?l0003oool0oooo00l0oooo103o00070?ooo`030000o`3oool0oooo
01L0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0H0?oo
o`00o`3oool;0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0<0?ooo`80003o5`3oool00`3o0000
oooo0?ooo`0;0?ooo`<0o`00303oool00`000?l0oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0603oool00?l0oooo
2`3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02P3oool20000oaT0oooo00<0o`000?ooo`3oool0
1`3oool40?l000l0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo
0?ooo`0=0?ooo`P0003o6P3oool00?l0oooo2`3oool00`000?l0oooo0?oo
o`0D0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo00<0oooo0`3o
000C0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool00P3o
ool;0000o`P0oooo00<0003o0?ooo`3oool05`3oool00?l0oooo2`3oool0
0`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0
o`0000<0o`005P3oool00`000?l0oooo0?ooo`0D0?ooo`L0003o4`3oool0
0`000?l0oooo0?ooo`0G0?ooo`00o`3oool;0?ooo`030000o`3oool0oooo
0180oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`030?oo
o`80003o7@3oool30?l001/0oooo00<0003o0?ooo`3oool03@3oool60000
o`<0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0G0?oo
o`00o`3oool;0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3o
ool03`3oool01@000?l0oooo0?ooo`3oool0003o01/0oooo103o00000`3o
ool0o`000?ooo`0K0?ooo`030000o`3oool0oooo00L0oooo1P000?l90?oo
o`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool05`3oool00?l0
oooo2`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0100
oooo00@0003o0?ooo`3oool0003o6@3oool30?l000H0oooo00<0o`000?oo
o`3oool06@3oool010000?l0oooo0?ooo`3oool60000o`l0oooo00<0o`00
0?ooo`3oool0503oool00`000?l0oooo0?ooo`0G0?ooo`00o`3oool;0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04@3oool20000
oaP0oooo0P3o00090?ooo`030?l0003oool0oooo01P0oooo1@000?lE0?oo
o`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool05`3oool00?l0
oooo2`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0180
oooo0P000?lF0?ooo`80o`002`3oool00`3o0000oooo0?ooo`0E0?ooo`<0
003o0P3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo01@0
oooo00<0003o0?ooo`3oool05`3oool00?l0oooo2`3oool00`000?l0oooo
0?ooo`0@0?ooo`030?l0003oool0oooo0140oooo00@0003o0?ooo`3oool0
003o4`3oool20?l000d0oooo00<0o`000?ooo`3oool0403oool50000o`D0
oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo01L0oooo003o0?ooo`/0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`0@0?ooo`80003o103oool00`000?l0oooo
0?ooo`0>0?ooo`80o`00403oool00`3o0000oooo0?ooo`0:0?ooo`D0003o
2P3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00d0oooo
203o000I0?ooo`00o`3oool;0?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo00/0oooo0P3o000B0?ooo`030?l0003oool0oooo00L0oooo0`00
0?l?0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool01`3o
ool60?l000L0oooo00<0003o0?ooo`3oool05`3oool00?l0oooo2`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`80o`005@3oool0
0`3o0000oooo0?ooo`030?ooo`<0003o4`3oool00`000?l0oooo0?ooo`0C
0?ooo`/0o`003P3oool00`000?l0oooo0?ooo`0F0?ooo`00o`3oool;0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`090?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool05@3oool00`3o0000oooo0?ooo`030000oaH0oooo00<0003o0?oo
o`3oool03P3oool50?l00080oooo00<0o`000?ooo`3oool0503oool00`00
0?l0oooo0?ooo`0F0?ooo`00o`3oool;0?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00@0oooo0P3o000I0?ooo`80003o6@3oool00`000?l0
oooo0?ooo`0;0?ooo`<0o`001`3oool00`3o0000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo01H0oooo003o0?ooo`/0oooo00<0003o0?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00/0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0G0?ooo`80003o
00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`070?ooo`@0o`00
2P3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo01H0oooo
003o0?ooo`/0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool00P3o
000H0?ooo`80003o0`3oool00`3o0000oooo0?ooo`0G0?ooo`040000o`3o
ool0oooo0?ooo`H0o`003P3oool00`3o0000oooo0?ooo`0D0?ooo`030000
o`3oool0oooo01H0oooo003o0?ooo`/0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0
003o0?l0003oool05P3oool30000o`D0oooo00<0o`000?ooo`3oool05P3o
ool50?l001@0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?oo
o`0F0?ooo`00o`3oool;0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0?0?ooo`030?l000000?l0
oooo01@0oooo0P000?l80?ooo`030?l0003oool0oooo0140oooo1@3o0000
0`3oool0003o0?ooo`0F0?ooo`030?l0003oool0oooo0180oooo0`000?lH
0?ooo`00o`3oool;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0003o
01<0oooo0P000?l;0?ooo`030?l0003oool0oooo00`0oooo103o00060?oo
o`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool0303oool50000
o`80oooo00<0003o0?ooo`3oool05P3oool00?l0oooo2`3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool03@3oool20?l000<0oooo00<0003o0?ooo`3oool03P3oool20000o`d0
oooo00<0o`000?ooo`3oool02@3oool30?l000/0oooo00<0003o0?ooo`3o
ool05@3oool00`3o0000oooo0?ooo`070?ooo`D0003o203oool00`000?l0
oooo0?ooo`0E0?ooo`00o`3oool;0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool20000o`l0oooo
00<0o`000?ooo`3oool01P3oool30?l000h0oooo00<0003o0?ooo`3oool0
5@3oool0103o0000oooo0?ooo`3oool60000o`d0oooo00<0003o0?ooo`3o
ool05@3oool00?l0oooo2`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00P0oooo0P000?lB0?ooo`030?l0
003oool0oooo0080oooo0`3o000A0?ooo`030000o`3oool0oooo01@0oooo
1@000?lC0?ooo`030000o`3oool0oooo01D0oooo003o0?ooo`/0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`050?ooo`80003o503oool00`3o0000oooo0?l000020?l001@0oooo00<0
003o0?ooo`3oool03P3oool60000o`80oooo00<0o`000?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`0E0?ooo`00o`3oool;0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0D0?ooo`80o`00603oool00`000?l0oooo0?ooo`07
0?ooo`H0003o203oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0
oooo01D0oooo003o0?ooo`/0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool02`3oool010000?l0oooo0?ooo`3oool20000oaD0oooo0P3o0000
0`3oool0o`000?ooo`0G0?ooo`040000o`3oool0oooo0?ooo`H0003o3P3o
ool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01D0oooo003o
0?ooo`/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0000o`0E0?ooo`80o`000`3oool00`3o0000oooo0?ooo`0F
0?ooo`@0003o503oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0
oooo01D0oooo003o0?ooo`/0oooo00<0003o0?l0003o00001P3o00030?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0>0?ooo`80003o503oool20?l000H0oooo00<0o`000?oo
o`3oool04P3oool40000oaL0oooo00<0o`000?ooo`3oool04@3oool30?l0
00030000o`3oool0oooo01@0oooo003o0?ooo`/0oooo00<0003o0?ooo`3o
ool01P3oool40?l000/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0>0?ooo`<0003o4@3oool30?l000P0oooo00<0o`000?ooo`3o
ool03`3oool30000o`@0oooo00<0003o0?ooo`3oool0503oool00`3o0000
oooo0?ooo`0<0?ooo`D0o`000`3oool00`000?l0oooo0?ooo`0D0?ooo`00
o`3oool;0?ooo`030000o`3oool0oooo00T0oooo103o00070?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool03@3oool20000o`<0oooo
00<0003o0?ooo`3oool0303oool20?l000/0oooo00<0o`000?ooo`3oool0
303oool30000o`L0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo
0?ooo`020?ooo`X0o`00203oool00`000?l0oooo0?ooo`0D0?ooo`00o`3o
ool;0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00P3o
ool20?l000@0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0;0?ooo`80003o1@3oool00`000?l0oooo0?ooo`0:0?ooo`80o`003@3o
ool00`3o0000oooo0?ooo`080?ooo`@0003o2P3oool00`000?l0oooo0?oo
o`0C0?ooo`H0o`004P3oool00`000?l0oooo0?ooo`0D0?ooo`00o`3oool;
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool3
0?l000030?ooo`000?l0oooo00/0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo0P3o000@
0?ooo`030?l0003oool0oooo00<0oooo10000?l>0?ooo`030000o`3oool0
oooo00h0oooo1@3o00020?ooo`030?l0003oool0oooo01<0oooo00<0003o
0?ooo`3oool0503oool00?l0oooo2`3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?l0003oool02P3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?oo
o`3oool0103oool20?l00180oooo00<0o`000?ooo`3oool00`000?lC0?oo
o`030000o`3oool0oooo00/0oooo0P3o00070?ooo`030?l0003oool0oooo
01<0oooo00<0003o0?ooo`3oool0503oool00?l0oooo2`3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
00002@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0
oooo00@0003o0?ooo`3oool0oooo0P3o000D0?ooo`030?l000000?l0003o
01H0oooo00<0003o0?ooo`3oool01`3oool40?l000T0oooo00<0o`000?oo
o`3oool04`3oool00`000?l0oooo0?ooo`0D0?ooo`00o`3oool;0?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool010000?l0
oooo0?ooo`3oool20?l000H0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0;0?ooo`040000o`3oool0o`000?l001D0oooo0P000?l0
0`3o0000oooo0?ooo`0E0?ooo`040000o`3oool0oooo0?ooo`H0o`003P3o
ool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01<0oooo003o
0?ooo`/0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool04`3oool20000o`80oooo00<0o`000?ooo`3oool05@3oool4
0?l001@0oooo00<0o`000?ooo`3oool04@3oool30000oaD0oooo003o0?oo
o`/0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo0P3o00020?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool0303oool20?l000030000o`3oool0oooo
0140oooo0P000?l50?ooo`030?l0003oool0oooo0180oooo0P3o00000`3o
ool0003o0?ooo`0E0?ooo`030?l0003oool0oooo00`0oooo1@000?l20?oo
o`030000o`3oool0oooo01<0oooo003o0?ooo`/0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0
oooo0P3o000<0?ooo`030000o`3oool0oooo00/0oooo0P3o00030?ooo`03
0000o`3oool0oooo00d0oooo0`000?l70?ooo`030?l0003oool0oooo00h0
oooo103o00030?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3o
ool01P3oool60000o`L0oooo00<0003o0?ooo`3oool04`3oool00?l0oooo
2`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01`3oool30?l000X0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00/0oooo
0P000?l:0?ooo`030?l0003oool0oooo00T0oooo1@3o00070?ooo`030000
o`3oool0oooo01@0oooo00@0o`000?ooo`3oool0oooo1@000?l=0?ooo`03
0000o`3oool0oooo01<0oooo003o0?ooo`/0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo
00D0o`000?ooo`3oool0oooo0?l000080?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`80
003o3@3oool00`3o0000oooo0?ooo`060?ooo`80o`003@3oool00`000?l0
oooo0?ooo`0B0?ooo`D0003o4P3oool00`000?l0oooo0?ooo`0C0?ooo`00
o`3oool;0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo0080oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0:0?ooo`80o`00
2@3oool00`000?l0oooo0?ooo`050?ooo`80003o3`3oool00`3o0000oooo
0?ooo`030?ooo`<0o`003`3oool00`000?l0oooo0?ooo`0<0?ooo`H0003o
00<0oooo0?l0003oool0503oool00`000?l0oooo0?ooo`0C0?ooo`00o`3o
ool;0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool00`3oool20000oa80oooo00<0
o`000?ooo`3o00000P3o000B0?ooo`030000o`3oool0oooo00P0oooo1000
0?l80?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool04P3o
ool00?l0oooo2`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`040?l0003oool0oooo0000o``0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`020000oa<0oooo0`3o000F0?ooo`030000o`3o
ool0oooo00D0oooo0P000?l<0?ooo`030?l0003oool0oooo01<0oooo00<0
003o0?ooo`3oool04P3oool00?l0oooo2`3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`070?ooo`030?l000000?l0oooo00/0oooo00<0o`00
0?ooo`3oool03@3oool20000oa<0oooo0P3o00020?ooo`030?l0003oool0
oooo01@0oooo00@0003o0?ooo`3oool0oooo10000?l>0?ooo`030?l0003o
ool0oooo01<0oooo00<0003o0?ooo`3oool04P3oool00?l0oooo2`3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
o`0000T0oooo0P3o000>0?ooo`<0003o4@3oool30?l000@0oooo00<0o`00
0?ooo`3oool04P3oool60000oa<0oooo00<0o`000?ooo`3oool0403oool3
0?l001@0oooo003o0?ooo`/0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01`3oool01@000?l0oooo0?ooo`3oool0o`0000L0oooo00<0o`00
0?ooo`3oool0303oool20000o`<0oooo00<0003o0?ooo`3oool0303oool2
0?l000L0oooo00<0o`000?ooo`3oool03P3oool40000o`80oooo00<0003o
0?ooo`3oool0503oool00`3o0000oooo0?ooo`060?ooo`X0o`000P3oool0
0`000?l0oooo0?ooo`0B0?ooo`00o`3oool;0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`030?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0:0?ooo`80o`002P3oool00`3o
0000oooo0?ooo`0;0?ooo`80003o1`3oool00`000?l0oooo0?ooo`0C0?oo
o`040?l0003oool0oooo0?ooo`D0o`00303oool00`000?l0oooo0?ooo`0B
0?ooo`00o`3oool;0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01@3oool01@3o0000oooo0?ooo`3oool0
o`0000d0oooo0P000?l70?ooo`030000o`3oool0oooo00L0oooo0P3o000<
0?ooo`030?l0003oool0oooo00P0oooo0`000?l90?ooo`030000o`3oool0
oooo0180oooo1@3o000A0?ooo`030000o`3oool0oooo0180oooo003o0?oo
o`/0oooo1P000?l00`3oool0o`000?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0o`0000`0oooo0P000?l90?ooo`030000o`3oool0oooo
00D0oooo0P3o000>0?ooo`030?l0003oool0oooo00H0oooo0P000?l<0?oo
o`030000o`3oool0oooo0100oooo0P3o00020?ooo`030?l0003oool0oooo
0180oooo00<0003o0?ooo`3oool04@3oool00?l0oooo2`3oool00`000?l0
oooo0?ooo`030?ooo`040000o`3o0000003o0000o`@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?oo
o`030000o`3oool0oooo0080oooo0P3o000A0?ooo`040?l0003oool0oooo
0?ooo`@0003o3`3oool00`000?l0oooo0?ooo`0;0?ooo`@0o`00103oool0
0`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo0140oooo003o0?oo
o`/0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040000
o`L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0o`0000X0oooo00<0003o0?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`020?l00180oooo1@000?lC0?ooo`030000o`3oool0oooo
00H0oooo1@3o00080?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool04@3oool00?l0oooo2`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo0P000?l50?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool0203oool20?l00080oooo00<0o`000?ooo`3o
ool01P3oool20000o`l0oooo0P3o000B0?ooo`80003o00<0oooo0?l0003o
ool05@3oool010000?l0oooo0?ooo`3oool50?l000d0oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0A0?ooo`00o`3oool;0?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0000o`020000o`80oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0=0?ooo`80o`0000<0003o0?ooo`3o
ool03`3oool20000o`@0oooo00<0o`000?ooo`3oool04`3oool40?l00180
oooo00<0o`000?ooo`3oool0403oool30000oa<0oooo003o0?ooo`/0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?l0003oool01`3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0<0?ooo`80o`000`3oool00`000?l0oooo
0?ooo`0<0?ooo`80003o1P3oool00`3o0000oooo0?ooo`0@0?ooo`<0o`00
00<0oooo0000o`3oool04`3oool00`3o0000oooo0?ooo`0;0?ooo`D0003o
5P3oool00?l0oooo2`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000003o0?oo
o`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool0103o0000oooo0000o`000?l>0?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool02@3oool30000o`P0oooo00<0o`000?ooo`3oool0
303oool40?l000@0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo
0?ooo`060?ooo`D0003o6`3oool00:D0oooo1@00001P0?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`040?l0003oool0oooo0000o`@0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00`0oooo
0P3o00070?ooo`030000o`3oool0oooo00H0oooo0P000?l<0?ooo`030?l0
003oool0oooo00<0oooo100000040?l000P0oooo00<0003o0?ooo`3oool0
4`3oool00`3o0000oooo0?ooo`050000ob00oooo002W0?ooo`030000003o
ool0oooo0600oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00@0oooo00D0o`000?ooo`3oool0oooo
0000o`020?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0o`000?ooo`0;0?ooo`80o`002@3oool00`000?l0oooo
0?ooo`040?ooo`80003o3P3oool00`3o0000oooo0?ooo`050?ooo`80o`00
3@3oool00`000?l0oooo0?ooo`0@0?ooo`D0003o9@3oool00:L0oooo00<0
00000?ooo`3oool0H03oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`030?ooo`<0003o203oool00`3o0000oooo0?ooo`080?ooo`80003o0P3o
ool00`3o0000oooo0?ooo`070?ooo`80o`00303oool010000?l0oooo0?oo
o`3oool20000oa40oooo00@0o`000?ooo`3oool0oooo0`3o00000`000000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo1@000?lZ0?ooo`00
W`3oool4000000@0oooo00<000000?ooo`3oool0H03oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`030?ooo`040000o`3oool0003o0000o`H0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo0P3o000>0?ooo`040000o`3oool0003o0000
oa<0oooo00@0o`000?ooo`3o0000o`000`3oool00`000000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00H0oooo1@000?l_0?ooo`00Y`3oool00`00
0000oooo0?ooo`1P0?ooo`030000o`3oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo0000o`060?ooo`030?l0003oool0oooo00@0oooo00@0003o
0?ooo`3oool0003o1@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?oo
o`0>0?ooo`80003o503oool30?l000D0oooo00<000000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`050000oc@0oooo002V0?ooo`800000HP3oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00D0
003o0?ooo`3oool0oooo0?l000090?ooo`80003o203oool01@3o0000oooo
0?ooo`3oool0o`0000l0oooo0P000?l00`3oool0003o0?ooo`0?0?ooo`@0
o`000P3oool00`3o0000oooo0?ooo`020?ooo`8000003P3oool40000ocT0
oooo003o0?ooo`/0oooo00<0003o0?l0003o00000P3o00030?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0o`0000T0oooo00<0003o0?ooo`3oool0
2@3oool30?l000h0oooo0P000?l40?ooo`030000o`3oool0oooo00/0oooo
0P3o00060?ooo`030?l0003oool0oooo0100oooo0P000?lm0?ooo`00o`3o
ool;0?ooo`040000o`3oool0oooo0?ooo`@0o`0000<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0:0?ooo`80o`00
3@3oool20000o`H0oooo00<0003o0?ooo`3oool0203oool30?l000T0oooo
00<0o`000?ooo`3oool02`3oool40000ocl0oooo003o0?ooo`/0oooo00D0
003o0?ooo`3oool0oooo0?l000020?ooo`030000o`3o0000oooo00@0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0003o00L0oooo00<0003o0?ooo`3oool02@3oool20?l00080oooo
00<0o`000?ooo`3oool0203oool20000o`T0oooo00<0003o0?ooo`3oool0
1@3oool20?l000`0oooo00<0o`000?ooo`3oool01`3oool40000od<0oooo
003o0?ooo`/0oooo00@0003o0?ooo`3oool0o`000`3oool010000?l0oooo
0?l0003o00020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool01@3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo
00H0oooo0P000?l;0?ooo`030000o`3oool0oooo0080oooo0`3o000>0?oo
o`030?l0003oool0oooo00D0oooo0P000?m70?ooo`00o`3oool;0?ooo`04
0000o`3oool0oooo0?l00080oooo00<0003o0?ooo`3oool00P3oool20?l0
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?oo
o`050000o`3oool0oooo0?ooo`000?l02`3oool00`3o0000oooo0?ooo`04
0?ooo`030?l0003oool0oooo00<0oooo0P000?l>0?ooo`040000o`3oool0
o`000?l00180oooo00<0o`000?ooo`3oool010000?m90?ooo`00o`3oool;
0?ooo`80003o00D0oooo0?l0003oool0oooo0000o`050?ooo`80o`000`3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`000?l02P3oool20?l000L0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0>0?ooo`80o`004`3oool40000odd0oooo001`
0?ooo`h00000SP000?l0103o00000000000000000?l5000000030?l00000
000000000080o`0000<0003o0000000000001@0000000`3o000000000000
0007000000030000o`000000000000P0000000<0o`000000000000002000
0000103o000000000000o`000?l?00000080o`0000<000000000o`000000
400000020000od@000003@3oool007h0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00L0oooo00D0
00000?ooo`3oool0oooo0?l0000<0?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
0P3oool01@000000o`000000o`3oool0003o00D0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo0P000?l00`3oool0003o0?ooo`060?ooo`80o`002`3oool20000o`h0
oooo0`3o00030?ooo`030000o`3oool0oooo00d0oooo0P000?l70?ooo`03
0000003oool0oooo04T0oooo001n0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`070?ooo`050000
003oool0oooo0?ooo`3o0000303oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`050?ooo`H0o`0000@0oooo0000o`3o
ool0003o103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0o`00
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo0P3o000;0?ooo`80003o00<0oooo0?l0
003oool02`3oool20?l000H0oooo00<0003o0?ooo`3oool02`3oool20000
o`T0oooo00<000000?ooo`3oool0B@3oool007h0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0o`000?l000070?l000<0oooo00@000000?ooo`3o
ool0003o103oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo
0?ooo`80o`000P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00@0oooo00@0003o0?ooo`3oool0o`002`3oool20000o`@0oooo00<0
o`000?ooo`3oool01`3oool20?l000T0oooo00<0003o0?ooo`3oool01P3o
ool40000oeL0oooo001n0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203ooolG
0?l000P0oooo00D0o`000?ooo`3oool0oooo000000020000o`050?ooo`00
0?l0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`030?ooo`<0o`00
1`3oool20000o`L0oooo00<0003o0?ooo`3o00002`3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo0P3o000;0?ooo`030000
o`3oool0oooo0080oooo10000?mK0?ooo`00OP3oool00`000?l0oooo0?oo
o`020?ooof@0o`0000<0oooo0000o`3oool02@3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P00
0?l40?ooo`80o`00103oool00`000?l0oooo0?ooo`040?ooo`80o`001`3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?ooo`80o`003@3o
ool00`000?l0oooo0?ooo`020000oel0oooo001n0?ooo`D0o`002@3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`040?ooo`D0003o00<0oooo0000003oool00P3oool0
0`3o0000oooo0000o`030?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3o00001P3oool00`000?l0oooo0?ooo`070?ooo`80o`0000<0oooo
0000o`3oool0203oool00`000?l0oooo0?ooo`070?ooo`050?l0003oool0
oooo0?ooo`3o0000403oool20000of40oooo001n0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00L0oooo1`000?l30?ooo`050?l0003oool0oooo0000003oool00P3o
00020?ooo`040000o`3oool0oooo0000o`H0oooo00D0o`000?ooo`3oool0
oooo0?l000040?ooo`030000o`3oool0oooo00L0oooo00D0o`000?ooo`3o
ool0oooo0000o`070?ooo`80003o2`3oool30?l000l0oooo0P000?mS0?oo
o`00OP3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0000o`080000o`T0oooo00<0o`000?ooo`3o
ool00P3o00050?ooo`80003o1@3oool20?l000D0oooo0P3o00020000o`T0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80
003o3@3oool00`3o0000oooo0?ooo`0<0?ooo`<0003oI@3oool007h0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2P3oool0103o0000oooo0?ooo`3ooolE0000o`P0oooo00<0003o0?ooo`3o
ool01P3oool40?l000030000003oool0oooo00<0oooo0`000?l40?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool20?l000H0
oooo00<0003o0?ooo`3oool00P000?l=0?ooo`80o`0000<0oooo0?l0003o
ool02P3oool20000ofP0oooo001n0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00T0oooo;0000?l80?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool0203oool010000?l0oooo0?ooo`3oool40?l00080
oooo00<0o`000?ooo`0000000`3oool20000o`<0oooo00@0003o0?ooo`3o
ool0o`00203oool00`000?l0oooo0?l000070?ooo`030?l0003oool0oooo
00L0oooo0P000?l=0?ooo`80o`000`3oool00`3o0000oooo0?ooo`070?oo
o`80003oJP3oool007h0oooo=P000?l00`3oool0003o0?ooo`0<0?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0203oool010000?l0o`000?l0003o00060?ooo`030?l0003oool00000
00<0003o1@3oool00`000?l0oooo0?l000070?ooo`80003o0P3oool00`3o
0000oooo0?ooo`030?ooo`80o`00203oool20000o`030?ooo`000?l0oooo
00X0oooo0P3o00060?ooo`030?l0003oool0oooo00@0oooo0P000?m/0?oo
o`00OP3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?l000090?l000T0oooo0`000?l80?ooo`80
o`001`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080
o`002@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0
oooo0P3o00080?ooo`030?l0003oool0oooo0080oooo0P000?m^0?ooo`00
OP3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
0`3oool70?l000T0oooo00<0003o0?ooo`3oool01@3oool20000o`030?oo
o`3o0000000000L0oooo00<0o`000?ooo`000?l01@3oool20000o`L0oooo
0P3o000:0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
103oool20?l000/0oooo00@0o`000?ooo`000?l0003oL03oool007h0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
2@3oool0103o0000oooo0?ooo`3oool>0?l000H0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`020?ooo`<0003o0`3oool00`3o0000
00000?ooo`040?ooo`80o`000P3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3o0000203oool20000o`L0
oooo00@0003o0?ooo`3oool0oooo0P3o000=0?ooo`80003oLP3oool007h0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0;0?oooad0o`00203oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00P0oooo10000?l60?ooo`040?l000000000oooo0?oo
o`<0o`001@3oool010000?l0oooo0000o`000?l70?ooo`80o`000P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00@0003o
0?ooo`3o0000o`003@3oool20000og@0oooo001n0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool01@3oool`0?l000`0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool01@3oool40000o`T0oooo103o0008
0?ooo`80003o1`3oool20?l000D0oooo00<0o`000?ooo`3oool00P3oool2
0000o`/0oooo00<0o`000?ooo`3oool02`3oool20000ogH0oooo001n0?oo
oaH0o`001P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`090?ooo`030?l000000?l0003o00D0003o0`3oool00`00
0?l0oooo0?ooo`050?ooo`@0o`001`3oool30000o`030?ooo`000?l0oooo
00@0oooo0P3o00070?ooo`030?l0003oool0oooo0080003o2`3oool20?l0
00030000o`3oool0oooo00T0oooo0P000?mh0?ooo`00OP3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00T0oooo3@000?l:0?ooo`030000o`3oool0oooo0080
oooo0`3o00030?ooo`030000003o0000oooo00<0oooo0P000?l40?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0203oool20000o`/0
oooo0P3o00030?ooo`030000o`3oool0oooo00H0oooo0P000?mj0?ooo`00
OP3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`060?ooo`l0003o00<0oooo0000o`3oool02@3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0o`000080o`001P3oool010000000o`00
0?ooo`3oool20000o`L0oooo00@0003o0?ooo`3o0000o`002@3oool20000
o`030?l0003oool0oooo00P0oooo0P3o00060?ooo`030000o`3oool0oooo
00<0oooo0P000?ml0?ooo`00OP3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool01@3oool>0000o`<0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo103o00090?ooo`04
000000000?l0003o0000o`X0oooo00<0o`000?ooo`3oool01`3oool20000
o`<0oooo00<0o`000?ooo`3oool01@3oool20?l000P0oooo00@0003o0?oo
o`3oool0oooo0P000?mn0?ooo`00OP3oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool0103o
0000oooo0?ooo`3ooolO0000o`D0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3o00001P3o00030?ooo`030000o`3oool0oooo00D0oooo0`000?l0
0`3o0000oooo0?ooo`080?ooo`80o`0000<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo0P3o000;
0?ooo`<0003oP03oool007h0oooo00<0003o0?ooo`3oool00P3ooolY0000
o`X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`030?ooo`L0o`002P3oool00`000?l0oooo0?ooo`020?oo
o`<0003o0P3oool00`000000oooo0?l000070?ooo`80o`000`3oool00`00
0?l0oooo0?ooo`030?ooo`80003o1`3oool00`3o0000oooo0?ooo`020?l0
00d0oooo00<0003o0?ooo`3oool0P03oool007h0oooo1@000?l90?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00P0
oooo1`3o00060?ooo`030?l0003oool0oooo00T0oooo10000?l50?ooo`03
0000003oool0o`0000D0oooo0P3o00050?ooo`040000o`3oool0oooo0?oo
o`80003o2P3oool20?l000d0oooo0P000?n30?ooo`00OP3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`070?ooo`h0
o`0000<0oooo0000o`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`<0
003o203oool010000000oooo0?ooo`3o00020?ooo`80o`00203oool30000
o`X0oooo0P3o00000`3oool0o`000?ooo`0:0?ooo`80003oQ@3oool007h0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00D0oooo3`3o00030?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`030?ooo`@0003o0P3oool00`000?l0oooo0?ooo`060?ooo`03
0000003oool0oooo00<0o`002@3oool20000o`X0oooo0P3o00030?ooo`03
0?l0003oool0oooo00L0oooo0P000?n70?ooo`00OP3oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00<0oooo
3`3o00050?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0003o00<0003o
1P3oool00`000?l0oooo0?ooo`060?ooo`@0o`00203oool30000o`80oooo
00<0003o0?ooo`3oool01@3oool20?l000H0oooo00<0o`000?ooo`3oool0
0`3oool30000ohT0oooo001n0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?l0000O0?l000L0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool0103oool70000o`/0oooo00<0
003o0?ooo`3oool00P3oool30?l000050000003oool0oooo0?ooo`3o0000
1@3oool20000o`D0oooo00<0003o0?ooo`3oool00`3oool20?l000P0oooo
00@0o`000?ooo`3oool0oooo0P000?n<0?ooo`00OP3ooolN0?l000`0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`090?ooo`L0003o1P3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3o0000o`000080o`000`3oool01@000000oooo0?ooo`3oool0o`0000<0
oooo0P000?l80?ooo`030000o`3oool0oooo0080o`002`3oool30000ohh0
oooo001n0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00L0oooo3`000?l00`3oool0003o0?ooo`0:0?ooo`030?l0
003oool0oooo00D0oooo1@3o00070?ooo`030000003oool0oooo0080oooo
0`000?l:0?ooo`030000o`3o0000o`0000/0oooo0P000?nA0?ooo`00OP3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`070000o`<0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00D0o`00103oool00`000?l0oooo0?oo
o`050?ooo`03000000000?l0003o0080003o00<0o`000?ooo`3oool02@3o
ool20?l000030000o`3oool0oooo00P0oooo0P000?nC0?ooo`00OP3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000000o`000?l03@000?l:0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool0203oool40?l000X0oooo00<0003o
0?ooo`3oool00P3oool30000o`@0oooo00<0o`000?ooo`3oool01P3oool3
0?l00080oooo00<0003o0?ooo`3oool01P3oool20000oiD0oooo001n0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0:0?ooo`040?l0003oool0oooo0?oooaP0003o3@3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool00`3oool50?l000030?ooo`3o0000oooo00/0oooo1@000?l2
0?ooo`030000003oool0oooo0080oooo00<0o`000?ooo`3oool0103oool2
0?l000H0oooo00<0003o0?ooo`3oool00`3oool20000oiL0oooo001n0?oo
o`030000o`3oool0oooo00X0oooo8@000?l:0?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00P0oooo1`3o00060?ooo`030?l0003oool0oooo
00P0oooo0`000?l60?ooo`030000003oool0oooo00<0oooo00<0o`000?oo
o`3oool00`3o00080?ooo`030000o`3oool0oooo00<0003oV@3oool007h0
oooo3@000?l20?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`070?ooo`h0
o`0000<0oooo0000o`3oool02`3oool00`3o0000oooo0?ooo`030?ooo`@0
003o0P3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo0`3o000<0?ooo`80003oW03oool007h0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool01`3o00030?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000003o
0000o`030000o`L0oooo00<0003o0?ooo`3oool00`3oool00`000000oooo
0?ooo`030?l000030?ooo`3o0000oooo00X0oooo0P000?nN0?ooo`00OP3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00/0oooo403o000:0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool01@3oool50000o``0oooo00<0003o0?ooo`3oool00`3o
ool30?l000@0oooo00<0o`000?ooo`3oool01P3oool30000oj00oooo001n
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00P0oooo4@3o000<
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool0
10000?l0oooo0?ooo`3oool40000o`D0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?l000030?l000030000003oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool20000oj<0oooo001o0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0o`000?l0000F
0?l00080oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool5
0000o`T0oooo00<0o`000?ooo`3oool01`3oool40?l000@0oooo00<00000
0?ooo`3oool0103oool0103o0000oooo0?ooo`3oool30000ojD0oooo001o
0?ooo`030000o`3oool0oooo0080oooo603o000=0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool00P3oool7
0000o`030?ooo`000?l0oooo00/0oooo00<0o`000?ooo`3oool00`3oool4
0?l000<0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`05
0?ooo`<0003oZ03oool007l0oooo1@3o00090?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0?0000o`P0oooo00<0003o0?ooo`3oool02P3oool60?l0
00L0oooo00<0003o0?ooo`3oool00P3oool010000000oooo0?ooo`3oool4
0000oj/0oooo001o0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`050?oo
o`P0003o2P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00H0oooo1@3o000<0?ooo`030000o`3oool0oooo0080oooo00@000000000
o`000?l0003o[`3oool007l0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`030?ooo`l0003o1@3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo00@0003o0?oo
o`3oool0oooo103o00040?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`000?l00`000?nb0?ooo`00O`3oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool0103o
0000oooo0?ooo`3oool@0000o`L0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00T0oooo1@3o0008
0?ooo`030?l0003oool0oooo00T0oooo0`000?l30?ooo`030000003oool0
oooo0;00oooo001o0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool01@3ooolH0000o`X0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00@0o`000?oo
o`3oool0oooo203o00000`3oool0003o0?ooo`0;0?ooo`030?l0003oool0
oooo00@0oooo10000?l60?ooo`030000003oool0oooo0;00oooo001o0?oo
oaH0003o1P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00L0oooo1`3o00090?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`000?l010000?l:0?ooo`030000003oool0oooo
0;00oooo001o0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`060?ooo`l0
o`000`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00H0
oooo1P000?l?0?ooo`030000003oool0oooo0;00oooo001o0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
2P3oool90?l000D0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo10000?lE0?ooo`030000
003oool0oooo0;00oooo001o0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00T0oooo4@3o000<0?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool02@3oool60000oaT0oooo00<000000?ooo`3oool0/03o
ool007l0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00L0oooo403o00020?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo0080oooo1`000?lO0?ooo`030000003oool0
oooo0;00oooo001o0?ooo`030000o`3oool0oooo00X0oooo6@3o00040?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00L0oooo20000?lV0?oo
o`030000003oool0oooo0;00oooo001o0?ooo`d0o`0000<0oooo0?l0003o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00L0003o;P3oool00`000000oooo0?ooo`2`0?ooo`00
O`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00/0oooo40000?le0?ooo`030000003oool0oooo0;00oooo
001o0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool0103oool70000o`030?l0003oool0oooo0480oooo00<0
00000?ooo`3oool0/03oool007l0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00@0o`00
0?ooo`3oool0oooo4@000?m<0?ooo`030000003oool0oooo0;00oooo001o
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303ooolA
0000oed0oooo00<000000?ooo`3oool0/03oool007l0oooo00<0003o0?oo
o`3oool00P3ooolI0000ofd0oooo00<000000?ooo`3oool0/03oool007l0
oooo1@000?n60?ooo`030000003oool0oooo0;00oooo003o0?ooo`/0oooo
00<000000?ooo`3oool0/03oool00?l0oooo2`3oool00`000000oooo0?oo
o`2`0?ooo`00o`3oool;0?ooo`030000003oool0oooo0;00oooo003o0?oo
o`/0oooo00<000000?ooo`3oool0/03oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{445, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.77",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/schwarzchristoffel/\
SchwarzChristoffelFigures/mat1177.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The region with ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \(-\[ImaginaryI]\)\)}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(-\(\[Pi]\/2\)\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(\[Pi]\/2\)}]}]]],
  "."
}], "Text"],

Cell[TextData[{
  "Solution.  The exterior angles are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(-\(\[Pi]\/2\)\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(\[Pi]\/2\)}]}]]],
  ",  and the formula for the derivative ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " is  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z - \
\((\(-1\))\))\)\^\(\(-\((\(-\(\[Pi]\/2\)\))\)\)/\[Pi]\)\) \((z - \
1)\)\^\(\(-\((\[Pi]\/2)\)\)/\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(1\/2\)\) \((z - 1)\)\^\(-\(1\/2\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \((z + \
1)\)\^\(1\/2\)\/\((z - 1)\)\^\(1\/2\)\ \  = \ \ A \(\(\((z + 1)\)\^\(1\/2\)\) \
\((z + 1)\)\^\(1\/2\)\)\/\(\(\((z + 1)\)\^\(1\/2\)\) \((z - \
1)\)\^\(1\/2\)\)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \( z + 1\)\/\(\(\((z \
+ 1)\)\^\(1\/2\)\) \((z - 1)\)\^\(1\/2\)\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \((z\/\((z\^2 - 1)\)\
\^\(1\/2\) + 1\/\((z\^2 - 1)\)\^\(1\/2\))\)\)\)\)}]],
  " \nintegrate and get \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ A\ \((z\^2 - 1)\)\^\(1\/2\)\ \  + \ \ A\ Log \((z \
+ \((z\^2 - 1)\)\^\(1\/2\))\)\)]],
  "\n\t\t\t\nuse the conditions  ",
  Cell[BoxData[
      \(f \((\(-1\))\) = 0\)]],
  "  and  ",
  Cell[BoxData[
      \(f \((1)\) = \(-\[ImaginaryI]\)\)]],
  "  and solve the resulting system for ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["B",
    FontFamily->"Courier New"],
  ".  The desired result is\n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ \(1\/\[Pi]\) \((z\^2 - 1)\)\^\(1\/2\)\  + \ \(1\/\
\[Pi]\) Log \((z + \((z\^2 - 1)\)\^\(1\/2\))\)\  - \ \[ImaginaryI]\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the formula ",
  Cell[BoxData[
      \(\(f'\)[z]\)],
    AspectRatioFixed->True],
  " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f1, A, B, z, F];\)\ \), "\n", 
    \(\(f1[z_]\  = \ \ \ A\ z\/\((z\^2 - 1)\)\^\(1\/2\)\  + \ 
          A\ 1\/\((z\^2 - 1)\)\^\(1\/2\);\)\ \), "\n", 
    \(\(f[z_]\  = \ 
        B\  + \ \[Integral]A \((\ \ z\/\((z\^2 - 1)\)\^\(1\/2\) + 
                  1\/\((z\^2 - 1)\)\^\(1\/2\))\) \[DifferentialD]z;\)\ \), "\n\
", 
    \(\(Print["\<f'[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = B + \[Integral] \>", 
        f1[z], "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
We will use this form of the integral to continue the computations.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(F[z_]\  = \ 
        B + A\ \((\@\(\(-1\) + z\^2\) + 
                Log[z + \@\(\(-1\) + z\^2\)])\);\)\ \), "\n", 
    \(\(Print["\<F[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(eq1\  = \ F[\(-1\)]\  \[Equal] \ 0;\)\ \), "\n", 
    \(\(eq2\  = \ F[1]\ \  \[Equal] \(-\ \[ImaginaryI]\);\)\ \), "\n", 
    \(\(solset\  = \ Solve[{eq1, eq2}, {A, B}];\)\ \), "\n", 
    \(\(f[z_]\  = \ 
        ReplaceAll[F[z], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \), "\n", 
    \(\(Print[eq1];\)\ \), "\n", 
    \(\(Print[eq2];\)\ \), "\n", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_]\  = \ Expand[f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[
    \(\(\(\(f1[z_] = \(-\(\@\(\(-1\) + z\^2\)\/\[Pi]\)\) + 
          Log[z - \@\(\(-1\) + z\^2\)]\/\[Pi] - \[ImaginaryI];\)\ \
\[IndentingNewLine]
    \(f2[z_] = \@\(\(-1\) + z\^2\)\/\[Pi] + 
          Log[z + \@\(\(-1\) + z\^2\)]\/\[Pi] - \[ImaginaryI];\)\ \
\[IndentingNewLine]
    \(Needs["\<Graphics`Colors`\>"];\)\ \[IndentingNewLine]
    \(Needs["\<Graphics`ComplexMap`\>"];\)\ \[IndentingNewLine]
    \(graph1\  = \ 
        CartesianMap[
          f1, {\(-7.00001\), \(-0.00001\), 0.5}, {0.00001, 2.00001, 0.2}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\[IndentingNewLine]
    \(graph2\  = \ 
        CartesianMap[f2, {0.00001, 3.00001, 0.5}, {0.00001, 2.00001, 0.2}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\[IndentingNewLine]
    \(Show[graph1, graph2, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[\(-2\), 2, 1]}, 
        PlotRange \[Rule] {{\(-1.5\), 1.6}, {\(-1\), 0.6}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\[IndentingNewLine]
    \(Print["\<The image of the upper half plane Im[z] > 0 under the \
mapping\>"];\)\ \[IndentingNewLine]
    \(Print["\<w = f[z] = \>", f[z]];\)\)\(\ \)\)\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(w\ \  = \ \ \(f \((z)\)\ \  = \ \ \(2\/\[Pi]\) \((z\^2 - 1)\)\^\(1\/2\
\)\ \  + \ \(2\/\[Pi]\) Arcsin \((1\/z)\)\)\)]],
  "  maps the upper half-plane onto the domain indicated in Figure 11.78.   \n\
Hint: Set  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_3 = 1\)}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \(-\[ImaginaryI]\)\ d\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(w\_3\), "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["let",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "d"}], "\[Rule]", 
            "\[Infinity]"}]}]}]]]
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000770000[b000`400?l0
0000o`00003oo`3oooo80?ooo`00o`3oooo80?ooo`00o`3oooo80?ooo`00
o`3oooo80?ooo`00o`3oooo80?ooo`00o`3oooo80?ooo`00a`3oool00`00
0?l0oooo0?ooo`1;0?ooo`030?l000000?l0003o04h0oooo00<0003o0?oo
o`3oool0GP3oool00<L0oooo00<0003o0?ooo`3oool0B`3oool00`3o0000
003o0000o`1>0?ooo`030000o`3oool0oooo05h0oooo00370?ooo`030000
o`3oool0oooo04/0oooo00<0o`000000o`000?l0CP3oool00`000?l0oooo
0?ooo`1N0?ooo`00a`3oool00`000?l0oooo0?ooo`1;0?ooo`030?l00000
0?l0003o04h0oooo00<0003o0?ooo`3oool0GP3oool00<L0oooo00<0003o
0?ooo`3oool0B`3oool00`3o0000003o0000o`1>0?ooo`030000o`3oool0
oooo05h0oooo00370?ooo`030000o`3oool0oooo04/0oooo00<0o`000000
o`000?l0CP3oool00`000?l0oooo0?ooo`1N0?ooo`00a`3oool00`000?l0
oooo0?ooo`1;0?ooo`030?l000000?l0003o04h0oooo00<0003o0?ooo`3o
ool0GP3oool00<L0oooo00<0003o0?ooo`3oool0B`3oool00`3o0000003o
0000o`1>0?ooo`030000o`3oool0oooo05h0oooo00370?ooo`030000o`3o
ool0oooo04/0oooo00<0o`000000o`000?l0CP3oool00`000?l0oooo0?oo
o`1N0?ooo`00a`3oool00`000?l0oooo0?ooo`1;0?ooo`030?l000000?l0
003o04h0oooo00<0003o0?ooo`3oool0GP3oool00<L0oooo00<0003o0?oo
o`3oool0B`3oool00`3o0000003o0000o`1>0?ooo`030000o`3oool0oooo
05h0oooo00370?ooo`030000o`3oool0oooo04/0oooo00<0o`000000o`00
0?l0CP3oool00`000?l0oooo0?ooo`1N0?ooo`00a`3oool00`000?l0oooo
0?ooo`1;0?ooo`030?l000000?l0003o04h0oooo00<0003o0?ooo`3oool0
GP3oool00<L0oooo00<0003o0?ooo`3oool0A`3oool50?l000030000o`3o
0000o`0000D0o`00B03oool00`000?l0oooo0?ooo`1N0?ooo`00a`3oool0
0`000?l0oooo0?ooo`100?ooo`L0o`001@3oool20000o`H0oooo1P3o0012
0?ooo`030000o`3oool0oooo05h0oooo00370?ooo`030000o`3oool0oooo
03h0oooo0P3o000<0?ooo`80003o303oool30?l003l0oooo00<0003o0?oo
o`3oool0GP3oool00<L0oooo00<0003o0?ooo`3oool0>`3oool30?l000h0
oooo0P000?l?0?ooo`<0o`00?03oool00`000?l0oooo0?ooo`1N0?ooo`00
a`3oool00`000?l0oooo0?ooo`0h0?ooo`<0o`004@3oool20000oa80oooo
0P3o000j0?ooo`030000o`3oool0oooo05h0oooo00370?ooo`030000o`3o
ool0oooo03H0oooo0P3o000D0?ooo`80003o503oool20?l003P0oooo00<0
003o0?ooo`3oool0GP3oool00<L0oooo00<0003o0?ooo`3oool0=03oool2
0?l001H0oooo0P000?lF0?ooo`030?l0003oool0oooo03D0oooo00<0003o
0?ooo`3oool0GP3oool00<L0oooo00<0003o0?ooo`3oool0<P3oool20?l0
01P0oooo0P000?lG0?ooo`80o`00=@3oool00`000?l0oooo0?ooo`1N0?oo
o`00a`3oool00`000?l0oooo0?ooo`0a0?ooo`030?l0003oool0oooo01P0
oooo0P000?lI0?ooo`80o`00<`3oool00`000?l0oooo0?ooo`1N0?ooo`00
a`3oool00`000?l0oooo0?ooo`0`0?ooo`030?l0003oool0oooo01T0oooo
0P000?lK0?ooo`80o`00<@3oool00`000?l0oooo0?ooo`1N0?ooo`00a`3o
ool00`000?l0oooo0?ooo`0^0?ooo`80o`004`3oool5000000@0oooo0P00
0?lM0?ooo`80o`00;`3oool00`000?l0oooo0?ooo`1N0?ooo`00a`3oool0
0`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0oooo01D0oooo00<00000
0?ooo`3oool0103oool20000oal0oooo00<0o`000?ooo`3oool0;03oool0
0`000?l0oooo0?ooo`1N0?ooo`00a`3oool00`000?l0oooo0?ooo`0/0?oo
o`030?l0003oool0oooo01H0oooo00<000000?ooo`3oool0103oool20000
o`8000007P3oool00`3o0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo
05h0oooo00370?ooo`030000o`3oool0oooo02X0oooo0P3o000A0?ooo`@0
0000103oool00`000000oooo0?ooo`040?ooo`80003o8@3oool00`3o0000
oooo0?ooo`0Z0?ooo`030000o`3oool0oooo05h0oooo00370?ooo`030000
o`3oool0oooo02T0oooo00<0o`000?ooo`3oool06@3oool00`000000oooo
0?ooo`040?ooo`80003o8P3oool00`3o0000oooo0?ooo`0Y0?ooo`030000
o`3oool0oooo05h0oooo00370?ooo`030000o`3oool0oooo02P0oooo00<0
o`000?ooo`3oool06@3oool2000000H0oooo0P000?lS0?ooo`80o`00:@3o
ool00`000?l0oooo0?ooo`1N0?ooo`00a`3oool00`000?l0oooo0?ooo`0V
0?ooo`80o`00903oool20000obD0oooo00<0o`000?ooo`3oool09P3oool0
0`000?l0oooo0?ooo`1N0?ooo`00a`3oool00`000?l0oooo0?ooo`0U0?oo
o`030?l0003oool0oooo02@0oooo0P000?lV0?ooo`030?l0003oool0oooo
02D0oooo00<0003o0?ooo`3oool0GP3oool00<L0oooo00<0003o0?ooo`3o
ool0903oool00`3o0000oooo0?ooo`0U0?ooo`80003o9`3oool00`3o0000
oooo0?ooo`0T0?ooo`030000o`3oool0oooo05h0oooo00370?ooo`030000
o`3oool0oooo02<0oooo00<0o`000?ooo`3oool09P3oool20000obP0oooo
00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`1N0?ooo`00a`3o
ool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo02L0oooo0P00
0?lY0?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool0GP3o
ool00<L0oooo00<0003o0?ooo`3oool08P3oool00`3o0000oooo0?ooo`0W
0?ooo`80003o:P3oool00`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0
oooo05h0oooo00370?ooo`030000o`3oool0oooo0240oooo00<0o`000?oo
o`3oool0:03oool20000ob/0oooo00<0o`000?ooo`3oool0803oool00`00
0?l0oooo0?ooo`1N0?ooo`00a`3oool00`000?l0oooo0?ooo`0P0?ooo`03
0?l0003oool0oooo02T0oooo0P000?l/0?ooo`030?l0003oool0oooo01l0
oooo00<0003o0?ooo`3oool0GP3oool00<L0oooo00<0003o0?ooo`3oool0
7`3oool00`3o0000oooo0?ooo`0Z0?ooo`80003o;@3oool00`3o0000oooo
0?ooo`0N0?ooo`030000o`3oool0oooo05h0oooo00370?ooo`030000o`3o
ool0oooo01h0oooo00<0o`000?ooo`3oool0:`3oool20000obh0oooo00<0
o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`1N0?ooo`00a`3oool0
0`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo02`0oooo0P000?l^
0?ooo`030?l0003oool0oooo01d0oooo00<0003o0?ooo`3oool0GP3oool0
0<L0oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`0/0?oo
o`80003o;`3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo
05h0oooo00370?ooo`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3o
ool0;@3oool20000oc00oooo00<0o`000?ooo`3oool06`3oool00`000?l0
oooo0?ooo`1N0?ooo`00a`3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0
003oool0oooo02h0oooo0P000?la0?ooo`030?l0003oool0oooo01X0oooo
00<0003o0?ooo`3oool0GP3oool00<L0oooo00<0003o0?ooo`3oool06P3o
ool00`3o0000oooo0?ooo`0_0?ooo`80003o<@3oool00`3o0000oooo0?oo
o`0J0?ooo`030000o`3oool0oooo05h0oooo00370?ooo`030000o`3oool0
oooo01X0oooo00<0o`000?ooo`3oool0;`3oool20000oc80oooo00<0o`00
0?ooo`3oool06@3oool00`000?l0oooo0?ooo`1N0?ooo`00a`3oool00`00
0?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo0300oooo0P000?lc0?oo
o`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0GP3oool00<L0
oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0a0?ooo`80
003o<`3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo05h0
oooo00370?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0
<@3oool20000oc@0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo
0?ooo`1N0?ooo`00a`3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003o
ool0oooo0380oooo0P000?ld0?ooo`030?l0003oool0oooo01L0oooo00<0
003o0?ooo`3oool0GP3oool00<L0oooo00<0003o0?ooo`3oool05`3oool0
0`3o0000oooo0?ooo`0Z0?oooa@0003o:`3oool00`3o0000oooo0?ooo`0F
0?ooo`030000o`3oool0oooo05h0oooo00370?ooo`030000o`3oool0oooo
01H0oooo00<0o`000?ooo`3oool09P3oool50000o`P0oooo0P000?l:0?oo
o`<0003o:03oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo
05h0oooo00370?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3o
ool08`3oool40000o`d0oooo0P000?l=0?ooo`<0003o9P3oool00`3o0000
oooo0?ooo`0E0?ooo`030000o`3oool0oooo05h0oooo00370?ooo`030000
o`3oool0oooo01D0oooo00<0o`000?ooo`3oool0803oool30000oa40oooo
0P000?l@0?ooo`<0003o8`3oool00`3o0000oooo0?ooo`0E0?ooo`030000
o`3oool0oooo05h0oooo00370?ooo`030000o`3oool0oooo01@0oooo00<0
o`000?ooo`3oool07`3oool20000oa@0oooo0P000?lC0?ooo`<0003o8@3o
ool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo05h0oooo0037
0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool07P3oool2
0000oaH0oooo0P000?lF0?ooo`80003o7`3oool00`3o0000oooo0?ooo`0D
0?ooo`030000o`3oool0oooo05h0oooo00370?ooo`030000o`3oool0oooo
01<0oooo00<0o`000?ooo`3oool0703oool20000oaP0oooo0P000?lH0?oo
o`80003o7P3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo
05h0oooo00370?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3o
ool06`3oool20000oaX0oooo0P000?lJ0?ooo`80003o703oool00`3o0000
oooo0?ooo`0C0?ooo`030000o`3oool0oooo05h0oooo00370?ooo`030000
o`3oool0oooo0180oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo
0?ooo`0J0?ooo`80003o703oool00`000?l0oooo0?ooo`0J0?ooo`030?l0
003oool0oooo0180oooo00<0003o0?ooo`3oool0GP3oool00<L0oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0I0?ooo`80003o7@3o
ool20000oad0oooo0P000?lJ0?ooo`030?l0003oool0oooo0180oooo00<0
003o0?ooo`3oool0GP3oool00<L0oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0G0?ooo`80003o7`3oool20000oal0oooo0P000?lI
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0GP3oool0
0<L0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0G0?oo
o`030000o`3oool0oooo01l0oooo0P000?lQ0?ooo`030000o`3oool0oooo
01H0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`1N0?oo
o`00a`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01H0
oooo00<0003o0?ooo`3oool0803oool20000ob80oooo00<0003o0?ooo`3o
ool05P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo05h0
oooo00370?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
5P3oool00`000?l0oooo0?ooo`0Q0?ooo`80003o8`3oool00`000?l0oooo
0?ooo`0E0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
GP3oool00<L0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?oo
o`0D0?ooo`80003o903oool20000ob@0oooo00<0003o0?ooo`3oool05@3o
ool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo05h0oooo0037
0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`0T0?ooo`80003o9@3oool20000oaD0oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`1N0?ooo`00a`3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?oo
o`3oool09@3oool20000obL0oooo00<0003o0?ooo`3oool04`3oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo05h0oooo00370?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0V0?ooo`80003o:03oool00`000?l0oooo0?ooo`0B0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0GP3oool00<L0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0B0?ooo`030000
o`3oool0oooo02L0oooo0P000?lY0?ooo`030000o`3oool0oooo0180oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`1N0?ooo`00a`3o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool0:03oool20000obX0oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo05h0oooo0037
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0Y0?ooo`80003o:`3oool00`000?l0oooo0?ooo`0A
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0GP3oool0
0<L0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0@0?oo
o`030000o`3oool0oooo02@0oooo1P3o00000`000?l0o`000?l000050?l0
02H0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo05h0oooo00370?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0O0?ooo`H0
o`001P3oool20000o`H0oooo1`3o000P0?ooo`030000o`3oool0oooo0100
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1N0?ooo`00
a`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool06`3oool50?l000`0oooo0P000?l=0?ooo`80o`00
7`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0GP3oool00<L0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01X0oooo0P3o
000A0?ooo`80003o3`3oool30?l001d0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo05h0oooo0037
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0H0?ooo`<0o`004`3oool20000oa80oooo0`3o000K
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`1N0?ooo`00a`3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool05`3oool20?l0
01H0oooo0P000?lE0?ooo`80o`006P3oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0GP3oool00<L0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo01D0oooo0P3o000H0?ooo`80003o5`3oool30?l001P0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo05h0oooo00370?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0D0?ooo`80o`00
6P3oool20000oaX0oooo0P3o000G0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`1N0?ooo`00a`3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool04`3oool20?l001`0oooo0P000?lL0?ooo`<0o`005@3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool0GP3oool00<L0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo0180oooo0P3o000N
0?ooo`80003o7`3oool20?l001@0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo05h0oooo00370?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0A0?ooo`80o`00803oool20000ob40oooo0P3o000B0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`1N0?ooo`00a`3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0403oool00`3o0000
oooo0?ooo`0P0?ooo`80003o8`3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`1N0?ooo`00a`3oool00`000?l0o`000?l000050?l000<0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0?0?ooo`80o`00
8`3oool20000ob@0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`0:0?ooo`040?l0003oool0oooo0?ooo`L0o`0000<0003o0?ooo`3o
ool0GP3oool00<L0oooo00<0003o0?ooo`3oool01@3oool40?l000/0oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0S0?ooo`80003o
9@3oool20?l00100oooo00<0003o0?ooo`3oool02@3oool40?l000L0oooo
00<0003o0?ooo`3oool0GP3oool00<L0oooo00<0003o0?ooo`3oool01`3o
ool0103o0000oooo0?l0003o00080?ooo`030000o`3oool0oooo00l0oooo
00<0o`000?ooo`3oool0903oool20000obL0oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`060?ooo`80o`0000<0oooo0?l0003oool0
203oool00`000?l0oooo0?ooo`1N0?ooo`00a`3oool00`000?l0oooo0?oo
o`070?ooo`040?l0003oool0oooo0?ooo`80o`001P3oool00`000?l0oooo
0?ooo`0=0?ooo`80o`009`3oool20000obP0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`040?ooo`80o`000`3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo05h0oooo00370?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool00`3oool20?l000<0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0M0?oooa@0003o8@3o
ool20?l000h0oooo00@0003o0?ooo`3oool0oooo0P3o00050?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0GP3oool00<L0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`80o`0000<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0J0?ooo`@0003o2P3o
ool20000o`P0oooo1P000?lM0?ooo`030?l0003oool0oooo00/0oooo00@0
003o0?ooo`3o0000o`00203oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo05h0oooo00370?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0o`000?ooo`0=0?ooo`030?l0003o
ool0oooo01L0oooo10000?l>0?ooo`80003o3P3oool40000oaX0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0GP3oool00<L0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
o`0000/0oooo0P3o000G0?ooo`<0003o4P3oool20000oa80oooo0`000?lH
0?ooo`030?l0003oool0oooo00T0oooo00<0o`000?ooo`000?l02@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo05h0oooo00370?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool01000
0?l0oooo0?ooo`3oool20?l000P0oooo00<0o`000?ooo`3oool0503oool3
0000oaD0oooo0P000?lE0?ooo`@0003o5@3oool00`3o0000oooo0?ooo`06
0?ooo`80o`000P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool0GP3oool00<L0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool00`3o0000oooo0?ooo`0B0?oo
o`<0003o603oool20000oaT0oooo0`000?lC0?ooo`80o`001@3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`1N0?ooo`00N@3oool4000004X0
oooo00<0003o0000000000000`0000020?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool0103o0000oooo0?ooo`3oool20?l0
01<0oooo0P000?lK0?ooo`80003o703oool20000oa<0oooo00D0o`000?oo
o`3oool0oooo0?l000070?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool00`3oool2000000030000o`000000000004X0oooo1000000@
0?ooo`00N@3oool00`000000oooo0?ooo`1;0?ooo`040000o`3oool0oooo
000000@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0o`0001<0oooo0P000?lM0?ooo`80003o7P3oool2
0000oa80oooo00<0o`000?ooo`3o00002@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0A0?ooo`00NP3oool00`000000oooo0?ooo`1:0?oo
o`040000o`3oool0oooo000000<0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo0100oooo0P000?lO
0?ooo`80003o803oool20000oa40oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`00L`3oool40000
00@0oooo00<000000?ooo`3oool0A03oool4000000050?ooo`000?l0oooo
0?ooo`0000000`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3o00003`3oool20000ob40oooo0P000?lR
0?ooo`80003o3P3oool00`3o0000oooo0?l0000:0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`1<
0?ooo`030000003oool0oooo00l0oooo001i0?ooo`040000003oool0oooo
000004X0oooo00@0003o0?ooo`3oool000000`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00P0oooo00@0o`000?ooo`3oool0o`00
3@3oool20000ob<0oooo0P000?lT0?ooo`80003o303oool0103o0000oooo
0?ooo`3o000:0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`1:0?ooo`040000003oool0oooo0000
0100oooo001j0?ooo`800000B`3oool010000?l0oooo0000000000020?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`020?ooo`030?l0003oool0oooo00P0oooo0P000?lU0?oo
o`80003o9P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
0080oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo0080oooo00<000000000o`3oool0C03oool20000
0140oooo00370?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool20000obL0oooo0P000?lW0?ooo`80
003o1`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo05h0oooo00370?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool20000oad0oooo
303o00000`000?l0o`000?l0000;0?l001d0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo05h0oooo00370?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00P0oooo00@0o`000?ooo`000?l0003o6@3oool60?l000`0oooo
0P000?l<0?ooo`<0o`006`3oool01@000?l0oooo0?ooo`3oool0o`0000X0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0GP3oool00<L0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0F0?ooo`<0o`004P3oool20000o`l0oooo103o000H0?ooo`80003o
00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`1P0?ooo`00
a`3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o0000oooo01@0
oooo0`3o000E0?ooo`80003o4`3oool50?l001D0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00<0
oooo00D0o`000?ooo`3oool0oooo0000o`1P0?ooo`00a`3oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`090?ooo`80003o0P3oool00`3o0000oooo0?ooo`0?0?oo
o`<0o`00603oool20000oaP0oooo0P3o000B0?ooo`040?l0003oool0003o
0000o``0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`03
0?ooo`040?l0003oool0oooo0000of00oooo001^0?ooo`P00000DP000?l2
000000030?l000000000000000<0000000<0003o0000000000001@000000
0`3o0000000000000009000000030000o`000000000000<0000000<0o`00
0000000000002P0000040?l001/000000P000?lJ000000<0o`003P000000
0`3o0000000000000002000000030000o`000000000000X0000000<0o`00
0000000000001@0000000`000?l0000000000003000000030?l000000000
00000580003o200000070?ooo`00MP3oool00`000?l0oooo0000000E0?oo
o`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0;0?ooo`040000o`3oool0o`000?l000@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01`3oool30?l001l0oooo0P000?lM
0?ooo`80o`00303oool00`3o0000oooo0?ooo`030?ooo`80003o2`3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`000?l03@3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo01@0oooo00<0o`000?ooo`3oool04`3oool00`000000oooo0000o`0?
0?ooo`00MP3oool00`000?l0oooo0000000E0?ooo`030?l0003oool0oooo
01@0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0;0?oo
o`030000003o0000oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`080?ooo`80003o203oool00`3o0000oooo0?ooo`040?oo
o`80o`008P3oool20000oal0oooo0`3o00080?ooo`030?l0003oool0oooo
00H0oooo0P000?l:0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool00P3oool20?l000030000003oool0oooo00/0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo
01<0oooo00<000000?ooo`000?l03`3oool007H0oooo00<0003o0?ooo`00
00005@3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool02P3oool20?l000040?ooo`000?l0oooo0?oo
o`80003o1`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool00P3oool20?l002@0oooo0P000?lR0?oo
o`<0o`001@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0
003o00@0o`002`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo01@0oooo00<0o`000?ooo`3oool04`3oool00`000000oooo0000o`0?
0?ooo`00MP3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo
01@0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`040?oo
o`H0o`00103oool20000o`L0oooo0P3o00090?ooo`80003o2`3oool00`3o
0000oooo0?ooo`020?l002H0oooo0P000?lU0?ooo`<0o`0000<0oooo0?l0
003oool02`3oool20000o`T0oooo0P3o00060?ooo`030000o`3oool0003o
00D0oooo1P3o00050?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool0503oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo
00d0oooo001f0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3o
ool0503oool00`000?l0oooo0?ooo`060?oooa80o`002`3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0303oool20?l002P0oooo0P000?lX0?ooo`80o`003P3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00@0oooo0P000?l;0?oooa80
o`001`3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo01D0
oooo00<0003o0?ooo`3oool03@3oool007H0oooo>03o000;0?ooo`030?l0
003oool0oooo00d0oooo0`000?l50?ooo`030?l0003oool0oooo00L0oooo
0P000?l=0?ooo`<0o`00703ooolL0000oa`0oooo0`3o000=0?ooo`80003o
2@3oool00`3o0000oooo0?ooo`020?ooo`040000o`3oool0oooo0000o`l0
oooo00<0o`000?ooo`3oool02P3ooolg0?l000l0oooo001f0?ooo`030000
o`3oool0oooo01D0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo00/0oooo0P000?l30?ooo`050000
o`3oool0oooo0?ooo`3o00002@3oool00`000?l0oooo0?ooo`0;0?ooo`80
o`000`3oool00`3o0000oooo0?ooo`0E0?ooo`@0003o3@3oool20000o`d0
oooo10000?lG0?ooo`040?l0003oool0oooo0?ooo`80o`003@3oool00`00
0?l0oooo0?ooo`070?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool2
0000o``0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0D
0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool03@3oool0
07H0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0D0?oo
o`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0103oool60000
o`H0oooo00<0003o0?l0003o0000203oool20000o``0oooo0P3o00050?oo
o`030?l0003oool0oooo0100oooo1@000?lA0?ooo`80003o4@3oool60000
oa40oooo00<0o`000?ooo`3oool00`3oool20?l000`0oooo0P000?l80?oo
o`80o`0000<0003o0?ooo`3oool0103oool50000o`L0oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo
01D0oooo00<0003o0?ooo`3oool03@3oool007H0oooo00<0003o0?ooo`3o
ool05@3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0180
oooo00<0o`000?ooo`000?l010000?l<0?ooo`030?l0003oool0oooo00H0
oooo0P000?l<0?ooo`80o`00203oool00`3o0000oooo0?ooo`0:0?ooo`D0
003o5P3oool20000oaL0oooo10000?l<0?ooo`030?l0003oool0oooo00H0
oooo0P3o000<0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?l0003o
00002P3oool60000o`030?ooo`3o0000oooo01<0oooo00<0003o0?ooo`3o
ool0503oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00d0
oooo001f0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool0
503oool00`000?l0oooo0?ooo`060?ooo`h0003o3`3oool20?l000030?oo
o`000?l0oooo00D0oooo00<0003o0?ooo`3oool02P3oool20?l000X0oooo
00<0o`000?ooo`3oool01P3oool40000oa/0oooo0P000?lK0?ooo`@0003o
203oool00`3o0000oooo0?ooo`080?ooo`80o`002`3oool20000o`H0oooo
00<0003o0?ooo`3oool00P3o000>0?ooo`X0003o303oool00`000?l0oooo
0?ooo`0D0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0
3@3oool007H0oooo00<0003o0?ooo`3oool05@3oool0103o0000oooo0?oo
o`3ooolL0000o``0oooo00<0o`000?ooo`3oool02`3oool30?l000<0oooo
00<0003o0?ooo`3oool00P3oool20000o``0oooo00<0o`000?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`030?ooo`80003o7`3oool20000oal0oooo
0`000?l40?ooo`030?l0003oool0oooo00/0oooo00<0o`000?ooo`3oool0
2P3oool20000o`<0oooo00<0003o0?ooo`3oool00`3oool20?l000d0oooo
00<0o`000?ooo`3oool01P3ooolK0000o`P0oooo00<0o`000?ooo`3oool0
5@3oool00`000?l0oooo0?ooo`0=0?ooo`00MP3ooolL0000oa<0oooo00<0
003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`060?ooo`D0o`001`3o
ool010000?l0oooo0000o`000?l<0?ooo`80o`003P3oool00`3o0000oooo
0?ooo`030000ob40oooo0P000?lR0?ooo`<0003o00<0oooo0?l0003oool0
3@3oool20?l000`0oooo0P000?l00`3oool0003o0?ooo`060?ooo`D0o`00
203oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00`0oooo
8@000?l?0?ooo`00MP3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003o
ool0oooo01@0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?oo
o`040?ooo`80o`00303oool20000o``0oooo0P3o000@0?ooo`<0003o903o
ool20000obD0oooo0`000?l?0?ooo`80o`00303oool30000o`/0oooo0P3o
00060?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0503o
ool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00d0oooo001f
0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool0503oool0
0`000?l0oooo0?ooo`0@0?ooo`T0o`00303oool20000o`030?ooo`000?l0
oooo00T0oooo0P3o000@0?ooo`80003o00<0o`000?ooo`3oool0903oool2
0000obD0oooo00<0o`000?ooo`3oool00P000?l?0?ooo`80o`002P3oool0
0`000?l0oooo0?ooo`020000o`/0oooo2@3o000B0?ooo`030000o`3oool0
oooo01@0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0>
0?ooo`00M`3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo
01@0oooo00<0003o0?ooo`3oool02`3oool50?l00080oooo00<0o`000?oo
o`3oool03@3oool30000o`<0oooo00<0003o0?ooo`3oool01P3oool20?l0
00l0oooo0`000?l30?ooo`030?l0003oool0oooo0200oooo0`3o00000`00
0?l0o`000?l000020?l00280oooo00<0o`000?ooo`3oool00P3oool30000
o`h0oooo0P3o00070?ooo`030000o`3oool0oooo00<0oooo0`000?l=0?oo
o`040?l0003oool0oooo0?ooo`D0o`003@3oool00`000?l0oooo0?ooo`0D
0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool03P3oool0
07L0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0B0?oo
oa00o`00203oool00`3o0000oooo0?ooo`090?ooo`<0003o1`3oool00`00
0?l0oooo0?ooo`020?ooo`<0o`003P3oool30000o`H0oooo00<0o`000?oo
o`3oool04`3oool=0?l000<0oooo0P000?l30?ooo`d0o`005@3oool00`3o
0000oooo0?ooo`050?ooo`<0003o3@3oool30?l000@0oooo00<0003o0?oo
o`3oool01P3oool20000o`/0oooo00<0o`000?ooo`3oool01P3oool@0?l0
01@0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0>0?oo
o`00M`3oool00`000?l0oooo0?ooo`060?ooob<0o`000P3oool00`000?l0
oooo0?ooo`0C0?ooo`030?l0003oool0oooo00D0oooo10000?l:0?ooo`03
0000o`3oool0oooo0080o`003`3oool20000o`T0oooo00<0o`000?ooo`3o
ool03`3oool40?l00100oooo0P000?l@0?ooo`D0o`00403oool00`3o0000
oooo0?ooo`080?ooo`80003o3P3oool30?l000030000o`3oool0oooo00T0
oooo10000?l70?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3o
ool08`3o00080?ooo`030000o`3oool0oooo00h0oooo001g0?ooo`T0o`00
3P3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo01<0oooo
00<0o`000?ooo`3oool01@000?l>0?ooo`<0o`003`3oool20000o``0oooo
00<0o`000?ooo`3oool02P3oool40?l001@0oooo0P000?lE0?ooo`@0o`00
2`3oool00`3o0000oooo0?ooo`0;0?ooo`80003o3`3oool30?l000d0oooo
1@000?l20?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0
503oool00`3o0000oooo0?ooo`0<0?ooo`T0o`00403oool007L0oooo00<0
003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3o
ool0oooo0140oooo1@000?l@0?ooo`<0o`0000<0oooo0000o`3oool0303o
ool30000o`h0oooo00<0o`000?ooo`3oool01@3oool50?l001P0oooo0P00
0?lI0?ooo`@0o`001`3oool00`3o0000oooo0?ooo`0=0?ooo`80003o3@3o
ool00`000?l0oooo0?ooo`020?l00100oooo1@000?lC0?ooo`030000o`3o
ool0oooo01@0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?oo
o`0>0?ooo`00M`3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0
oooo01@0oooo00<0003o0?ooo`3oool0303oool50000o`80oooo00<0o`00
0?ooo`3oool03@3oool30?l000D0oooo00<0003o0?ooo`3oool0203oool2
0000oa40oooo00@0o`000?ooo`3oool0oooo103o000M0?ooo`80003o7@3o
ool40?l000<0oooo00<0o`000?ooo`3oool03`3oool20000o`X0oooo00<0
003o0?ooo`3oool00`3oool30?l000l0oooo00<0o`000?ooo`3oool01@00
0?l>0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0503o
ool00`000?l0oooo0?ooo`0>0?ooo`00M`3oool00`000?l0oooo0?ooo`0D
0?ooo`030?l0003oool0oooo01@0oooo00@0003o0?ooo`3oool0oooo2`00
0?l70?ooo`030?l0003oool0oooo00/0oooo0P3o00080?ooo`030000o`3o
ool0oooo00H0oooo0P000?lC0?ooo`@0o`008@3oool20000ob40oooo103o
000C0?ooo`80003o203oool00`000?l0oooo0?ooo`060?ooo`<0o`002`3o
ool00`3o0000oooo0?ooo`060?ooo`/0003o0`3oool00`000?l0oooo0?oo
o`0D0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool03P3o
ool007L0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`07
0?oooa40003o4`3oool00`3o0000oooo0?ooo`060?ooo`@0o`002P3oool0
0`000?l0oooo0?ooo`030?ooo`<0003o4@3oool40?l000030?ooo`3o0000
oooo0280oooo0P000?lS0?ooo`030?l0003oool0o`0000<0o`004@3oool3
0000o`@0oooo00<0003o0?ooo`3oool02P3oool40?l000L0oooo00<0o`00
0?ooo`3oool04@3ooolA0000o`T0oooo00<0o`000?ooo`3oool0503oool0
0`000?l0oooo0?ooo`0>0?ooo`00M`3ooolQ0000o`d0oooo00<0003o0?oo
o`3oool0503oool00`3o0000oooo0?ooo`060?l000l0oooo00<0003o0?oo
o`000?l00P000?l@0?ooo`@0o`001@3oool00`3o0000oooo0?ooo`0Q0?oo
o`80003o8`3oool00`3o0000oooo0?ooo`030?ooo`@0o`00403oool50000
oa00oooo1@3o00020?ooo`030?l0003oool0oooo01@0oooo00<0003o0?oo
o`3oool02`3ooolQ0000oa00oooo001g0?ooo`030000o`3oool0oooo01@0
oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0B0?ooo`D0
o`00503oool30000oa40oooo0P3o000:0?ooo`030?l0003oool0oooo0200
oooo0P000?lR0?ooo`030?l0003oool0oooo00P0oooo0P3o000B0?ooo`<0
003o4`3oool50?l001<0oooo00<0003o0?ooo`3oool05@3oool00`3o0000
oooo0?ooo`0D0?ooo`030000o`3oool0oooo00h0oooo001g0?ooo`030000
o`3oool0oooo01@0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo
0?ooo`0<0?ooo`D0o`000P3oool00`3o0000oooo0?ooo`0A0?ooo`<0003o
00<0oooo0000o`3oool03`3oool20?l000`0oooo00<0o`000?ooo`3oool0
4P3ooolO0000oa<0oooo00<0o`000?ooo`3oool02P3oool20?l00100oooo
00<0003o0?ooo`3oool00P000?lC0?ooo`030?l0003oool0oooo00H0o`00
3@3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo01@0oooo
00<0003o0?ooo`3oool03P3oool007L0oooo00<0003o0?ooo`3oool0503o
ool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00H0oooo1P3o
00070?ooo`030?l0003oool0oooo00d0oooo10000?l40?ooo`030000o`3o
ool0oooo00/0oooo0`3o000>0?ooo`030?l0003oool0oooo00/0oooo1`00
0?l>0?ooo`80003o3`3oool60000o`d0oooo00<0o`000?ooo`3oool0303o
ool30?l000d0oooo00<0003o0?ooo`3oool00P3oool40000o`l0oooo00<0
o`000?ooo`3oool01P3oool50?l000P0oooo00<0003o0?ooo`3oool05@3o
ool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo00h0oooo001g
0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool04`3oool;
0?l000d0oooo00<0o`000?ooo`3oool0203oool50000o`T0oooo00<0003o
0?ooo`3oool01P3oool40?l00180oooo00<0o`000?ooo`3oool0103oool6
0000oaD0oooo0P000?lE0?ooo`H0003o1P3oool00`3o0000oooo0?ooo`0@
0?ooo`@0o`00203oool00`000?l0oooo0?ooo`070?ooo`D0003o2P3oool0
0`3o0000oooo0?ooo`0;0?ooo``0o`00503oool00`3o0000oooo0?ooo`0D
0?ooo`030000o`3oool0oooo00h0oooo001g0?ooo`030000o`3oool0oooo
0180oooo603o00020?ooo`030000o`3oool0oooo01<0oooo00<0o`000?oo
o`3oool01P3oool20000o`h0oooo00<0003o0?ooo`3oool00`3oool30?l0
01H0oooo00<0o`000?ooo`3oool010000?lK0?ooo`80003o6`3oool40000
o`80oooo00<0o`000?ooo`3oool0503oool30?l000D0oooo00<0003o0?oo
o`3oool0303oool30000o`H0oooo00<0o`000?ooo`3oool0503oool01000
0?l0oooo0?ooo`3ooolF0?l001D0oooo00<0003o0?ooo`3oool03P3oool0
07L0oooo5@3o00030?ooo`030?l0003oool0oooo01@0oooo00<0003o0?oo
o`3oool0503oool0103o0000oooo0?ooo`3oool40000oa00oooo00<0003o
0?ooo`3oool00`3o000H0?ooo`@0003o7`3oool20000oal0oooo10000?lH
0?ooo`@0o`0000<0003o0?ooo`3oool0403oool40000o`80oooo00<0o`00
0?ooo`3oool0503oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0
oooo01H0o`00403oool007L0oooo00<0003o0?ooo`3oool05@3oool00`3o
0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0180oooo1P000?lC0?oo
o`@0o`005`3oool40000o`030?ooo`3o0000oooo0200oooo0P000?lQ0?oo
o`030?l0003oool0003o00<0003o603oool30?l001@0oooo1@000?lD0?oo
o`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool05@3oool00`00
0?l0oooo0?ooo`0>0?ooo`00M`3oool00`000?l0oooo0?ooo`0E0?ooo`03
0?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool01`3oool;0000o`80
oooo00<0o`000?ooo`3oool03`3oool50?l00080oooo00<0003o0?ooo`3o
ool0403oool60000o`D0oooo00<0o`000?ooo`3oool07`3oool20000ob40
oooo00<0o`000?ooo`3oool00`3oool60000oa80oooo00<0003o0?ooo`3o
ool00`3o000C0?ooo`030?l0003oool0oooo00/0003o2@3oool00`000?l0
oooo0?ooo`0D0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3o
ool03P3oool007L0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo
0?ooo`0D0?ooo`040000o`3oool0oooo0?ooo`H0003o3@3oool00`3o0000
oooo0?ooo`0<0?ooo`<0o`00203oool00`000?l0oooo0?ooo`0:0?ooo`D0
003o2`3oool00`3o0000oooo0?ooo`0O0?ooo`80003o8@3oool00`3o0000
oooo0?ooo`090?ooo`D0003o303oool00`000?l0oooo0?ooo`040?ooo`@0
o`003`3oool00`3o0000oooo0?ooo`0;0?ooo`H0003o0`3oool00`000?l0
oooo0?ooo`0D0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3o
ool03P3oool007L0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo
0?ooo`070?oooa40003o503oool00`3o0000oooo0?ooo`070?ooo`@0o`00
2`3oool00`000?l0oooo0?ooo`060?ooo`@0003o4@3oool00`3o0000oooo
0?ooo`0A0?ooo`d0o`0000<0003o0?l0003o00002@3o000F0?ooo`030?l0
003oool0oooo00l0oooo10000?l80?ooo`030000o`3oool0oooo00P0oooo
1P3o00080?ooo`030?l0003oool0oooo0180oooo4P000?l80?ooo`030?l0
003oool0oooo01D0oooo00<0003o0?ooo`3oool03P3oool007L0oooo00<0
003o0?ooo`3oool03@3ooolB0000o`d0oooo00<0003o0?ooo`3oool05@3o
ool0103o0000oooo0?ooo`3oool60?l000l0oooo00<0003o0?ooo`3oool0
0`3oool30000oaD0oooo00<0o`000?ooo`3oool02`3oool60?l000d0oooo
0P000?l:0?ooo`X0o`00303oool00`3o0000oooo0?ooo`0C0?ooo`<0003o
1@3oool00`000?l0oooo0?ooo`0>0?ooo`H0o`000P3oool00`3o0000oooo
0?ooo`0E0?ooo`030000o`3oool0oooo00`0oooo4@000?l?0?ooo`030000
o`3oool0oooo00h0oooo001g0?oooa00003o203oool00`3o0000oooo0?oo
o`0D0?ooo`030000o`3oool0oooo01<0oooo1P3o000E0?ooo`030000o`3o
ool0oooo00<0003o603oool00`3o0000oooo0?ooo`030?ooo`P0o`004`3o
ool20000oa@0oooo203o00040?ooo`030?l0003oool0oooo01H0oooo1000
0?l00`3oool0003o0?ooo`0E0?ooo`D0o`005@3oool00`000?l0oooo0?oo
o`0D0?ooo`030?l0003oool0oooo00H0oooo40000?l@0?ooo`00M`3oool0
0`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo01D0oooo00<0003o
0?ooo`3oool0303oool60?l00080oooo00<0o`000?ooo`3oool0503oool5
0000oa/0oooo1P3o000K0?ooo`80003o703oool60?l001/0oooo10000?lF
0?ooo`030?l0003oool0oooo00H0o`003`3oool00`000?l0oooo0?ooo`0D
0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool03P3oool0
07L0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0E0?oo
o`030000o`3oool0oooo00L0oooo1@3o00080?ooo`030?l0003oool0oooo
00l0oooo1@000?l30?ooo`030000o`3oool0oooo01H0oooo103o00000`3o
ool0o`000?ooo`0N0?ooo`80003o7`3oool00`3o0000oooo0?ooo`040?l0
01L0oooo00@0003o0?ooo`3oool0oooo1@000?lA0?ooo`030?l0003oool0
oooo00H0oooo1P3o00090?ooo`030000o`3oool0oooo01@0oooo00<0o`00
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0>0?ooo`00M`3oool00`00
0?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo01<0oooo303o000=0?oo
o`030?l0003oool0oooo00`0oooo0`000?l80?ooo`030000o`3oool0oooo
0100oooo1P3o00050?ooo`030?l0003oool0oooo01d0oooo0P000?lO0?oo
o`030?l0003oool0oooo00@0oooo1@3o000B0?ooo`030000o`3oool0oooo
00H0oooo10000?l=0?ooo`030?l0003oool0oooo00`0oooo303o000D0?oo
o`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool03P3oool007L0
oooo00<0003o0?ooo`3oool05@3oool0103o0000oooo0?ooo`3ooolB0?l0
0080oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`080?oo
o`@0003o2`3oool00`000?l0oooo0?ooo`0;0?ooo`D0o`002`3oool00`3o
0000oooo0?ooo`0M0?ooo`80003o7`3oool00`3o0000oooo0?ooo`090?oo
o`H0o`00303oool00`000?l0oooo0?ooo`0:0?ooo`@0003o2@3oool00`3o
0000oooo0?ooo`0D0?ooo`040000o`3oool0oooo0?oooa40o`000`3oool0
0`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00h0oooo001g0?oo
o`040000o`3oool0oooo0?oooaP0o`00503oool00`000?l0oooo0?ooo`0E
0?ooo`040?l0003oool0oooo0?ooo`H0003o403oool00`000?l0oooo0?oo
o`060?ooo`@0o`00403oool00`3o0000oooo0?ooo`0M0?ooo`80003o7`3o
ool00`3o0000oooo0?ooo`0?0?ooo`@0o`001`3oool00`000?l0oooo0?oo
o`0?0?ooo`H0003o0P3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3o
ool0oooo0180oooo603o00030?ooo`030000o`3oool0oooo00h0oooo001g
0?ooo`@0o`00503oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0
oooo01<0oooo1P000?lF0?ooo`040000o`3oool0oooo0?ooo`D0o`00503o
ool00`3o0000oooo0?ooo`0@0?oooa`0003o4P3oool00`3o0000oooo0?oo
o`0C0?ooo`D0o`000P3oool00`000?l0oooo0?ooo`0E0?ooo`D0003o5@3o
ool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo0180oooo103o
000@0?ooo`00M`3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0
oooo01D0oooo00<0003o0?ooo`3oool03@3oool60000o`80oooo00<0o`00
0?ooo`3oool05@3oool60?l001T0oooo00<0o`000?ooo`3oool02P3oool6
0000o`h0oooo00<000000?ooo`3oool02`3oool60000o``0oooo00<0o`00
0?ooo`3oool0603oool50?l001L0oooo00<0o`000?ooo`3oool01P000?l?
0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool05@3oool0
0`000?l0oooo0?ooo`0>0?ooo`00M`3oool00`000?l0oooo0?ooo`0E0?oo
o`030?l0003oool0oooo01D0oooo00@0003o0?ooo`3oool0oooo30000?l8
0?ooo`030?l0003oool0oooo0100oooo1@3o00020?ooo`030000o`3oool0
oooo01/0oooo00<0o`000?ooo`3oool00P3oool70000oa@0oooo00<00000
0?ooo`3oool04@3oool80000o`<0oooo00<0o`000?ooo`3oool06`3oool0
0`000?l0oooo0?ooo`030?l001@0oooo00<0o`000?ooo`3oool01P3oool<
0000o`<0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0E
0?ooo`030000o`3oool0oooo00h0oooo001g0?ooo`030000o`3oool0oooo
01D0oooo00<0o`000?ooo`3oool03@3oool<0000oa@0oooo00<0o`000?oo
o`3oool0303oool40?l000L0oooo00<0003o0?ooo`3oool0603oool80000
oa/0oooo00<000000?ooo`3oool06@3oool70000oaX0oooo00<0003o0?oo
o`3oool00`3oool40?l000l0oooo00<0o`000?ooo`3oool04`3oool<0000
o`l0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0>0?oo
o`00M`3oool00`000?l0oooo0?ooo`0C0?oooa80003o203oool00`000?l0
oooo0?ooo`0F0?ooo`030?l0003oool0oooo00L0oooo103o000<0?ooo`03
0000o`3oool0oooo00l0oooo20000?lS0?ooo`030000003oool0oooo0200
oooo20000?lA0?ooo`030000o`3oool0oooo00P0oooo1`3o00080?ooo`03
0?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool01P3ooolB0000oaD0
oooo00<0003o0?ooo`3oool03P3oool007L0oooo5P000?l20?ooo`030?l0
003oool0oooo01D0oooo00<0003o0?ooo`3oool05P3oool0103o0000oooo
0?ooo`3oool60?l00100oooo00<0003o0?ooo`3oool0203oool70000ob/0
oooo00<000000?ooo`3oool0:03oool70000o`X0oooo00<0003o0?ooo`3o
ool03`3oool60?l00080oooo00<0o`000?ooo`3oool05P3oool00`000?l0
oooo0?ooo`0E0?ooo`030?l0003oool0oooo01H0003o403oool007L0oooo
00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0E0?ooo`030000
o`3oool0oooo01@0oooo1P3o000F0?ooo`040000o`3oool0oooo0?ooo`L0
003o<P3oool00`000000oooo0?ooo`0_0?ooo`H0003o103oool00`000?l0
oooo0?ooo`0E0?ooo`H0o`00503oool00`000?l0oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool03P3oool007L0oooo
00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0F0?ooo`030000
o`3oool0oooo00L0oooo303o00020?ooo`030?l0003oool0oooo01H0oooo
1@000?li0?ooo`030000003oool0oooo03D0oooo0`000?l00`3oool0003o
0?ooo`0H0?ooo`040?l0003oool0oooo0?ooo``0o`00203oool00`000?l0
oooo0?ooo`0F0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3o
ool03P3oool007L0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo
0?ooo`0F0?ooo`040000o`3oool0oooo0?ooo`H0o`003P3oool00`3o0000
oooo0?ooo`0C0?ooo`<0003o?P3oool00`000000oooo0?ooo`0h0?ooo`D0
003o5P3oool00`3o0000oooo0?ooo`0=0?ooo`H0o`000P3oool00`000?l0
oooo0?ooo`0E0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3o
ool03P3oool007L0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo
0?ooo`0=0?ooo``0o`00503oool00`3o0000oooo0?ooo`0>0?ooo`D0003o
@@3oool00`000000oooo0?ooo`0m0?ooo`H0003o403oool00`3o0000oooo
0?ooo`0C0?ooo``0o`003P3oool00`3o0000oooo0?ooo`0F0?ooo`030000
o`3oool0oooo00h0oooo001g0?ooo`030000o`3oool0oooo01@0oooo4P3o
00080?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool0203o
ool60000odH0oooo00<000000?ooo`3oool0@`3oool70000o`T0oooo00<0
o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`070?oooa40o`005P3o
ool00`000?l0oooo0?ooo`0>0?ooo`00M`3ooolG0?l00080oooo00<0o`00
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0F0?ooo`040?l0003oool0
oooo0?ooo`H0003oC03oool00`000000oooo0?ooo`1:0?ooo`H0003o0P3o
ool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01D0oooo00<0
o`000?ooo`3oool05`3o000@0?ooo`00M`3oool00`000?l0oooo0?ooo`0F
0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool03P3oool<
0000oe80oooo00<000000?ooo`3oool0D03oool<0000o`l0oooo00<0003o
0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0
oooo00h0oooo001g0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?oo
o`3oool05@3oool00`000?l0oooo0?ooo`070?ooo`L0003oGP3oool00`00
0000oooo0?ooo`1L0?ooo`H0003o2@3oool00`000?l0oooo0?ooo`0E0?oo
o`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool03P3oool007P0
oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0C0?ooo``0
003oI@3oool00`000000oooo0?ooo`1R0?ooo``0003o5@3oool00`3o0000
oooo0?ooo`0E0?ooo`030000o`3oool0oooo00l0oooo001h0?ooo`030000
o`3oool0oooo01D0oooo00<0o`000?ooo`3oool01`3oool<0000og40oooo
00<000000?ooo`3oool0KP3oool<0000o`T0oooo00<0o`000?ooo`3oool0
5@3oool00`000?l0oooo0?ooo`0?0?ooo`00N03oool00`000?l0oooo0?oo
o`0=0?oooa80003oO@3oool00`000000oooo0?ooo`1j0?oooa80003o3`3o
ool00`000?l0oooo0?ooo`0?0?ooo`00N03oool@0000og@0oooo0P000004
0?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`8000001`3oool0
0`000000oooo0?ooo`2<0?oooa00003o4@3oool00?/0oooo00@000000?oo
o`3oool000002P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2]0?ooo`00n`3oool0
10000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0103oool300000:d0oooo003k0?ooo`040000003oool0
oooo000000/0oooo00@000000?ooo`3oool0oooo0P0000070?ooo`030000
003oool0oooo0:d0oooo003k0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0:d0oooo003l0?ooo`8000002@3oool4000000<0oooo
0`00002f0?ooo`00o`3oooo80?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{455, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.78",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/schwarzchristoffel/\
SchwarzChristoffelFigures/mat1178.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The region with ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_3 = 1\)}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(-\(\[Pi]\/2\)\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", "\[Pi]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "3"], "=", \(-\(\[Pi]\/2\)\)}]}]]],
  "."
}], "Text"],

Cell[TextData[{
  "Solution.  The exterior angles are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(-\(\[Pi]\/2\)\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", "\[Pi]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "3"], "=", \(-\(\[Pi]\/2\)\)}]}]]],
  ",  and the formula for the derivative ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " is  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\ \((z - x\_3)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z - \
\((\(-1\))\))\)\^\(\(-\((\(-\(\[Pi]\/2\)\))\)\)/\[Pi]\)\) \(\((z - 
                  0)\)\^\(\(-\((\[Pi])\)\)/\[Pi]\)\) \((z - 1)\)\^\(\(-\((\(-\
\(\[Pi]\/2\)\))\)\)/\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \(\((z + 
                    1)\)\^\(1\/2\)\) \(\((z)\)\^\(-1\)\) \((z - \
1)\)\^\(1\/2\)\ \  = \ \ A\ \(z\^\(-1\)\) \((z\^2 - 1)\)\^\(1\/2\)\)\)\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ \((z\^2 - 1)\)\^\(1\
\/2\)\/z\ \  = \ \ A\ \(\(\((z\^2 - 1)\)\^\(1\/2\)\) \((z\^2 - 1)\)\^\(1\/2\)\
\)\/\(z \((z\^2 - 1)\)\^\(1\/2\)\)\)\)\[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ \((z\^2 - 1)\)\/\(z \
\((z\^2 - 1)\)\^\(1\/2\)\)\ \  = \ \ A\ \(z\^3 - z\)\/\(\(z\^2\) \((z\^2 - 1)\
\)\^\(1\/2\)\)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ z\/\((z\^2 - \
1)\)\^\(1\/2\)\  - \ A\ 1\/\(\((1 - 1\/z\^2)\)\^\(1\/2\)\ z\^2\)\)\)\)}]],
  "  \nintegrate and get \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ A\ \((z\^2 - 1)\)\^\(1\/2\)\ \  + \ \ \
A\[Cross]Arcsin \((1\/z)\)\)]],
  "\n\t\t\t\nuse the conditions  ",
  Cell[BoxData[
      \(f \((\(-1\))\) = \(-1\)\)]],
  "  and  ",
  Cell[BoxData[
      \(f \((1)\) = 1\)]],
  "  and solve the resulting system for ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["B",
    FontFamily->"Courier New"],
  ".  The desired result is\n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ \(2\/\[Pi]\) \((z\^2 - 1)\)\^\(1\/2\)\ \  + \ \(2\
\/\[Pi]\) Arcsin \((1\/z)\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the formula ",
  Cell[BoxData[
      \(\(f'\)[z]\)],
    AspectRatioFixed->True],
  " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[A, B, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f1, F];\)\ \), "\n", 
    \(\(f1[z_]\  = \ \ \ A\ z\/\((z\^2 - 1)\)\^\(1\/2\)\  - \ 
          A\ 1\/\(\((1 - 1\/z\^2)\)\^\(1\/2\)\ z\^2\);\)\ \), "\n", 
    \(\(f[z_]\  = \ 
        B\  + \ \[Integral]A \((\ \ z\/\((z\^2 - 1)\)\^\(1\/2\) - \ 
                  1\/\(\((1 - 1\/z\^2)\)\^\(1\/2\)\ z\^2\))\) \
\[DifferentialD]z;\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = B + \[Integral] \>", 
        f1[z], "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
We will use this form of the integral to continue the computations.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(F[z_]\  = \ 
        B + A\ \((\@\(\(-1\) + z\^2\) + ArcSin[1\/z])\);\)\ \), "\n", 
    \(\(Print["\<F[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(eq1\  = \ F[\(-1\)]\  \[Equal] \ \(-1\);\)\ \), "\n", 
    \(\(eq2\  = \ F[1]\ \  \[Equal] \ 1;\)\ \), "\n", 
    \(\(solset\  = \ Solve[{eq1, eq2}, {A, B}];\)\ \), "\n", 
    \(\(f[z_]\  = \ 
        ReplaceAll[F[z], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \), "\n", 
    \(\(Print[eq1];\)\ \), "\n", 
    \(\(Print[eq2];\)\ \), "\n", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_]\  = \ Expand[f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[{
    \(\(f1[
          z_] = \(-\(\(2\ \@\(\(-1\) + z\^2\)\)\/\[Pi]\)\) + \(2\ \
ArcSin[1\/z]\)\/\[Pi];\)\ \), "\[IndentingNewLine]", 
    \(\(f2[
          z_] = \(2\ \@\(\(-1\) + z\^2\)\)\/\[Pi] + \(2\ \
ArcSin[1\/z]\)\/\[Pi];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(graph1\  = \ 
        CartesianMap[
          f1, {\(-3.00001\), 0.00001, 0.5}, {0.00001, 1.20001, 0.12}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(graph2\  = \ 
        CartesianMap[f2, {0.00001, 3.00001, 0.5}, {0.00001, 1.20001, 0.12}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, 
        PlotRange \[Rule] {{\(-2\), 2}, {\(-1.5\), 0.75}}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], {\(-1\), 0.75}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0 under the \
mapping\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = f[z] = \>", f[z]];\)\ \)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ 
          4 \((z + 1)\)\^\(1/4\)\  + \ 
            log \(\((z + 1)\)\^\(1/4\) - 1\)\/\(\((z + 1)\)\^\(1/4\) + 1\)\  \
+ \ \[ImaginaryI]\ log \( \[ImaginaryI] - \((z + 1)\)\^\(1/4\)\)\/\(\
\[ImaginaryI] + \((z + 1)\)\^\(1/4\)\)\)\)]],
  "  maps the upper half-plane onto the domain indicated in Figure 11.84.  \n\
Hint: Set  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 0\)}]]],
  " and ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \[ImaginaryI]\ \[Pi]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(w\_2\), "=", 
          RowBox[{
            RowBox[{\(-d\), "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["let",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "d"}], "\[Rule]", 
            "\[Infinity]"}]}]}]]],
  ".  Use the change of variable  ",
  Cell[BoxData[
      \(z + 1 = s\^4\)]],
  "  in the resulting integral."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004i0000[b000`400?l0
0000o`00003oo`3ooolj0?ooo`00o`3ooolj0?ooo`00o`3ooolj0?ooo`00
o`3ooolj0?ooo`00o`3ooolj0?ooo`00o`3ooolj0?ooo`00o`3ooolj0?oo
o`00Q@3oool500000480oooo1@00000O0?ooo`@000008P3oool200000240
oooo00270?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo00000200
oooo00270?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01l0oooo
001o0?ooo`@00000103oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0N0?ooo`00Q`3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo01l0oooo00@000000?ooo`3oool000008@3oool010000000oooo0?oo
o`00000P0?ooo`00QP3oool2000004D0oooo0P00000R0?ooo`8000008`3o
ool200000240oooo003o0?ooocX0oooo003o0?ooocX0oooo003o0?ooocX0
oooo003o0?ooocX0oooo001b0?oookP0003o3`3oool008@0oooo00<00000
0?ooo`3oool06P3oool00`3o0000oooo0?ooo`050?ooo`030000003oool0
oooo0180oooo00<0003o0?ooo`3oool03@3oool00`000000oooo0?l0000=
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00H0o`000?ooo`3oool0oooo000000000?l40?ooo`030?l0
003oool0oooo0080oooo00H0003o0?ooo`3oool0oooo0?l0003oool20?l0
00l0oooo002Q0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3o
ool04P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool010000?l0
oooo0?ooo`3ooolS0?l00140oooo002Q0?ooo`030?l0003oool0oooo00D0
oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`020?oooaL0o`000`3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00X0003o3`3oool00:40oooo
00<0o`000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000
o`3oool0oooo00l0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`030?ooo`X0o`00103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0103o0000oooo
0?ooo`3ooolD0000o`80oooo00D0003o0?ooo`3oool0oooo0?l0000B0?oo
o`00X@3oool00`3o0000oooo0?ooo`050?ooo`030000003oool0oooo0180
oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`050?ooo``0
o`001@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00@0o`000?ooo`3oool0oooo3P000?l20?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0>0?l0
00l0oooo002Q0?ooo`030?l0003oool0oooo00D0oooo00<000000?ooo`3o
ool04P3oool00`000?l0oooo0?ooo`0<0?ooo`/0o`001P3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool00P3oool70000o`<0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`040000o`3oool0oooo0?ooo`X0o`0000<0oooo0?l0
003oool00`3oool01P000?l0oooo0?ooo`3oool0o`000?ooo`80003o3`3o
ool00:40oooo00<0o`000?ooo`3oool01@3oool00`000000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo00D0oooo1`3o00040?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`02
0?ooo`T0003o0`3oool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0
oooo0?ooo``0o`000P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00`0003o4@3oool00:40oooo00<0o`000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00D0o`002`3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo2P000?l4
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool7
0?l00080oooo00<0o`000?ooo`3oool00`3oool010000?l0oooo0?ooo`3o
ool:0000o`80oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`@0o`00
3`3oool00:80oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?oo
o`0@0?ooo`D0o`00403oool00`3o0000oooo0?ooo`090?ooo`L0003o1@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo1`3o
00030?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3oool0oooo
1P000?l20?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
2`3o00020?ooo`030000o`3oool0oooo00d0oooo002R0?ooo`030?l0003o
ool0oooo00@0oooo00<000000?ooo`3oool02P3oool60?l000<0oooo00<0
003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`050?ooo`@0003o00<0
oooo0000o`3oool02@3oool00`3o0000oooo0?ooo`050?ooo`L0o`000`3o
ool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo0?ooo`H0003o
0P3oool010000?l0oooo0?ooo`3oool:0?l00080oooo00<0o`000?ooo`3o
ool020000?l@0?ooo`00XP3oool00`3o0000oooo0?ooo`040?ooo`030000
003oool0oooo00H0oooo103o00090?ooo`030000o`3oool0oooo00l0oooo
00@0o`000?ooo`3oool0oooo10000?l50?ooo`030000o`3oool0oooo00P0
oooo00@0o`000?ooo`3oool0oooo103o00020?ooo`030000o`3oool0oooo
00D0oooo00@0o`000?ooo`3oool0oooo1`000?l20?ooo`030?l0003oool0
oooo0080oooo1@3o00020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool01@000?l00`3oool0003o0?ooo`020?ooo`@0o`003`3oool0
0:<0oooo00<0o`000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`@0o`003@3oool00`000?l0oooo0?ooo`0?0?ooo`@0003o2P3oool00`00
0?l0oooo0?ooo`060?ooo`D0o`001P3oool00`000?l0oooo0?ooo`040?oo
o`D0003o0`3oool00`000?l0oooo0?ooo`020?ooo`H0o`000P3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00D0003o0P3oool00`3o
0000oooo0?ooo`050?l000030?ooo`3o0000oooo0100oooo002S0?ooo`03
0?l0003oool0oooo00<0oooo00<000000?ooo`3o00000P3o000B0?ooo`03
0000o`3oool0oooo00X0oooo10000?l00`3o0000oooo0?ooo`0;0?ooo`04
0000o`3oool0oooo0?ooo`D0o`000P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00@0003o00<0oooo0?l0003oool01@3oool50?l0
0080oooo00<0o`000?ooo`3oool00P3oool90000o`<0oooo00<0003o0?oo
o`3oool0103o00020?ooo`030000o`3oool0oooo00@0003o3`3oool00:<0
oooo00@0o`000?ooo`3oool0oooo103o000E0?ooo`030000o`3oool0oooo
00H0oooo10000?l50?ooo`030?l0003oool0oooo00X0oooo103o00070?oo
o`030?l0003oool0oooo00@0oooo1@000?l50?ooo`030?l0003oool0oooo
00@0o`0000<0oooo0000o`3oool0103oool00`3o0000oooo0000o`020000
o`030?ooo`000?l0oooo00@0oooo00<0o`000?ooo`3oool01@3o00000`3o
ool0o`000?ooo`020?ooo`@0003o00@0oooo0?l0003oool0o`003`3oool0
0:<0oooo103o00020?ooo`030000003oool0oooo01@0oooo00@0003o0?oo
o`3oool0oooo1@000?l90?ooo`030?l0003oool0oooo00H0oooo103o0000
0`3oool0003o0?ooo`090?ooo`030?l0003oool0003o00<0003o0P3oool0
0`000?l0oooo0?ooo`030?ooo`D0o`001@3oool010000?l0oooo0?ooo`3o
ool40000o`@0oooo00@0003o0?ooo`3oool0oooo1@3o00000`3oool0003o
0000o`070000o`040?ooo`000?l0oooo0?ooo`<0o`00403oool00:40oooo
0P3o00000`3oool0o`000?ooo`030?ooo`030000003oool0oooo01@0oooo
10000?l>0?ooo`030?l0003oool0oooo0080oooo103o00050?ooo`030000
o`3oool0oooo00H0oooo10000?l70?ooo`D0o`000`3oool00`3o0000oooo
0?ooo`030?ooo`D0003o0`3oool0103o0000oooo0?ooo`3oool50?l00080
oooo00H0o`000?ooo`000?l0003o0?ooo`000?l20?ooo`T0o`0000@0oooo
0000o`000?l0003o3`3oool009h0oooo0`3o00030?ooo`030?l0003oool0
oooo0080oooo00<000000?ooo`3oool04P3oool20000o`030?ooo`000?l0
oooo0100oooo103o00090?ooo`030000o`3oool0oooo00<0oooo0`000?l2
0?ooo`030?l0003oool0oooo00@0oooo0P3o00000`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0003o00<0003o00<0oooo0000o`3oool00`3oool6
0?l00080oooo00<0003o0?ooo`3oool010000?l20?ooo`@0o`000P3oool0
0`3o0000oooo0?ooo`050000o`030?ooo`3o0000oooo00l0oooo002L0?oo
o`80o`001`3oool01@3o0000oooo0?ooo`3oool000000180oooo0P000?l3
0?ooo`030000o`3oool0oooo00d0oooo0`3o000=0?ooo`D0003o1P3oool0
0`3o0000oooo0?ooo`030?l00080oooo00<0003o0?ooo`3oool0103oool3
0000o`D0oooo1@3o00020?ooo`040?l0003oool0oooo0?ooo`D0003o0P3o
ool01P3o0000oooo0?l0003o0000oooo0000o`<0oooo10000?l20?ooo`03
0000o`3oool0oooo00<0o`003`3oool009X0oooo0P3o00090?ooo`050?l0
003oool0oooo0?ooo`000000403oool20000o`D0oooo00<0003o0?ooo`3o
ool02P3oool30?l000<0oooo00<0o`000?ooo`3oool0203oool30000o`X0
oooo0`3o00060?ooo`030000o`3oool0003o00<0003o0P3oool00`3o0000
oooo0?l000030?l000030?ooo`000?l0oooo00<0oooo1@000?l20?ooo`03
0000o`3oool0oooo00@0o`000P3oool50000o`040?ooo`3o0000oooo0?oo
o`D0o`000`000?l?0?ooo`00V03oool20?l000`0oooo00@0o`000?ooo`3o
ool000003P3oool20000o`P0oooo00<0003o0?ooo`3oool01`3oool20?l0
00H0oooo00<0o`000?ooo`3oool01@3oool30000o`80oooo00<0003o0?oo
o`3oool01@3oool40?l000L0oooo0`000?l50?ooo`<0o`001@3oool00`00
0?l0oooo0?ooo`020000o`80oooo00@0o`000?ooo`3oool0oooo103o0002
0?ooo`@0003o0P3oool00`000?l0oooo0?ooo`040?l00080oooo0`000?l2
0?ooo`030?l0003oool0oooo00d0oooo002G0?ooo`030?l0003oool0oooo
00`0oooo00@0o`000?ooo`3oool00000303oool20000o`X0oooo00<0003o
0?ooo`3oool0103oool30?l000P0oooo00<0o`000?ooo`3oool00`3oool2
0000o`D0oooo00@0003o0?ooo`3oool0oooo103o00040?ooo`030?l0003o
ool0oooo0080oooo0P000?l00`3oool0003o0?ooo`030?ooo`80o`0000<0
oooo0?l0003oool01@3oool30000o`@0oooo00@0o`000?ooo`3o0000o`00
0P3oool01P000?l0oooo0000o`000?l0oooo0?l000<0oooo103o00020?oo
o`060?l0003oool0003o0000o`3oool0003o0P3oool20?l000l0oooo002E
0?ooo`80o`00403oool00`3o0000oooo0000000:0?ooo`80003o3@3oool0
10000?l0oooo0?ooo`3oool20?l000/0oooo00<0o`000?ooo`3oool00`00
0?l80?ooo`<0o`00203oool00`3o0000oooo0000o`020000o`@0oooo00@0
003o0?ooo`3o0000o`00103oool00`3o0000oooo0000o`030000o`030?oo
o`000?l0oooo0080oooo103o00030?ooo`<0003o103oool30?l00080oooo
00<0003o0?ooo`3oool00`000?l20?ooo`@0o`0000<0oooo0000o`3oool0
3P3oool009@0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0000
00090?ooo`030000o`3oool0oooo00d0oooo00@0003o0?ooo`3o0000o`00
3P3oool20000o`T0oooo0P3o00000`000?l0oooo0?ooo`070?ooo`<0003o
1P3oool30?l000D0oooo0`000?l50?ooo`@0o`000P3oool00`3o0000oooo
0?ooo`020000o`030?ooo`000?l0oooo0080oooo0`3o00020?ooo`D0003o
0P3oool30?l000040?ooo`000?l0oooo0?ooo`80003o3`3oool00980oooo
0P3o000D0?ooo`030?l000000000oooo00H0oooo0P000?l@0?ooo`80o`00
3P3oool20000o`030?l0003oool0oooo00H0oooo0P3o00030?ooo`030000
o`3oool0oooo00@0oooo0P000?l20?ooo`030?l0003oool0oooo0080oooo
0P3o00020?ooo`040000o`3oool0oooo0?ooo`80003o00<0oooo0?l0003o
ool00`3oool20?l000030000o`3oool0oooo00<0oooo0`000?l30?ooo`@0
o`0000<0oooo0000o`000?l00P000?l20?ooo`030000o`3oool0oooo00<0
o`000P3oool40000o`80o`003`3oool00940oooo00<0o`000?ooo`3oool0
5@3oool00`3o0000oooo0?ooo`030?ooo`80003o4@3oool00`3o0000oooo
0000o`0<0?ooo`80003o0P3oool00`3o0000oooo0?ooo`040?ooo`80o`00
1@3oool00`000?l0oooo0?ooo`020?ooo`80003o103oool00`3o0000oooo
0?ooo`020?l000@0oooo00@0003o0?ooo`000?l0003o0`3oool00`3o0000
oooo0?ooo`020?l00080oooo00<0003o0?ooo`3oool00`000?l0103oool0
o`000?ooo`3oool20?l000030?ooo`000?l0oooo0080003o0P3oool00`3o
0000oooo0?ooo`040?l00080oooo0`000?l0103oool0o`000?l0003o000A
0?ooo`00S`3oool20?l001P0oooo00@0o`000?ooo`3oool0oooo0P000?lA
0?ooo`80o`000`3oool00`000?l0oooo0?ooo`070?ooo`80003o1@3oool0
103o0000oooo0?ooo`3oool20?l000P0oooo00@0003o0?ooo`000?l0003o
1P3oool30?l000D0oooo0`000?l50?ooo`<0o`00103oool30000o`@0oooo
0`3o00030?ooo`80003o0`3oool40?l00080oooo00H0003o0?ooo`000?l0
003o0?l0003oool20?l000030?ooo`000?l0oooo0080003o3`3oool008h0
oooo00<0o`000?ooo`3oool0603oool010000000o`000?ooo`000?lA0?oo
o`80o`001P3oool00`000?l0oooo0?ooo`040?ooo`80003o1`3oool0103o
0000oooo0?l0003o00090?ooo`<0003o1P3oool20?l000030?ooo`3o0000
oooo00<0oooo0P000?l20?ooo`040000o`3oool0oooo0?ooo`80o`0000@0
oooo0?l0003oool0oooo0`000?l0103oool0003o0?ooo`3oool30?l00004
0?ooo`3o0000oooo0?ooo`80003o00<0oooo0000o`3oool00P3o0000103o
ool0o`000?ooo`3oool40000o`040?ooo`3o0000o`000?l00080oooo0`00
0?l00`3oool0o`000?ooo`0>0?ooo`00S@3oool00`3o0000oooo0?ooo`0I
0?ooo`03000000000?l0003o0140oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`020?ooo`80003o2@3oool20?l000T0oooo0P000?l2
0?ooo`030000o`3oool0oooo0080oooo0P3o00030?ooo`030?l0003oool0
oooo0080003o103oool010000?l0oooo0?l0003o00040?ooo`80003o1@3o
ool20?l000@0oooo0`000?l20?ooo`<0o`000P3oool40000o`80oooo0`3o
00020?ooo`<0003o0P3oool20?l00100oooo002<0?ooo`030?l0003oool0
oooo01X0oooo00<0003o0?ooo`3o00003`3oool20?l000X0oooo00@0003o
0?ooo`000?l0003o2P3oool0103o0000oooo0?ooo`3o00060?ooo`80003o
103oool00`000?l0oooo0?ooo`020?l000D0oooo00<0o`000000o`000?l0
1@3oool30?l000@0oooo0P000?l00`3o0000oooo0?ooo`020?ooo`80o`00
00<0003o0?ooo`3oool00`000?l00`3oool0o`000?ooo`020?l00080oooo
0`000?l20?ooo`070?l0003oool0o`000?l0003oool0003o0?ooo`020000
o`030?ooo`3o0000oooo0080o`0000<0003o0?ooo`000?l03`3oool008X0
oooo0P3o000L0?ooo`050000o`000000oooo0?ooo`3o00003@3oool00`3o
0000oooo0?ooo`0:0?ooo`80003o2P3oool20?l000<0oooo00<0o`000?oo
o`3oool00P3oool20000o`L0oooo0P3o00060?ooo`80003o00<0o`000?oo
o`3oool00P3oool20?l00080oooo00<0003o0?ooo`3oool00P000?l30?oo
o`040?l0003oool0o`000?l000<0oooo0P000?l40?ooo`80o`000P3oool3
0000o`<0oooo0`3o00030?ooo`80003o0P3oool30?l00080oooo0P000?l@
0?ooo`00R@3oool00`3o0000oooo0?ooo`0J0?ooo`80003o00<0oooo0000
003oool00P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo
00T0oooo0P000?l00`3oool0003o0?ooo`080?ooo`030?l0003oool0oooo
00@0oooo00@0o`000?ooo`000?l0003o1`3oool20?l000030000o`3oool0
oooo00@0oooo00H0003o0?ooo`3oool0oooo0?l0003oool20?l000D0oooo
0P000?l50?ooo`80o`000`3oool30000o`<0oooo0P3o0000103oool0o`00
0000o`000?l20?ooo`040000o`3oool0o`000?l00080oooo00D0o`000?oo
o`000?l0003o0?ooo`030?l000030?ooo`3o0000003o0080003o00<0oooo
0?l0003o00003`3oool008P0oooo00<0o`000?ooo`3oool06P3oool01@00
0?l0oooo0?ooo`3oool0000000<0oooo00<0o`000?ooo`3oool01`3oool2
0?l000/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`04
0?ooo`80o`001`3oool20000o`P0oooo00D0o`000?ooo`3oool0oooo0000
o`030?ooo`80003o103oool20?l000D0oooo0`000?l40?ooo`80o`0000<0
oooo0?l0003oool00P000?l30?ooo`030000o`3o0000o`000080oooo0P00
0?l40?ooo`80o`000`3oool30000o`040?ooo`3o0000o`000000o`80oooo
0P000?l0103o0000oooo0?l0003o00020000o`l0oooo00270?ooo`030?l0
003oool0oooo01X0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool01P3oool010000?l0oooo0?ooo`3o00050?ooo`80
o`001@3oool30000o`@0oooo0P3o00000`3oool0o`000?ooo`020?ooo`80
003o0`3oool010000?l0oooo0?l0003o00030?ooo`80003o103oool20?l0
00<0oooo00<0003o0?ooo`3o00000P3oool20?l00080oooo0`000?l0103o
ool0o`000?l0003o00020?ooo`<0003o0P3oool20?l000040?ooo`000?l0
003o0000o`l0oooo00260?ooo`030?l0003oool0oooo01X0oooo00<0003o
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030?l0003oool0
oooo0080oooo0P3o000;0?ooo`80003o1`3oool00`000?l0oooo0?ooo`02
0?l000L0oooo0P000?l30?ooo`030?l0003oool0oooo0080oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`060?l0003oool0
oooo0?ooo`3o0000oooo0P000?l50?ooo`80o`000`3oool20000o`040?oo
o`3o0000oooo0?ooo`80o`0000<0oooo0000o`3oool00P000?l30?ooo`80
o`000`3oool20000o`050?ooo`3o0000o`000?ooo`3o00000P3oool30000
o`040?ooo`3o0000o`000?ooo`80003o4P3oool008D0oooo00<0o`000?oo
o`3oool06P3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00@0o`000?ooo`3oool0o`00303oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3o0000oooo00L0oooo00<0003o0?ooo`3oool0103oool0
103o0000oooo0?l0003o00060?ooo`80003o00<0oooo0000o`3oool00P3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo0P3o
00000`000?l0oooo0?ooo`020000o`<0oooo0`3o00040?ooo`040000o`3o
ool0oooo0?ooo`<0o`000P3oool20000o`030?ooo`3o0000o`0000<0oooo
00<0o`000000o`000?l00P3oool20?l000030?ooo`000?l0003o01@0oooo
00250?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`80o`00303oool00`000?l0oooo0?oo
o`090?ooo`030?l000000?l0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`060000o`3oool0oooo0?ooo`000?l0
oooo0P3o00040?ooo`80003o00@0o`000?ooo`3oool0oooo0P3o00030?oo
o`80003o103oool30?l000<0oooo0`000?l00`3oool0o`000?l000030?oo
o`80003o0P3oool00`3o0000oooo0000o`020?ooo`80003o00D0o`000?oo
o`3o0000o`000?ooo`020000oaH0oooo00240?ooo`030?l0003oool0oooo
01T0oooo00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`80o`002`3oool00`000?l0oooo0?ooo`090?ooo`040?l0003oool0oooo
0000o`D0oooo00<0003o0?ooo`3oool01P3oool20?l000D0oooo0P000?l5
0?ooo`030?l0003oool0oooo00<0oooo00@0003o0?ooo`3oool0oooo0`3o
00040?ooo`80003o0`3oool20?l00080oooo00@0o`000?ooo`000?l0003o
0`3oool0103o0000oooo0?ooo`3oool20000o`040?ooo`3o0000o`000?l0
0080oooo0`000?l20?ooo`80o`0000<0oooo0000o`000?l0603oool008<0
oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`070?ooo`03
0000003oool0oooo00D0oooo00<0o`000?ooo`3o00002@3oool00`000?l0
oooo0?ooo`080?ooo`80o`000`3oool010000?l0oooo0?ooo`3oool20000
o`L0oooo0P3o00020?ooo`030?l0003oool0oooo0080003o1P3oool00`3o
0000oooo0000o`030?ooo`030000o`3oool0oooo0080oooo0P3o00040?oo
o`040000o`3oool0oooo0000o`80o`00103oool20000o`<0oooo0P3o0000
103oool0003o0000o`000?l20?ooo`80o`000P3oool20000o`030?ooo`00
0?l0oooo0080o`0000<0oooo0000o`000?l06P3oool00880oooo00<0o`00
0?ooo`3oool06@3oool00`000?l0oooo0?ooo`080?ooo`030000003oool0
oooo00@0oooo00D0o`000?ooo`3oool0oooo0?l000070?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0000
o`080?ooo`030?l0003oool0oooo00<0oooo00<0o`000000o`3oool01@3o
ool20?l00080oooo00@0003o0?ooo`000?l0003o103oool00`3o0000oooo
0?l000020?ooo`80003o0`3oool00`3o0000003o0?ooo`020?ooo`80003o
00<0oooo0?l0003oool00P3o00030?ooo`030000o`3oool0oooo0080o`00
0P3oool20000o`<0oooo0P3o00020?ooo`030000o`3oool0oooo01X0oooo
00210?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`060?l0003oool0oooo0?ooo`3o0000
003o0`3oool20?l00080oooo0`000?l40?ooo`040?l0003oool0oooo0?oo
o`80003o00<0oooo0?l0003o00000`3oool010000?l0o`000?ooo`3oool2
0?l000040?ooo`000?l0003o0000oad0oooo00210?ooo`030?l0003oool0
oooo01P0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`000?l01@3oool20?l000D0oooo0P000?l00`3oool0o`000?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`000?l00P3oool2
0?l000<0oooo0P000?l30?ooo`030?l0003oool0oooo0080oooo0P000?l3
0?ooo`80o`0000@0oooo0?l000000?l0003o0P3oool0103o0000oooo0000
o`3oool20000o`040?ooo`3o0000o`000?l000<0oooo00<0003o0?ooo`3o
ool07@3oool00800oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo
0?ooo`0:0?ooo`050000003oool0oooo0?ooo`3o00002@3oool20?l00003
0?ooo`000?l0oooo00P0oooo00<0o`000?ooo`3oool01P3oool01@000?l0
oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`020?ooo`@0o`001@3oool01P000?l0oooo0?ooo`3oool0
003o0?l000@0oooo00H0003o0?ooo`3oool0o`000?ooo`3o00030?ooo`80
003o00<0oooo0000o`3oool00P3o00030?ooo`030000o`3oool0oooo0080
o`000P3oool20000o`<0oooo0P3o00020?ooo`80003o803oool00800oooo
00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0;0?ooo`040000
003oool0oooo0?l000`0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
00001P3oool00`000?l0oooo0?ooo`040?ooo`80o`00103oool20000o`@0
oooo00<0o`000000o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool0103o0000oooo0?ooo`3oool2
0000o`030?ooo`3o0000o`0000<0oooo0`000?l00`3oool0o`000?l00002
0?ooo`80003o8P3oool007l0oooo00<0o`000?ooo`3oool0603oool00`00
0?l0oooo0?ooo`0<0?ooo`040000003oool0oooo0?l000/0oooo00<0003o
0?ooo`3o00001`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`040?l0003oool0oooo0?l00080oooo00<0003o0?ooo`3oool00`3o
ool0103o0000oooo0000o`3oool20000o`@0oooo00<0o`000?ooo`3o0000
0P000?l30?ooo`80o`0000@0003o0?ooo`000?l0003o0`3oool00`3o0000
oooo0?ooo`020000o`<0oooo00D0o`000?ooo`3oool0oooo0000o`0T0?oo
o`00O`3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo00`0
oooo00<000000?ooo`3o00002`3oool01@000?l0oooo0?ooo`3oool0o`00
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0003o00@0oooo00<0003o0?ooo`3oool0103oool01`3o
0000oooo0?ooo`3oool0o`000?ooo`000?l01@3oool01@3o0000oooo0?oo
o`3oool0003o00@0oooo0P3o00020?ooo`030000o`3oool0oooo0080oooo
00D0o`000?ooo`3oool0oooo0000o`030?ooo`80o`0000<0oooo0?l00000
0?l0103oool00`3o0000003o0?ooo`020000obD0oooo001n0?ooo`030?l0
003oool0oooo01P0oooo00<0003o0?ooo`3oool03@3oool00`000000o`00
0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo0P3o00030?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool01@3o0000oooo
0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo0P3o00030?ooo`80
003o0`3oool0203o0000oooo0?ooo`3oool0003o0?ooo`3o0000oooo0P3o
00030?ooo`050000o`3oool0003o0?ooo`3o00000`3oool010000?l0o`00
0?l0003oool20?l00080oooo00<0003o0?ooo`3oool09@3oool007h0oooo
00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?l000080?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0000o`050?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3o00000P3oool00`3o0000oooo0?ooo`020?ooo`060000
o`3oool0oooo0000o`3oool0o`000`3oool010000?l0oooo0?ooo`3oool2
0?l00080oooo0P000?l30?ooo`050?l0003oool0oooo0?ooo`000?l00P3o
ool20?l000<0oooo00<0003o0?ooo`3oool09P3oool007d0oooo00<0o`00
0?ooo`3oool0603oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00@0003o
0?ooo`3oool0oooo0P3o00040?ooo`030000o`3oool0oooo0080oooo00D0
o`000000o`3oool0oooo0000o`030?ooo`050?l0003oool0o`000?ooo`00
0?l0103oool01@3o0000oooo0000o`3oool0003o00<0oooo0P3o00000`3o
ool0003o0000o`0Y0?ooo`00O@3oool00`3o0000oooo0?ooo`0G0?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000000003oool02P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0o`0000H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0003o00<0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80
o`000`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
003o0`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo0P3o00020?oo
o`80003o0P3oool20?l00080oooo00<0003o0?ooo`3oool0:@3oool007`0
oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`030?ooo`@0
00001`3oool00`3o000000000?ooo`090?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool00P3o00030?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?ooo`3oool20000
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool01P3o
0000oooo0?ooo`3o0000oooo0000o`@0oooo00@0o`000?ooo`3oool0oooo
0P000?l20?ooo`090?l0003oool0oooo0?ooo`000?l0oooo0?l0003oool0
o`0000@0oooo0P000?l00`3oool0o`000?ooo`020?ooo`030000o`3oool0
oooo02X0oooo001l0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`030?l0003oool00000
00X0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?oo
o`040?l0003oool0oooo0000o`L0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`020?ooo`030?l000000?l0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o0000
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`030000o`3o
0000oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`80003o
0P3oool00`3o0000oooo0?ooo`020000obd0oooo001l0?ooo`030?l0003o
ool0oooo01L0oooo00<0003o0?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`030?l0003oool0000000T0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`040?ooo`030?l000000?l0oooo00H0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`040?l0003o
ool0oooo0000o`80oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`060000o`3oool0oooo0?l0003oool0o`000`3oool01P00
0?l0oooo0?ooo`3oool0o`000000o`80oooo00T0003o0?ooo`3oool0oooo
0?l0003oool0o`000?ooo`000?l00`3oool0103o0000oooo0000o`000?l_
0?ooo`00O03oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo
00H0oooo00<000000?ooo`3oool0103oool0103o0000oooo0?ooo`000009
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
10000?l0oooo0?l0003o00040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`80003o1@3o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`030?ooo`050?l0003oool0003o0?ooo`000?l00`3oool01@3o
0000oooo0?ooo`3oool0003o00<0oooo00@0o`000?ooo`3oool0003o<03o
ool007`0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`04
0?ooo`040000003oool0oooo000000D0oooo00@0o`000?ooo`3oool00000
203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo
00@0003o0?ooo`3oool0oooo0P3o00020?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80
003o103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?oo
o`3o0000oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool0203o0000oooo0?ooo`000?l0oooo0?l0003oool0o`000P3oool00`00
0?l0oooo0?ooo`0_0?ooo`00O03oool00`3o0000oooo0?ooo`0F0?ooo`03
0000o`3oool0oooo00H0oooo0P0000060?ooo`040?l0003oool0oooo0000
00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo0P3o00050?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00`3oool01P000?l0oooo0000o`000?l0
oooo0?l000@0oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?oo
o`000?l30?ooo`060?l0003oool0oooo0?ooo`000?l0oooo0P000?l01@3o
ool0o`000?ooo`3oool0003o00<0oooo00@0o`000?ooo`3oool0003o<P3o
ool007/0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0=
0?ooo`050?l0003oool0oooo0?ooo`000000203oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool30?l000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`060?l0003oool0oooo0000o`3oool0
o`000P3oool0103o0000oooo0?ooo`000?l40?ooo`050?l0003oool0oooo
0?ooo`000?l00P3oool0103o0000oooo0?l000000?lc0?ooo`00N`3oool0
0`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0080oooo10000000
0`3oool000000000000200000080oooo00@0o`000?ooo`3oool0oooo0P00
00060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`040?l0003oool0oooo0?l00080oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`070000
o`3oool0oooo0?ooo`3o0000oooo0000o`020?ooo`030000o`3oool0oooo
0080oooo00@0o`000?ooo`3oool0003o0`3oool20?l00080oooo00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0000o`3oool0003o0080oooo00@0
o`000?ooo`3oool0003o=03oool007/0oooo00<0o`000?ooo`3oool05`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`020?ooo`030?l000000?l0oooo00@0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080003o103o
ool01@3o0000oooo0?ooo`3oool0003o00<0oooo0P3o00020?ooo`050000
o`3oool0oooo0?ooo`3o00000`3oool010000?l0oooo0?ooo`3o00020?oo
o`030000o`3oool0oooo03<0oooo001b0?ooo`T0003o00<0o`000?ooo`3o
ool05`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3o0000o`0000<0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`060?l0003oool0oooo0?oo
o`000?l0oooo0P000?l20?ooo`040?l0003oool0oooo0000o`<0oooo00D0
o`000?ooo`3oool0o`000000o`030?ooo`080?l0003oool0oooo0?ooo`00
0?l0oooo0000o`3o00020?ooo`030000o`3oool0oooo03@0oooo001k0?oo
o`030?l000000?l0003o00h0003o2@3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`040000o`3oool0oooo
0?ooo`<0o`001@3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l00`3oool00`000?l0o`000?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`3o00000P3oool01@000?l0o`000?ooo`3oool0o`0000<0
oooo00L0003o0?ooo`3oool0o`000000o`3oool0003o03L0oooo001k0?oo
o`030?l0003oool0oooo00h0oooo2P000?l>0?ooo`030?l0003oool0oooo
0080oooo00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo0`3o00030?oo
o`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`050?l000000?l0oooo0?ooo`000?l00`3oool0103o0000oooo0?oo
o`000?l20?ooo`80o`000`3oool010000?l0oooo0?ooo`3o00020?ooo`03
0000o`3oool0oooo03H0oooo001k0?ooo`030?l0003oool0oooo01L0oooo
3P000?l00`3oool0o`000?ooo`030?ooo`030000003oool0oooo00<0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080o`0000<0oooo0000o`3oool0
0`3oool0103o0000oooo0?ooo`000?l50?ooo`030?l0003oool0003o0080
003o0P3oool01@3o0000oooo0?ooo`3oool0003o0080oooo0`3o00001@3o
ool0003o0?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool0=`3oool0
07/0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`060?oo
o`040000003oool0oooo00000080oooo00<0003o0?l000000?l010000?l5
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o0000
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`040?l0003o
ool0oooo0?ooo`80003o0P3oool0103o0000oooo0?ooo`000?l30?ooo`05
0?l0003oool0oooo0000o`3o00000P3oool00`3o0000oooo0000o`0j0?oo
o`00N`3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo00L0
oooo00<000000?ooo`0000000`3oool00`3o0000oooo0?ooo`020?ooo`03
000000000?l0003o0080003o00<0oooo0000o`3oool01`3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00P3o00001@3oool0o`000?ooo`3oool0003o
00@0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`050000o`3o0000
oooo0?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l20?ooo`80o`00
0P3oool00`000?l0oooo0?ooo`0h0?ooo`00N`3oool00`3o0000oooo0?oo
o`0F0?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`0000000`3o
ool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo1P00
0?l40?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80o`000P3o
ool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0
0P3oool00`3o0000oooo0000o`020000o`80oooo00D0o`000?ooo`3oool0
oooo0000o`020?ooo`80o`0000<0oooo0000o`3oool0>P3oool007/0oooo
00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`060?ooo`D00000
00<0oooo0?l0003oool0103oool00`000000oooo0?ooo`020?ooo`030000
o`3oool0oooo00<0oooo10000?l00`3o0000003o0000o`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3o0000003o00@0oooo00D0o`000?ooo`3o
ool0oooo0000o`030?ooo`030?l0003oool0oooo0080003o0P3oool0103o
0000oooo0?ooo`000?l20?ooo`050?l0003oool0oooo0000o`3o0000>`3o
ool007`0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`060?ooo`040?l0003oool0oooo0?ooo`D0003o1@3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`000?l00P3o00020?ooo`050?l0003oool0oooo0?ooo`00
0?l00P3oool0103o0000oooo0?ooo`000?l20?ooo`030000o`3o0000oooo
0080oooo00H0003o0?ooo`3oool0o`000?ooo`000?lm0?ooo`00O03oool0
0`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool30000o`<0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00<0oooo0P3o00030?ooo`050000o`3oool0oooo0?ooo`3o0000
0P3oool010000?l0oooo0?ooo`3o00020000o`050?ooo`000?l0oooo0?oo
o`3o00000P3oool00`000?l0oooo0?ooo`0k0?ooo`00O03oool00`3o0000
oooo0?ooo`0F0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?ooo`3oool30000
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo0000o`030?ooo`060?l0003oool0o`000?l0003oool0003o
0P3oool0103o0000oooo0?ooo`000?l30?ooo`030?l0003oool0oooo0080
003o0P3oool00`3o0000oooo0000o`0n0?ooo`00O03oool00`3o0000oooo
0?ooo`0F0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0003o00@0003o1@3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo00@0o`000?ooo`3oool0003o103oool01P3o0000
oooo0?ooo`3oool0003o0?l00080oooo00@0o`000?ooo`3oool0003o0P3o
ool0203o0000oooo0?ooo`3oool0003o0?ooo`000?l0o`000P3oool00`00
0?l0oooo0?ooo`0l0?ooo`00O03oool00`3o0000oooo0?ooo`0F0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo10000?l00`3oool0o`000?ooo`030?ooo`030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0oooo
0?ooo`000?l00P3oool20?l00080oooo00D0003o0?ooo`3oool0oooo0?l0
00020?ooo`050000o`3oool0oooo0?l0003oool00P000?lo0?ooo`00O@3o
ool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo00H0003o0?ooo`3oool0oooo
0000o`3o00020000o`80oooo00<0003o0?ooo`3oool00P3oool01@3o0000
oooo0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000o`03
0?ooo`<0o`0000@0003o0?ooo`3oool0o`000`3oool010000?l0oooo0?oo
o`3o00020?ooo`030000o`3oool0oooo03d0oooo001m0?ooo`030?l0003o
ool0oooo01D0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00@0003o0P3oool00`3o0000oooo0?ooo`020?ooo`040000o`3o
ool0oooo0?l000<0oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo
0000o`3oool30?l00080oooo00@0003o0?ooo`3oool0o`000P3oool00`00
0?l0oooo0?ooo`0n0?ooo`00O@3oool00`3o0000oooo0?ooo`0E0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`050000o`3oool0003o
0000o`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0
003o0?ooo`3oool0oooo0?l000020?ooo`040000o`3oool0oooo0?ooo`80
o`0000D0oooo0000o`3oool0oooo0?l000020?ooo`030000o`3oool0oooo
03h0oooo001m0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000003o0000o`020000o`80oooo00<0o`000?ooo`3oool00P3oool01`00
0?l0oooo0?ooo`3oool0o`000?ooo`000?l00`3oool01`3o0000oooo0?oo
o`000?l0o`000?ooo`3o00000P3oool00`000?l0oooo0?ooo`0o0?ooo`00
OP3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
00@0o`000?ooo`3oool0oooo0`000?l01@3o0000oooo0?ooo`3oool0003o
00<0oooo00@0o`000?ooo`3oool0003o0`3oool01@3o0000oooo0?ooo`00
0?l0oooo0080o`000P3oool00`000?l0oooo0?ooo`0o0?ooo`00OP3oool0
0`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool010000?l0oooo0?ooo`3o00020000o`030?ooo`000?l0oooo0080oooo
00@0o`000?ooo`3oool0003o0P3oool0103o0000oooo0?ooo`000?l20?oo
o`040?l0003oool0o`000000od80oooo001o0?ooo`030?l0003oool0oooo
01D0oooo00<0003o0?ooo`3oool02`3oool01@3o0000oooo0?ooo`3oool0
000000D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00<0oooo0P3o00040?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003o
ool0oooo0?ooo`000?l00P3oool0103o0000oooo0?ooo`3oool30000o`03
0?ooo`3o0000oooo0080oooo00@0003o0?ooo`3oool0o`000P3oool01000
0?l0oooo0?ooo`3o00020?ooo`030000o`3oool0oooo0400oooo001o0?oo
o`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool02`3oool01@3o
0000oooo0?ooo`3oool0000000D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o0080oooo
00<0o`000?ooo`3oool00P3oool010000?l0oooo0000o`3o00030000o`<0
oooo00H0o`000?ooo`3oool0003o0?ooo`3o00030?ooo`030000o`3oool0
oooo0400oooo00200?ooo`030?l0003oool0oooo01@0oooo00<0003o0?oo
o`3oool02`3oool01@3o0000oooo0?ooo`3oool0000000D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`80003o103oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0
0P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3o
ool00`000?l01`3o0000oooo0?ooo`3oool0003o0?ooo`3o00000P3oool0
0`000?l0oooo0?ooo`110?ooo`00P03oool00`3o0000oooo0?ooo`0D0?oo
o`030000o`3oool0oooo00/0oooo00D0o`000?ooo`3oool0oooo00000005
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0
o`000?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`00
0?l00P3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00H0o`000000
o`3oool0003o0?ooo`3o00030?ooo`030000o`3oool0oooo0440oooo0021
0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool02`3oool0
103o0000oooo0?ooo`0000050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00@0003o0?ooo`3oool0oooo0P3o00030?ooo`050000
o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`00
00<0oooo00@0003o0?ooo`3oool0o`000P3oool01P000?l0oooo0?ooo`3o
ool0o`000?ooo`<0003o00@0o`000000o`3oool0003oA03oool00880oooo
00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0;0?ooo`040?l0
003oool0oooo000000H0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`040000o`3oool0oooo0?ooo`L0o`0000<0003o0?l0
003o00000P3o00040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0
10000?l0oooo0?ooo`3o00040?ooo`040000o`3oool0oooo0?l00080oooo
00@0003o0?ooo`3oool0o`000P3oool01@000?l0oooo0?ooo`3o0000oooo
0080003oA03oool008<0oooo00<0o`000?ooo`3oool04`3oool00`000?l0
oooo0?ooo`0:0?ooo`040?l0003oool0oooo000000H0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?l000060000o`3o0000o`00
0?l0003oool0o`001@3oool010000?l0oooo0?ooo`3oool50?l000030000
o`3o0000o`0000D0o`0000@0003o0?ooo`3oool0o`000`3oool01@000?l0
oooo0?ooo`3oool0o`000080oooo00@0003o0?ooo`3oool0o`000P3oool0
0`000?l0oooo0?l000030?ooo`030000o`3oool0oooo0480oooo00230?oo
o`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo000000060?ooo`040000o`3oool0oooo0?ooo`H0o`00103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000
0`3oool00`000?l0o`000?l000030?l000050?ooo`000?l0oooo0?ooo`3o
00000`3oool01P000?l0oooo0?ooo`3o0000oooo0000o`80oooo00@0o`00
0?ooo`3oool0003oA@3oool008@0oooo00<0o`000?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0000000H0oooo00@0003o
0?l0003o0000o`00103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`04
0000o`3oool0oooo0?l00080oooo00<0o`000000o`3o00000`3o00001@3o
ool0003o0?ooo`3oool0o`000080oooo00@0003o0?ooo`3oool0o`000P3o
ool00`000?l0oooo0?ooo`130?ooo`00Q@3oool00`3o0000oooo0?ooo`0C
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`000000103oool2
0?l000030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000
0P3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00P0003o0?ooo`3o
ool0oooo0?l0003oool0o`000000o`<0o`000P3oool010000?l0oooo0?oo
o`3o00020?ooo`030000o`3oool0oooo04<0oooo00260?ooo`030?l0003o
ool0oooo01<0oooo00<0003o0?ooo`3oool02@3oool0103o000000000?oo
o`3oool20?l000<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3o
ool0oooo0?l000020?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool0
1@000?l0oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool00`3o
00000`000?l0o`000?l000030?ooo`030000o`3oool0oooo04<0oooo0027
0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0203oool0
103o000000000?l0003o00050?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000
o`3oool0oooo0?ooo`3o00000P3oool01@000?l0oooo0?ooo`3oool0o`00
0080oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`040000o`3oool0
oooo0?l00080oooo00<0003o0?ooo`3o00000P3o00000`000?l0oooo0?oo
o`140?ooo`00R03oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool01@000?l0oooo0?ooo`3oool0o`000080oooo00D0003o0?ooo`3oool0
oooo0?l000020?ooo`040000o`3oool0oooo0?l00080oooo00@0003o0?oo
o`3oool0o`000P3oool010000?l0oooo0?ooo`3o00020?ooo`030000o`3o
ool0oooo04@0oooo00290?ooo`030?l0003oool0oooo0180oooo00<0003o
0?ooo`3oool01P3oool30?l000P0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0
003o0?ooo`3oool0oooo0?l000020?ooo`050000o`3oool0oooo0?ooo`3o
00000P3oool010000?l0oooo0?ooo`3o00020?ooo`040000o`3oool0oooo
0?l00080oooo00@0003o0?ooo`3oool0o`000P3oool00`000?l0oooo0?oo
o`140?ooo`00RP3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0
oooo00<0oooo0P3o00020?ooo`030000003o0000oooo00H0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool0103o0000oooo0?oo
o`000?l30?ooo`040?l0003oool0oooo0000o`80oooo00@0o`000?ooo`3o
ool0003o0P3oool0103o0000oooo0?ooo`000?l20?ooo`030?l0003oool0
003o04L0oooo002;0?ooo`030?l0003oool0oooo0140oooo00@0003o0?oo
o`3oool0oooo0P3o00040?ooo`030000003o0000oooo00L0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003o
ool0oooo0?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l30?ooo`04
0?l0003oool0oooo0000o`80oooo00@0o`000?ooo`3oool0003o0P3oool0
103o0000oooo0?ooo`000?l20?ooo`030?l0003oool0003o04L0oooo002<
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o00001P3oool0
0`000000oooo0?l000070?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0003o0?l000070000o`030?l00000
0?l0003o00@0003o00<0o`000000o`000?l00`000?l00`3o0000003o0000
o`030000o`060?l0003oool0oooo0000o`3oool0o`000P3oool00`000?l0
oooo0?ooo`150?ooo`00S@3oool20?l00180oooo00<0003o0?ooo`3oool0
1@3oool010000000oooo0?ooo`3o00070?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0003o00D0003o00<0oooo0?l0003oool00P3oool01@000?l0
oooo0?ooo`3oool0o`000080oooo00D0003o0?ooo`3oool0oooo0?l00002
0?ooo`040000o`3oool0oooo0?l00080oooo00@0003o0?ooo`3oool0o`00
10000?l0103o0000003o0?ooo`000?m70?ooo`00S`3oool00`3o0000oooo
0?ooo`0>0?ooo`030?l0003oool0003o00H0oooo00@000000?ooo`3oool0
o`001`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00H0003o0?ooo`000?l0003o0?l000000?l30?ooo`050000o`3oool0
oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`000080oooo
00D0003o0?ooo`3oool0oooo0?l000020?ooo`040000o`3oool0oooo0?l0
0080oooo00H0003o0?ooo`3oool0o`000?ooo`000?l20?ooo`040?l0003o
ool0003o0000odL0oooo002@0?ooo`030?l0003oool0oooo00`0oooo00D0
o`000?ooo`3oool0oooo0000o`050?ooo`050000003oool0oooo0?ooo`3o
00001`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080
oooo0`000?l20?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3o
ool0oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool0
1@000?l0oooo0?ooo`3oool0o`000080oooo00@0003o0?ooo`3oool0o`00
0P3oool01P000?l0oooo0?ooo`3o0000oooo0000o`80oooo00@0o`000?oo
o`3oool0003oA`3oool00940oooo00<0o`000?ooo`3oool02P3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00H0o`000?ooo`000?l0003o0?ooo`000?l40?ooo`030?l0003o
ool0oooo0080oooo00@0003o0?ooo`3oool0o`000`3oool01@000?l0oooo
0?ooo`3oool0o`000080oooo00D0003o0?ooo`3oool0oooo0?l000020?oo
o`040000o`3oool0oooo0?l00080oooo00H0003o0?ooo`3oool0o`000?oo
o`000?l20?ooo`030?l0003oool0003o04P0oooo002B0?ooo`80o`002@3o
ool00`3o0000oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`000000
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00<0o`000000o`3oool00`3oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00@0003o0?ooo`3oool0o`000`3oool01@000?l0oooo0?ooo`3oool0
o`000080oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`040000o`3o
ool0oooo0?l00080oooo00<0003o0?ooo`3o00000P3oool01P000?l0oooo
0?ooo`3o0000oooo0000odP0oooo002D0?ooo`030?l0003oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool010000?l0oooo0?ooo`0000050?oo
o`030?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool0oooo0P000?l0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`020?ooo`050?l0003oool0oooo0?ooo`000?l0
0`3oool0103o0000oooo0?ooo`000?l30?ooo`040?l0003oool0oooo0000
o`80oooo00H0o`000?ooo`3oool0003o0?ooo`3o00020?ooo`060000o`3o
ool0oooo0?l0003oool0003oB03oool009D0oooo0P3o00050?ooo`030?l0
003oool0oooo00P0oooo0P000?l00`000000oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo0`000?l30?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o0080
oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`3o00020?oo
o`050000o`3oool0oooo0?ooo`3o00000P3oool00`000?l0oooo0?ooo`03
0?l000030000o`3o0000o`000080o`0000H0003o0?ooo`3oool0o`000?oo
o`000?m80?ooo`00U`3oool20?l00080oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo0`00
0?l40?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0
oooo0000o`020?ooo`050?l0003oool0o`000?l000000?l01@3o00001000
0?l0o`000?l0003o00020?ooo`030000o`3oool0o`000080oooo00<0003o
0?l0003o00000P3o00000`000?l0oooo0?ooo`160?ooo`00V@3oool20?l0
00h0oooo00<000000000o`3oool01@3oool00`3o0000oooo0?ooo`020000
o`80oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool010000?l0oooo0?ooo`3o
00020?ooo`030?l000000?l0o`0000<0o`000P3oool010000?l0oooo0?oo
o`3o00020?ooo`040000o`3oool0oooo0?l00080oooo00<0003o0?ooo`3o
00000P3oool01P000?l0oooo0?ooo`3o0000oooo0000odP0oooo002I0?oo
o`<0o`003@3oool00`000000oooo0000o`060?ooo`030?l000000?l0oooo
00@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`05
0?l000050?ooo`000?l0oooo0?ooo`3o00000`3oool010000?l0oooo0?oo
o`3o00020?ooo`040000o`3oool0oooo0?l00080oooo00<0003o0?ooo`3o
00000P3oool01P000?l0oooo0?ooo`3o0000oooo0000odP0oooo002I0?oo
o`030?l0003oool0oooo0080o`002`3oool00`000000oooo0000o`050?oo
o`80003o00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`050?l0003oool0oooo0?ooo`000?l0103oool40?l000040000o`3oool0
oooo0?l000<0oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`040000
o`3oool0oooo0?l00080oooo00@0003o0?ooo`3oool0o`000P3oool00`00
0?l0oooo0?l000020?ooo`030000o`3oool0o`000080oooo00<0003o0?oo
o`3oool0AP3oool009T0oooo00<0o`000?ooo`3oool00P3oool30?l000P0
oooo00@000000?ooo`3oool0003o0`3oool010000?l0oooo0?ooo`3o0006
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?l000<0oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`040000o`3oool0oooo0?l00080oooo00@0003o0?ooo`3oool0
o`000P3oool010000?l0oooo0?ooo`3o00020?ooo`030000o`3oool0o`00
0080oooo00<0003o0?ooo`3o00000P3oool00`000?l0oooo0?ooo`160?oo
o`00V03oool00`3o0000oooo0?ooo`060?ooo`80o`001P3oool01`000000
oooo0?ooo`3oool0003o0?ooo`000?l0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
o`020?l000030?ooo`3o0000oooo0080oooo00D0003o0?ooo`3oool0oooo
0?l000030?ooo`040000o`3oool0oooo0?l00080oooo00@0003o0?ooo`3o
ool0o`000P3oool010000?l0oooo0?ooo`3o00020?ooo`030000o`3oool0
o`000080oooo00H0003o0?ooo`3o0000o`000?ooo`000?m80?ooo`00V03o
ool00`3o0000oooo0?ooo`080?ooo`80o`00103oool00`000000oooo0?oo
o`020?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?l000000?l0
103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00@0o`000?ooo`3o
ool0003o0P3oool0103o0000oooo0?ooo`000?l30?ooo`060?l0003oool0
oooo0000o`3oool0o`001@000?l00`3o0000003o0000o`020000o`030?l0
00000?l0003o04P0oooo002H0?ooo`030?l0003oool0oooo00X0oooo0P3o
00020?ooo`070000003oool0oooo0?ooo`000?l0oooo0000o`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool20?l00080
oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0oooo
0?ooo`3o00000P3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00@0
003o0?ooo`3oool0o`0010000?l0103o0000oooo0?ooo`000?l20?ooo`03
0?l0003oool0003o0080oooo00<0o`000?ooo`000?l0B03oool009P0oooo
00<0o`000?ooo`3oool0303oool20?l000040000003oool0oooo0000o`<0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0o`000`3oool00`000?l0oooo0?ooo`020?ooo`04
0?l0003oool0oooo0000o`<0oooo00D0o`000?ooo`3oool0oooo0000o`02
0?ooo`030?l000000?l0003o00<0003o00H0o`000?ooo`3oool0003o0?oo
o`3o00020?ooo`060000o`3oool0oooo0?l0003oool0003o0P3oool00`3o
0000oooo0000o`180?ooo`00V03oool00`3o0000oooo0?ooo`0>0?ooo`80
o`0000<0oooo0000o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?l0003oool00P3oool01@3o0000
oooo0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000o`03
0?ooo`030?l0003oool0003o00<0003o00@0o`000?ooo`3oool0003o0P3o
ool0103o0000oooo0?ooo`000?l20?ooo`030?l0003oool0003o0080oooo
00<0o`000?ooo`000?l00P3oool00`3o0000oooo0000o`180?ooo`00V03o
ool00`3o0000oooo0?ooo`0>0?ooo`030000003oool0o`0000H0oooo00<0
003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`3oool20?l000050000
o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`04
0?l0003oool0oooo0000o`<0oooo00@0o`000000o`3oool0003o0P3oool0
1`3o0000oooo0?ooo`3oool0003o0?ooo`3o00000P3oool01P000?l0oooo
0?ooo`3o0000oooo0000o`80oooo00<0o`000?ooo`000?l00P3oool00`3o
0000oooo0000o`180?ooo`00U`3oool20?l000H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`03000000000?l0oooo0080
o`001@3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo0?l0
0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
003o00<0oooo00@0o`000?ooo`3oool0oooo0`000?l01@3o0000oooo0?oo
o`3oool0003o0080oooo00@0o`000?ooo`3oool0003o0P3oool00`3o0000
oooo0000o`020?ooo`060?l0003oool0oooo0000o`3oool0o`000P3oool0
1@000?l0oooo0?l0003oool0003o04P0oooo002G0?ooo`030?l0003oool0
oooo00H0oooo00@000000?ooo`3oool000001@3oool00`000000003o0?oo
o`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool20?l000@0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000
o`3oool0oooo0080oooo00@0o`000000o`000?l0003o0`3oool0103o0000
oooo0?ooo`000?l20?ooo`040?l0003oool0oooo0000o`80oooo00H0o`00
0?ooo`3oool0003o0?ooo`3o00020?ooo`030000o`3o0000o`000080o`00
00D0003o0?l0003o0000o`000000o`180?ooo`00LP3ooolh0000o`030000
003oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool01P000?l0oooo
0?ooo`3o0000oooo0?l000@0oooo00<0003o0?ooo`3oool00P3oool01P3o
0000oooo0?ooo`3oool0003o0?ooo`80003o00D0o`000?ooo`3oool0oooo
0000o`020?ooo`040?l0003oool0oooo0000o`80oooo00@0o`000?ooo`3o
ool0003o0P3oool0103o0000oooo0?ooo`000?l40?l000030000o`3oool0
o`000080oooo00D0003o0?ooo`3o0000oooo0000o`180?ooo`00X@3oool0
0`000000oooo000000050?ooo`03000000000?l0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool01@000?l0o`000?ooo`3oool0o`0000D0oooo00D0
003o0?ooo`3oool0oooo0?l000030?ooo`80003o0P3oool01@3o0000oooo
0?ooo`3oool0003o0080oooo00@0o`000?ooo`3oool0003o0`3oool0103o
0000oooo0?ooo`000?l40?l000030000o`3oool0o`000080oooo00X0003o
0?ooo`3oool0o`000?ooo`000?l0oooo0?l0003oool0003oB03oool00:00
oooo1@0000040?ooo`030000003oool0003o00D0oooo00L0o`000?ooo`3o
ool0oooo0?l0003oool0003o00<0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`050?l000000?l0003o0?ooo`000?l00`3o
ool01`3o0000oooo0?ooo`3oool0003o0?ooo`3o00000`3oool02@000?l0
oooo0?ooo`3o0000oooo0?l000000?l0oooo0?l000020?ooo`060000o`3o
ool0oooo0?l0003oool0003o0P3oool01`3o0000oooo0000o`3oool0o`00
0?ooo`000?l0B03oool00:T0oooo00@000000?ooo`3oool0003o1@3oool0
0`3o0000oooo0?l000020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0
003o0?ooo`3oool0oooo0?l000030?ooo`040000o`3oool0oooo0?l00080
oooo00<0003o0?l0003o00000P3o00001`3oool0003o0?ooo`3oool0o`00
0?ooo`000?l00P3oool00`3o0000oooo0000o`020?ooo`030?l0003oool0
003o0080oooo00<0o`000?ooo`000?l0A`3oool00:T0oooo00D000000?oo
o`3oool0oooo0000o`050?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool01P3o0000oooo0?ooo`3oool0003o0?ooo`80003o
00<0oooo0?l0003oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000<0
oooo00<0003o0?ooo`3o00000P3o00001`000?l0oooo0?ooo`3oool0o`00
0?ooo`000?l00P3oool01P3o0000oooo0?ooo`000?l0oooo0?l00080oooo
00@0003o0?ooo`3o0000oooo0`000?l00`3o0000003o0000o`170?ooo`00
Z@3oool00`000000oooo0?ooo`020?ooo`070000o`3oool0oooo0?ooo`3o
0000oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool2
0000o`<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`050?l0003o
ool0oooo0?ooo`000?l00P3o00030?ooo`060000o`3oool0oooo0?l0003o
ool0003o0P3oool0103o0000oooo0?ooo`000?l20?ooo`050?l0003oool0
003o0?ooo`3o00000P000?l20?ooo`030?l0003oool0003o04L0oooo002Y
0?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3o00000`3oool0
0`3o0000oooo0?ooo`020?ooo`070000o`3oool0oooo0?ooo`3o0000oooo
0000o`020?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool010000?l0
oooo0?ooo`3oool30?l000040000o`3oool0oooo0?l00080oooo00@0003o
0?ooo`3oool0o`000P3oool01@000?l0oooo0?ooo`3o0000oooo00<0003o
00D0o`000000o`000?l0003o0?l000020?ooo`050000o`3oool0o`000?oo
o`000?l0A`3oool00:T0oooo00<000000?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o
0000oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000<0oooo00<0003o
0?ooo`3oool00P3o00030?ooo`030000o`3oool0o`0000<0oooo00<0003o
0?ooo`3o00000P3oool010000?l0oooo0?ooo`3o00020000o`80oooo00D0
o`000?ooo`000?l0oooo0?l000020?ooo`050000o`3oool0o`000?ooo`00
0?l0A`3oool00:T0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool00`000?l0
oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01000
0?l0o`000?ooo`3o00030?ooo`040000o`3oool0oooo0?l00080oooo00D0
003o0?ooo`3oool0o`000?ooo`030000o`080?l0003oool0oooo0000o`3o
ool0o`000?ooo`000?l20?ooo`070?l0003oool0003o0?ooo`3o0000oooo
0000o`170?ooo`00Z@3oool00`000000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00<0oooo00@0o`000?ooo`3oool0oooo0P000?l30?ooo`050?l0
003oool0oooo0?ooo`000?l00P3oool01P3o0000oooo0?ooo`3oool0o`00
0000o`80oooo00L0o`000?ooo`3oool0oooo0000o`3oool0o`0000<0oooo
00<0003o0?ooo`3o00000P000?l30?ooo`050?l0003oool0003o0?ooo`3o
00000P3oool00`000?l0oooo0?l000020?ooo`050000o`3oool0o`000?l0
00000?l0AP3oool00:T0oooo00<000000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`030?ooo`050?l0003oool0003o0?ooo`000?l00`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0o`0000D0oooo0000
o`3oool0oooo0?l000030?ooo`040000o`3oool0oooo0?l00080oooo0P00
0?l0103o0000oooo0?ooo`000?l20?ooo`030?l0003oool0003o0080oooo
00P0o`000?ooo`000?l0oooo0?l0003oool0o`000000o`80o`0000<0oooo
0000o`3oool0A@3oool00:T0oooo00<000000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool0
0`3o0000oooo0?ooo`020?ooo`040000o`3o0000oooo0?l000<0oooo00@0
003o0?ooo`3oool0o`000`3oool00`000?l0oooo0?l000030000o`80oooo
00<0o`000?ooo`000?l00P3oool0203o0000oooo0?ooo`000?l0oooo0?l0
003oool0003o0`3o00001P3oool0003o0?ooo`3o0000oooo0000odH0oooo
002Y0?ooo`030000003oool0oooo00T0oooo00L0003o0?ooo`3oool0oooo
0000o`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000020?oo
o`050?l0003oool0003o0?ooo`3o00000`3oool010000?l0oooo0?ooo`3o
00030?ooo`80003o00L0o`000?ooo`3oool0oooo0000o`3oool0o`000080
oooo00H0003o0?ooo`3oool0o`000?ooo`000?l30?l000080000o`3oool0
oooo0?l0003oool0003o0?ooo`3o00020?ooo`030000o`3oool0oooo04<0
oooo002Y0?ooo`030000003oool0oooo00X0oooo00<0003o0?ooo`000?l0
0`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo0P3o00020?ooo`04
0000o`3oool0oooo0?l000<0oooo00D0003o0?ooo`3oool0o`000?ooo`02
0000o`80oooo00@0o`000?ooo`3oool0003o0P3oool0103o0000oooo0000
o`3oool30?l000030000o`3oool0o`000080oooo00<0003o0?ooo`3o0000
0P3oool01@000?l0oooo0?l0003oool0003o04D0oooo002Y0?ooo`030000
003oool0oooo00/0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0o`000080o`000`3oool010000?l0oooo
0?ooo`3o00020?ooo`050000o`3oool0oooo0000o`3o00000P3oool00`00
0?l0oooo0?l000020?ooo`090000o`3oool0oooo0?l0003oool0o`000000
o`3oool0o`000080oooo00D0003o0?ooo`3o0000oooo0000o`020?ooo`05
0?l0003oool0003o0?ooo`3o00000P000?m50?ooo`00Z@3oool00`000000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool01@000?l0oooo0?ooo`3oool0o`000080oooo00@0003o0?oo
o`3oool0o`000`3oool20000o`050?ooo`3o0000oooo0?ooo`000?l00P3o
ool01@3o0000oooo0?ooo`000?l0oooo0080o`0000T0oooo0000o`3oool0
oooo0?l0003oool0003o0?ooo`3o00000P3oool00`000?l0oooo0?l00003
0000odP0oooo002Y0?ooo`030000003oool0oooo00d0oooo00<0003o0?oo
o`3oool00P3oool01P3o0000oooo0?ooo`3o0000oooo0000o`80oooo00D0
o`000?ooo`3oool0oooo0000o`020?ooo`050?l000000?l0003o0?ooo`00
0?l00P3oool01P3o0000oooo0?ooo`000?l0oooo0?l00080oooo00@0003o
0?l0003oool0o`000P3oool00`000?l0oooo0?l000020?ooo`040000o`3o
ool0o`000?ooo`<0003oB`3oool00:T0oooo00<000000?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`020?ooo`80o`000`3oool010000?l0oooo0?oo
o`3o00020?ooo`050000o`3oool0oooo0000o`3o00000P3oool020000?l0
oooo0?ooo`3oool0o`000?ooo`000?l0oooo0`3o00001`3oool0003o0?oo
o`3oool0o`000?ooo`000?l00P3oool01P3o0000oooo0000o`000?l0o`00
0000odh0oooo002Y0?ooo`030000003oool0oooo00l0oooo00@0003o0?oo
o`3oool0oooo0P3o00030?ooo`050000o`3oool0oooo0?ooo`3o00000P3o
ool20000o`030?ooo`3o0000oooo0080oooo00L0003o0?ooo`3oool0o`00
0?ooo`3o0000003o0080oooo00<0o`000?ooo`000?l00P3oool01`3o0000
oooo0?ooo`000?l0oooo0?l000000?l0DP3oool00:T0oooo00<000000?oo
o`3oool0403oool00`000?l0oooo0?l000020?ooo`050?l0003oool0oooo
0?ooo`000?l00`3oool0103o0000003o0000o`000?l20?ooo`050?l0003o
ool0oooo0?ooo`000?l00P3oool01P3o0000oooo0?ooo`000?l0oooo0?l0
0080oooo00@0003o0?ooo`3oool0o`0010000?mC0?ooo`00Z@3oool00`00
0000oooo0?ooo`0A0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
1`000?l0oooo0000o`000?l0o`000?ooo`000?l00`3oool02P3o0000oooo
0?ooo`000?l0oooo0?l0003oool0o`000?ooo`000?l20?ooo`030?l0003o
ool0003o0080oooo00<0o`000?ooo`3oool0E@3oool00:T0oooo00<00000
0?ooo`3oool04P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00@0
003o0?ooo`3oool0o`000P3oool010000?l0oooo0?ooo`3o00020?ooo`05
0?l000000?l0oooo0?ooo`3o00000P3oool00`000?l0oooo0?l000020?oo
o`80003oF03oool00:T0oooo00<000000?ooo`3oool04`3oool01@000?l0
oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`000?l00P3oool0103o
0000oooo0?ooo`000?l20?ooo`80o`000P3oool01P000?l0oooo0?ooo`3o
0000oooo0000o`80oooo00<0o`000000o`3oool0F@3oool00:T0oooo00<0
00000?ooo`3oool0503oool01P000?l0oooo0?ooo`3oool0o`000000o`80
oooo00/0003o0?ooo`3oool0oooo0?l0003oool0003o0?ooo`3o0000oooo
0?l000020?ooo`040000o`3oool0oooo0?l00080oooo0P000?mL0?ooo`00
Z@3oool00`000000oooo0?ooo`0E0?ooo`050000o`3oool0oooo0000o`3o
00000`3oool01`000?l0oooo0?ooo`3o0000oooo0?l000000?l00`3oool0
103o0000oooo0?ooo`000?l20?ooo`030?l000000?l0003o05d0oooo002Y
0?ooo`030000003oool0oooo01H0oooo0P000?l20?ooo`050?l0003oool0
oooo0?ooo`000?l00P3oool0103o0000oooo0?ooo`000?l20?ooo`050?l0
003oool0oooo0000o`3oool00P000?mO0?ooo`00Z@3oool00`000000oooo
0?ooo`0G0?ooo`040000o`3oool0oooo0?l000<0oooo00D0003o0?ooo`3o
0000oooo0?l000020?ooo`040000o`3oool0oooo0?l00080oooo00<0003o
0?ooo`3oool0G`3oool00:T0oooo00<000000?ooo`3oool0603oool01000
0?l0oooo0?ooo`3o00030?ooo`050000o`3oool0oooo0?ooo`3o00000P3o
ool01@000?l0oooo0?ooo`3o0000003o0680oooo002Y0?ooo`030000003o
ool0oooo01T0oooo00P0003o0?ooo`3oool0o`000?ooo`3o0000oooo0000
o`80oooo00@0o`000?ooo`3oool0oooo0P000?mT0?ooo`00Z@3oool00`00
0000oooo0?ooo`0J0?ooo`040000o`3oool0oooo0?l000<0oooo00H0003o
0?ooo`3oool0o`000?ooo`000?mV0?ooo`00Z@3oool00`000000oooo0?oo
o`0K0?ooo`040000o`3o0000oooo0?l000<0oooo00@0003o0?ooo`3oool0
o`00I`3oool00:T0oooo00<000000?ooo`3oool0703oool00`000?l0oooo
0?ooo`020?l00080oooo0P000?mX0?ooo`00Z@3oool00`000000oooo0?oo
o`0M0?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0000o`1Y0?ooo`00
Z@3oool00`000000oooo0?ooo`0N0?ooo`050000o`3oool0oooo0000o`3o
0000JP3oool00:T0oooo00<000000?ooo`3oool07`3oool20000of`0oooo
002Y0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0JP3o
ool00:T0oooo00<000000?ooo`3oool0S@3oool00:T0oooo00<000000?oo
o`3oool0S@3oool00:T0oooo00<000000?ooo`3oool0S@3oool00:T0oooo
00<000000?ooo`3oool0S@3oool00:T0oooo00<000000?ooo`3oool0S@3o
ool00:T0oooo00<000000?ooo`3oool0S@3oool00:T0oooo00<000000?oo
o`3oool0S@3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{313, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.84",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/schwarzchristoffel/\
SchwarzChristoffelFigures/mat1184.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The region with ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 0\)}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(-\(\[Pi]\/4\)\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", "\[Pi]"}]}]]],
  "."
}], "Text"],

Cell[TextData[{
  "Solution.  The exterior angles are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(-\(\[Pi]\/4\)\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", "\[Pi]"}]}]]],
  ",  and the formula for the derivative ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " is  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z - \
\((\(-1\))\))\)\^\(\(-\((\(-\(\[Pi]\/4\)\))\)\)/\[Pi]\)\) \((z - \
0)\)\^\(\(-\((\[Pi])\)\)/\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ \(\((z + 
                  1)\)\^\(1\/4\)\) \((z)\)\^\(-1\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \((z + \
1)\)\^\(1\/4\)\/z\)\)\)}]],
  "   \nintegrate \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ 
        B\  + \ A\ \(\[Integral]\(\((z + 1)\)\^\(1\/4\)\/z\) \
\[DifferentialD]z\)\)],
    AspectRatioFixed->True],
  "\n\t\t\t\nuse the substitutions \n\n\t\t\t",
  Cell[BoxData[{
      \(z + 1\ \  = \ \ s\^4\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ z\ \  = \ \ s\^4 - 1\), "\[IndentingNewLine]", 
      \(\ \ \ \[DifferentialD]z\ \  = \ \ 4\ \(s\^3\) \[DifferentialD]s\)}]],
  "  \nand get\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\(\((z + 1)\)\^\(1\/4\)\/z\) \[DifferentialD]z\ \  = \ \
\ \[Integral]\(\((s\^4)\)\^\(1/4\)\/\(s\^4 - 1\)\) 
            4\ \(s\^3\) \[DifferentialD]s\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \
\ \ \)\(\[Integral]\(\(4\ s\^4\)\/\(s\^4 - 
                  1\)\) \[DifferentialD]s\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(4\ s\  - \ 2\ Arctan\ s\  + \ Log \((s - 1)\)\  - \ 
          Log \((s + 1)\)\)\)\)}],
    AspectRatioFixed->True],
  "  \n\nUse the identity  ",
  Cell[BoxData[
      \(\(-\ 2\) 
          ArcTan\ s\  = \ \(\(-2\) \(\[ImaginaryI]\/2\) 
            Log \((\(\[ImaginaryI] + s\)\/\(\[ImaginaryI] - s\))\)\  = \ \
\[ImaginaryI]\ Log \((\(\[ImaginaryI] - s\)\/\(\[ImaginaryI] + s\))\)\)\)]],
  "  and write the integral as\n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\(\((z + 1)\)\^\(1\/4\)\/z\) \[DifferentialD]z\ \  = \ \ 4\
\ s\ \  + \ \ Log \((\(s - 1\)\/\(s + 1\))\)\ \  + \ \ \[ImaginaryI]\ Log \((\
\(\[ImaginaryI] - s\)\/\(\[ImaginaryI] + s\))\)\)],
    AspectRatioFixed->True],
  " \n\nNow use the substitution ",
  Cell[BoxData[
      \(s \[Rule] \ \((z + 1)\)\^\(1\/4\)\)]],
  " and get \n\n\t\t\t",
  Cell[BoxData[{
      \(f \((z)\)\ \  = \ \ B\  + \ \(\(A\) \(\[Integral]\(\((z + \
1)\)\^\(1\/4\)\/z\) \[DifferentialD]z\)\(\ \ \)\)\), "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \ \)\(B\  + \ 
          A \((4 \((z + 1)\)\^\(1/4\)\  + \ 
                Log \(\((z + 1)\)\^\(1/4\) - 1\)\/\(\((z + 1)\)\^\(1/4\) + \
1\)\  + \ \[ImaginaryI]\ Log \( \[ImaginaryI] - \((z + 1)\)\^\(1/4\)\)\/\(\
\[ImaginaryI] + \((z + 1)\)\^\(1/4\)\))\)\)\)\)}],
    AspectRatioFixed->True],
  "\n\t\t\t\nuse the conditions  ",
  Cell[BoxData[
      \(f \((0)\)\  = \ 0\)]],
  ",  ",
  Cell[BoxData[
      \(f \((1)\) = \[ImaginaryI]\ \[Pi]\)]],
  "  and solve the resulting system for ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["B",
    FontFamily->"Courier New"],
  ".  The desired result is\n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ 4 \((1 + z)\)\^\(1/4\) + 
          Log \(\((z + 1)\)\^\(1/4\) - 1\)\/\(\((z + 1)\)\^\(1/4\) + 1\) + \
\[ImaginaryI]\ Log \( \[ImaginaryI] - \((z + 1)\)\^\(1/4\)\)\/\(\[ImaginaryI] \
+ \((z + 1)\)\^\(1/4\)\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the formula ",
  Cell[BoxData[
      \(\(f'\)[z]\)],
    AspectRatioFixed->True],
  " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f1, A, B, z, F];\)\ \), "\n", 
    \(\(f1[z_]\  = \ \ A \((\((z + 1)\)\^\(1\/4\)\/z)\);\)\ \), "\n", 
    \(\(f[z_]\  = \ 
        B\  + \ \[Integral]A \((\((z + 1)\)\^\(1\/4\)\/z)\) \
\[DifferentialD]z;\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = B + \[Integral] \>", 
        f1[z], "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
This is one, formula for the integral.   However, we will use the following \
form of the integral to continue the computations.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(F[z_]\  = \ 
        B\  + \ A\ \((4\ \((1 + z)\)\^\(1/4\) + \[ImaginaryI]\ Log[\(\
\[ImaginaryI] - \((1 + z)\)\^\(1/4\)\)\/\(\[ImaginaryI] + \((1 + \
z)\)\^\(1/4\)\)] + 
                Log[\(\(-1\) + \((1 + z)\)\^\(1/4\)\)\/\(1 + \((1 + \
z)\)\^\(1/4\)\)])\);\)\ \), "\n", 
    \(\(Print["\<F[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{\(eq1\  = \ F[\(-1\)]\  \[Equal] \ \[ImaginaryI]\ \[Pi];\), " ",
         "\n", 
        RowBox[{
          RowBox[{"eq2", " ", "=", " ", 
            RowBox[{\(F[0]\), "  ", "\[Equal]", " ", 
              InterpretationBox[\(-\[Infinity]\),
                DirectedInfinity[ -1]]}]}], ";"}], 
        "\n", \(solset\  = \ Solve[{eq1, eq2}, {A, B}];\), " ", 
        "\n", \(f[z_]\  = \ 
            ReplaceAll[F[z], 
              solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\
\)];\), " ", "\n", \(Print[eq1];\), " ", "\n", \(Print[eq2];\), " ", 
        "\n", \(Print[
            solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
];\), " ", "\[IndentingNewLine]", \(Print["\<\>"];\), " ", 
        "\n", \(Print["\<f[z] = \>", f[z]];\), " ", 
        "\[IndentingNewLine]", \(Print["\<\>"];\), " ", 
        "\[IndentingNewLine]", \(Print["\<We will use the replacements A\
\[Rule]1,B\[Rule]0\>"];\), 
        "\[IndentingNewLine]", \(f[z_]\  = \ 
            ReplaceAll[F[z], {A \[Rule] 1, B \[Rule] 0}];\), " ", 
        "\[IndentingNewLine]", \(Print["\<f[z] = \>", f[z]];\)}], 
      " "}]], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[
    \(\(\(\(f[z_] = \ 
        4 \((1 + z)\)\^\(1/4\) + 
          Log[\(\(-1\) + \((1 + z)\)\^\(1/4\)\)\/\(1 + \((1 + \
z)\)\^\(1/4\)\)] + \[ImaginaryI]\ Log[\(\[ImaginaryI] - \((1 + \
z)\)\^\(1/4\)\)\/\(\[ImaginaryI] + \((1 + z)\)\^\(1/4\)\)];\)\
\[IndentingNewLine]
    \(Needs["\<Graphics`Colors`\>"];\)\ \[IndentingNewLine]
    \(Needs["\<Graphics`ComplexMap`\>"];\)\ \[IndentingNewLine]
    \(CartesianMap[f, {\(-4\), 8, 0.5}, {0.00001, 4.00001, 0.2}, 
        PlotStyle \[Rule] {Blue, Red}, 
        PlotRange \[Rule] {{\(-1.5\), 3.5}, {0, 
              4.3}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-2\), 4, 
              1], {\[Pi]\/2, \[Pi]}}];\)\ \ \[IndentingNewLine]
    \(Print["\<The image of the upper half plane Im[z] > 0 under the \
mapping\>"];\)\ \[IndentingNewLine]
    \(Print["\<w = f[z] = \>", f[z]];\)\)\(\ \)\)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We are done!\n\nAside.  If you prefer you can use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s integrand for calculating f[z]."
}], "Text"],

Cell[BoxData[{
    \(\(f[
          z_] = \[Integral]\(\((z + 1)\)\^\(1\/4\)\/z\) \[DifferentialD]z;\)\ \
\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[f, {\(-4\), 8, 0.5}, {0.00001, 4.00001, 0.2}, 
        PlotStyle \[Rule] {Blue, Red}, 
        PlotRange \[Rule] {{\(-1.5\), 3.5}, {0, 
              4.3}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-2\), 4, 
              1], {\[Pi]\/2, \[Pi]}}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0 under the \
mapping\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = f[z] = \>", f[z]];\)\ \)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that  ",
  Cell[BoxData[
      \(w\ \  = \ \ \(f \((z)\)\ \  = \ \ \(\(-\[ImaginaryI]\)\/2\) \
\(z\^\(1\/2\)\) \((z - 3)\)\)\)]],
  "  maps the upper half-plane onto the domain indicated in Figure 11.85.   \n\
Hint: Set  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 1\)}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \(-d\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(w\_2\), "=", 
          RowBox[{
            RowBox[{"\[ImaginaryI]", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["let",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "d"}], "\[Rule]", 
            "0"}]}]}]]],
  ". "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006A0000[b000`400?l0
0000o`00003oo`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00
o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3ooonB0?ooo`00o`3oool_0?oo
o`030000003oool0oooo0600oooo003o0?ooobl0oooo00<000000?ooo`3o
ool0H03oool00?l0oooo;`3oool00`000000oooo0?ooo`1P0?ooo`00o`3o
ool_0?ooo`030000003oool0oooo0600oooo003o0?ooobl0oooo20000?l0
0`3o0000003o0000o`080000oe00oooo003o0?ooobl0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0003o00<0o`000000o`000?l00P000?m60?ooo`00o`3oool_0?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo10000?m20?ooo`00
o`3oool_0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
1`000?ll0?ooo`00o`3oool_0?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool010000?l0o`000000
o`000?lh0?ooo`00o`3oool_0?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`070000oc40oooo003o0?ooobl0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo10000?l^0?ooo`00o`3oool_0?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`070?ooo`040000o`3oool0oooo0?ooo`@0003o:P3oool0
0?l0oooo;`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l000000?l0003o02L0oooo003o0?ooobl0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`040000ob<0oooo003o0?ooobl0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`<0003o803oool00?l0oooo;`3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`000?l00P00
0?lM0?ooo`00o`3oool_0?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`030?ooo`<0003o6P3oool00?l0oooo;`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0o`000?ooo`0G0?ooo`00o`3oool_0?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`070?ooo`040?l000000?l0003o0000
oaD0oooo003o0?ooobl0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool30000oa80
oooo003o0?ooobl0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool30000o`l0oooo
003o0?ooobl0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0=0?ooo`00o`3oool_0?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool03P3oool00?l0oooo;`3oool00`000?l0o`000?l0000;0?l0
00030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0>0?oo
o`00o`3oool_0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0o`000?l000060?l000H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool03`3oool00?l0oooo
;`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?l000050?l000030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00l0oooo
003o0?ooobl0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool010000?l0o`000?l0003o00040?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`0@0?ooo`00o`3oool_0?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00@0003o0?ooo`3oool0oooo1P3o00060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
403oool00:40oooo0`0000130?ooo`@00000@`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3o00000P3o00030?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`040?l00000
00000000000000H0oooo00<0003o0?ooo`3oool0403oool00:80oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`140?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`020?ooo`80o`0000<0003o0?l0003oool01P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`00W`3oool5
000004@0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?l000020?l000@0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
000000L0oooo00<0003o0?ooo`3oool04@3oool009T0oooo100000020?oo
o`040000003oool0oooo000003h0oooo100000040?ooo`030000003oool0
oooo0480oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool00P3oool40?l000P0oooo00<0003o0?ooo`3oool01P3oool0
103o0000oooo0?ooo`0000050?ooo`030000o`3oool0oooo0180oooo002P
0?ooo`030000003oool0000004@0oooo00@000000?ooo`3oool00000@`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`060?ooo`<0o`001P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool000000080oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0B0?ooo`00X@3oool2000004D0oooo0P0000140?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool00`3o00020?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool00P0000050?ooo`030000o`3oool0oooo0180oooo003o0?oo
obl0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`80o`0000<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
01<0oooo003o0?ooobl0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3o0000o`0000D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`0C0?ooo`00o`3oool_0?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool010000?l0oooo0?ooo`3oool20?l000<0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`0D0?ooo`00o`3oool_0?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`<0o`00
2@3oool00`000?l0oooo0?ooo`0D0?ooo`00o`3oool_0?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`@0o`001@3o
ool00`000?l0oooo0?ooo`0E0?ooo`00o`3oool_0?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo0080oooo0P3o00030?ooo`030000o`3oool0oooo01D0oooo001/0?oo
o`L00000^@000?l2000000H0003o00<0o`000000o`000?l00`000?l00`00
0000003o00000004000000030?l000000000000000@0000000<0003o0000
00000000100000000`3o0000000000000004000000030000o`0000000000
00D0000000<0o`000000000000001P0000000`000?l00000000000050000
00030?l000000000000000@000000P3o00000`000000003o0000000=0000
00T0oooo001c0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01T0
oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0H0?ooo`03
0?l0003oool0oooo02P0oooo0`000?l50?ooo`030?l0003oool0oooo00<0
oooo1P000?l00`3o0000003o0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`040?ooo`030000003oool0003o01P0oooo001c0?ooo`030000
o`3oool0oooo01/0oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo
0?ooo`0I0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool0
603oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0003o00D0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0003o0080003o0P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0F0?ooo`00L`3oool00`000?l0oooo0?oo
o`0K0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool06@3o
ool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01P0oooo00<0
o`000?ooo`3oool09`3oool010000?l0oooo0000o`000?l50?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`D0003o103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
5`3oool007<0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?oo
o`0J0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool06@3o
ool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo02H0oooo00D0
003o0?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0003o00<0oooo0?l0003oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo01L0oooo
001c0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool06P3o
ool00`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo01T0oooo00<0
003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3o0000oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0H0?ooo`00L`3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0
oooo01X0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0I
0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0903oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0000o`02
0000o`80oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0H0?ooo`00L`3oool00`000?l0oooo0?ooo`0K0?oo
o`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool06@3oool00`3o
0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?oo
o`3oool08`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`020?ooo`<0003o1P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0I0?ooo`00L`3oool00`000?l0oooo0?ooo`0K0?ooo`03
0?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool06P3oool00`3o0000
oooo0?ooo`0H0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3o
ool08P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`040000o`3oool0003o0000o`@0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool06@3oool007<0oooo00<0003o0?ooo`3o
ool06`3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo01X0
oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0H0?ooo`03
0?l0003oool0oooo0240oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?ooo`3oool30000
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo01X0oooo001c0?ooo`03
0000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool06P3oool00`000?l0
oooo0?ooo`0J0?ooo`030?l0003oool0oooo00L0oooo8@3o000;0?ooo`03
0?l0003oool0oooo0200oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`03
0?l000000?l0003o00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo01X0oooo001c0?ooo`030000
o`3oool0oooo01P0ooooA`3o000A0?ooo`030000o`3oool0oooo00d0oooo
4P3o000K0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`030000o`80oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo01/0oooo001c0?oooa/0o`000`3o
ool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo01X0oooo00<0
o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003o
ool0oooo00@0oooo1`3o000C0?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`80003o1`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo01/0oooo001c0?ooo`030000o`3oool0
oooo01/0oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0J
0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0603oool0
0`3o0000oooo0?ooo`0;0?ooo`@0o`003P3oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool30000o`D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0L0?ooo`00L`3oool00`00
0?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?oo
o`3oool06@3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo
01P0oooo00<0o`000?ooo`3oool03`3oool30?l000/0oooo00<0003o0?oo
o`3oool02P3oool00`000?l0o`000?l000040?l000<0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00H0oooo00@0003o0?ooo`3oool0003o0`3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo01`0oooo001c0?oo
o`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool06`3oool00`00
0?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?oo
o`3oool0603oool00`3o0000oooo0?ooo`0B0?ooo`@0o`001P3oool00`00
0?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3o00000P3o00001P000?l0o`000?l0003o0000oooo0?l000D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`020?ooo`<0003o00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0M0?ooo`00L`3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0
oooo01/0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool05`3oool2
0?l000<0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0oooo0P3o
00050?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000003o0000o`070?ooo`030000o`3o
ool0oooo01d0oooo001c0?ooo`030000o`3oool0oooo01/0oooo00<0o`00
0?ooo`3oool06`3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0
oooo01P0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0I
0?ooo`80o`0000<0003o0?ooo`3oool03@3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?l0
00030?l000030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020000o`@0oooo00<0
003o0?ooo`3oool07P3oool007<0oooo00<0003o0?ooo`3oool06`3oool0
0`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo01T0oooo00<0o`00
0?ooo`3oool0603oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0
oooo01X0oooo00<0003o0?l0003o00003P3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3o0000o`0000<0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`80003o0P3o
ool00`000?l0oooo0?ooo`0N0?ooo`00L`3oool00`000?l0oooo0?ooo`0K
0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool06@3oool0
0`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo01L0oooo00<0o`00
0?ooo`3oool06P3oool010000?l0oooo0?ooo`3o000=0?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00@0003o0?ooo`3oool0oooo0P3o00000`3oool0
o`000?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo0P000?lQ0?ooo`00L`3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0
003oool0oooo01/0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo
0?ooo`0H0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0
6@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00X0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`80
o`001@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo01l0oooo001c0?ooo`030000o`3oool0oooo01/0oooo
00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0
003oool0003o0300003o0P3oool00`3o0000oooo0?ooo`0H0?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool02@3oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000050?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o00000P3o00020?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool0803oool007<0oooo00<0003o0?ooo`3oool06`3oool00`3o0000
oooo0?ooo`0K0?ooo`030000o`3oool0003o01/0003o6@3oool00`000?l0
oooo0?ooo`0E0?ooo`X0003o4`3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00P0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo0080oooo00<0o`000000o`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0P0?ooo`00L`3oool00`00
0?l0oooo0?ooo`0H0?ooob<0003o6P3oool00`3o0000oooo0?ooo`0H0?oo
o`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool01@3oool40000
o`h0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`040000o`3oool0oooo0?l000@0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0o`000?l000040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo0240oooo001c0?ooo`030000o`3oool0oooo
00H0oooo4P000?l40?ooo`030?l0003oool0oooo01X0oooo00<0003o0?oo
o`3oool06@3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo
01L0oooo00<0o`000?ooo`3oool02@3oool60000o`P0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo
0?l000@0oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool010000?l0oooo0?oo
o`3oool20?l00080oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
8@3oool007<0oooo2@000?lF0?ooo`030?l0003oool0oooo01X0oooo00<0
003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3o
ool0oooo01L0oooo00<0o`000?ooo`3oool03`3oool20000o`D0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`<0003o00<0
o`000000o`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo0P3o00070?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0R0?ooo`00L`3o
ool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo01X0oooo00<0
003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3o
ool0oooo01L0oooo00<0o`000?ooo`3oool04@3oool30000o`80oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`050?ooo`050000o`3o
ool0oooo0?l0003oool010000?l30?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00D0oooo0P3o00060?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0S0?ooo`00L`3o
ool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo01X0oooo00<0
003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3o
ool0oooo01L0oooo00<0o`000?ooo`3oool0503oool40000o`/0oooo00<0
o`000?ooo`3oool01@3oool010000?l0oooo0?ooo`3o00030?ooo`060000
o`3oool0003o0000o`3oool0o`000`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?l00080oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo02<0oooo001c0?ooo`03
0000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool06P3oool00`000?l0
oooo0?ooo`0I0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3o
ool05`3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080
003o2P3oool00`3o0000oooo0?ooo`040?ooo`040000o`3oool0oooo0?l0
00<0oooo00D0003o0?ooo`3oool0oooo0?l000020000o`80oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`3o0000003o0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0903oool0
07<0oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0J0?oo
o`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0603oool00`00
0?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?oo
o`3oool00P3oool20000o`P0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?l000030?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00P000?l50?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0o`00
00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0T0?oo
o`00L`3oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo01X0
oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0H0?ooo`03
0000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool05@3oool00`000?l0
oooo0?ooo`050?ooo`80003o1`3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`80003o103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?l0
00<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0U0?oo
o`00L`3oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo01X0
oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0H0?ooo`03
0000o`3oool0oooo00@0oooo203o000:0?ooo`030?l0003oool0oooo01D0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`08
0?l0003oool0oooo0?ooo`3o0000003o0?ooo`3o00020?ooo`030000o`3o
ool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`80003o
00<0oooo0?l0003oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool20?l000030?oo
o`3o0000oooo00H0oooo00<0003o0?ooo`3oool09P3oool007<0oooo00<0
003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3o
ool0oooo01T0oooo00<0o`000?ooo`3oool0103ooolK0?l000P0oooo4`3o
000?0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?l000020?l000030000o`3oool0o`000080oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo
00<0003o0?l0003oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo02H0oooo001c0?ooo`030000o`3o
ool0oooo01`0oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo0?oo
o`0P0?l001@0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?oo
o`060?ooo`P0o`001P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00<0oooo0P3o00030?ooo`050000o`3o0000o`000?l000000?l0
103oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00@0o`000?ooo`00
0?l0003o0P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?l000060?oo
o`030000o`3oool0oooo02L0oooo001c0?ooo`030000o`3oool0oooo01`0
oooo00<0o`000?ooo`3oool0303ooolA0?l001T0oooo00<0o`000?ooo`3o
ool0603oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo00h0
oooo1@3o00000`3oool0003o0?ooo`0<0?ooo`80003o0P3oool20?l00009
0?ooo`3o0000oooo0?ooo`000?l0o`000?ooo`3o0000003o00<0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo0P000?l70?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?l000@0oooo00<0
003o0?ooo`3oool09`3oool007<0oooo00<0003o0?ooo`3oool06@3ooolB
0?l000h0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool04`3oool3
0?l000h0oooo00<0003o0?l0003oool00`3oool02P3o0000oooo0000o`3o
0000oooo0000o`3oool0o`000?ooo`3o00040?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`030?ooo`040?l0003oool0oooo0000obX0oooo001c0?oo
o`030000o`3oool0oooo00L0oooo4P3o00030?ooo`030?l0003oool0oooo
01X0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0H0?oo
o`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool0503oool00`00
0?l0oooo0?l000030?l000/0oooo0P000?l30?ooo`@0o`0000@0oooo0000
o`3oool0oooo0P3o00030?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0000o`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030?l000000?l0oooo02X0oooo001c0?ooo`030000o`3o0000o`00
00L0o`005@3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo
01T0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0F0?oo
o`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0103oool30?l0
00P0oooo00<0o`000?ooo`000?l00P000?l20?ooo`<0003o0P3oool20?l0
00040?ooo`3o0000oooo0000o`D0oooo00<0o`000?ooo`3oool00`3oool0
10000?l0oooo0?ooo`3oool20000o`030?ooo`3o0000oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo02T0oooo001c0?ooo`030000o`3oool0oooo01`0oooo00<0o`00
0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0
oooo01P0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0C
0?ooo`030000o`3oool0oooo00L0oooo0P3o00050?ooo`030?l0003oool0
oooo00<0oooo0`000?l30?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?l0003oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0:P3oool0
07<0oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0J0?oo
o`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0603oool00`00
0?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?oo
o`3oool02@3oool30?l00080oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`020?l000<0oooo00<0003o0?ooo`3o00000`3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000000
o`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool0:`3oool007@0oooo00<0003o0?ooo`3o
ool06`3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo01X0
oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0303oool60?l000<0
oooo103o00040?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0?l00006
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P000?l3
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0[0?ooo`00M03oool00`000?l0oooo0?ooo`0K0?oo
o`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool06@3oool00`3o
0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo00d0oooo2@000?l00`3o
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool00P3oool40?l00003000000000?l0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0000o`070?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0;03oool007@0
oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0K0?ooo`03
0000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool03`3ooolH0000o`T0
oooo40000?l60?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool01P3oool010000000003o0?ooo`3oool20000o`D0oooo00<0o`000?oo
o`3o0000103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo0P000?l70?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool0;@3oool007@0oooo00<0003o0?ooo`3oool0703oool00`3o0000
oooo0?ooo`0J0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3o
ool00`3oool<0000o`P0oooo00<0003o0?ooo`3oool05P3oool00`3o0000
oooo0?ooo`0=0?ooo`T0003o3@3oool00`3o0000oooo0?ooo`060?ooo`04
000000000?l0oooo0000o`H0oooo00D0o`000?ooo`3oool0oooo0?l00002
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool3
0000o`D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0]
0?ooo`00M03oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo
01X0oooo00<0003o0?ooo`3oool03`3oool@0000oa@0oooo00<0003o0?oo
o`3oool05P3oool00`3o0000oooo0?ooo`0B0?ooo`040000o`3oool0oooo
0?ooo`/0003o0P3oool00`3o0000oooo0?ooo`040?ooo`D0003o1P3oool0
0`3o0000oooo0?ooo`030?ooo`030?l0003oool0003o00H0oooo00<0o`00
0?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool20000o`80oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0^0?ooo`00M03oool0
0`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo01X0oooo00<0003o
0?ooo`000?l03`000?l:0?ooo`030?l0003oool0oooo01L0oooo00<0003o
0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0
oooo00`0oooo2@000?l20?ooo`030000003oool0003o00@0oooo0P3o0007
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3o0000oooo00P0oooo00<0003o
0?ooo`3oool0;`3oool007@0oooo00<0003o0?ooo`3oool0703oool00`3o
0000oooo0?ooo`0;0?oooa40003o6P3oool00`3o0000oooo0?ooo`0G0?oo
o`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool04P3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00H0oooo00<000000?oo
o`000?l00P3oool20?l000L0oooo0P000?l00`3oool0o`000?ooo`030?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo0300oooo001d0?ooo`03
0000o`3oool0oooo01T0oooo4@000?l?0?ooo`030000o`3oool0oooo01T0
oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo0180oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`060?ooo`030000003oool0oooo0080o`00203oool01@000?l0
oooo0?ooo`3oool0o`0000<0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0003o00H0oooo00<0003o0?oo
o`3oool0<@3oool007@0oooo00<0003o0?ooo`3oool01`3ooolB0000o`<0
oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0I0?ooo`03
0?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool05P3oool00`3o0000
oooo0?ooo`0B0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool01P3oool010000000o`000?l000000?l70?ooo`80003o1@3oool00`3o
0000oooo0?l000080?ooo`030000o`3oool0oooo00D0oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`030000o`3oool0oooo0380oooo001d0?oo
o`X0003o5@3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo
01T0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0F0?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`030?ooo`@0o`000`3oool00`000?l0oooo0?ooo`020?oo
o`80003o1`3oool20?l000P0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l0=03oool0
07@0oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0J0?oo
o`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool05`3oool00`00
0?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool0103oool@0?l000<0oooo00D000000?ooo`3oool0oooo0000o`02
0?ooo`80003o203oool0103o0000oooo0?ooo`3o00060?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0000
o`0e0?ooo`00M03oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0
oooo01X0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo00@0oooo;@3o000:0?ooo`030?l0003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool20000o`T0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0d
0?ooo`00M03oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo
01X0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0C0?oo
o``0o`004@3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool01P3oool010000000oooo0?ooo`3oool2
0000o`P0oooo0P3o00060?ooo`040?l0003oool0oooo0000o`L0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0e0?ooo`00M03oool0
0`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo01X0oooo00<0003o
0?ooo`3oool06P3oool00`3o0000oooo0?ooo`030?ooo`l0o`001@3oool0
0`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo0180oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`060?ooo`040000003oool0
003o0000o`80oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`070?ooo`80003o1`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo03H0oooo001d0?ooo`030000o`3oool0oooo01`0oooo00<0o`00
0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0D0?ooo``0o`00503oool0
0`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo0180oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`050?ooo`<0003o103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?l0003oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo03L0oooo001e0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?oo
o`3oool06`3oool00`000?l0oooo0?ooo`0;0?ooo`P0o`001P3oool00`3o
0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
00@0003o00<0oooo0000003oool01@3oool00`000?l0oooo0?ooo`020?l0
00T0oooo00@0003o0?ooo`3oool0o`001@3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo03P0oooo001e0?ooo`030000o`3oool0oooo
01/0oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?l0000;0?l0
00h0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0E0?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool03@3oool50000
o`D0oooo00<000000?ooo`3oool0103oool00`000?l0o`000?l0000:0?oo
o`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0?l00009
0?ooo`030000o`3oool0oooo03T0oooo001e0?ooo`030000o`3oool0oooo
01/0oooo00<0o`000?ooo`3oool0403oool=0?l001X0oooo00<0o`000?oo
o`3oool05`3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo
0180oooo00<0003o0?ooo`3oool0103oool90000o`80oooo00<0o`000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`80o`0000<0003o0?oo
o`3oool01`3oool20000o`H0oooo00<0o`000?ooo`3o00002@3oool00`00
0?l0oooo0?ooo`0j0?ooo`00M@3oool00`000?l0oooo0?ooo`0L0?ooo`03
0?l0003oool0oooo00L0oooo203o000;0?ooo`030000o`3oool0oooo01T0
oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0E0?ooo`03
0?l0003oool0oooo00X0oooo3`000?l;0?ooo`030?l0003oool0oooo00D0
oooo00@000000?ooo`3oool0oooo0P3o00020?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo03/0oooo001e0?ooo`030000o`3oool0oooo01T0
oooo3@3o000C0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3o
ool05`3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00X0
003o2@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0
oooo00@000000?ooo`3o0000o`001@3oool00`000?l0oooo0?ooo`030?oo
o`80003o2@3oool00`3o0000oooo0?l000070?ooo`030000o`3oool0oooo
03`0oooo001e0?ooo`030000o`3oool0oooo00/0oooo3P3o00030?ooo`03
0?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool06@3oool00`3o0000
oooo0?ooo`0G0?ooo`030000o`3oool0oooo0180oooo1P000?lC0?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0103oool20?l000L0
oooo00@0003o0?ooo`3oool0oooo0P000?l:0?ooo`050?l0003oool0oooo
0?ooo`3o00001@3oool00`000?l0oooo0?ooo`0m0?ooo`00M@3oool00`00
0?l0oooo0?ooo`020?ooo`T0o`004@3oool00`3o0000oooo0?ooo`0J0?oo
o`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool05`3oool00`00
0?l0oooo0?ooo`080?ooo`X0003o103oool00`3o0000oooo0?ooo`0B0?oo
o`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0103o00000`00
0000oooo0?ooo`060?ooo`040000o`3oool0oooo0000o`/0oooo00<0o`00
0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o0400oooo001e
0?ooo`D0o`006P3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0
oooo01T0oooo00<0o`000?ooo`3oool05`3oool;0000o`h0oooo00<0o`00
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`0=0?ooo`D0o`00103oool0
0`000000oooo0?ooo`070?ooo`80003o2P3oool20?l000L0oooo00<0o`00
0?ooo`000?l0@@3oool007D0oooo00<0003o0?ooo`3oool0703oool00`3o
0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?oo
o`3oool03`3oool90000oaP0oooo00<0o`000?ooo`3oool04P3oool00`00
0?l0oooo0?ooo`090?ooo`@0o`000P3oool00`3o0000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo0`000?l:0?ooo`030?l0003oool0oooo
00L0oooo0P000?m20?ooo`00M@3oool00`000?l0oooo0?ooo`0L0?ooo`03
0?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool06@3oool00`3o0000
oooo0?ooo`040?ooo`/0003o2@3oool00`000?l0oooo0?ooo`0E0?ooo`03
0?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0103oool50?l000H0
oooo00<0o`000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`80
003o0`3oool00`000?l0oooo0?ooo`050?ooo`80o`002@3oool00`000?l0
oooo0?ooo`120?ooo`00MP3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0
003oool0oooo01/0oooo00<0003o0?ooo`3oool04`3oool<0000oa@0oooo
00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0C0?ooo`H0o`00
303oool00`3o0000oooo0?ooo`030?ooo`030000003oool0oooo00<0003o
1P3oool00`000?l0oooo0?ooo`020?ooo`80o`002P3oool00`000?l0oooo
0?ooo`130?ooo`00MP3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003o
ool0oooo01/0oooo00<0003o0?ooo`3oool02`3oool80000o`D0oooo00<0
o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003o
ool0oooo00d0oooo1P3o00000`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo00<0oooo00<000000000o`000?l02P3oool010000?l0oooo0?oo
o`3o000;0?ooo`030000o`3oool0oooo04@0oooo001f0?ooo`030000o`3o
ool0oooo01/0oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?oo
o`030?ooo`P0003o3P3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3o
ool0oooo01D0oooo00<0o`000?ooo`3oool01`3oool60?l000H0oooo00<0
003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`020?ooo`80003o303o
ool00`000?l0o`000?l0000;0?ooo`030000o`3oool0oooo04D0oooo001f
0?ooo`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool0603oool8
0000oaH0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0E
0?ooo`040?l0003oool0oooo0?ooo`H0o`00303oool00`000?l0oooo0?oo
o`0@0?ooo`060?l0003oool0003o0000o`3oool000002`3oool20?l00003
0000o`3oool0oooo00P0oooo0P000?m80?ooo`00MP3oool00`000?l0oooo
0?ooo`0L0?ooo`030?l0003oool0oooo00l0oooo2@000?l20?ooo`030000
o`3oool0oooo01T0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo
0?ooo`0C0?ooo`H0o`004P3oool00`000?l0oooo0?ooo`0?0?ooo`<0003o
0`3oool00`000000oooo0?ooo`070?ooo`80o`000P3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo04P0oooo001f0?ooo`030000o`3o
ool0oooo01`0oooo00<0o`000?ooo`3oool01`3oool80000o`/0oooo00<0
003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3o
ool0oooo00`0oooo1`3o00030?ooo`030?l0003oool0oooo0180oooo00<0
003o0?ooo`3oool0303oool30000o`80oooo00D0o`000?ooo`3oool0oooo
000000070?ooo`80o`001@3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo04T0oooo001f0?ooo`030000o`3oool0oooo01`0oooo00<0
o`000000o`000?l01`000?lC0?ooo`030000o`3oool0oooo01X0oooo00<0
o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`040?ooo`P0o`002P3o
ool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00P0oooo1000
0?l50?ooo`050?l0003oool0oooo0?ooo`0000001@3oool20?l000P0oooo
00<0003o0?ooo`3oool00P3oool20000od`0oooo001f0?ooo`030000o`3o
ool0oooo01@0oooo2@000?lL0?ooo`030000o`3oool0oooo01X0oooo00<0
o`000?ooo`3oool05P3oool70?l00180oooo00<0o`000?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`030?ooo`@0003o2@3oool01@3o0000oooo0?oo
o`3oool0000000<0oooo0P3o000:0?ooo`050000o`3oool0oooo0?ooo`00
0?l0CP3oool007H0oooo00<0003o0?ooo`3oool01`3oool=0000o`P0oooo
00<0o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0
003oool0oooo00h0oooo203o00000`3oool0003o0?ooo`0F0?ooo`030?l0
003oool0oooo01<0oooo1P000?l>0?ooo`050?l0003oool0oooo0000003o
ool00P3o000=0?ooo`<0003oC`3oool007H0oooo2P000?lE0?ooo`030?l0
003oool0oooo01/0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo
0?ooo`070?ooo`L0o`002@3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0
003oool0oooo00l0oooo1@000?lC0?ooo`030?l0003oool0oooo0080o`00
3P3oool20000oe40oooo001f0?ooo`030000o`3oool0oooo01`0oooo00<0
o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003o
ool0o`0000L0o`00403oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003o
ool0oooo00/0oooo10000?l50?ooo`030000o`3oool0oooo0100oooo0`3o
00000`000000oooo0?ooo`0;0?ooo`80003oD`3oool007L0oooo00<0003o
0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0
oooo01@0oooo1`3o000I0?ooo`030000o`3oool0oooo01D0oooo00<0o`00
0?ooo`3oool01P3oool40000o`T0oooo00<0003o0?ooo`3oool03P3oool2
0?l000040?ooo`3o0000oooo000000/0oooo0P000?mE0?ooo`00M`3oool0
0`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo01/0oooo00<0003o
0?ooo`3oool0303oool80?l000D0oooo00<0o`000?ooo`3oool0603oool0
0`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00H0003o3@3oool0
0`000?l0oooo0?ooo`0;0?ooo`<0o`000`3oool00`3o0000oooo0000000:
0?ooo`030000o`3oool0oooo05D0oooo001g0?ooo`030000o`3oool0oooo
01`0oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`040?oo
o`P0o`003@3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo
0180oooo1P000?lC0?ooo`030000o`3oool0oooo00T0oooo0P3o00070?oo
o`030?l000000000oooo00L0oooo0P000?mH0?ooo`00M`3oool00`000?l0
oooo0?ooo`0L0?ooo`030?l0003oool0oooo01T0oooo203o000E0?ooo`03
0?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0303oool60000o`<0
oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`050?ooo`<0
o`002@3oool00`3o000000000?ooo`050?ooo`80003oFP3oool007L0oooo
00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0@0?ooo`T0o`00
0P3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo01L0oooo
00<0003o0?ooo`3oool0203oool40000o`X0oooo00<0o`000?ooo`3oool0
4`3oool010000?l0oooo0?ooo`3oool40?l000d0oooo00<0o`000?ooo`3o
ool00P3oool20000oe`0oooo001g0?ooo`030000o`3oool0oooo01`0oooo
00<0o`000?ooo`3oool0203oool80?l000/0oooo00<0003o0?ooo`3oool0
6@3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo00<0oooo
1@000?l>0?ooo`030?l0003oool0oooo01<0oooo103o000A0?ooo`030?l0
003oool0oooo0080003oGP3oool007L0oooo00<0003o0?ooo`3oool0703o
ool00`3o0000oooo0?ooo`080?l001<0oooo00<0003o0?ooo`3oool06@3o
ool00`3o0000oooo0?ooo`0G0?ooo`H0003o4`3oool00`3o0000oooo0?oo
o`0?0?ooo`@0o`0000<0oooo0000o`3oool04P3oool30000of00oooo001g
0?ooo`030000o`3oool0oooo01T0oooo1P3o000K0?ooo`030000o`3oool0
oooo01T0oooo00<0o`000?ooo`3oool03`3oool90000oaP0oooo00<0o`00
0?ooo`3oool0303oool30?l000D0oooo00<0003o0?ooo`3oool03`3oool2
0000o`030000003oool0oooo0600oooo001g0?ooo`030000o`3oool0oooo
01<0oooo1P3o00030?ooo`030?l0003oool0oooo01/0oooo00<0003o0?oo
o`3oool06@3oool00`3o0000oooo0?ooo`090?ooo`H0003o203oool00`00
0?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo00T0oooo0`3o00080?oo
o`030000o`3oool0oooo00d0oooo0P000?l20?ooo`030000003oool0oooo
0600oooo001g0?ooo`030000o`3oool0oooo00/0oooo203o00090?ooo`03
0?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool06@3oool00`3o0000
oooo0?ooo`040?ooo`D0003o3`3oool00`000?l0oooo0?ooo`0E0?ooo`03
0?l0003oool0oooo00H0oooo0`3o000<0?ooo`030000o`3oool0oooo00X0
oooo0P000?l40?ooo`030000003oool0oooo0600oooo001h0?ooo`030000
o`3oool0oooo0080oooo203o000A0?ooo`030?l0003oool0oooo01/0oooo
00<0003o0?ooo`3oool06@3oool00`3o0000oooo0000o`040000oa@0oooo
00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`020?ooo`@0o`00
3`3oool00`000?l0oooo0?ooo`080?ooo`80003o1P3oool00`000000oooo
0?ooo`1P0?ooo`00N03oool50?l001T0oooo00<0o`000?ooo`3oool06`3o
ool00`000?l0oooo0?ooo`0D0?ooo`L0003o6@3oool00`000?l0oooo0?oo
o`0F0?ooo`@0o`004`3oool00`000?l0oooo0?ooo`050?ooo`<0003o203o
ool00`000000oooo0?ooo`1P0?ooo`00N03oool00`000?l0oooo0?ooo`0L
0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool0303oool8
0000o`D0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0B
0?ooo`D0o`005P3oool00`000?l0oooo0?ooo`020?ooo`<0003o2`3oool0
0`000000oooo0?ooo`1P0?ooo`00N03oool00`000?l0oooo0?ooo`0L0?oo
o`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool0103oool70000
o`h0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0<0?oo
o`D0o`00103oool00`3o0000oooo0?ooo`0E0?ooo`040000o`3oool0003o
0000o`h0oooo00<000000?ooo`3oool0H03oool007P0oooo00<0003o0?oo
o`3oool0703oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0003o
00@0003o5@3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo
00P0oooo103o00090?ooo`030?l0003oool0oooo01@0oooo0`000?l@0?oo
o`030000003oool0oooo0600oooo001h0?ooo`030000o`3oool0oooo01`0
oooo00<0o`000?ooo`3oool05`3oool60000oaX0oooo00<0o`000?ooo`3o
ool0603oool00`000?l0oooo0?ooo`030?ooo`D0o`003P3oool00`3o0000
oooo0?ooo`0?0?ooo`@0003o4`3oool00`000000oooo0?ooo`1P0?ooo`00
N@3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo0100oooo
1`000?l40?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0
603oool00`000?l0o`000?l000030?l001<0oooo00<0o`000?ooo`3oool0
2`3oool40000oaL0oooo00<000000?ooo`3oool0H03oool007T0oooo00<0
003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`070?ooo`P0003o303o
ool00`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo01<0oooo1@3o
00000`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00L0oooo1000
0?lK0?ooo`030000003oool0oooo0600oooo001i0?ooo`030000o`3oool0
oooo01`0oooo00<0o`000?ooo`3oool01`000?lD0?ooo`030000o`3oool0
oooo01T0oooo00<0o`000?ooo`3oool03@3oool60?l000D0oooo00<0003o
0?ooo`3oool05@3oool00`3o0000oooo0?ooo`030?ooo`@0003o7`3oool0
0`000000oooo0?ooo`1P0?ooo`00N@3oool00`000?l0oooo0?ooo`0I0?oo
o`H0003o6`3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo
00P0oooo1@3o000;0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?oo
o`000?l00P000?lS0?ooo`030000003oool0oooo0600oooo001i0?ooo`03
0000o`3oool0oooo01<0oooo1P000?l30?ooo`030?l0003oool0oooo01/0
oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`030?ooo`D0
o`00403oool00`000?l0oooo0?ooo`0D0?ooo`@0003o9P3oool00`000000
oooo0?ooo`1P0?ooo`00N@3oool00`000?l0oooo0?ooo`0;0?ooo`P0003o
2P3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo01T0oooo
1P3o000E0?ooo`030000o`3oool0oooo0140oooo0`000?lZ0?ooo`030000
003oool0oooo0600oooo001i0?ooo`030000o`3oool0oooo0080oooo2@00
0?lB0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool0503o
ool70?l001T0oooo00<0003o0?ooo`3oool03@3oool40000obd0oooo00<0
00000?ooo`3oool0H03oool007T0oooo1@000?lK0?ooo`030?l0003oool0
oooo01X0oooo00<0003o0?ooo`3oool0303oool80?l000H0oooo00<0o`00
0?ooo`3oool05`3oool00`000?l0oooo0?ooo`090?ooo`@0003o<@3oool0
0`000000oooo0?ooo`1P0?ooo`00N@3oool00`000?l0oooo0?ooo`0M0?oo
o`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool01@3oool70?l0
00h0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`040?oo
o`D0003o=@3oool00`000000oooo0?ooo`1P0?ooo`00N@3oool00`000?l0
oooo0?ooo`0M0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3o
ool01@3o000E0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`00
0?l00`000?lj0?ooo`030000003oool0oooo0600oooo001j0?ooo`030000
o`3oool0oooo01`0oooo00<0o`000?ooo`3oool05`3oool60?l001/0oooo
00<0o`000?ooo`3oool05@3oool40000och0oooo00<000000?ooo`3oool0
H03oool007X0oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo0?oo
o`0B0?ooo`D0o`00103oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003o
ool0oooo0140oooo10000?m20?ooo`030000003oool0oooo0600oooo001j
0?ooo`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool0303oool6
0?l000T0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0=
0?ooo`@0003oAP3oool00`000000oooo0?ooo`1P0?ooo`00NP3oool00`00
0?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo00H0oooo1P3o000?0?oo
o`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3oool02@3oool40000
odX0oooo00<000000?ooo`3oool0H03oool007X0oooo00<0003o0?ooo`3o
ool0703oool0103o0000oooo0?ooo`3oool50?l001D0oooo00<0003o0?oo
o`3oool06P3oool00`3o0000oooo0?ooo`040?ooo`D0003oAP3oool20000
00H0oooo00<000000?ooo`3oool0H03oool007/0oooo00<0003o0?ooo`3o
ool06@3oool60?l001/0oooo00<0003o0?ooo`3oool06P3oool00`3o0000
003o0000o`030000odX0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`1P0?ooo`00N`3oool00`000?l0oooo0?ooo`0C0?ooo`H0
o`000`3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo01H0
oooo1@000?mA0?ooo`030000003oool0oooo00@0oooo0P00001Q0?ooo`00
N`3oool00`000?l0oooo0?ooo`0=0?ooo`H0o`002@3oool00`3o0000oooo
0?ooo`0K0?ooo`030000o`3oool0oooo0180oooo10000?mG0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0H03oool007/0oooo00<0
003o0?ooo`3oool01`3oool60?l000l0oooo00<0o`000?ooo`3oool06`3o
ool00`000?l0oooo0?ooo`0>0?ooo`@0003oF03oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo0600oooo001k0?ooo`040000o`3o
ool0oooo0?ooo`H0o`005@3oool00`3o0000oooo0?ooo`0K0?ooo`030000
o`3oool0oooo00X0oooo10000?mM0?ooo`8000001P3oool00`000000oooo
0?ooo`1P0?ooo`00N`3oool40?l001`0oooo00<0o`000?ooo`3oool06`3o
ool00`000?l0oooo0?ooo`040?ooo`D0003oJ@3oool00`000000oooo0?oo
o`1P0?ooo`00O03oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0
oooo01/0oooo00<0003o0?ooo`000?l010000?m^0?ooo`030000003oool0
oooo0600oooo001l0?ooo`030000o`3oool0oooo01`0oooo00<0o`000?oo
o`3oool05`3oool60000og<0oooo00<000000?ooo`3oool0H03oool007`0
oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0B0?ooo`D0
003oN@3oool00`000000oooo0?ooo`1P0?ooo`00O03oool00`000?l0oooo
0?ooo`0L0?ooo`030?l0003oool0oooo00`0oooo1P000?mn0?ooo`030000
003oool0oooo0600oooo001l0?ooo`030000o`3oool0oooo01d0oooo00<0
o`000?ooo`3oool01@3oool60000oh@0oooo00<000000?ooo`3oool0H03o
ool007`0oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`05
0000ohX0oooo00<000000?ooo`3oool0H03oool007`0oooo00<0003o0?oo
o`3oool06P3oool60000ohl0oooo00<000000?ooo`3oool0H03oool007`0
oooo00<0003o0?ooo`3oool0503oool60000oiD0oooo00<000000?ooo`3o
ool0H03oool007`0oooo00<0003o0?ooo`3oool03P3oool60000oi/0oooo
00<000000?ooo`3oool0H03oool007`0oooo00<0003o0?ooo`3oool0203o
ool60000oj40oooo00<000000?ooo`3oool0H03oool007d0oooo00@0003o
0?ooo`3oool0oooo1P000?nW0?ooo`030000003oool0oooo0600oooo001m
0?ooo`@0003o[@3oool00`000000oooo0?ooo`1P0?ooo`00o`3oool_0?oo
o`030000003oool0oooo0600oooo003o0?ooobl0oooo00<000000?ooo`3o
ool0H03oool00?l0oooo;`3oool00`000000oooo0?ooo`1P0?ooo`00o`3o
ool_0?ooo`030000003oool0oooo0600oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{401, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.85",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/schwarzchristoffel/\
SchwarzChristoffelFigures/mat1185.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  The region with ",
  Cell[BoxData[
      RowBox[{\(x\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 1\)}]]],
  " and ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(\[Pi]\/2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(-\[Pi]\)}]}]]],
  "."
}], "Text"],

Cell[TextData[{
  "Solution.  The exterior angles are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(\[Pi]\/2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(-\[Pi]\)}]}]]],
  ",  and the formula for the derivative ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " is  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z - 
                  0)\)\^\(\(-\(\[Pi]\/2\)\)/\[Pi]\)\) \((z - \
1)\)\^\(\(-\((\(-\[Pi]\))\)\)/\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ \
\(z\^\(-\(1\/2\)\)\) \((z - 1)\)\^1\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ \
\(z\^\(-\(1\/2\)\)\) \((z - 1)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \((z\^\(1\/2\)\  - \ 
              z\^\(-\(1\/2\)\))\)\)\)\)}]],
  " \nintegrate and get \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ B\ \  + \ \ A\ \((\(2\/3\) z\^\(3/2\)\  - \ 
                2\ z\^\(1\/2\))\)\)],
    AspectRatioFixed->True],
  "\n\t\t\t\nuse the conditions  ",
  Cell[BoxData[
      \(f \((0)\)\  = \ 0\)]],
  ",  ",
  Cell[BoxData[
      \(f \((1)\) = \[ImaginaryI]\)]],
  "  and solve the resulting system for ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["B",
    FontFamily->"Courier New"],
  ".  The desired result is\n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ \(\(-\[ImaginaryI]\)\/2\) \(z\^\(1\/2\)\) \((z - 
              3)\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Enter the formula ",
  Cell[BoxData[
      \(\(f'\)[z]\)],
    AspectRatioFixed->True],
  " and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f1, A, B, z, F];\)\ \), "\n", 
    \(\(f1[z_]\  = \ \ A \((z\^\(1\/2\) - z\^\(-\(1\/2\)\))\);\)\ \), "\n", 
    \(\(f[z_]\  = \ 
        B\  + \ \[Integral]A \((z\^\(1\/2\) - 
                  z\^\(-\(1\/2\)\))\) \[DifferentialD]z;\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = B + \[Integral] \>", 
        f1[z], "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
This is one, formula for the integral.   However, we will use the following \
form of the integral to continue the computations.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(F[z_]\  = \ 
        B\  + \ A\ \((\(-2\)\ \@z + \(2\ z\^\(3/2\)\)\/3)\);\)\ \), "\n", 
    \(\(Print["\<F[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(eq1\  = \ F[0]\  \[Equal] \ 0;\)\ \), "\n", 
    \(\(eq2\  = \ F[1]\ \  \[Equal] \ \[ImaginaryI];\)\ \), "\n", 
    \(\(solset\  = \ Solve[{eq1, eq2}, {A, B}];\)\ \), "\n", 
    \(\(f[z_]\  = \ 
        ReplaceAll[F[z], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \), "\n", 
    \(\(Print[eq1];\)\ \), "\n", 
    \(\(Print[eq2];\)\ \), "\n", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[
    \(\(\(\(f[
          z_] = \(\(-\[ImaginaryI]\)\/2\) \(z\^\(1\/2\)\) \((z - 
              3)\);\)\ \[IndentingNewLine]
    \(Needs["\<Graphics`Colors`\>"];\)\ \[IndentingNewLine]
    \(Needs["\<Graphics`ComplexMap`\>"];\)\ \[IndentingNewLine]
    \(CartesianMap[f, {\(-3\), 4, 0.5}, {0.00001, 2.00001, 0.2}, 
        PlotStyle \[Rule] {Blue, 
            Red}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-4\), 2, 2], 
            Range[0, 3, 3]}];\)\ \ \[IndentingNewLine]
    \(Print["\<The image of the upper half plane Im[z] > 0 under the \
mapping\>"];\)\ \[IndentingNewLine]
    \(Print["\<w = f[z] = \>", f[z]];\)\)\(\ \)\)\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Schwarz Christoffel formula to show that  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ 
          B\  + \ A\ \(\[Integral]\(\(\(\ \)\(1\)\)\/\(\(\((z + 
                                1)\)\^\(2\/3\)\) \((z - 1)\)\^\(2\/3\)\)\) \
\[DifferentialD]z\)\)\)],
    AspectRatioFixed->True],
  "  will map the upper-half-plane onto an equilateral triangle. \nHint: For \
convenience we have chosen  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 1\)}]]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009h0000[b000`400?l0
0000o`00003oo`3ooooo0?ooogX0oooo003o0?ooool0ooooNP3oool00?l0
ooooo`3ooomj0?ooo`00o`3ooooo0?ooogX0oooo003o0?ooool0ooooNP3o
ool00?l0ooooo`3ooomj0?ooo`00o`3ooooo0?ooogX0oooo001T0?ooo`<0
0000803oool200000240oooo1000000P0?ooo`D00000@03oool5000001l0
oooo1000000Q0?ooo`8000008P3oool3000003D0oooo1@00002V0?ooo`D0
0000403oool006D0oooo00<000000?ooo`3oool07P3oool010000000oooo
0?ooo`00000P0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0240
oooo00@000000?ooo`3oool000008P3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0403oool00680
oooo1@00000Q0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0N0?ooo`D0
0000=`3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0100
oooo001L0?ooo`@000000P3oool010000000oooo0?ooo`00000J0?ooo`@0
00001@3oool00`000000oooo0?ooo`0H0?ooo`@00000103oool00`000000
oooo0?ooo`0I0?ooo`@00000103oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0M0?ooo`040000003oool0oooo00000300oooo100000040?oo
o`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0403oool006<0
oooo00<000000?ooo`000000803oool010000000oooo0?ooo`00000P0?oo
o`040000003oool0oooo00000280oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0O0?ooo`040000003oool0oooo00000200oooo00@0
00000?ooo`3oool00000803oool00`000000oooo0000000h0?ooo`030000
003oool0oooo0:P0oooo00<000000?ooo`3oool0403oool006@0oooo0P00
000Q0?ooo`8000008P3oool200000280oooo0P0000130?ooo`8000008P3o
ool200000280oooo0P00000R0?ooo`800000=`3oool200000:T0oooo0P00
000B0?ooo`00o`3ooooo0?oooa00oooo00<000000?ooo`3oool0I`3oool0
0?l0ooooo`3oool@0?ooo`030000003oool0oooo06L0oooo003o0?ooool0
oooo403oool00`000000oooo0?ooo`1W0?ooo`00o`3ooooo0?oooa00oooo
00<000000?ooo`3oool0I`3oool00?l0oooo]03oool400000:l0003o1000
000>0?ooo`00E@3oool60000o`030?l000000?l0003o0480003o00<0o`00
0000o`000?l07P000?l20?l001@0003o00<0o`000000o`000?l03`000?l0
0`3o0000003o0000o`0=0000o`030?l000000?l0003o00l0003o00<0o`00
0000o`000?l04`000?l00`3o0000003o0000o`0N0000o`030?l000000?l0
003o0480003o00<0o`000000o`000?l010000?lY0?ooo`03000000000?l0
003o0380oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0<03oool20000o`030000003oool0oooo0100oooo001K0?oo
o`030?l0003oool0oooo00<0oooo00<000000?ooo`3oool08@3oool00`00
0?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<0o`000?ooo`3oool0603oool00`00
0?l0oooo0?ooo`0P0?ooo`030000003oool0oooo00@0oooo00<0o`000?oo
o`3oool0;P3oool010000?l0oooo0000o`000?l`0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo02h0oooo0P000?l0
0`3oool0003o0?ooo`0B0?ooo`00F`3oool00`3o0000oooo0?ooo`030?oo
o`030000003oool0oooo0240oooo00<0003o0?ooo`3oool0603oool00`3o
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`060?oo
o`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0803oool00`00
0000oooo0?ooo`040?ooo`030?l0003oool0oooo02l0oooo00@0003o0?oo
o`3oool0003o;`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0]0?ooo`040000o`3oool0oooo0000oa@0oooo001K
0?ooo`030?l0003oool0oooo02L0oooo00<0003o0?ooo`3oool0603oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0W
0?ooo`030?l0003oool0oooo02l0oooo00@0003o0?ooo`3oool0oooo0P00
0?l]0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool04@3o
00000`000?l0o`000?l0000?0?l00080oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0[0?ooo`80003o0`3oool00`000?l0oooo0?oo
o`0B0?ooo`00F`3oool00`3o0000oooo0?ooo`0W0?ooo`030000o`3oool0
oooo01P0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01P3oool:
0?l000030000o`3o0000o`0000h0o`0000<0003o0?l0003o00003P3o0000
0`000?l0o`000?l0000;0?l000D0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo0100oooo00<0o`00
0?ooo`3oool05`3oool00`000?l0oooo0?ooo`0X0?ooo`030?l0003oool0
oooo0300oooo00<0003o0?ooo`3oool00P3oool20000ob/0oooo00<0o`00
0?ooo`3oool00`3oool80?l000030000o`3o0000o`0000P0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo0P3o00000`000?l0o`000?l000050?l000H0oooo00<0o`00
0?ooo`3oool0:@3oool20000o`@0oooo00<0003o0?ooo`3oool04`3oool0
05/0oooo00<0o`000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0H0?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`040?ooo`D0o`0000<0003o0?l0003o00001P3o00000`3o
ool0o`000?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`020?oo
o`D0o`0000<0003o0?l0003o00000`3o00050?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0G0?oo
o`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3oool0<03oool00`00
0?l0oooo0?ooo`040?ooo`80003o:@3oool00`3o0000oooo0?ooo`030?l0
00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`050?ooo`<0o`000`3oool00`3o0000oooo0?ooo`0W0?oo
o`80003o1P3oool00`000?l0oooo0?ooo`0C0?ooo`00F`3oool00`3o0000
oooo0?ooo`0X0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`050?ooo`d0o`001@3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool=0?l000L0
oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0G0?ooo`03
0000o`3oool0oooo02P0oooo00<0o`000?ooo`3oool0<@3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo02D0oooo103o000;0?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool02@3oool30?l002T0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0D0?ooo`00F`3oool00`3o0000oooo0?ooo`0X0?ooo`030000
o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0303oool40?l000030000
o`3o0000o`0000D0o`001`3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3o0000003o00h0003o00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`050?ooo`L0o`00
00<0003o0?l0003o00000P3o000>0?ooo`030?l0003oool0oooo01L0oooo
00<0003o0?ooo`3oool0:03oool00`3o0000oooo0?ooo`0b0?ooo`030000
o`3oool0oooo00D0oooo0P000?lR0?ooo`<0o`000P3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00@0oooo10000?l00`3o0000003o
0000o`0?0000o`040?l000000?l0003o0000o`H0oooo00<0003o0?ooo`3o
ool02`3oool60?l00280oooo0P000?l70?ooo`030000o`3oool0oooo01D0
oooo001K0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool0
5`3oool00`3o0000oooo0?ooo`040?ooo`P0o`00103oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`0>0000o`030?ooo`3o0000oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000003o0000o`0>0000o`030?l0
00000?l0003o00L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo0080oooo2P3o00030?ooo`030?l0
003oool0oooo01P0oooo00<0003o0?ooo`3oool09`3oool00`3o0000oooo
0?ooo`0c0?ooo`030000o`3oool0oooo00L0oooo0P000?lN0?ooo`80o`00
1@3oool00`3o0000oooo0?ooo`0:0?ooo`L0003o103oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00@0o`000?ooo`3oool0
oooo1`000?l=0?ooo`030?l0003oool0oooo00<0oooo103o000L0?ooo`80
003o2@3oool00`000?l0oooo0?ooo`0E0?ooo`00F`3oool00`3o0000oooo
0?ooo`0X0?ooo`030000o`3oool0oooo01H0oooo203o000<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`030?ooo`D0003o00<0o`000000o`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@000?l20?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`P0o`00
5P3oool00`000?l0oooo0?ooo`0W0?ooo`030?l0003oool0oooo03@0oooo
00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0H0?ooo`<0o`00
203oool00`3o0000oooo0?ooo`050?ooo`H0003o2@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool40000o`T0oooo00<0o`000?ooo`3oool0203oool00`3o0000oooo
0?ooo`0H0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0
5P3oool005/0oooo00<0o`000?ooo`3oool0:03oool00`000?l0oooo0?oo
o`0@0?ooo`H0o`000P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool00`3oool;0000o`D0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool80000o`H0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo0080oooo1P3o000@0?ooo`030000o`3o
ool0oooo02L0oooo00<0o`000?ooo`3oool0=03oool00`000?l0oooo0?oo
o`090?ooo`80003o5P3oool20?l000/0oooo00<0o`000?ooo`3oool00P3o
ool30000o`D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool010000?l0oooo0?ooo`3oool20000o`L0oooo00<0o`000?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0E0?ooo`80003o2`3oool00`000?l0oooo
0?ooo`0F0?ooo`00F`3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3o
ool0oooo00X0oooo1P3o00080?ooo`030?l0003oool0oooo0100oooo00<0
003o0?ooo`3oool02@3oool20000o`030?l000000?l0003o00<0003o1P3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool0103o0000oooo0?ooo`3oool40?l000030000
o`3o0000o`000080o`000`3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`030?ooo`H0003o00<0o`000000o`3oool02`3oool00`000?l0oooo
0?ooo`0@0?ooo`030?l0003oool0oooo00P0oooo1`3o00090?ooo`030000
o`3oool0oooo02L0oooo00<0o`000?ooo`3oool0=@3oool00`000?l0oooo
0?ooo`0:0?ooo`80003o4P3oool20?l000d0oooo00<0o`000?ooo`3oool0
0P000?l80?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1P3o00000`000?l0o`000?l000030?l000<0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`030?ooo`<0003o103oool00`3o0000oooo
0?ooo`0:0?ooo`80o`004`3oool20000o``0oooo00<0003o0?ooo`3oool0
5`3oool005`0oooo00<0o`000?ooo`3oool09`3oool00`000?l0oooo0?oo
o`040?ooo`H0o`003P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo00D0oooo10000?l20?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`030?l00000
0?l0o`0000X0o`00103oool00`000?l0oooo0?ooo`020?ooo`/0o`0000<0
003o0?l0003oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`000?l010000?l70?ooo`030000o`3o
ool0oooo0100oooo00<0o`000?ooo`3oool03`3oool60?l000<0oooo00<0
003o0?ooo`3oool09`3oool00`3o0000oooo0?ooo`0e0?ooo`030000o`3o
ool0oooo00`0oooo0P000?l?0?ooo`030?l0003oool0oooo00h0oooo00<0
o`000000o`3oool02@3oool00`000?l0oooo0?ooo`050?ooo`D0o`001P3o
ool00`000?l0oooo0?ooo`030?ooo`H0o`001P3oool00`000?l0oooo0?oo
o`070?ooo`<0003o00<0o`000?ooo`3oool03@3oool20?l000l0oooo0P00
0?l>0?ooo`030000o`3oool0oooo01L0oooo001L0?ooo`030?l0003oool0
oooo02P0oooo00<0003o0?l0003o00000`3o000D0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool01@000?l60?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool01P3oool90?l000030?ooo`000?l0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o0000203o0008
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool5
0000o`80oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0E
0?ooo`80o`0000@0003o0?l0003o0000o`009`3oool00`3o0000oooo0?oo
o`0f0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o0000oooo00/0oooo00<0
003o0?ooo`3o0000103o00030?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool0103o0000oooo0?ooo`3oool30?l000<0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000003o0000o`0?0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0H0?ooo`00G03oool00`3o0000oooo0?ooo`0T0?ooo`@0o`0000<0
003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0?0?ooo`@0003o303o
ool00`3o0000oooo0?ooo`080?ooo`040000o`3oool0oooo0?ooo`D0o`00
00<0oooo0?l0003oool01`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3o00020?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2P3oool40000oa00oooo00<0o`000?ooo`3oool0603oool010000?l0oooo
0?ooo`3oool40?l002<0oooo00<0o`000?ooo`3oool0=`3oool00`000?l0
oooo0?ooo`0=0?ooo`80003o2P3oool00`3o0000oooo0?ooo`0=0?ooo`80
003o00<0oooo0?l0003oool02P3oool00`3o0000003o0?l000080?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`<0o`0000<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`020000o`h0oooo00<0o`000?ooo`3oool0203oool20000o`l0
oooo00<0003o0?ooo`3oool06@3oool005`0oooo00<0o`000?ooo`3oool0
7`3oool50?l000@0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo
0?ooo`0:0?ooo`@0003o00<0oooo0000o`3oool03@3oool00`3o0000oooo
0?ooo`060?ooo`80o`0000@0003o0?l0003o0000o`001P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`80
o`0000<0003o0?l0003o00002@3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00@0003o303oool00`3o0000oooo0?ooo`0H0?ooo`03
0000o`3oool0oooo00D0oooo1@3o000N0?ooo`030?l0003oool0oooo03L0
oooo00<0003o0?ooo`3oool03`3oool20000o`L0oooo00<0o`000?ooo`3o
ool0303oool20000o`@0oooo00<0o`000?ooo`3oool01P3oool20?l00080
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool010000?l0
oooo0?l0003o00090?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`050?ooo`80003o4@3oool00`00
0?l0oooo0?ooo`0I0?ooo`00G03oool00`3o0000oooo0?ooo`0K0?ooo`@0
o`002@3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo00L0
oooo0`000?l50?ooo`030000o`3oool0oooo00`0oooo00@0o`000?ooo`3o
ool0oooo1@3o00020?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o0000003o
00h0003o00<0o`000000o`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3o00030?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0103oool30000
o`T0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0:0?oo
o`@0o`006P3oool00`3o0000oooo0?ooo`0h0?ooo`030000o`3oool0oooo
0100oooo0P000?l40?ooo`030?l0003oool0oooo00/0oooo0P000?l60?oo
o`030?l0003oool0oooo00@0oooo0P3o00040?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`000?l030000?l00`3oool0o`000?ooo`070?oo
o`040000o`3oool0oooo0?ooo`<0o`001P3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool00P3oool2
0000oa80oooo00<0003o0?ooo`3oool06P3oool005`0oooo00<0o`000?oo
o`3oool05P3oool50?l000d0oooo00<0003o0?ooo`3oool0603oool00`3o
0000oooo0?ooo`040?ooo`<0003o2@3oool00`000?l0oooo0?ooo`0;0?oo
o`@0o`00203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00D0oooo1`000?l00`3oool0o`000?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`000?l01P000?l70?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01@3oool40?l000h0oooo00<0003o0?oo
o`3oool01`3oool40000o`@0oooo00<0o`000?ooo`3oool06@3oool00`00
0?l0oooo0?ooo`0>0?ooo`D0o`00503oool00`3o0000oooo0?ooo`0i0?oo
o`030000o`3oool0oooo0180oooo00@0003o0?ooo`3oool0o`003@3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00<0o`001P3oool0
0`000?l0oooo0?ooo`040?ooo`80003o00<0o`000000o`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`040000o`3o0000003o0000o`D0oooo00<0
003o0?ooo`3oool01@3oool20?l000<0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`0<0?ooo`040?l0003oool0oooo0000oa@0oooo
00<0003o0?ooo`3oool06P3oool005d0oooo00<0o`000?ooo`3oool0403o
ool50?l001<0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0000
o`030000o``0oooo00<0003o0?ooo`3oool02@3oool30?l000/0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0o`000000o`060000o`030?ooo`00
0?l0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`000?l01P00
0?l00`3o0000003o0?ooo`060?ooo`030000o`3oool0oooo00T0oooo103o
000;0?ooo`030000o`3oool0oooo00/0oooo10000?l00`3o0000oooo0?oo
o`0H0?ooo`030000o`3oool0oooo01@0oooo103o000@0?ooo`030?l0003o
ool0oooo03X0oooo00<0003o0?ooo`3oool04P3oool20000o`d0oooo00<0
003o0?ooo`3oool02@3oool20?l000T0oooo00@0003o0?ooo`3oool0oooo
0`000?l20?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`030000o`80oooo00<0003o0?ooo`3oool0
1`3oool30?l000X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000003o
0000o`0D0?ooo`030000o`3oool0oooo01/0oooo001M0?ooo`030?l0003o
ool0oooo00`0oooo103o000H0?ooo`030000o`3oool0oooo01L0oooo00<0
003o0?l000000?l0403oool00`000?l0oooo0?ooo`060?ooo`<0o`000`3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo0P00
0?l00`3oool0o`000?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0000
o`020000o`@0oooo00<0003o0?ooo`3oool02@3oool0103o0000oooo0?oo
o`3oool40?l000L0oooo00<0003o0?ooo`3oool03`3oool00`3o0000003o
0000o`0H0?ooo`030000o`3oool0oooo01P0oooo103o000<0?ooo`030?l0
003oool0oooo03/0oooo00<0003o0?ooo`3oool04P3oool00`3o0000003o
0000o`0:0?ooo`030000o`3oool0oooo00P0oooo0`3o000:0?ooo`@0003o
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool30000o`X0oooo0`3o000:0?ooo`80003o
2P3oool20000oaD0oooo00<0003o0?ooo`3oool0703oool005d0oooo00<0
o`000?ooo`3oool01`3oool50?l001`0oooo00<0003o0?ooo`3oool0503o
ool30000o`030?ooo`3o0000oooo0140oooo00<0003o0?ooo`3oool00P3o
ool30?l000H0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`030000o`<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool00P3oool30000o`030?ooo`000?l0oooo00X0oooo00<0
o`000?ooo`3oool01@3oool30?l000<0oooo00<0003o0?ooo`3oool0403o
ool00`3o0000oooo0?ooo`030000oaD0oooo00<0003o0?ooo`3oool0703o
ool40?l000P0oooo00<0o`000?ooo`3oool0>`3oool00`000?l0oooo0?oo
o`0A0?ooo`050?l0003oool0oooo0?ooo`000?l02@3oool00`000?l0oooo
0?ooo`070?ooo`050?l0003oool0oooo0?ooo`3o0000203oool30000o`P0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00H0oooo0`000?l80?ooo`040?l0003oool0oooo0?l0
00/0oooo00<0003o0?ooo`3oool01P3oool010000?l0oooo0?ooo`3o000D
0?ooo`030000o`3oool0oooo01`0oooo001N0?ooo`030?l0003oool0oooo
0080oooo103o000R0?ooo`030000o`3oool0oooo0100oooo0`000?l40?oo
o`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool00P3o00090?oo
o`030?l0003oool0oooo00P0oooo10000?l70?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool70?l000030000o`3o0000o`00
00H0o`001P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo0`000?l90?ooo`030?l0003oool0oooo00T0oooo0`3o00000`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00@0oooo0`000?lA0?oo
o`030000o`3oool0oooo0240oooo103o00030?ooo`030?l0003oool0oooo
03d0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`020?oo
o`80003o1P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00<0oooo00<0o`000?ooo`3oool00`3oool20000o`80oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`040?l000030000o`3o0000o`00
0080o`000P3oool00`3o0000oooo0?ooo`050?ooo`040000o`3oool0oooo
0?ooo`80003o1@3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool0103oool20000o`<0oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0M0?ooo`00GP3oool50?l0
02H0oooo00<0003o0?ooo`3oool03@3oool30000o`P0oooo00<0o`000?oo
o`3oool03`3oool00`000?l0o`000?l0000<0?ooo`030?l0003oool0oooo
00@0oooo0`000?l00`3oool0003o0?ooo`080?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?l0003o00001P3o00060?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3o00001@3o00000`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`000?l00P000?l60?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?l0003o0000403oool00`3o
0000oooo0?ooo`070?ooo`<0003o3P3oool00`000?l0oooo0?ooo`0U0?oo
o`@0o`00?`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo
00@0oooo0P000?l30?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`020000o`D0oooo00<0003o0?oo
o`3oool00`3oool50?l000@0oooo00<0003o0?ooo`3oool00P3oool40?l0
00H0oooo00<0003o0?ooo`3oool00`3oool20000o`80oooo00<0o`000?oo
o`3oool0103oool00`3o0000oooo0?ooo`080?ooo`040000o`3oool0oooo
0?ooo`80003o1P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo01d0oooo001K0?ooo`@0o`00:P3oool00`000?l0oooo0?ooo`0;0?oo
o`80003o2`3oool00`3o0000oooo0?ooo`0=0?ooo`80o`0000<0oooo0000
o`3oool0303oool00`3o0000oooo0?ooo`040000o`@0oooo00<0003o0?oo
o`3oool01`3oool0103o0000oooo0?ooo`3oool40?l000030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?l0003o00000P3o0002
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool2
0000o`@0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`02
0?l000h0oooo00<0o`000?ooo`3oool02P3oool20000o``0oooo00<0003o
0?ooo`3oool0:03oool50?l003`0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`060?ooo`<0003o2P3oool00`3o0000oooo0?ooo`06
0?ooo`030?l000000?l0oooo00H0oooo00@0003o0?ooo`3oool0oooo0P3o
00020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?l000030?ooo`000?l0oooo00L0oooo00<0
003o0?l0003oool01`3oool00`3o0000oooo0?ooo`070?ooo`040000o`3o
ool0003o0000o`P0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`0N0?ooo`00E`3oool40?l000<0oooo00<0o`000?ooo`3oool0:@3o
ool00`000?l0oooo0?ooo`070?ooo`<0003o3@3oool00`3o0000oooo0?oo
o`0:0?ooo`<0o`000`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l00000
0?l0oooo00P0oooo00<0003o0?ooo`3oool01P3oool40?l000@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`@0o`00203oool00`000?l0oooo0?ooo`050?ooo`<0003o00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`030?ooo`80o`002`3o
ool00`3o0000oooo0?ooo`0=0?ooo`<0003o203oool00`000?l0oooo0?oo
o`0Y0?ooo`030?l0003oool0oooo0080oooo0`3o000i0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool0203oool30000o`P0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?l000080?ooo`030000o`3o
0000o`0000D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00<0o`000000o`3oool01`3o
ool00`3o0000003o0?ooo`080?ooo`030?l0003oool0oooo00H0oooo0P00
0?l:0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool07P3o
ool005D0oooo0P3o00070?ooo`030?l0003oool0oooo02T0oooo00<0003o
0?ooo`3oool0103oool30000oa40oooo00<0o`000?ooo`3oool01P3oool3
0?l000L0oooo00<0003o0?ooo`3oool02@3oool20000o`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool0103oool20?l000030?ooo`3o0000
oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`040?l0003oool0o`000?l000H0oooo00<0
003o0?ooo`3oool0203oool00`3o0000003o0000o`0;0?ooo`030000o`3o
ool0oooo00D0oooo0`3o00080?ooo`030?l0003oool0oooo0100oooo0`00
0?l50?ooo`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3oool01P3o
ool20?l003P0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo0080003o1P3oool00`3o0000oooo0?oo
o`050?ooo`040000o`3oool0oooo0?l000H0oooo0P3o00000`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0o`0000H0oooo
00<0o`000?ooo`3oool00P000?l80?ooo`030?l0003oool0oooo00<0oooo
0P000?l00`3oool0003o0?ooo`0:0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool07`3oool005l0oooo00<0o`000?ooo`3oool0:03o
ool010000?l0oooo0?ooo`3oool30000oa@0oooo00<0o`000?ooo`3oool0
103oool20?l000X0oooo00<0003o0?ooo`3oool01`3oool20000o`<0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`030?l000<0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00@0o`000?ooo`3oool0
oooo0`3o00020?ooo`030000o`3oool0oooo00P0oooo00@0o`000?ooo`3o
ool0oooo0P000?l80?ooo`030000o`3oool0oooo00T0oooo0P3o00050?oo
o`030?l0003oool0oooo01@0oooo0`000?l20?ooo`030000o`3oool0oooo
02P0oooo00<0o`000?ooo`3oool0@@3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool00P3oool0103o0000oooo0?ooo`3oool20?l000<0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`02
0?l000@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`06
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0803o
ool005l0oooo00<0o`000?ooo`3oool0:@3oool30000oaP0oooo00<0o`00
0?ooo`3oool00`3o000=0?ooo`030000o`3oool0oooo00@0oooo0P000?l5
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?l0003o00001P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0000o`000?l02`000?l00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool20?l000030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool00`3oool20000o`H0oooo00<0003o
0?ooo`3oool02`3oool20?l000<0oooo00<0o`000?ooo`3oool05`3oool3
0000obX0oooo00<0o`000?ooo`3oool0@@3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool2
0000o`030?ooo`3o0000oooo00H0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?l000050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0000o`000?l02@000?l00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00@0o`000?ooo`3oool0o`001P3oool00`000?l0oooo0?oo
o`050?ooo`040?l0003oool0003o0000o`D0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo0200oooo
001O0?ooo`030?l0003oool0oooo02H0oooo10000?lJ0?ooo`<0o`00403o
ool00`000?l0oooo0?ooo`020?ooo`80003o203oool00`3o0000oooo0?oo
o`050?ooo`80o`0000<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0003o00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l000000?l0003o00@0003o00<0
oooo0000o`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
0000o`0000L0oooo00<0o`000?ooo`3oool01P3oool20000o`<0oooo00<0
003o0?ooo`3oool03P3oool30?l001/0oooo00@0003o0?ooo`000?l0003o
:03oool00`3o0000oooo0?ooo`120?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0003o00@0003o00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0003o0000o`<0
oooo00<0003o0?ooo`3oool0103oool20?l000P0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0Q0?ooo`00
H03oool00`3o0000oooo0?ooo`0S0?ooo`80003o0`3oool00`000?l0oooo
0?ooo`0G0?ooo`<0o`004P3oool010000?l0oooo0000o`000?l:0?ooo`03
0?l0003oool0oooo0080oooo0`3o00030?ooo`030000o`3oool0oooo00H0
oooo00@0o`000?ooo`3oool0oooo1P000?l40?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`<0003o1@3oool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0oooo
0?ooo`80o`001@3oool00`3o0000oooo0?ooo`080?ooo`80003o00<0oooo
0000o`3oool04@3oool20?l001T0oooo00<0003o0?ooo`3oool00P3oool2
0000obD0oooo00<0o`000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0000o`020000o`<0oooo00<0003o0?ooo`3oool01P3oool2
0?l000L0oooo0P000?l50?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool0103o0000oooo0?ooo`3oool30000o`L0oooo0`3o
00070?ooo`030000o`3oool0oooo0080oooo0`000?l00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0Q0?ooo`00H03oool00`3o0000oooo0?ooo`0Q
0?ooo`80003o1P3oool00`000?l0oooo0?ooo`0D0?ooo`80o`000P3oool0
0`3o0000oooo0?ooo`0@0?ooo`80003o3@3oool0103o0000oooo0?l0003o
00060?ooo`030000o`3oool0oooo00H0oooo00@0o`000?ooo`000?l0003o
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0003o00<0oooo0?l0003oool01`3oool00`000?l0oooo
0?ooo`030?ooo`80o`000P3oool00`3o0000oooo0?ooo`0;0?ooo`80003o
4@3oool00`3o0000oooo0?ooo`020?l001L0oooo00<0003o0?ooo`3oool0
103oool20000ob<0oooo00<0o`000?ooo`3oool0A03oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`020?ooo`80003o00<0oooo0000o`3oool0
1P3oool0103o0000oooo0?ooo`3o00060?ooo`80003o1@3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool010000?l0oooo0000o`000?l40?ooo`050?l0003oool0oooo
0?ooo`3o00001`3oool010000?l0oooo0000o`000?l40?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo0280oooo001Q0?ooo`030?l0003oool0
oooo01h0oooo0P000?l80?ooo`030000o`3oool0oooo01<0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0=0?ooo`80003o00<0oooo
0000o`3oool0303oool20?l000T0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0o`000?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000003o0000o`06
0?ooo`030000o`3oool0oooo00H0oooo0`3o000=0?ooo`040000o`3oool0
003o0000o`l0oooo00<0o`000?ooo`3oool00P3oool20?l001@0oooo00<0
003o0?ooo`3oool01`3oool30000oal0oooo00<0o`000?ooo`3oool0A@3o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool0103o0000oooo0?oo
o`3oool20000o`80oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool08P3oool00640oooo
00<0o`000?ooo`3oool0703oool20000o`X0oooo00<0003o0?ooo`3oool0
4@3oool20?l000H0oooo00<0o`000?ooo`3oool02`3oool20000o`@0oooo
00<0003o0?ooo`3oool0203oool20?l000030?ooo`3o0000oooo00P0oooo
00<0003o0?ooo`3oool00`3oool20000o`030?ooo`3o0000oooo00H0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo0080003o103oool00`000?l0oooo
0?ooo`070?ooo`<0o`002`3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo00X0oooo0P000?lM0?ooo`030?l0
003oool0oooo04H0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool010000?l0oooo0000o`000?l50?ooo`030?l0003oool0oooo00<0
oooo00<0o`000?ooo`000?l0103oool00`000?l0oooo0?ooo`020?ooo`D0
o`0000<0003o0?l0003o00000P3o00040?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3o00001P3oool00`3o0000oooo0?ooo`020?ooo`<0
003o1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0S0?ooo`00
H@3oool00`3o0000oooo0?ooo`0J0?ooo`80003o3@3oool00`000?l0oooo
0?ooo`0>0?ooo`80o`002@3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01`3oool01@3o0000oooo
0?ooo`3oool0o`0000X0oooo00<0003o0?ooo`3oool00P000?l30?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080
oooo0P000?l00`3oool0003o0?ooo`090?ooo`030?l0003oool0oooo0080
o`002@3oool00`000?l0oooo0?ooo`030?ooo`80003o2`3oool00`3o0000
oooo0?ooo`060?ooo`80o`00403oool00`000?l0oooo0?ooo`0=0?ooo`80
003o6`3oool00`3o0000oooo0?ooo`170?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool0oooo0P000?l20?oo
o`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?l000<0oooo00@0003o0?ooo`3oool0oooo0P3o0003
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000000o`3oool01@3oool0
0`3o0000oooo0?ooo`020000o`<0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`0T0?ooo`00HP3oool00`3o
0000oooo0?ooo`0G0?ooo`80003o3`3oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo00T0oooo00<0o`000?ooo`3oool01`3oool20000
o`P0oooo00<0003o0?ooo`3oool0103oool20?l000D0oooo00<0o`000?oo
o`3oool01`3oool30000o`H0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`H0o`0000<0003o0?l0003o0000103o00050?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool20000
o`T0oooo00<0o`000?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`090?ooo`80o`003P3oool00`000?l0oooo0?ooo`0?0?oo
o`80003o603oool00`3o0000oooo0?ooo`180?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0o`000?ooo`060?ooo`030000o`3oool0o`0000D0oooo00<0003o0?l0
003o00000P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0o`00
0?ooo`3o0000o`000000o`060?ooo`040?l0003oool0oooo0000o`H0oooo
00<0o`000000o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo02@0oooo001R0?ooo`030?l0003o
ool0oooo01D0oooo0P000?lB0?ooo`030000o`3oool0oooo00X0oooo0P3o
000=0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool30000o`L0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0o`000?l000030?l000D0oooo00<0003o0?ooo`3oool00`3o
ool50?l000030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool010000?l0oooo0000o`000?l60?ooo`030?l0003oool0oooo00D0oooo
0P3o00040?ooo`030000o`3oool0oooo00P0oooo0P000?l70?ooo`030?l0
003oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0B0?ooo`80003o5P3oool00`3o0000oooo0?ooo`190?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`3o
00000`3oool20?l000050000o`3oool0oooo0?ooo`3o00000`3oool01@00
0?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?l0003oool00P3oool2
0?l000<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool09@3oool006<0oooo00<0o`000?ooo`3oool04P3oool20000
oaD0oooo00<0003o0?ooo`3oool01`3oool20?l00100oooo00<0o`000?oo
o`3oool00P3oool20000o``0oooo00<0003o0?ooo`3oool00P3o00090?oo
o`030?l0003oool0oooo00<0oooo0P000?l20?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool00P3oool20?l000030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo0080oooo00@0003o0?l0003o0000o`000`3oool0
0`3o0000oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l01@3o
ool00`3o0000oooo0?ooo`070?ooo`80o`000P3oool00`000?l0oooo0?oo
o`0:0?ooo`80003o103oool00`3o0000oooo0?ooo`0=0?ooo`80o`002P3o
ool00`000?l0oooo0?ooo`0D0?ooo`80003o4`3oool00`3o0000oooo0?oo
o`1:0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool0103o0000oooo0000o`000?l30?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3o00000P3oool01@000?l0oooo
0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000020?oo
o`030000o`3oool0oooo00<0o`001P3oool010000?l0oooo0?ooo`3oool2
0000o`030?ooo`3o0000oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`0U0?ooo`00H`3oool00`3o
0000oooo0?ooo`0@0?ooo`80003o5`3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool00P000?l?0?oo
o`030000o`3o0000oooo00/0oooo00<0o`000?ooo`3oool00P000?l50?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o00000P3o00020?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00@0003o0?oo
o`3oool0oooo0P3o00000`3oool0o`000?ooo`060?ooo`030000o`3oool0
oooo00<0oooo0P000?l20?ooo`030?l0003oool0oooo00X0oooo00<0o`00
0000o`3oool03P3oool010000?l0oooo0?ooo`3o000B0?ooo`80o`001`3o
ool00`000?l0oooo0?ooo`0G0?ooo`80003o4@3oool00`3o0000oooo0?oo
o`1;0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool01@3oool0103o0000oooo0?ooo`3oool30000o`L0oooo
00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`000080
oooo00@0003o0?ooo`3oool0o`000`3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo00@0oooo00@0003o0?ooo`000?l0003o0`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool09P3oool006@0oooo00<0o`000?oo
o`3oool03@3oool20000oaX0oooo00<0003o0?ooo`3oool00`3oool20?l0
01@0oooo00<0o`000000o`3oool0403oool00`3o0000003o0?ooo`0<0?oo
o`030?l000000?l0oooo00H0oooo00<0003o0?ooo`3oool0103oool30?l0
00H0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`040?ooo`80o`001`3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3o0000oooo00`0oooo00<0003o0?l0003oool03`3oool20000
o`030?l0003oool0oooo0180oooo0P3o00050?ooo`030000o`3oool0oooo
01T0oooo0P000?l>0?ooo`030?l0003oool0oooo04`0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo0P000?l50?ooo`030?l0003oool0o`00
00<0oooo00D0003o0?ooo`3oool0003o0?l000050000o`040?l0003oool0
oooo0000o`@0oooo00<0o`000?ooo`3o00001@3oool20000o`H0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo02H0oooo001T0?ooo`030?l0003oool0
oooo00/0oooo0P000?lM0?ooo`030000o`3oool0oooo0080o`005P3oool0
0`000?l0o`000?ooo`0?0?ooo`030?l0003oool0003o00d0oooo00<0o`00
0?ooo`3oool01`3oool010000?l0oooo0?ooo`3oool20?l00080oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3o
00040?ooo`030000o`3oool0oooo00L0oooo00<0o`000000o`3oool02P3o
ool010000?l0oooo0?ooo`3o000@0?ooo`030?l000000?l0oooo01D0oooo
00D0o`000?ooo`3oool0oooo0000o`0N0?ooo`80003o303oool00`3o0000
oooo0?ooo`1=0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo0080003o0P3oool01@3o0000oooo0?ooo`3oool0o`00
00<0oooo0P000?l0203oool0o`000?ooo`3oool0003o0?ooo`3o0000oooo
0`000?l30?ooo`050?l0003oool0oooo0?ooo`3o00000P3oool20000o`80
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool09`3oool006D0oooo00<0o`000?ooo`3oool0203oool20000ob00oooo
00<0003o0?l0003oool05P3oool010000?l0oooo0?ooo`3o000>0?ooo`05
0?l0003oool0oooo0?ooo`000?l02P3oool20000o`030?ooo`3o0000oooo
00P0oooo00<0003o0?l0003o0000103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80o`0000<0oooo0000
o`3oool0203oool0103o0000oooo0?ooo`000?l:0?ooo`050000o`3oool0
oooo0?ooo`3o00003P3oool0103o0000oooo0?ooo`000?lF0?ooo`80o`00
00<0003o0?ooo`3oool07`3oool20000o`T0oooo00<0o`000?ooo`3oool0
C`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
2`3o00030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`020?ooo`030000o`3o0000oooo00@0oooo
00@0o`000?ooo`000?l0003o0`3oool01@3o0000oooo0000o`3oool0o`00
0080oooo00D0003o0?ooo`000?l0oooo0?l000040?ooo`030?l000000?l0
003o00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`040000o`3oool0oooo0?ooo`/0o`001@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo02P0oooo001U0?ooo`030?l0003oool0
oooo00H0oooo0P000?lQ0?ooo`030?l000000?l0oooo01H0oooo00D0003o
0?ooo`3oool0oooo0?l0000=0?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0
1@3oool00`3o0000oooo0?ooo`050?ooo`030?l000000?l0oooo00L0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo
0?ooo`020?ooo`80003o5@3oool00`000?l0o`000?ooo`0R0?ooo`80003o
1`3oool00`3o0000oooo0?ooo`1?0?ooo`030000o`3oool0oooo00D0oooo
1`3o00000`3oool0003o0?ooo`040?ooo`040?l0003oool0oooo0?ooo`D0
o`00103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo0P000?l50?ooo`040?l0003oool0oooo0000o`80oooo00D0o`000?oo
o`000?l0oooo0?l000020?ooo`040000o`3oool0oooo0?l000D0oooo00<0
003o0?l0003oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo0080oooo1P3o00020?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3o00001@3o00080?ooo`030000o`3oool0oooo02P0oooo001V
0?ooo`030?l0003oool0oooo00<0oooo0P000?lR0?ooo`040?l0003oool0
oooo0000oa@0oooo0P000?l50?ooo`030?l0003oool0oooo00P0oooo0P3o
00070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0003o00H0oooo00<0
o`000?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0o`0000T0003o
00D0o`000?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3o00001P3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool04P3oool010000?l0oooo0?l0003o000S0?ooo`80003o103oool00`3o
0000oooo0?ooo`1A0?ooo`030000o`3oool0oooo0080oooo103o00060?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?l000040?l000D0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`020000o`80oooo00D0003o0?ooo`3o0000oooo0000o`02
0?ooo`070?l0003oool0003o0?ooo`3o0000oooo0000o`020?ooo`030?l0
003oool0003o0080oooo0P000?l20?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool40?l00080oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
0`3o00050?ooo`030000o`3oool0oooo02T0oooo001V0?ooo`040?l0003o
ool0oooo0?ooo`80003o8P3oool20?l000<0oooo00<0003o0?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0o`000?ooo`3oool0203oool010000?l0oooo0?ooo`3oool20000o`P0
oooo00<0o`000?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o
00H0oooo00<0o`000?ooo`3oool00`3oool40000o`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000003o0000o`3oool0
003o00D0oooo00<0o`000?ooo`3oool0103oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0o`000?ooo`3oool01P3oool20000o`<0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0280oooo0P000?l20?ooo`030?l0003o
ool0oooo0540oooo00<0003o0?ooo`3oool00P3o00030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo1P3o00000`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo0080oooo0P000?l30?ooo`040?l0003o
ool0003o0?ooo`80o`0000L0003o0?l0003oool0oooo0000o`3oool0o`00
00<0oooo0P000?l40?ooo`030?l0003oool0oooo00<0oooo00<0003o0?l0
003o0000103o00050?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`040?l0003oool0oooo
0?ooo`<0o`000P3oool00`000?l0oooo0?ooo`0Y0?ooo`00I`3oool00`3o
0000003o0000o`0S0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool03`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00@0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0000o`0;0?oo
o`040?l0003oool0oooo0?l000@0oooo00<0003o0?ooo`3oool0103oool0
103o0000oooo0?ooo`3oool30000o`@0oooo00D0o`000?ooo`3oool0oooo
0000o`030?ooo`040?l0003oool0oooo0?ooo`80003o103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00@0o`000?ooo`3o
ool0o`002`3oool00`000?l0oooo0000o`0;0?ooo`030?l0003oool0oooo
00D0oooo00<0o`000?ooo`3oool0203oool20000o`l0oooo00<0003o0?oo
o`3oool0103oool20?l002@0oooo00<0003o0?l0003oool0E03oool00`00
0?l0o`000?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool20?l000D0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`030?ooo`D0o`0000<0oooo0?l0003oool0103oool30000
o`80oooo00<0o`000?ooo`000?l00P3o00001P000?l0o`000?l000000?l0
oooo0?l00080oooo0`000?l50?ooo`030?l0003oool0o`0000@0o`001@3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0o`000000o`3oool0:`3oool006H0oooo00<0003o
0?l0003oool08`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00d0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool2
0?l000H0oooo00<0003o0?ooo`3oool0103oool00`3o0000003o0000o`03
0?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?oo
o`3oool0o`0000<0oooo00<0003o0?ooo`000?l00P000?l00`3oool0o`00
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo0P3o000=0?ooo`030000
o`3oool0oooo00/0oooo0P3o00040?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo0280oooo00<0o`000000o`3oool0E03oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00P3oool20000o`@0oooo103o00020?ooo`040000
o`3oool0oooo0?ooo`80003o00/0oooo0?l0003oool0003o0?l000000?l0
o`000000o`3oool0o`000?ooo`020000o`80oooo0P000?l00`3oool0o`00
0?l000030?l000@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0:`3oool006@0oooo0P000?l20?ooo`030?l0003o
ool0oooo01l0oooo0P3o000:0?ooo`030000o`3oool0oooo00/0oooo00<0
003o0?ooo`3oool0303oool0103o0000oooo0?ooo`3o000>0?ooo`030000
o`3oool0003o00`0oooo0P3o00070?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?l0003oool00`3oool01@000?l0oooo0?ooo`3oool0o`0000<0
oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo
0080oooo00<0o`000000o`3oool00`3oool00`000?l0oooo0?ooo`060?oo
o`80o`00303oool00`000?l0oooo0000o`0>0?ooo`040?l0003oool0oooo
0?l000l0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`08
0?ooo`80o`008@3oool00`3o0000oooo0?ooo`020000oe<0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`80o`00103oool00`000?l0oooo0?ooo`030?ooo`040?l0003oool0
oooo0?ooo`<0o`001@3oool01@000?l0oooo0?l000000?l0o`000080003o
00@0oooo0?l0003oool0003o1@3oool20?l000@0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0[0?ooo`00H`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo01d0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00h0oooo0P3o000>0?ooo`050000
o`3oool0oooo0?ooo`000?l02P3oool0103o0000oooo0?ooo`3o00070?oo
o`070000o`3oool0oooo0?ooo`000?l0oooo0?l000040?ooo`050000o`3o
ool0oooo0?ooo`3o00000`3oool010000?l0oooo0?ooo`3o00030?ooo`03
0000o`3oool0oooo00<0oooo00@0o`000?ooo`000?l0003o0P3oool00`00
0?l0oooo0?ooo`050?ooo`040?l0003oool0oooo0?l000X0oooo00D0003o
0?ooo`3oool0oooo0000o`0>0?ooo`80o`004@3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool07@3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0540oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3o0000o`000080o`0000@0
oooo0?l000000?l0oooo0P3o00020000o`050?l0003oool0003o0?l0003o
ool0103o00000`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0;03oool00640oooo0P000?l60?ooo`030?l0003oool0oooo01/0oooo
0P3o000>0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0
3`3oool20?l000h0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo
00D0003o0?ooo`3oool0oooo0?l000020?ooo`040000o`3oool0oooo0?l0
00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`80003o1`3oool01@3o0000oooo0?ooo`3oool0o`0000T0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<0?ooo`80o`004P3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool0703oool00`3o0000oooo0?ooo`040?ooo`80003oD@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool3
0?l00080003o00<0o`000000o`3o00000P000?l30?l000@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo02`0oooo001P0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool06@3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00D0oooo0P000?lA0?oo
o`030?l0003oool0oooo0080o`002`3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00D0o`000?oo
o`3oool0oooo0000o`030?ooo`040?l0003oool0oooo0000o`80oooo00@0
o`000?ooo`3oool0003o103oool00`3o0000oooo0?ooo`030?ooo`80003o
1P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
0P000?l60?ooo`030000o`3oool0oooo00T0oooo0P3o00020?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo01X0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`1?0?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool20?l000030?oo
o`000?l0003o03<0003o00<0oooo0?l0003oool0103oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo02d0oooo
001N0?ooo`80003o2P3oool00`3o0000oooo0?ooo`0H0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0@0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0003o00@0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?oo
o`3o00020?ooo`040000o`3oool0oooo0?l00080oooo00D0003o0?ooo`3o
ool0oooo0?l000050?ooo`040000o`3oool0oooo0000o`@0oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`02
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0@0?ooo`80o`006@3oool00`3o0000oooo0?ooo`09
0?ooo`80003oC`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`3o
ool:0000o`<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo1P3o00000`000?l0o`000000
o`040?l000@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`040000o`3oool0oooo0?ooo`X0003o0`3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`0]0?ooo`00G03oool20000o`d0oooo00<0
o`000?ooo`3oool05P3oool00`3o0000oooo0?ooo`0C0?ooo`050000o`3o
ool0oooo0?ooo`000?l04`3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool01@000?l0oooo
0?ooo`3oool0o`0000T0oooo00<0o`000?ooo`3oool00P000?l30?ooo`03
0000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`020?oo
o`<0o`0000<0003o0?l0003o00000`3oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030?l0003o
ool0oooo00L0oooo00@0o`000?ooo`3oool0003o2P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0
4@3oool01@000?l0oooo0?ooo`3oool0003o01D0oooo00<0o`000?ooo`3o
ool05P3oool00`3o0000oooo0?ooo`0;0?ooo`80003oCP3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool40000o`80oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00`3oool010000?l0oooo0?ooo`3oool30?l00080003o00<0o`000000
o`000?l00P3o00020000o`<0o`000`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0003o103oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0;P3oool005/0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0D0?ooo`030?l0003oool0oooo01D0oooo0`000?lC0?ooo`03
0?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`090?ooo`80003o00<0o`000?ooo`3oool02@3oool00`3o0000
003o0?ooo`050?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`3o
ool0003o103o00000`3oool0003o0?ooo`030?l000050000o`3oool0oooo
0?ooo`3o0000103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
o`0000/0oooo00<0o`000000o`3oool02`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool04@3oool3
0000oaL0oooo00<0o`000?ooo`3oool0503oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo04`0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080003o00<0oooo
0?l0003oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`D0o`000P3oool02`000?l0oooo0?l000000?l0o`000000o`3o0000
oooo0?l0003oool0003o0080oooo1@3o00040?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00H0o`000?ooo`000?l0003o0?ooo`00
0?l50?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0;`3o
ool005T0oooo0P000?lA0?ooo`030?l0003oool0oooo01<0oooo00<0o`00
0?ooo`3oool05`3oool20000oa80oooo00<0o`000?ooo`3oool0203oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0000o`3oool02P3oool00`000?l0o`000?ooo`060?ooo`030000o`3oool0
oooo0080oooo00@0o`000?ooo`3o0000003o0P3oool01@3o0000oooo0000
o`3oool0o`000080oooo00@0003o0?l0003o0000o`00103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00P0
oooo00<0o`000?ooo`3oool0403oool20000oaT0oooo00<0o`000?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`0?0?ooo`80003oC03oool00`000?l0
oooo0?ooo`030?ooo`040?l0003oool0oooo0?ooo`@0003o0`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`D0o`0000<0oooo0000
o`3oool00`3oool03@000?l0oooo0?l0003oool0003o0?l000000?l0o`00
0000o`3oool0o`000?ooo`000?l0103oool00`000?l0oooo0?l000040?l0
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0oooo10000?l3
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0;`3oool0
05P0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0A0?oo
o`030?l0003oool0oooo01L0oooo00@0003o0?ooo`3oool0003o403oool0
0`3o0000oooo0?ooo`0:0?ooo`050?l0003oool0oooo0?ooo`000?l03@3o
ool0103o0000oooo0000o`000?l90?ooo`040000o`3oool0o`000?l000H0
oooo00@0003o0?ooo`3oool0oooo0P3o00002@3oool0003o0?ooo`3oool0
o`000?ooo`000?l0oooo0?l000020?ooo`040000o`3oool0oooo0?l000<0
oooo00<0003o0?ooo`3oool0103oool20?l000030?ooo`000?l0oooo00P0
oooo0P000?l00`3oool0o`000?ooo`0<0?ooo`050000o`3oool0oooo0?oo
o`3o0000303oool00`3o0000oooo0?ooo`0>0?ooo`040000o`3oool0oooo
0000oaT0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo04X0oooo00<0003o0?ooo`3oool00P3oool0
103o0000oooo0000o`000?l20?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool0103o00050?ooo`080000o`3o
ool0003o0000o`3oool0o`000?ooo`000?l20?l000070000o`3o0000o`00
0000o`3oool0o`000?ooo`020000o`030?ooo`000?l0oooo00@0oooo0`3o
00030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00P000?l00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo0300oooo001F0?ooo`80003o5P3oool00`3o0000oooo0?ooo`0?
0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo0P3o0000
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080oooo0`000?l5
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?l000020?l00080oooo00T0003o0?ooo`3o0000oooo0000
o`3oool0o`000?ooo`000?l00P3oool01@3o0000oooo0?l0003oool0003o
00H0oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`<0003o103oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3o0000o`0000d0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo01L0oooo00<0o`000?ooo`3oool03`3oool00`3o0000oooo0?ooo`0D
0?ooo`80003oBP3oool00`000?l0oooo0?ooo`020?ooo`80003o103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`@0o`000`3oool0
0`3o0000oooo0?ooo`030?ooo`80003o0P3oool0103o0000oooo0000o`3o
ool20?l000070000o`3o0000oooo0?ooo`000?l0oooo0?l000020?ooo`80
003o1@3oool00`3o0000oooo0?ooo`050?l000<0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool20000o`@0oooo00<0003o0?ooo`3o
ool0<03oool005D0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo
0?ooo`0=0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?l0003o0000303oool00`3o0000oooo0?ooo`050?ooo`80003o
0`3oool00`000?l0oooo0?ooo`030?ooo`80o`001@3oool20000o`80oooo
00<0o`000?ooo`000?l00P3oool01@3o0000003o0?l0003oool0003o0080
oooo00<0o`000?ooo`3oool00P000?l50?ooo`80o`001@3oool010000?l0
oooo0?ooo`3oool20000o`L0oooo00<0o`000?ooo`3oool02P3oool20?l0
0100oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo04P0oooo00H0003o0?oo
o`000?l0003o0?ooo`3o00050?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`060?l0003o
ool0o`000?l0003oool0003o1@3oool0103o0000oooo0?ooo`3oool20000
o`060?ooo`000?l0oooo0?l0003oool0003o0P3oool01`3o0000oooo0000
o`3oool0o`000?ooo`000?l00P3oool0103o0000oooo0000o`3oool20000
o`<0oooo00<0o`000?ooo`3oool00`3oool01P000?l0oooo0?l0003o0000
oooo0?l000D0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00H0o`000?ooo`000?l0003o
0?ooo`000?lc0?ooo`00L03oool00`3o0000oooo0?ooo`0:0?ooo`80o`00
6@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool03P3oool010000?l0oooo0?ooo`3o000:0?ooo`03
0?l0003oool0oooo00P0oooo0`000?l80?ooo`80o`000P3oool0103o0000
oooo0?ooo`000?l20?ooo`0;0?l0003oool0003o0?ooo`3o0000003o0?l0
003oool0003o0?ooo`3o00000P3oool010000?l0oooo0?ooo`3o00020?oo
o`80o`001`3oool40000o`X0oooo00<0o`000?ooo`3oool01`3oool20?l0
0080oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0603oool20?l0
00`0oooo00<0o`000?ooo`3oool0H`3oool20000o`@0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool0103o00040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000000o`000?l0103oool01P3o0000oooo0?ooo`000?l0
oooo0?l00080oooo00<0003o0?ooo`3o00000P3oool010000?l0oooo0?oo
o`3o00040?ooo`80003o00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`020?ooo`@0o`000P3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`80003o<`3oool00700oooo00<0o`000?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo0080oooo0P3o00080?ooo`030?l0003oool0oooo00X0oooo0`00
0?l80?ooo`<0o`000`3oool030000?l0oooo0?ooo`3o0000oooo0000o`3o
0000003o0?l000000?l0oooo0?l00080oooo00@0003o0?ooo`3oool0oooo
0`3o00080?ooo`<0003o303oool00`3o0000oooo0?ooo`050?ooo`80o`00
1@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0
003oool0oooo00P0oooo00<0o`000?ooo`3oool0I@3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o0000o`000080oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00@0o`000?ooo`000?l0003o0P3oool01P3o0000
oooo0?ooo`000?l0oooo0?l00080oooo00D0003o0?ooo`000?l0oooo0?l0
00050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?l000030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool0<P3oool00740oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0
oooo00T0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00D0oooo0`3o00040?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool00P000?l70?ooo`@0o`000P3oool2
0000o`090?ooo`3o0000003o0?l000000?l0o`000000o`3o0000oooo0080
003o0P3oool30?l000L0oooo0`000?l20?ooo`030000o`3oool0oooo00/0
oooo00@0o`000?ooo`3oool0oooo0`3o00070?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`090?oo
o`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool01`3oool00`3o
0000oooo0?ooo`1V0?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo
0?ooo`80o`001@3oool00`3o0000oooo0?ooo`030?ooo`070000o`3oool0
oooo0?ooo`000?l0oooo0?l000030?ooo`050?l0003oool0oooo0?ooo`00
0?l00P3oool01P3o0000oooo0?ooo`000?l0oooo0?l00080oooo0P000?l3
0?ooo`070?l0003oool0oooo0?ooo`3o0000oooo0000o`030?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool20?l000<0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool0<`3oool00780oooo00<0
o`000?ooo`3oool01@3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3o
ool0oooo00/0oooo0P000?l50?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool0203oool30?l000030?ooo`3o0000oooo00/0oooo00<0
003o0?ooo`3oool00`3oool20000o`D0oooo00@0o`000?ooo`3oool0oooo
0P3o00020?ooo`040000o`3oool0o`000?l00080003o00<0o`000?ooo`00
0?l00P3oool20?l000<0oooo00<0o`000?ooo`3oool00P3oool20000o`H0
oooo00<0003o0?ooo`3oool02P3oool0103o0000oooo0?l0003o000;0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool00`3oool20000
o`d0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`050?oo
o`030?l0003oool0oooo06L0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo103o00000`3o
ool0003o0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00@0003o0?oo
o`000?l0003o0`3oool00`3o0000oooo0?l000030?ooo`050000o`3oool0
003o0000o`3o00001@000?l0103o0000003o0?ooo`000?l40?ooo`030?l0
003oool0o`0000<0oooo0`000?l60?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool0103o00040?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`0c0?ooo`00L`3o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo01T0oooo00<0
003o0?ooo`3oool03P3oool20000o`80oooo00<0o`000?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`0<0?ooo`<0o`002`3oool00`000?l0oooo0?oo
o`050?ooo`D0003o00<0o`000?ooo`3oool00`3oool30?l000030000o`3o
0000003o0080o`0000<0oooo0000o`3o00000P3o00050?ooo`D0003o203o
ool00`000?l0oooo0?ooo`090?ooo`<0o`003@3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo0080003o403oool00`000?l0oooo0?oo
o`0I0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool0J@3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3o00000P3o00050?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00P3oool20000o`H0oooo00<0o`000?ooo`3oool00P3o
ool01@000?l0oooo0?ooo`3oool0o`000080oooo00@0003o0?ooo`3oool0
o`000`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0
oooo0P000?l40?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool01P3o0000oooo0?l0003o0000oooo0000o`@0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0d0?ooo`00M03oool01@3o
0000oooo0?ooo`3oool0o`0001/0oooo00<0003o0?ooo`3oool04@3oool2
0000o`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`020?l000T0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000003o0000o`070000o`030?l000000?l0o`000080003o0P3o0008
0000o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool01`3oool2
0?l00080oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0>
0?ooo`030?l000000?l0003o0180oooo00<0003o0?ooo`3oool06P3oool0
1@3o0000oooo0?ooo`3oool0o`0006`0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`80o`000`3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P00
0?l00`3oool0003o0?ooo`030?ooo`80o`0000D0oooo0?l0003oool0oooo
0000o`030?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool01@3o0000
oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3o0000103oool00`00
0?l0oooo0?ooo`020000o`80oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0o`000000
o`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
03@0oooo001e0?ooo`030?l0003oool0o`0001/0oooo00<0003o0?ooo`3o
ool04`3oool00`3o0000003o0000o`0>0?ooo`030000o`3oool0oooo00d0
oooo00<0o`000?ooo`3oool00P3oool60?l00080oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`070?ooo`80003o00<0o`000000o`3o
00000P3o00080?ooo`030?l0003oool0oooo00X0oooo00@0003o0?ooo`3o
ool0oooo1P3o00040?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool03@3oool20000o`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool06P3oool00`3o0000oooo0?l0001^0?ooo`030000o`3oool0oooo
0080oooo00H0o`000?ooo`3oool0o`000?ooo`000?l30?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool20000o`@0oooo00@0
003o0?ooo`3oool0o`00103oool20?l000050000o`3oool0oooo0?ooo`3o
00000`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?oo
o`3o00000`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo0P000?l4
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0o`000?l000020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool0=@3oool007H0oooo00<0o`000?ooo`3oool06P3oool00`00
0?l0oooo0?ooo`0C0?ooo`040?l0003oool0oooo0000o`d0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`080?ooo`H0o`002@3oool0
0`3o0000oooo0?l000070?l00080003o00D0o`000000o`000?l0003o0?oo
o`090?l000X0oooo1P3o000:0?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool02`3oool010000?l0oooo0?ooo`3o000E0?ooo`030000
o`3oool0oooo01X0oooo00<0o`000?ooo`3oool0K@3oool00`000?l0oooo
0?ooo`020?ooo`<0o`000P3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00@0003o0?ooo`3oool0oooo0P000?l00`3oool0
o`000?ooo`040?ooo`030000o`3oool0o`0000D0oooo00<0003o0?l0003o
ool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00H0o`000?oo
o`3oool0oooo0?l000000?l50?ooo`030?l0003oool0003o00D0oooo00@0
o`000?ooo`000?l0003o0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o00040?ooo`030000
o`3oool0oooo03D0oooo001e0?ooo`030?l0003oool0o`0001X0oooo00<0
003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`020?ooo`80003o2`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00@0
003o0?ooo`3oool0oooo2`3o00050?ooo`<0003o0P3o00000`3oool0003o
0000o`020?l00080003o1P3oool;0?l000<0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00T0oooo
0P000?l40?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0
603oool20?l00700oooo00H0003o0?ooo`3o0000o`000?ooo`3o00040?oo
o`050000o`3oool0oooo0?ooo`3o00001@3oool30000o`<0oooo00<0o`00
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
o`0000<0o`000`3oool010000?l0oooo0?ooo`3oool40?l000030?ooo`00
0?l0oooo00D0oooo00<0o`000?ooo`3oool0103oool0103o0000oooo0?oo
o`3oool20000o`D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`020?ooo`060?l0003oool0o`000?l0003oool0003o>03oool007@0
oooo00@0o`000?ooo`3oool0oooo0P3o000G0?ooo`030000o`3oool0oooo
01@0oooo00<0o`000?ooo`3oool0103oool20000o`T0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00/0oooo00@0o`000?ooo`3oool0oooo0P000?l20?ooo`0:0?l0003oool0
003o0?l000000?l0o`000000o`3oool0o`000?ooo`<0003o0`3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`80003o1P3oool00`3o
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01H0oooo0P3o00020?oo
o`030?l0003oool0oooo06h0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0oooo0P00
0?l60?ooo`030?l0003oool0oooo0080oooo00<0o`000?ooo`000?l0103o
ool00`000?l0oooo0?ooo`030?ooo`@0o`0000<0003o0?l0003o00000P3o
00050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o0000103o
ool00`3o0000oooo0?ooo`030?ooo`<0003o0P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo
0000o`0i0?ooo`00L`3oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0oooo01@0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?oo
o`070?ooo`<0003o1@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool0103o0000003o0000
o`000?l30?ooo`0;0?l0003oool0003o0?ooo`3o0000003o0?l0003oool0
003o0?ooo`3o00000`3oool30000o`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo0080oooo10000?l90?ooo`030?l0003oool0oooo01<0oooo00<0
003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`030?ooo`030?l0003o
ool0oooo06d0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool010000?l0oooo
0?ooo`000?l50?ooo`030?l0003oool0oooo0080o`000`3oool010000?l0
oooo0?ooo`000?l50?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`040000o`3oool0oooo
0000o`<0oooo00@0o`000?ooo`3oool0o`001@3oool01`000?l0oooo0?oo
o`3oool0003o0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0=`3oool00780oooo
00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0B0?ooo`030000
o`3oool0oooo01@0oooo00<0o`000?ooo`3oool02P3oool30000o`80oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00X0oooo0P000?l50?ooo`030?l0003oool0003o0080oooo
00<0o`000000o`3o00000P3oool00`000?l0oooo0?l000050?ooo`80003o
303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`000?l00P000?l=0?ooo`030?l0003oool0oooo01@0oooo
00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo06d0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`03
0000o`3oool0oooo0080oooo0P000?l30?ooo`030000o`3oool0oooo00@0
oooo0P3o00060?ooo`<0003o1@3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool30000o`D0
oooo00<0o`000?ooo`3o00001@3oool00`000?l0oooo0?ooo`020?ooo`80
003o103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?oo
o`3oool0>03oool00780oooo00<0o`000?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0@0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3o
ool03P3oool40000o`d0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`070?ooo`<0003o00<0oooo0?l0003oool00`3oool0103o0000
oooo0?ooo`000?l20?ooo`030?l000000?l0o`000080oooo00@0003o0?oo
o`3oool0o`00103oool00`3o0000oooo0000o`020000o`T0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`<0003o4@3oool0
0`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`1/0?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool01P000?l0oooo0000o`00
0?l0oooo0?l000@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`<0003o0`3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool30000o`L0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080003o00<0oooo0000o`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo03P0oooo001a0?ooo`030?l0003o
ool0oooo00T0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0D0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool00`00
0?l:0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0103o
ool30000o`D0oooo00@0o`000?ooo`3oool0o`000P3oool020000?l0oooo
0?ooo`3o0000oooo0000o`3oool0o`000P3oool010000?l0oooo0?ooo`3o
00020?ooo`030?l0003oool0oooo00<0oooo0`000?l60?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0203oool30000o`80oooo00<0
003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?oo
o`1/0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00@0003o0?ooo`3oool0
oooo0P3o00000`3oool0o`000?ooo`050?ooo`040000o`3oool0oooo0000
o`80oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`040?l0003oool0oooo0000o`80oooo00<0003o0?ooo`3oool00`3oool2
0?l000030?ooo`3o0000o`000080oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`80003o0`3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo03T0oooo001`0?ooo`030?l0003oool0oooo
00/0oooo0P3o000>0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?oo
o`3oool0403oool00`000?l0oooo0?ooo`030?ooo`L0003o0`3oool00`3o
0000oooo0?ooo`0<0?ooo`L0003o2@3oool20?l000<0oooo00P0003o0?oo
o`3oool0o`000?ooo`000?l0oooo0?l00080oooo00@0003o0?ooo`3oool0
oooo0P3o00090?ooo`L0003o3P3oool0103o0000oooo0?ooo`3oool70000
o`D0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0C0?oo
o`030000o`3oool0oooo00d0oooo0P3o000=0?ooo`030?l0003oool0oooo
06/0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030000
o`@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?l000040?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool20000
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000003o0000o`040?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool0
0`3o0000oooo0000o`040?ooo`030?l0003oool0oooo00<0oooo0`000?l2
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0>@3oool0
06l0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0;0?oooa<0003o3@3oool30?l000<0oooo00T0003o0?oo
o`3oool0oooo0?l0003oool0003o0?ooo`3o00000`3oool010000?l0oooo
0?ooo`3oool30?l000`0oooo50000?l<0?ooo`030000o`3oool0oooo0100
oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00h0oooo00<0o`000?ooo`3oool0J`3oool00`000?l0
oooo0?ooo`020?ooo`030?l000000?l0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo0P3o00000`3oool0003o0?ooo`060?ooo`030?l000000?l0003o00T0
003o00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?l000070?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool01P000?l0
oooo0?ooo`3oool0003o0?l000@0oooo00<0003o0?ooo`3oool0>P3oool0
06h0oooo00<0o`000?ooo`3oool0403oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool02@3oool01`3o0000oooo0?ooo`3oool0o`000?ooo`000?l00`3o
ool0103o0000oooo0?ooo`000?l20?ooo`070?l0003oool0oooo0?ooo`00
0?l0oooo0?l000030?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo0100oooo00<0o`000?ooo`3oool0J`3oool00`00
0?l0oooo0000o`020000o`050?l0003oool0oooo0?ooo`000?l01@3oool0
1`3o0000oooo0?ooo`3oool0o`000?ooo`000?l01`3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3o00000`3oool00`3o0000oooo0?ooo`030?ooo`050000
o`3oool0oooo0?ooo`3o00000`000?l00`3oool0003o0?ooo`0l0?ooo`00
K@3oool00`3o0000oooo0?ooo`0B0?ooo`80o`00203oool00`000?l0oooo
0?ooo`0E0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00L0oooo
0P3o00050?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0
003o0P3oool01P3o0000oooo0?ooo`3oool0o`000000o`D0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0D
0?ooo`030000o`3oool0oooo00L0oooo0P3o000D0?ooo`030?l0003oool0
oooo06X0oooo0P000?l30?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool0103o0000oooo0?l0003o00030?ooo`030000o`3o
ool0oooo00<0oooo00@0003o0?ooo`3o0000o`001@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool20?l000030000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0
oooo0P3o00000`3oool0o`000?ooo`030?ooo`030000o`3oool0oooo0080
oooo00@0o`000?ooo`3oool0oooo0P000?lm0?ooo`00K03oool00`3o0000
oooo0?ooo`0E0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool05@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00H0003o0?l0003o0000o`000?ooo`3o0002
0?ooo`050000o`3oool0oooo0?l0003oool00P3o00000`3oool0003o0?oo
o`050?ooo`80o`00203oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0E0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0503o
ool00`3o0000oooo0?ooo`1[0?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`040?l0003oool0oooo0?ooo`80o`000`3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool0?03oool006/0oooo00<0o`000?ooo`3oool0
5`3oool20?l000@0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`040?ooo`80o`001`3oool00`000?l0oooo
0?ooo`020?ooo`@0o`0000<0003o0?l0003o00000P3o00040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo
0P3o000H0?ooo`030?l0003oool0oooo06X0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`070000o`3oool0oooo0?ooo`3o
0000oooo0?l000060?ooo`040000o`3oool0oooo0000o`D0oooo0P3o0000
0`3oool0o`000?ooo`060?ooo`030000o`3oool0oooo00@0oooo00@0o`00
0?ooo`3oool0o`001@3oool01@000?l0oooo0?ooo`3oool0003o00L0oooo
0P3o00020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0l0?ooo`00JP3oool00`3o0000oooo0?oo
o`0J0?ooo`80o`000P3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l0
0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00l0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo
0?ooo`0E0?ooo`030000o`3oool0oooo0080o`006`3oool00`3o0000oooo
0?ooo`1Z0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?l000030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`000?l01`3oool40?l000D0oooo00<0003o0?ooo`3oool0
0`3oool40?l000L0oooo00<0003o0?ooo`000?l01`3oool01P3o0000oooo
0?ooo`3o0000oooo0000o`@0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0m0?ooo`00JP3oool00`3o0000oooo0?ooo`0L0?ooo`80
o`00603oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`020?l000P0
oooo00<0003o0?ooo`3oool0103oool01@3o0000oooo0?ooo`3oool0003o
00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`80o`000`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00l0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0F0?oo
o`80o`007P3oool00`3o0000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool0103o
0000oooo0?ooo`3oool50?l000030000o`3o0000o`0000<0o`000P3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`050?l0003oool0
oooo0?ooo`000?l0@03oool006T0oooo00<0o`000?ooo`3oool07P3oool0
0`000?l0o`000?l0000E0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0?0?ooo`80o`002@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00H0oooo0P3o00000`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0C
0?ooo`80o`0000<0003o0?ooo`3oool07P3oool00`3o0000oooo0?ooo`1Y
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o0000
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`000?l01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool0103oool20000o`030?ooo`000?l0
oooo00@0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?l0003o
00020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0?P3o
ool006P0oooo00<0o`000?ooo`3oool07P3oool010000?l0oooo0?ooo`3o
ool20?l001<0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo00d0oooo0P3o00000`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0203oool30?l000l0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo0140oooo0P3o
00030?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0J@3o
ool00`000?l0oooo0?ooo`020?ooo`80o`000`3oool00`000?l0oooo0?oo
o`030?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool20000o`D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo0080oooo0P000?l30?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0o`0000<0oooo00<0003o0?ooo`3oool0?`3oool006L0oooo00<0
o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`030?ooo`<0o`00403o
ool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool02`3oool20?l000<0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00H0oooo00@0003o0?ooo`3oool0oooo0P3o000<0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0>0?ooo`<0o`001@3oool00`000?l0oooo0?ooo`0N0?ooo`030?l0
003oool0oooo06T0oooo00L0003o0?ooo`3oool0oooo0?l0003oool0o`00
00@0oooo00<0003o0?ooo`3oool00`3oool0103o0000oooo0?ooo`000?l5
0?ooo`050000o`3oool0oooo0?ooo`3o00002@3oool00`000?l0oooo0?oo
o`070?ooo`040?l0003oool0oooo0000o`H0oooo00@0003o0?ooo`3oool0
o`001@3oool00`000?l0oooo0?ooo`030?ooo`80o`000`3oool00`000?l0
oooo0?ooo`0o0?ooo`00IP3oool00`3o0000oooo0?ooo`0O0?ooo`030000
o`3oool0oooo00L0oooo0`3o000=0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`090?ooo`80o`00
1@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`80o`002P3oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo0180oooo00<0o`000?ooo`3oool02P3oool30?l000T0oooo
00<0003o0?ooo`3oool07P3oool00`3o0000oooo0?ooo`1Y0?ooo`030000
o`3o0000o`000080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`030?ooo`80003o1`3oool20000o`030?ooo`3o0000oooo00P0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0000o`080?ooo`80003o
1@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080o`00
00<0003o0?ooo`3oool0@03oool006D0oooo00<0o`000?ooo`3oool0803o
ool00`000?l0oooo0?ooo`0:0?ooo`<0o`002@3oool00`3o0000oooo0?oo
o`0B0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool01@3o
ool30?l000P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool01`3oool30?l000L0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00L0oooo0`3o
000<0?ooo`030000o`3oool0oooo01l0oooo00<0o`000?ooo`3oool0J03o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?l000090?ooo`040?l00000
0?l0003o0000o`L0oooo00<0003o0?ooo`3oool0103oool30000o`030?l0
00000?l0oooo00P0oooo00<0o`000000o`3oool00`3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
@03oool006D0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?oo
o`0>0?ooo`80o`001`3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3o
ool0oooo0100oooo00@0o`000?ooo`3oool0oooo103o000<0?ooo`050000
o`3oool0oooo0?ooo`000?l0203oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool01@000?l0
oooo0?ooo`3oool0003o00`0oooo103o00030?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`050?oo
o`80o`00403oool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo
06T0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`040000o`3oool0oooo0000o`<0oooo0P3o00070?ooo`040?l0003oool0
oooo0?ooo`H0003o00<0oooo0000o`3oool01@000?l40?ooo`030?l0003o
ool0oooo00D0oooo0P3o00020?ooo`040000o`3oool0oooo0000o`H0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`110?ooo`00I03o
ool00`3o0000oooo0?ooo`0P0?ooo`030000o`3oool0oooo0100oooo103o
00030?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0403o
ool40?l00140oooo00<0003o0?ooo`000?l0203oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3o
ool010000?l0oooo0?ooo`000?lA0?ooo`@0o`004P3oool00`000?l0oooo
0?ooo`0C0?ooo`030?l0003oool0oooo00@0o`004P3oool00`000?l0oooo
0?ooo`0O0?ooo`030?l0003oool0oooo06T0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`80003o1P3oool00`3o0000oooo
0?ooo`040?ooo`030?l0003oool0oooo00H0oooo1@000?l80?ooo`030?l0
003oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0000o`050?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
@P3oool006@0oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?oo
o`0D0?ooo`D0o`004`3oool00`000?l0oooo0?ooo`0=0?ooo`@0o`005@3o
ool20000o`P0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo0P000?lD0?ooo`D0o`003`3o
ool00`000?l0oooo0?ooo`0A0?ooo`D0o`005`3oool00`000?l0oooo0?oo
o`0O0?ooo`030?l0003oool0oooo06P0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo0P3o
00030?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3o
ool0103o0000oooo0?ooo`3oool20?l000L0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0480oooo
001S0?ooo`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool05`3o
ool00`3o0000oooo0?ooo`040?l000l0oooo00<0003o0?ooo`3oool01P3o
ool70?l000@0oooo00<0o`000?ooo`3oool04P3oool20000o`P0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo0P000?lD0?ooo`030?l0003oool0oooo0080oooo1`3o
00080?ooo`030000o`3oool0oooo00d0oooo103o00020?ooo`030?l0003o
ool0oooo01L0oooo00<0003o0?ooo`3oool0803oool00`3o0000oooo0?oo
o`1X0?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0oooo
0P000?l00`3oool0003o0?ooo`070?ooo`80o`0000<0oooo0?l0003oool0
2P3oool00`000?l0oooo0?ooo`090?ooo`040?l0003oool0oooo0?l000P0
oooo00@0003o0?ooo`000?l0003o0`3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo04<0oooo001S0?ooo`030?l0003oool0oooo0200
oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`040?oooaP0
o`002`3oool00`3o0000oooo0?ooo`0A0?ooo`040000o`3oool0oooo0000
o`H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00@0oooo00@0003o0?ooo`3oool0003o4P3oool0
0`3o0000oooo0?ooo`0:0?oooaP0o`001P3oool00`3o0000oooo0?ooo`0G
0?ooo`030000o`3oool0oooo0200oooo00<0o`000?ooo`3oool0J03oool0
0`000?l0oooo0?ooo`030?ooo`030?l000000?l0003o00@0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00T0oooo0`3o00080?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3o00001@3oool00`000?l0oooo0?ooo`130?ooo`00HP3oool00`3o
0000oooo0?ooo`0P0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?oo
o`3oool0503oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`020?ooo`80003o103oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool04`3oool00`3o
0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo0200oooo00<0o`000?oo
o`3oool0J03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool40?l000T0oooo00<0003o0?oo
o`3oool0203oool30?l000P0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0o`000?ooo`030?ooo`030000o`3oool0oooo04@0oooo001Q0?ooo`03
0?l0003oool0oooo0240oooo00<0003o0?ooo`3oool05`3oool00`3o0000
oooo0?ooo`0D0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?oo
o`3o00002@3oool00`000?l0oooo0?ooo`060?ooo`050?l0003oool0oooo
0?ooo`000?l01`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo0180oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo0240oooo00<0o`000?ooo`3oool0I`3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3o0000oooo00H0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`80o`001`3oool0
0`000?l0oooo0?ooo`050?ooo`<0o`000P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000000o`3oool00`3oool0
0`000?l0oooo0?ooo`140?ooo`00H@3oool00`3o0000oooo0?ooo`0P0?oo
o`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0503oool00`00
0?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00`0oooo0P000?l80?oo
o`80003o00<0oooo0?l0003oool0203oool00`000?l0oooo0?ooo`060?oo
o`040?l0003oool0003o0000o`T0oooo0P000?l=0?ooo`030?l0003oool0
oooo01<0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo0240oooo00<0o`000?ooo`3oool0J03oool0
10000?l0oooo0000o`000?l20?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`D0o`000P3o
ool00`000?l0oooo0?ooo`050?l000H0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080003o00<0
oooo0000o`3oool0AP3oool00600oooo00<0o`000?ooo`3oool08@3oool0
0`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo01@0oooo00<0003o
0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000000o`000?l0203oool00`000?l0oooo0?ooo`05
0?ooo`80003o00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0503oool0
0`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo0240oooo00<0o`00
0?ooo`3oool0J03oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00D0oooo00D0003o0?ooo`3oool0oooo0?l0000;0?ooo`<0o`0000<0
003o0?l0003o0000303oool01@3o0000oooo0?ooo`3oool0003o00L0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`160?ooo`00H03o
ool00`3o0000oooo0?ooo`0P0?ooo`030000o`3oool0oooo01T0oooo00<0
o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`060000o`80oooo00<0003o0?ooo`3oool01@000?l20?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`0D0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0603o
ool00`000?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo06L0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`040000o`3o
ool0oooo0?l000h0oooo00<0003o0?ooo`3oool0303oool0103o0000oooo
0?ooo`000?l80?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0AP3oool005l0oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo
0?ooo`0I0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0
503oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool01P3oool50000o`L0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo01@0oooo
00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0I0?ooo`030000
o`3oool0oooo0240oooo00<0o`000?ooo`3oool0J03oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00H0oooo00<0003o0?l0003oool0
3P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l000000?l0oooo00L0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`170?ooo`00G`3o
ool00`3o0000oooo0?ooo`0P0?ooo`030000o`3oool0oooo01X0oooo00<0
o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo01D0oooo00<0
003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3o
ool0oooo0280oooo00<0o`000?ooo`3oool0I`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0o`000000o`000?l03P3o
ool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0o`0000L0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`170?ooo`00GP3oool0
0`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo01X0oooo00<0o`00
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0
oooo00<0oooo0P000?l?0?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0E
0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool08P3oool0
0`3o0000oooo0?ooo`1X0?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o00d0oooo00<0
003o0?ooo`3oool02P3oool20000o`<0oooo00<0o`000?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo04P0oooo001M
0?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool06@3oool0
0`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01D0oooo00D0o`00
0?ooo`3oool0oooo0000o`0@0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?oo
o`0E0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool08P3o
ool00`3o0000oooo0?ooo`1W0?ooo`030000o`3oool0oooo00D0oooo00D0
o`000?ooo`3oool0oooo0?l000050?ooo`80003o2`3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo04P0oooo
001M0?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool06@3o
ool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01D0oooo00@0
o`000?ooo`3oool0003o4@3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool03`3oool01@000?l0oooo
0?ooo`3oool0o`0001L0oooo00<0003o0?ooo`3oool05P3oool00`3o0000
oooo0?ooo`0I0?ooo`030000o`3oool0oooo0280oooo00<0o`000?ooo`3o
ool0J03oool00`000?l0oooo0?ooo`040?ooo`050?l0003oool0oooo0?oo
o`3o00001`3oool20000o`T0oooo00<0003o0?ooo`3oool01`3oool20000
o`L0oooo00D0o`000?ooo`3oool0oooo0?l000060?ooo`030000o`3oool0
oooo04T0oooo001L0?ooo`030?l0003oool0oooo0280oooo00<0003o0?oo
o`3oool06P3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo
01H0oooo00<0o`000000o`3oool04@3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?l0000G0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?oo
o`3oool06@3oool00`000?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo
06P0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?l0000:0?oo
o`D0003o103oool00`000?l0oooo0?ooo`020?ooo`D0003o2@3oool0103o
0000oooo0?ooo`3o00060?ooo`030000o`3oool0oooo04X0oooo001L0?oo
o`030?l0003oool0oooo0280oooo00<0003o0?ooo`3oool06P3oool00`3o
0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01D0oooo0P000?l00`3o
0000oooo0?ooo`0?0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`0@0?ooo`80003o5`3oool00`00
0?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?oo
o`3oool08P3oool00`3o0000oooo0?ooo`1X0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool03P3oool90000o`l0oooo0P3o00070?oo
o`030000o`3oool0oooo04X0oooo001K0?ooo`030?l0003oool0oooo02<0
oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0G0?ooo`03
0000o`3oool0oooo01<0oooo00@0003o0?ooo`3oool0o`004@3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool03P3oool0103o0000oooo0?ooo`000?lF0?ooo`030000o`3oool0
oooo01L0oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0S
0?ooo`030?l0003oool0oooo06P0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?l0000C0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3o00001@3oool00`000?l0oooo0?ooo`1;0?ooo`00F`3oool00`3o
0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?oo
o`3oool05`3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03@3oool00`3o
0000oooo0?ooo`020?ooo`80003o503oool00`000?l0oooo0?ooo`0G0?oo
o`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool08`3oool00`3o
0000oooo0?ooo`1X0?ooo`030000o`3oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo0?l0000B0?ooo`030000o`3oool0oooo00l0oooo0P3o0003
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0B`3oool0
05X0oooo00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`0J0?oo
o`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool0403oool20000
o`H0oooo00<0o`000?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`3o
0000oooo0?ooo`050?ooo`80003o4P3oool00`000?l0oooo0?ooo`0G0?oo
o`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool08`3oool00`3o
0000oooo0?ooo`1X0?ooo`040000o`3oool0oooo0?l000D0oooo0P3o000@
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0103oool0
103o0000oooo0?ooo`000?m>0?ooo`00F@3oool00`3o0000oooo0?ooo`0T
0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool0603oool0
0`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool0603oool0
0`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo02<0oooo00<0o`00
0?ooo`3oool0J03oool00`000?l0o`000?l000080?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`06
0?ooo`80o`0000<0003o0?ooo`3oool0C03oool005T0oooo00<0o`000?oo
o`3oool0903oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo
01P0oooo00<0003o0?ooo`3oool0303oool20000o`/0oooo0P3o000:0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo0P000?l>0?oo
o`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool06`3oool00`00
0?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo06P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00/0oooo0P3o000:0?ooo`030000o`3oool0oooo04d0oooo001H0?ooo`03
0?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool06`3oool00`3o0000
oooo0?ooo`0H0?ooo`030000o`3oool0oooo00X0oooo0P000?l?0?ooo`03
0?l0003oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool2000000H0
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`080?ooo`03
0?l0003oool0oooo00`0oooo0P000?l;0?ooo`030000o`3oool0oooo01T0
oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0T0?ooo`03
0?l0003oool0oooo06T0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`1>0?ooo`00F03oool00`3o0000oooo
0?ooo`0U0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool0
6@3oool00`000?l0oooo0?ooo`070?ooo`80003o4P3oool00`3o0000oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00@000000?ooo`3oool0
00001@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0
oooo0P3o000A0?ooo`80003o2@3oool00`000?l0oooo0?ooo`0I0?ooo`03
0?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool0903oool00`3o0000
oooo0?ooo`1X0?ooo`030000o`3oool0oooo00T0oooo0P3o000;0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`1>0?ooo`00E`3oool00`3o0000oooo0?ooo`0U0?ooo`030000
o`3oool0oooo01`0oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo
0?ooo`050?ooo`80003o5@3oool00`3o0000oooo0?ooo`040?ooo`030?l0
003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000?l00000
0000000>0?ooo`030?l0003oool0oooo00<0oooo0P3o000E0?ooo`80003o
1P3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo01`0oooo
00<0003o0?ooo`3oool0903oool00`3o0000oooo0?ooo`1Y0?ooo`030000
o`3oool0oooo00X0oooo0P3o00090?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`1?0?ooo`00E`3o
ool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo01`0oooo00<0
o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo01H0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`090?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool03`3o
ool01@3o0000oooo0?ooo`3oool0o`0001T0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo01`0oooo
00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`1X0?ooo`030000
o`3oool0oooo00`0oooo0P3o00070?ooo`030000o`3oool0oooo00H0oooo
0P3o000=0?ooo`030000o`3oool0oooo04l0oooo001F0?ooo`030?l0003o
ool0oooo02H0oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo0?oo
o`0J0?ooo`040000o`3oool0oooo0?ooo`80003o6P3oool20?l00080oooo
00<0o`000?ooo`3oool01P3oool010000000oooo0?ooo`0000050?ooo`03
0000o`3oool0oooo00l0oooo00@0o`000?ooo`3o0000o`006`3oool20000
o`<0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0L0?oo
o`030000o`3oool0oooo02D0oooo00<0o`000?ooo`3oool0J@3oool00`00
0?l0oooo0?ooo`0=0?ooo`@0o`000`3oool010000?l0oooo0?ooo`3oool5
0?l000h0oooo00<0003o0?ooo`3oool0D03oool005H0oooo00<0o`000?oo
o`3oool09P3oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo
01X0oooo00@0003o0?ooo`000?l0003o7P3oool30?l000T0oooo0P000006
0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool07@3oool3
0000oa`0oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0V
0?ooo`030?l0003oool0oooo06T0oooo00<0003o0?ooo`3oool0403oool3
0?l000040000o`3o0000o`000?l00180oooo00<0003o0?ooo`3oool0D@3o
ool005D0oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo0?ooo`0N
0?ooo`030?l0003oool0oooo01T0oooo0P000?lQ0?ooo`040?l0003oool0
o`000?l000l0oooo00<0003o0?ooo`3oool03P3oool30?l00240oooo0P00
0?lK0?ooo`030?l0003oool0oooo01d0oooo00<0003o0?ooo`3oool09P3o
ool00`3o0000oooo0?ooo`1Y0?ooo`030000o`3oool0oooo01<0oooo00<0
003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`1A0?ooo`00E@3oool0
0`3o0000oooo0?ooo`0V0?ooo`030000o`3oool0oooo01h0oooo00<0o`00
0?ooo`3oool05`3oool20000o`030?ooo`000?l0oooo01l0oooo00<0o`00
0?ooo`3oool00P3oool20?l000d0oooo00<0003o0?ooo`3oool0303oool2
0?l000<0oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`02
0000oaT0oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0W
0?ooo`030?l0003oool0oooo06T0oooo00<0003o0?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo0580oooo001n0?oo
o`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0503oool30000
o`@0oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`040?oo
o`<0o`002P3oool00`000?l0oooo0?ooo`090?ooo`<0o`001@3oool00`3o
0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo0080oooo0`000?lF0?oo
o`030?l0003oool0oooo01h0oooo00<0003o0?ooo`3oool0TP3oool00`00
0?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo0180oooo00<0003o0?oo
o`3oool0DP3oool005D0oooo0P000?lW0?ooo`030000o`3oool0oooo01h0
oooo00<0o`000?ooo`3oool04P3oool20000o`L0oooo00<0003o0?ooo`3o
ool0703oool00`3o0000oooo0?ooo`080?ooo`D0o`001@3oool00`000?l0
oooo0?ooo`030?ooo`H0o`002@3oool00`3o0000oooo0?ooo`0K0?ooo`03
0000o`3oool0oooo00H0oooo0P000?lD0?ooo`030?l0003oool0oooo01h0
oooo00<0003o0?ooo`3oool09@3oool20000of`0oooo00<0003o0?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`030000o`3oool0oooo05<0
oooo001G0?ooo`<0003o903oool00`000?l0oooo0?ooo`0N0?ooo`030?l0
003oool0oooo0100oooo0P000?l:0?ooo`030000o`3oool0oooo01/0oooo
00<0o`000?ooo`3oool03@3oool50?l000030000o`3o0000o`0000<0o`00
3`3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00P0oooo
0P000?lB0?ooo`030?l0003oool0oooo01h0oooo00<0003o0?ooo`3oool0
8P3oool30000ofh0oooo00<0003o0?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0A0?ooo`030000o`3oool0oooo05<0oooo001J0?ooo`<0003o803o
ool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo00h0oooo0P00
0?l<0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo01T0oooo00<0
003o0?ooo`3oool02`3oool20000oa00oooo00<0o`000?ooo`3oool07P3o
ool00`000?l0oooo0?ooo`0O0?ooo`<0003oLP3oool00`000?l0oooo0?oo
o`0@0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0E03o
ool005d0oooo0`000?lM0?ooo`030000o`3oool0oooo01l0oooo00<0o`00
0?ooo`3oool0303oool20000o`l0oooo00<0003o0?ooo`3oool06@3oool0
0`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01<0oooo00<0o`00
0?ooo`3oool06@3oool00`000?l0oooo0?ooo`0=0?ooo`80003o3P3oool0
0`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo01/0oooo0`000?mf
0?ooo`030000o`3oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`1E0?ooo`00H03oool30000oaX0oooo00<0003o0?oo
o`3oool07`3oool00`3o0000oooo0?ooo`090?ooo`<0003o4P3oool00`00
0?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?oo
o`3oool0503oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo
0100oooo0`000?l;0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?oo
o`3oool0603oool30000ogT0oooo00<0003o0?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0?0?ooo`030000o`3oool0oooo05D0oooo001S0?ooo`<0
003o5`3oool00`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo00@0
oooo10000?lE0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo01D0
oooo00<0003o0?ooo`3oool0503oool40000o`H0oooo00<0o`000?ooo`3o
ool0803oool00`000?l0oooo0?ooo`0E0?ooo`<0003oO@3oool00`000?l0
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3o
ool0EP3oool006H0oooo0`000?lD0?ooo`030000o`3oool0oooo0200oooo
00<0o`000?ooo`3oool010000?lJ0?ooo`030000o`3oool0oooo01D0oooo
00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0
003oool0oooo01D0oooo00<0003o0?ooo`3oool0603oool40000o`80oooo
00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`0B0?ooo`<0003o
P03oool00`000?l0oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo
00<0003o0?ooo`3oool0EP3oool006T0oooo0`000?lA0?ooo`030000o`3o
ool0oooo01h0oooo1@000?lO0?ooo`030000o`3oool0oooo01<0oooo00<0
o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003o
ool0oooo01<0oooo00<0003o0?ooo`3oool07@3oool50000ob00oooo00<0
003o0?ooo`3oool03`3oool30000oh@0oooo00<0003o0?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo05L0oooo001/
0?ooo`T0003o203oool00`000?l0oooo0?ooo`0I0?ooo`D0003o0P3oool0
0`3o0000oooo0?ooo`0P0?ooo`030000o`3oool0oooo0180oooo00<0o`00
0?ooo`3oool05P3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0
oooo0180oooo00<0003o0?ooo`3oool0803oool00`3o0000oooo0?ooo`05
0000oa/0oooo00<0003o0?ooo`3oool01P3oool90000ohL0oooo00<0003o
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0
oooo05L0oooo001e0?ooo`T0003o3`3oool<0000o`L0oooo00<0o`000?oo
o`3oool0803oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
01L0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0@0?oo
o`030000o`3oool0oooo0200oooo00<0o`000?ooo`3oool01P3oool<0000
o`l0oooo2@000?nA0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`000?l0oooo0?ooo`1H0?ooo`00O@3oool@0000oa<0
oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0603oool00`3o0000
oooo0?ooo`0>0?ooo`030000o`3oool0oooo0240oooo00<0o`000?ooo`3o
ool04P3oool@0000oiX0oooo00<0003o0?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0;0?ooo`030000o`3oool0oooo05T0oooo001m0?ooo`030000
o`3oool0oooo0240oooo00<0o`000?ooo`3oool08@3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0
603oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0240oooo
00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`2H0?ooo`030000
o`3oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo
0?ooo`1I0?ooo`00O@3oool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003o
ool0oooo0280oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0I0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003oool0oooo0280oooo00<0
003o0?ooo`3oool0V@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00X0oooo00<0003o0?ooo`3oool0FP3oool007d0oooo00<0003o
0?ooo`3oool08@3oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0I
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool08P3oool0
0`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo09T0oooo00<0003o
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0
oooo05X0oooo001l0?ooo`030000o`3oool0oooo02<0oooo00<0o`000?oo
o`3oool08`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
01X0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo02<0oooo00<0o`000?ooo`3oool08P3oool00`00
0?l0oooo0?ooo`2J0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`1K0?ooo`00O03oool00`000?l0
oooo0?ooo`0S0?ooo`030?l0003oool0oooo02@0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo01/0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0S0?ooo`03
0?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0VP3oool00`000?l0
oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3o
ool0F`3oool007`0oooo00<0003o0?ooo`3oool0903oool00`3o0000oooo
0?ooo`0T0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
6`3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo00D0oooo
0P000?lV0?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0
V`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo
00<0003o0?ooo`3oool0G03oool007`0oooo00<0003o0?ooo`3oool0903o
ool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0703oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool09P3oool00`3o0000oooo0?oo
o`0S0?ooo`030000o`3oool0oooo09`0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo05d0oooo001l
0?ooo`030000o`3oool0oooo02@0oooo00<0o`000?ooo`3oool09P3oool2
0000o`<0oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0M
0?ooo`050?l0003oool0oooo0?ooo`000?l0:03oool00`3o0000oooo0?oo
o`0T0?ooo`030000o`3oool0oooo09`0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo05d0oooo001l
0?ooo`030000o`3oool0oooo02D0oooo00<0o`000?ooo`3oool09`3oool0
0`000?l0oooo0?l0000P0?ooo`030000o`3oool0oooo01h0oooo00<0o`00
0000o`000?l0:@3oool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0
oooo09d0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo05h0oooo001l0?ooo`030000o`3oool0oooo
02D0oooo00<0o`000?ooo`3oool0:03oool00`000?l0o`000?ooo`0O0?oo
o`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0:@3oool00`3o
0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo09d0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
05h0oooo001m0?ooo`030000o`3oool0oooo02@0oooo00<0o`000?ooo`3o
ool0:03oool00`3o0000003o0?ooo`0O0?ooo`030000o`3oool0oooo01`0
oooo0P000?l00`3oool0o`000?ooo`0Y0?ooo`030?l0003oool0oooo02@0
oooo00<0003o0?ooo`3oool0WP3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0G`3oool007d0oooo
00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`0V0?ooo`030?l0
003oool0oooo0080003o7P3oool00`000?l0oooo0?ooo`0K0?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool09P3oool00`3o0000oooo
0?ooo`0U0?ooo`030000o`3oool0oooo09l0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0600oooo
001m0?ooo`030000o`3oool0oooo02D0oooo00<0o`000?ooo`3oool09@3o
ool00`3o0000oooo0?ooo`030?ooo`80003o703oool00`000?l0oooo0?oo
o`0I0?ooo`80003o1P3oool00`3o0000oooo0?ooo`0U0?ooo`030?l0003o
ool0oooo02D0oooo00<0003o0?ooo`3oool0W`3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0H03o
ool007d0oooo00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`0U
0?ooo`030?l0003oool0oooo00D0oooo0P000?lJ0?ooo`030000o`3oool0
oooo01L0oooo0P000?l80?ooo`030?l0003oool0oooo02@0oooo00<0o`00
0?ooo`3oool09P3oool00`000?l0oooo0?ooo`2P0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1Q
0?ooo`00O@3oool00`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo
02<0oooo00<0o`000?ooo`3oool0203oool20000oaP0oooo00<0003o0?oo
o`3oool05@3oool20000o`/0oooo00<0o`000?ooo`3oool08`3oool00`3o
0000oooo0?ooo`0V0?ooo`030000o`3oool0oooo0:00oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
0640oooo001m0?ooo`030000o`3oool0oooo02H0oooo00<0o`000?ooo`3o
ool08P3oool00`3o0000oooo0?ooo`0;0?ooo`80003o5P3oool00`000?l0
oooo0?ooo`0C0?ooo`80003o3P3oool00`3o0000oooo0?ooo`0Q0?ooo`03
0?l0003oool0oooo02L0oooo00<0003o0?ooo`3oool0X@3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0HP3oool007d0oooo00<0003o0?ooo`3oool09`3oool00`3o0000oooo
0?ooo`0P0?ooo`030?l0003oool0oooo00h0oooo0`000?l<0?ooo`<00000
103oool00`000?l0oooo0?ooo`0?0?ooo`@0003o403oool00`3o0000oooo
0?ooo`0Q0?ooo`030?l0003oool0oooo02L0oooo00<0003o0?ooo`3oool0
X@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0HP3oool007d0oooo00<0003o0?ooo`3oool09`3o
ool00`3o0000oooo0?ooo`0P0?ooo`030?l0003oool0oooo0140oooo1000
0?l90?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0303o
ool30000oaD0oooo00<0o`000?ooo`3oool07`3oool00`3o0000oooo0?oo
o`0X0?ooo`030000o`3oool0oooo0:80oooo00D0003o0?ooo`3oool0oooo
0000o`030?ooo`030000o`3oool0oooo06<0oooo001m0?ooo`030000o`3o
ool0oooo02P0oooo00<0o`000?ooo`3oool07P3oool00`3o0000oooo0?oo
o`0F0?ooo`@0003o0P3oool5000000@0oooo00<0003o000000000000203o
ool40000oaT0oooo00<0o`000?ooo`3oool07@3oool00`3o0000oooo0?oo
o`0Y0?ooo`030000o`3oool0oooo0:<0oooo00@0003o0?ooo`3oool0003o
0P3oool00`000?l0oooo0?ooo`1T0?ooo`00O@3oool00`000?l0oooo0?oo
o`0Y0?ooo`030?l0003oool0oooo01`0oooo00<0o`000?ooo`3oool06`3o
oolF0000oah0oooo00<0o`000?ooo`3oool0703oool00`3o0000oooo0?oo
o`0Y0?ooo`030000o`3oool0oooo0:<0oooo00@0003o0?ooo`3oool0003o
0P3oool00`000?l0oooo0?ooo`1T0?ooo`00O@3oool00`000?l0oooo0?oo
o`0Y0?ooo`030?l0003oool0oooo01/0oooo00<0o`000?ooo`3oool07`3o
ool00`000000oooo000000050?ooo`030000o`3oool0oooo02H0oooo00<0
o`000?ooo`3oool06`3oool00`3o0000oooo0?ooo`0Z0?ooo`030000o`3o
ool0oooo09D0oooo0P00000=0?ooo`050000o`3oool0003o0?ooo`000?l0
I`3oool007d0oooo00<0003o0?ooo`3oool0:P3oool00`3o0000oooo0?oo
o`0J0?ooo`030?l0003oool0oooo0200oooo0P0000050?ooo`030000o`3o
ool0oooo02L0oooo00<0o`000?ooo`3oool06@3oool00`3o0000oooo0?oo
o`0Z0?ooo`030000o`3oool0oooo09H0oooo0P0000050?ooo`8000001P3o
ool01@000?l0oooo0000o`3oool0003o06L0oooo001n0?ooo`030000o`3o
ool0oooo02X0oooo00<0o`000?ooo`3oool0603oool00`3o0000oooo0?oo
o`0X0?ooo`030000o`3oool0oooo02P0oooo00<0o`000?ooo`3oool0603o
ool00`3o0000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo09D0oooo00<0
00000?ooo`000000103oool010000000oooo0?ooo`0000060?ooo`<0003o
J03oool007h0oooo00<0003o0?ooo`3oool0:P3oool00`3o0000oooo0?oo
o`0G0?ooo`030?l0003oool0oooo02T0oooo00<0003o0?ooo`3oool0:@3o
ool00`3o0000oooo0?ooo`0F0?ooo`030?l0003oool0oooo02/0oooo00<0
003o0?ooo`3oool0T`3oool01@000000oooo0000003oool0000000H0oooo
00<000000?ooo`3oool01@3oool30000ofP0oooo001n0?ooo`030000o`3o
ool0oooo02/0oooo00<0o`000?ooo`3oool05@3oool00`3o0000oooo0?oo
o`0Z0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool05@3o
ool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo09@0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00D0oooo
00<0003o0000003oool0I`3oool007h0oooo00<0003o0?ooo`3oool0:`3o
ool00`3o0000oooo0?ooo`0E0?ooo`030?l0003oool0oooo02X0oooo00<0
003o0?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0D0?ooo`030?l0003o
ool0oooo02`0oooo00<0003o0?ooo`3oool0V03oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1W0?ooo`00O`3oool00`000?l0oooo0?ooo`0[0?ooo`030?l0003o
ool0oooo01<0oooo00<0o`000?ooo`3oool0:`3oool00`000?l0oooo0?oo
o`0[0?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool0;@3o
ool00`000?l0oooo0?ooo`2H0?ooo`030000003oool0oooo0080oooo0P00
00080?ooo`030000003oool0oooo06L0oooo001o0?ooo`030000o`3oool0
oooo02`0oooo00<0o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`0/
0?ooo`030000o`3oool0oooo02`0oooo00<0o`000?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0^0?ooo`030000o`3oool0oooo09T0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`1W0?ooo`00O`3oool00`00
0?l0oooo0?ooo`0/0?ooo`030?l0003oool0oooo0100oooo00<0o`000?oo
o`3oool0;@3oool00`000?l0oooo0?ooo`0]0?ooo`030?l0003oool0oooo
00h0oooo00<0o`000?ooo`3oool0;P3oool00`000?l0oooo0?ooo`2J0?oo
o`030000003oool0oooo07D0oooo001o0?ooo`030000o`3oool0oooo02d0
oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0^0?ooo`03
0000o`3oool0oooo02h0oooo00<0o`000?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0^0?ooo`030000o`3oool0oooo09X0oooo2P00001^0?ooo`00
O`3oool00`000?l0oooo0?ooo`0^0?ooo`80o`003@3oool00`3o0000oooo
0?ooo`0_0?ooo`030000o`3oool0oooo02l0oooo00<0o`000?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0_0?ooo`030000o`3oool0oooo0?l0oooo
4`3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{632, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The exterior angles of an equilateral triangle are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(\(2  \[Pi]\)\/3\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(\(2  \[Pi]\)\/3\)}]}]]],
  ",  and the formula for the derivative  ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " is  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\((\(2  \[Pi]\)\/3)\)\)/\[Pi]\)\) \((z - \
x\_2)\)\^\(\(-\((\(2  \[Pi]\)\/3)\)\)/\[Pi]\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z - \
\((\(-1\))\))\)\^\(-\(2\/3\)\)\) \((z - 1)\)\^\(-\(2\/3\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(-\(2\/3\)\)\) \((z - 1)\)\^\(-\(2\/3\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(A\)\(\ \)\(\(\(\ \
\)\(1\)\)\/\(\(\((z + 
                        1)\)\^\(2\/3\)\) \((z - 1)\)\^\(2\/3\)\)\)\(\ \
\)\)\)\)}]],
  " \nintegrate and get \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ B\ \  + \ \ A\ \(\[Integral]\(\(\(\ \)\(1\)\)\/\(\
\(\((z + 1)\)\^\(2\/3\)\) \((z - 1)\)\^\(2\/3\)\)\) \[DifferentialD]z\)\)],
    AspectRatioFixed->True]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "We shall investigate three cases of this formula.\n\n(i)\t",
  Cell[BoxData[
      \(A\  = \ \(1\ \ \ and\ \ \ B\  = \ 0\)\)],
    AspectRatioFixed->True],
  "\n\n(ii)\t",
  Cell[BoxData[
      \(A\  = \ \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/6\)\ \ \ and\ \ \ B\
\  = \ 0\)\)],
    AspectRatioFixed->True],
  "\n\n(iii)\t",
  Cell[BoxData[
      \(A\  = \ \(\(2\ Gamma[5\/6]\)\/\(\@\[Pi]\ \
Gamma[1\/3]\)\ \ \ and\ \ \ B\  = \ \(-\(1\/2\)\) + \[ImaginaryI] \@ \
3\/2\)\)],
    AspectRatioFixed->True]
}], "Text"],

Cell[BoxData[{
    \(\(f[
          z_] = \[Integral]\(\(\(\ \)\(1\)\)\/\(\(\((z + 
                          1)\)\^\(2\/3\)\) \((z - 1)\)\^\(2\/3\)\)\) \
\[DifferentialD]z;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[f, {\(-4\), 4, 0.5}, {0.00001, 4.00001, 0.5}, 
        PlotStyle \[Rule] {Blue, 
            Red}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-4\), 2, 1], 
            Range[\(-3\), 3, 1]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0 under the \
mapping\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The complete image is an equilateral triangle.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[
          z_] = \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Pi]/
                  6\)\) \(\[Integral]\(\(\(\ \)\(1\)\)\/\(\(\((z + 
                            1)\)\^\(2\/3\)\) \((z - 1)\)\^\(2\/3\)\)\) \
\[DifferentialD]z\);\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[f, {\(-4\), 4, 0.5}, {0.00001, 4.00001, 0.5}, 
        PlotStyle \[Rule] {Blue, 
            Red}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-4\), 2, 1], 
            Range[\(-3\), 3, 1]}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0 under the \
mapping\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The complete image is an equilateral triangle.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
For our next construction we will start with the unit disk and map it onto \
the upper half plane, then onto the triangle.\
\>", "Text"],

Cell[BoxData[{
    \(\(Iden[z_] = z;\)\ \), "\[IndentingNewLine]", 
    \(\(tri = 
        PolarMap[
          Iden, {0.0, 0.99999999999999, 
            0.0999999999999995}, {0\/12, \(24  \[Pi]\)\/12, \[Pi]\/12}, 
          Ticks \[Rule] \ {Range[\(-1\), 1, 1], Range[\(-1\), 1, 1]}, 
          PlotStyle \[Rule] {Blue, Red}, 
          PlotRange \[Rule] All];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Start with the unit circle |z| < 1.\>"];\)\ \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(S[
          z_] = \(-\@3\) \(\[ImaginaryI]\ \((1 + z)\)\)\/\(\(-1\) + z\);\)\ \
\), "\[IndentingNewLine]", 
    \(\(tri = 
        PolarMap[
          S, {0.0, 0.99999999999999, 
            0.0999999999999995}, {0\/12, \(24  \[Pi]\)\/12, \[Pi]\/12}, 
          Ticks \[Rule] \ {Range[\(-4\), 4, 1], Range[3, 4, 1]}, 
          PlotStyle \[Rule] {Blue, Red}, 
          PlotRange \[Rule] {{\(-4.35\), 4.35}, {0, 4.35}}, 
          AspectRatio \[Rule] 1\/2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The image of the the unit disk |z| < 1 under the \
mapping\>"];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<w = S[z] = \>", S[z]]\), "\[IndentingNewLine]", 
    \(\(Print["\<is the upper half-plane  Im[w] > 0.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<    S[0] = \>", S[0]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[
          z_]\  = \(-1\) + \(\(2\ Gamma[5\/6]\)\/\(\@\[Pi]\ Gamma[
                    1\/3]\)\) \(\[Integral]\(\(\(\ \)\(1\)\)\/\(\(\((z + 
                              1)\)\^\(2\/3\)\) \((z - 1)\)\^\(2\/3\)\)\) \
\[DifferentialD]z\);\)\ \), "\[IndentingNewLine]", 
    \(\(F[z_] = 
        f[\(-\@3\) \(\[ImaginaryI]\ \((1 + z)\)\)\/\(\(-1\) + z\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(tri = 
        PolarMap[
          F, {0.0, 0.99999999999999, 
            0.0999999999999999}, {0\/12, \(24  \[Pi]\)\/12, \[Pi]\/12}, 
          Ticks \[Rule] \ {Range[\(-1\), 1, 1], {\@3}}, 
          PlotStyle \[Rule] {Blue, Red}, PlotRange \[Rule] All, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(poly = 
        Graphics[{Blue, 
            Line[{{\(-1\), 0}, {1, 0}, {0, \@3}, {\(-1\), 
                  0}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[tri, poly, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0 under the \
mapping\>"];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<w = f[z] = \>", f[z]]\), "\[IndentingNewLine]", 
    \(\(Print["\<This a familiar equilateral triangle.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The center is  \!\(w\_0\) =   \[ImaginaryI]\!\(\@3\/3\)  \
= \>\"", Chop[N[\[ImaginaryI] \@ 3\/3]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<               \!\(w\_0\) =  f[\[ImaginaryI]\!\(\@3\)] = \
\>\"", FullSimplify[f[\[ImaginaryI] \@ 3]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<               \!\(w\_0\) =  f[\[ImaginaryI]\!\(\@3\)] = \
\>\"", Chop[
          N[FullSimplify[
              f[\[ImaginaryI] \@ 3]]]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 6.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use the Schwarz Christoffel formula to show that  ",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\  = \ 
          B\  + \ A\ \(\[Integral]\(\(\(\ \)\(1\)\)\/\(\(\((z + 
                                1)\)\^\(1\/2\)\) \(z\^\(1\/2\)\) \((z - \
1)\)\^\(1\/2\)\)\) \[DifferentialD]z\)\)\)],
    AspectRatioFixed->True],
  "  will map the upper-half-plane onto a square. \nHint: For convenience we \
have chosen  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_3 = 1\)}]]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009M0000[b000`400?l0
0000o`00003oo`3ooooo0?oooel0oooo003o0?ooool0ooooG`3oool00?l0
ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo003o0?ooool0ooooG`3o
ool00?l0ooooo`3ooomO0?ooo`00o`3ooooo0?oooel0oooo001U0?ooo`<0
0000803oool200000240oooo1000000O0?ooo`D00000@03oool5000001h0
oooo1000000Q0?ooo`8000008`3oool300000<X0oooo1@00000;0?ooo`00
IP3oool00`000000oooo0?ooo`0N0?ooo`040000003oool0oooo00000200
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool08@3oool010000000
oooo0?ooo`00000S0?ooo`030000003oool0oooo0</0oooo00<000000?oo
o`3oool02`3oool006<0oooo1@00000Q0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0O0?ooo`D00000c03oool00`000000oooo0?ooo`0;0?ooo`00
G@3oool400000080oooo00@000000?ooo`3oool000006P3oool4000000D0
oooo00<000000?ooo`3oool0603oool4000000@0oooo00<000000?ooo`3o
ool0603oool4000000@0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool07P3oool010000000oooo0?ooo`00003=0?ooo`030000003oool0oooo
00/0oooo001T0?ooo`030000003oool000000200oooo00@000000?ooo`3o
ool00000803oool010000000oooo0?ooo`00000Q0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool07P3oool010000000oooo0?ooo`00
000P0?ooo`040000003oool0oooo00000240oooo00<000000?ooo`000000
c@3oool00`000000oooo0?ooo`0;0?ooo`00I@3oool200000240oooo0P00
000R0?ooo`8000008@3oool2000004<0oooo0P00000Q0?ooo`8000008P3o
ool2000002<0oooo0P00003<0?ooo`8000003@3oool00?l0oooo]P3oool0
0`000000oooo0?ooo`2U0?ooo`00o`3ooonf0?ooo`030000003oool0oooo
0:D0oooo003o0?oookH0oooo00<000000?ooo`3oool0Y@3oool00?l0oooo
]P3oool00`000000oooo0?ooo`1:0?ooo`030?l0003oool0oooo05P0oooo
003o0?oook<0oooo0`00002K0000o`@000002@3oool005D0oooo5`000000
0`000?l000000000000/000000030?l000000000000001D0000000<0003o
000000000000300000000`3o000000000000000800000080003o1`000000
0`3o000000000000000300000080003o100000000`3o0000000000000002
00000080003o0`0000000`3o0000000000000002000000030000o`000000
00000080000000@0o`0000000000000000000P000?l4000000030?l00000
0000000000<0000000<0003o0000000000000`0000020?l000L0000000<0
003o0000000000001`0000000`3o000000000000000=000000030000o`00
0000000001D0000000<0o`00000000000000;00000000`000?l000000000
000E000002L0oooo0P000?lY0?ooo`030?l0003oool0oooo00l0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?ooo`3oool09`3oool20000o`d0oooo001R
0?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool05`3oool0
0`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00`0oooo00<00000
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00H0oooo00<000000?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0B0?ooo`030000003oool0oooo01L0oooo00<0
003o0?ooo`3oool01`3oool00`000000oooo0?ooo`0b0?ooo`030000o`3o
ool0003o02P0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`0V0?ooo`030000o`3oool0003o00d0oooo001R
0?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool05`3oool0
0`000000oooo0?ooo`0B0?ooo`030?l0003oool0oooo00`0oooo00<00000
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0<0?ooo`80o`002@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o0000
o`0000L0o`0000<0003o0?l0003o00001P3o00000`000?l0o`000?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`030000003oool0
oooo00`0oooo00<0o`000?ooo`3oool04P3oool00`000000oooo0?ooo`0G
0?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3oool0<P3oool0
10000?l0oooo0?ooo`000?lW0?ooo`030?l0003oool0oooo00l0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?ooo`3oool09@3oool010000?l0oooo0?oo
o`000?l=0?ooo`00K03oool00`000?l0oooo0?ooo`0/0?ooo`030?l0003o
ool0oooo01D0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00<0oooo2@3o00000`000?l0o`000?l0
00080?l000030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`060?l0003oool0oooo0?ooo`000?l0
oooo2@3o00000`000?l0o`000?l000080?l000@0oooo0P000?l90?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool05@3oool00`3o0000
oooo0?ooo`0/0?ooo`030000o`3oool0oooo03`0oooo00D0003o0?ooo`3o
ool0oooo0000o`0V0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00l0oooo00<0o`000?ooo`3oool0903oool01@000?l0oooo0?ooo`3oool0
003o00d0oooo001/0?ooo`030000o`3oool0oooo02`0oooo00<0o`000?oo
o`3oool05@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo
00@0oooo0`3o00000`000?l0o`000?l000030?l000<0oooo00<0o`000?oo
o`3oool00`3oool20000o`@0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`030?l000000?l0003o00L0003o00D0o`000?oo
o`3oool0oooo0000o`050?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool0103o0000oooo0?ooo`3oool40?l000030000o`3o
0000o`0000P0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0F0?ooo`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool0?03o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02<0oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?oo
o`0S0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02`3o
ool006`0oooo00<0003o0?ooo`3oool0;03oool00`3o0000oooo0?ooo`0E
0?ooo`030000o`3oool0oooo00`0oooo203o00040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`02
0000o`030?l000000?l0003o00L0003o00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l000000?l0003o00H0003o00<0o`00
0000o`000?l00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3o00020?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0/
0?ooo`030000o`3oool0oooo03`0oooo00<0003o0?ooo`3oool00`3oool2
0000ob<0oooo00<0o`000?ooo`3oool02`3oool50?l000030000o`3o0000
o`0001`0o`0000<0003o0?l0003o00003`3oool00`3o0000oooo0?ooo`0Q
0?ooo`80003o1@3oool00`000?l0oooo0?ooo`0;0?ooo`00K03oool00`00
0?l0oooo0?ooo`0/0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?oo
o`3oool01P3oool50?l000030?ooo`3o0000oooo00T0oooo00<0003o0?oo
o`3oool01@3oool0103o0000oooo0?ooo`3oool60000o`<0oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo
00<0o`000?ooo`3oool01`000?l30?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01P3oool60?l000/0oooo00<0003o0?ooo`3oool0
5P3oool00`3o0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo03`0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0P0?ooo`040?l0
003oool0oooo0?ooo`X0o`001@3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00@0003o0?ooo`3oool0oooo2@3o00060?oo
o`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0;0?ooo`00K03oool00`000?l0oooo0?ooo`0/0?ooo`03
0?l0003oool0oooo01H0oooo00@0003o0?ooo`3oool0oooo1@3o00060?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool30000
o`040?l000000?l0003o0000o`<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?l000020?l000030000o`3o0000o`0000H0o`0000<0003o
0?l0003o00001P3o00001P000?l0o`000?l0003o0000oooo0?l000D0oooo
00@0003o0?ooo`3oool0oooo0`000?l0103o0000003o0000o`000?l40?oo
o`030000o`3oool0oooo00P0oooo00@0o`000?ooo`3oool0oooo203o0003
0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool0;@3oool0
0`000?l0oooo0?ooo`0l0?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool07P3oool50?l000l0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00X0oooo2P3o000N
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool02`3oool0
06`0oooo00<0003o0?ooo`3oool0;03oool00`3o0000oooo0?ooo`0E0?oo
o`030?l000000?l0o`000080o`002`3oool00`3o0000oooo0?ooo`070?oo
o`H0003o0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0o`00
00D0o`000`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`040000o`3oool0oooo0?ooo`@0o`00
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
1P000?l90?ooo`030?l0003oool0oooo00T0oooo0`3o00000`000?l0o`00
0?l0000E0?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0
?03oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01P0oooo
1@3o00020?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00l0oooo
00<0o`000?ooo`3oool00P3oool40?l001T0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0;0?ooo`00K03oool00`000?l0oooo0?oo
o`0]0?ooo`030?l0003oool0oooo0100oooo103o00000`3oool0003o0?oo
o`0=0?ooo`030?l0003oool0oooo00@0oooo0`000?l00`3oool0003o0?oo
o`060?ooo`030?l0003oool0oooo0080oooo0P3o00000`000?l0o`000?oo
o`030?ooo`030?l0003oool0oooo0080oooo00H0003o0?ooo`3oool0oooo
0?l0003oool70000o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?l000030000o`3o0000oooo00<0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0000o`020000o`D0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?l000l0
oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0m0?ooo`03
0000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool04`3oool40?l000L0
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`060?ooo`80o`005P3oool00`000?l0oooo0?ooo`080?ooo`03
0000o`3oool0oooo00/0oooo001]0?ooo`030000o`3oool0oooo02`0oooo
00<0o`000?ooo`3oool02`3oool50?l000D0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`040000o`D0oooo00<0003o0?ooo`3oool0
103oool50?l00080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0000o`070000o`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000
003o0000o`060000o`030?ooo`3o0000oooo00<0oooo00<0003o0?ooo`3o
ool01@3o00070?ooo`030000o`3oool0oooo00<0oooo10000?l00`3oool0
o`000?ooo`0>0?ooo`030000o`3oool0oooo00H0oooo103o000;0?ooo`03
0?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool0?@3oool00`000?l0
oooo0?ooo`090?ooo`030000o`3oool0oooo0100oooo0P3o000;0?ooo`03
0?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3o
ool0203oool30?l00180oooo00<0003o0?ooo`3oool02@3oool00`000?l0
oooo0?ooo`0;0?ooo`00K@3oool00`000?l0oooo0?ooo`0/0?ooo`030?l0
003oool0oooo00H0oooo1@3o000;0?ooo`030000o`3oool0oooo00/0oooo
00<0003o0?l000000?l02@3oool00`000?l0oooo0?ooo`020?ooo`80o`00
00<0oooo0?l0003oool01@3oool00`000?l0oooo0000o`020000o`030?l0
00000?l0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo
0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3oool01P000?l0
oooo0?ooo`3oool0003o0?l00080003o0P3oool00`000?l0oooo0?ooo`04
0?ooo`D0o`000`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3o0000
003o00d0oooo00<0003o0?ooo`3oool02`3oool40?l000L0oooo00<0o`00
0?ooo`3oool0;03oool00`000?l0oooo0?ooo`0m0?ooo`030000o`3oool0
oooo00X0oooo00<0003o0?ooo`3oool03@3oool20?l000d0oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`090?ooo`<0003o00<0o`00
0000o`000?l00`000?l90?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool0303oool20?l000l0oooo00<0003o0?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0;0?ooo`00K@3oool00`000?l0oooo0?ooo`0/0?oo
o`030?l0003oool0oooo0080oooo103o000@0?ooo`030000o`3oool0oooo
00P0oooo0`000?l00`3oool0o`000?ooo`090?ooo`030000o`3oool0oooo
0080o`000`3oool00`3o0000oooo0?ooo`030?ooo`<0003o0`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo103o00000`00
0?l0o`000?l000020?l000@0oooo00D0003o0?ooo`3oool0oooo0?l00003
0?ooo`@0003o1@3oool00`3o0000oooo0?ooo`020?ooo`<0o`0000<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`030000o`X0oooo00<0003o
0?ooo`3oool03`3oool30?l000<0oooo00<0o`000?ooo`3oool0;@3oool0
0`000?l0oooo0?ooo`0m0?ooo`030000o`3oool0oooo00/0oooo00<0003o
0?ooo`3oool02P3oool20?l00100oooo00<0o`000?ooo`3oool03@3oool=
0000o`<0oooo00<0o`000?ooo`3oool00`3oool:0000oa00oooo00<0o`00
0?ooo`3oool03P3oool20?l000`0oooo00<0003o0?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0;0?ooo`00K@3oool00`000?l0oooo0?ooo`0/0?oo
o`D0o`00503oool00`000?l0oooo0?ooo`050?ooo`<0003o1@3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3o0000o`0000H0oooo00<0o`000?oo
o`000?l00P000?l00`3oool0003o0?ooo`040?ooo`030?l0003oool0o`00
0080o`0000<0003o0?l0003o00000P3o00030?ooo`040000o`3oool0oooo
0?ooo`@0o`0000<0003o0?l0003oool00P3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0003o0080003o00<0oooo0?l0003oool01P3oool0
10000?l0oooo0?l0003o00070?ooo`030?l0003oool0oooo00<0oooo0P00
0?l80?ooo`030000o`3oool0oooo0180oooo103o000_0?ooo`030000o`3o
ool0oooo03d0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?oo
o`080?ooo`80o`004P3oool00`3o0000oooo0?ooo`090?ooo`@0003o00<0
oooo0000o`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`H0003o2`3o
ool00`3o0000oooo0?ooo`0@0?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`00K@3oool0
0`000?l0oooo0?ooo`0Y0?ooo`@0o`00603oool00`000?l0oooo0?ooo`02
0?ooo`<0003o203oool00`3o0000oooo0?ooo`050?ooo`80o`0000<0oooo
0000o`3oool01@3oool00`000?l0o`000000o`050?ooo`030000o`3oool0
oooo0080oooo0P3o00030?ooo`050000o`3oool0oooo0?ooo`3o00000`3o
ool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3o0000
0`3o00040?ooo`030000o`3oool0oooo00<0oooo00<0o`000000o`000?l0
1P3oool010000?l0oooo0?ooo`3oool20?l000D0oooo00<0o`000?ooo`3o
ool01@3oool30000o`D0oooo00<0003o0?ooo`3oool05@3oool40?l002`0
oooo00<0003o0?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool04P3oool00`3o0000
oooo0?ooo`040?ooo`D0003o1@3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool00`3oool40000o`L0
oooo00<0o`000?ooo`3oool04@3oool20?l000P0oooo00<0003o0?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`00KP3oool00`000?l0oooo
0?ooo`0T0?ooo`@0o`00103oool00`3o0000oooo0?ooo`0F0?ooo`@0003o
303oool0103o0000oooo0?ooo`3oool30?l000<0oooo00<0003o0?ooo`3o
ool00P3oool20000o`030?ooo`3o0000oooo00D0oooo00<0003o0?ooo`3o
ool00`3o00040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@00
0?l0oooo0?ooo`3oool0o`0000<0oooo00H0003o0?ooo`3oool0oooo0?l0
003oool20?l00080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020000o`<0oooo00<0003o0?ooo`3oool0103oool20?l00080oooo
00<0o`000?ooo`3oool02@3oool30000o`030?ooo`000?l0oooo01L0oooo
00@0o`000?ooo`3oool0oooo103o000W0?ooo`030000o`3oool0oooo03h0
oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`030?ooo`80
o`005P3oool00`3o0000oooo0000o`030000o`/0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00P0
oooo1@000?l00`3oool0o`000?ooo`0E0?ooo`80o`001@3oool00`000?l0
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00/0oooo001^0?ooo`030000
o`3oool0oooo0200oooo103o00080?ooo`030?l0003oool0oooo01D0oooo
0P000?l?0?ooo`040?l0003oool0o`000?l000L0oooo00@0003o0?ooo`00
0?l0003o103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o0000o`00
0080oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0000o`000?l0
o`0000L0003o00D0o`000000o`000?l0oooo0000o`030?ooo`040?l0003o
ool0oooo0?ooo`80o`0000<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`80003o00<0oooo0000o`3oool01`3oool30?l000h0oooo
0`000?lG0?ooo`030?l0003oool0oooo00D0oooo103o000S0?ooo`030000
o`3oool0oooo03h0oooo00<0003o0?ooo`3oool03P3oool01@000?l0oooo
0?ooo`3oool0o`0001L0oooo00<0003o0?l000000?l03`3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool03@3oool010000?l0o`000000o`000?lF0?ooo`050?l0003oool0oooo
0?ooo`000?l0403oool00`000?l0oooo0?ooo`0;0?ooo`00KP3oool00`00
0?l0oooo0?ooo`0L0?ooo`@0o`00303oool00`3o0000oooo0?ooo`0C0?oo
o`80003o00<0oooo0000o`3oool03P3oool20?l000T0oooo0P000?l60?oo
o`030?l0003oool0oooo00<0o`0000<0oooo0000o`3oool00`3oool00`3o
0000oooo0000o`030000o`80oooo00D0o`000?ooo`3oool0oooo0000o`03
0?ooo`030?l0003oool0oooo00@0003o00<0oooo0?l0003oool00`3oool0
10000?l0oooo0?l0003o00020?ooo`030?l0003oool0oooo00D0oooo0P00
0?l90?ooo`<0o`003@3oool00`000?l0oooo0?ooo`020000oaD0oooo00<0
o`000?ooo`3oool02@3oool40?l001l0oooo00<0003o0?ooo`3oool0?P3o
ool00`000?l0oooo0?ooo`0?0?ooo`030000o`3oool0o`0001H0oooo0P00
0?l00`3oool0o`000?ooo`0?0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00<0003o503oool00`3o0000oooo0000o`0A0?ooo`030000o`3o
ool0oooo00/0oooo001^0?ooo`030000o`3oool0oooo01T0oooo0`3o000A
0?ooo`030?l0003oool0oooo0100oooo0P000?l40?ooo`030000o`3oool0
oooo00X0oooo0P3o00000`3oool0o`000?ooo`060?ooo`80003o00<0oooo
0000o`3oool01P3oool20?l000@0oooo00L0003o0?ooo`3oool0oooo0000
o`3o0000003o0080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`04
0000o`3oool0oooo0?l000<0oooo00H0003o0?ooo`3oool0oooo0?l00000
0?l30?ooo`030000o`3oool0oooo0080oooo0`3o00070?ooo`030000o`3o
ool0003o00P0oooo00<0o`000?ooo`3oool00P3o000;0?ooo`030000o`3o
ool0oooo0080oooo0P000?lB0?ooo`030?l0003oool0oooo00h0oooo103o
000K0?ooo`030000o`3oool0oooo03h0oooo00<0003o0?ooo`3oool0403o
ool20000oa@0oooo0P000?l30?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool0103oool20000oa<0oooo00<0
003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`0;0?ooo`00KP3oool0
0`000?l0oooo0?ooo`0G0?ooo`80o`00503oool00`3o0000oooo0?ooo`0>
0?ooo`80003o1P3oool00`000?l0oooo0?ooo`080?ooo`80o`000`3oool0
0`3o0000oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`000?l01P3o
ool20?l000H0oooo0`000?l20?ooo`050?l0003oool0oooo0?ooo`000?l0
0P3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00D0o`000?ooo`3o
ool0oooo0000o`030?ooo`060?l0003oool0003o0000o`3oool0003o1@3o
ool30?l000D0oooo00@0003o0?ooo`3oool0oooo0P000?l50?ooo`030?l0
003oool0oooo00<0oooo0P3o00080?ooo`030000o`3oool0oooo00D0oooo
0P000?l@0?ooo`030?l0003oool0oooo0180oooo103o000F0?ooo`030000
o`3oool0oooo03l0oooo00<0003o0?ooo`3oool03`3oool0103o0000oooo
0?ooo`000?lA0?ooo`80003o1P3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo01L0o`000P3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00H0oooo0P000?l@0?ooo`030000o`3oool0o`000140
oooo00<0003o0?ooo`3oool02`3oool006l0oooo00<0003o0?ooo`3oool0
4`3oool30?l001H0oooo00<0o`000?ooo`3oool0303oool20000o`T0oooo
00<0003o0?ooo`3oool01@3oool20?l000H0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?ooo`80
o`000P3oool00`3o0000oooo0?ooo`020?ooo`80003o103oool01P3o0000
oooo0?ooo`3oool0003o0?ooo`D0o`0000<0003o0?l0003o0000103o0000
1@000?l0oooo0?ooo`3oool0o`0000<0oooo0P000?l50?ooo`040?l0003o
ool0oooo0?l000@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo00D0oooo0P3o00060?ooo`030000
o`3oool0oooo00L0oooo0P000?l=0?ooo`030?l0003oool0oooo01L0oooo
0P3o000D0?ooo`030000o`3oool0oooo03l0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo
0`000?l80?ooo`030?l0003oool0oooo00T0oooo103o00000`000?l0o`00
0?l0000;0?ooo`030?l0003oool0oooo00T0oooo0P3o00000`000?l0o`00
0?l000020?l000/0oooo00<0o`000?ooo`3oool0203oool20000o`d0oooo
00D0003o0?ooo`3oool0oooo0?l0000@0?ooo`030000o`3oool0oooo00/0
oooo001_0?ooo`030000o`3oool0oooo0100oooo0`3o000J0?ooo`030?l0
003oool0oooo00T0oooo0P000?l<0?ooo`030000o`3oool0oooo0080oooo
0P3o00090?ooo`040?l0003oool0003o0000o`H0oooo00@0003o0?ooo`3o
ool0o`00103oool00`3o0000oooo0?ooo`020000o`80oooo00D0003o0?oo
o`3oool0oooo0?l000020?ooo`030?l000000?l0o`000080oooo00@0o`00
0?ooo`3oool0003o0P3oool0203o0000oooo0?ooo`3oool0003o0?l0003o
ool0o`00103oool010000?l0oooo0000o`000?l20?ooo`030?l0003oool0
oooo0080oooo0P3o00000`3oool0003o0?ooo`060?ooo`040000o`3oool0
oooo0?l000X0oooo0P3o00030?ooo`030000o`3oool0oooo00X0oooo0P00
0?l;0?ooo`030?l0003oool0oooo01T0oooo0`3o000A0?ooo`030000o`3o
ool0oooo03l0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00P0oooo0P000?l<0?ooo`030?l0003o
ool0oooo00D0oooo0`3o00050?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`030?ooo`<0o`001`3o
ool00`3o0000oooo0?ooo`0;0?ooo`80003o2P3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool02`3o
ool006l0oooo00<0003o0?ooo`3oool03P3oool20?l001d0oooo00<0o`00
0?ooo`3oool01`3oool20000o`h0oooo00<0003o0?ooo`3oool00P3o000;
0?ooo`030?l000000?l0oooo00P0oooo00<0003o0?l0003oool01@3oool0
0`3o0000003o0?ooo`040?ooo`040000o`3oool0oooo0?ooo`80o`0000<0
oooo0000o`3oool00P3oool0103o0000oooo0?ooo`000?l20?ooo`040?l0
003oool0oooo0000o`80oooo0P3o00030?ooo`030000o`3oool0oooo0080
oooo0P000?l00`3o0000oooo0?ooo`040?ooo`030?l000000?l0oooo00L0
oooo0P000?l00`3o0000oooo0?ooo`0:0?ooo`040?l0003oool0oooo0000
o`h0oooo0P000?l80?ooo`030?l0003oool0oooo01d0oooo0`3o000>0?oo
o`030000o`3oool0oooo03l0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo0P000?l>0?oo
o`030?l0003oool0oooo0080oooo0`3o00080?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?oo
o`<0o`00103oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00D0oooo0P000?l60?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool02`3oool006l0oooo00<0003o0?ooo`3oool02`3oool30?l00200
oooo00<0o`000?ooo`3oool0103oool20000oa40oooo00<0003o0?l0003o
ool0303oool00`000?l0o`000?ooo`080?ooo`030?l000000?l0oooo00D0
oooo00<0003o0?l0003o0000103oool00`000?l0oooo0?l000020?l000<0
oooo00@0003o0?ooo`3oool0o`000P3oool010000?l0oooo0?ooo`3o0002
0?ooo`050000o`3oool0oooo0?l0003oool00P3o00000`000?l0oooo0?oo
o`030?ooo`80o`0000<0003o0?ooo`3oool0103oool00`000?l0o`000?l0
00080?ooo`030?l000000?l0oooo00`0oooo00<0o`000000o`3oool0403o
ool20000o`H0oooo00<0o`000?ooo`3oool0803oool20?l000`0oooo00<0
003o0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0?0?ooo`040?l0003oool0o`000?l000/0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo
0P3o00000`3oool0o`000?ooo`0@0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00/0oooo001`0?ooo`030000o`3oool0oooo00L0oooo0`3o
000S0?ooo`030?l0003oool0oooo0080oooo0P000?lC0?ooo`030?l00000
0?l0oooo00/0oooo00@0003o0?ooo`3oool0o`001`3oool0103o0000oooo
0?ooo`000?l40?ooo`040000o`3oool0oooo0?l000@0oooo00<0o`000000
o`3oool00P3oool0103o0000oooo0?ooo`000?l20?ooo`030?l000000?l0
003o00<0003o00<0o`000?ooo`000?l00`3oool01P3o0000oooo0?ooo`3o
ool0003o0?l000<0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`05
0000o`3oool0oooo0?ooo`3o00001P3oool0103o0000oooo0?ooo`000?l<
0?ooo`030000o`3oool0o`000180oooo0P000?l30?ooo`030?l0003oool0
oooo02<0oooo0`3o00080?ooo`030000o`3oool0oooo0400oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`080?ooo`050000o`3oool0
oooo0?ooo`000?l04P3oool20?l000d0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo0`3o
000A0?ooo`050000o`3oool0oooo0?ooo`000?l02P3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo001`0?ooo`030000o`3o
ool0oooo00D0oooo0P3o000W0?ooo`040?l0003oool0003o0000oa<0oooo
0P3o00000`3oool0003o0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool20?l000@0oooo00@0003o0?ooo`3oool0
003o103oool01P3o0000oooo0?ooo`3o0000oooo0000o`<0oooo00@0o`00
0?ooo`3oool0oooo0P000?l01P3o0000oooo0?ooo`000?l0oooo0?l000<0
003o0P3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00@0o`000?oo
o`3oool0o`00103oool010000?l0oooo0000o`000?l50?ooo`030?l0003o
ool0oooo0080oooo00<0o`000?ooo`3oool00P3oool20000o`X0oooo00@0
003o0?ooo`3oool0o`004`3oool20000o`030?ooo`3o0000oooo02L0oooo
0P3o00060?ooo`030000o`3oool0oooo0400oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0003o0140oooo
0`3o000>0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo0080o`00
403oool00`000?l0oooo0000o`0<0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool02`3oool00740oooo00@0003o0?ooo`3oool0oooo
0`3o000Y0?ooo`030?l000000?l0oooo01<0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`060?ooo`80003o1P3oool0103o0000oooo
0?ooo`3o00070?ooo`80003o1P3oool20?l000<0oooo00D0003o0?ooo`3o
ool0oooo0?l000030000o`80oooo00P0o`000?ooo`000?l0oooo0?l0003o
ool0003o0?ooo`80003o00D0o`000?ooo`3oool0oooo0000o`030?ooo`80
o`001P3oool00`000?l0oooo0?ooo`060?ooo`040?l0003oool0oooo0?l0
00L0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?oo
o`80o`004`3oool00`3o0000003o0?ooo`0Y0?ooo`<0o`000P3oool00`00
0?l0oooo0?ooo`110?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0?0?ooo`050?l0003oool0oooo
0?ooo`3o00003@3oool00`000?l0oooo0?ooo`050?ooo`D0003o00<0o`00
0000o`000?l00`000?l70?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool00P3oool20?l000l0oooo0P000?l<0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool02`3oool00740oooo00@0003o0?l0
003o0000o`00:P3oool20000o`030?ooo`3o0000oooo0180oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo00L0oooo0P3o00080?ooo`80003o1P3oool20?l000@0oooo00@0003o
0?ooo`000?l0o`000P3oool02P000?l0oooo0?ooo`3o0000oooo0000o`3o
ool0o`000?ooo`000?l20?ooo`050?l0003oool0003o0?ooo`000?l0103o
ool20?l000H0oooo0P000?l80?ooo`80o`002@3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0403o
ool0103o0000oooo0000o`000?l[0?ooo`80o`0000<0003o0?ooo`3oool0
@@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`000?l03P3oool20?l000@0oooo00<0o`000?ooo`3oool0
2`3oool80000o`D0oooo00<0o`000?ooo`3oool00`3oool60000o`030?oo
o`000?l0oooo00`0oooo00<0o`000?ooo`3oool0103oool20?l000d0oooo
0P000?l=0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
2`3oool00700oooo00<0o`000000o`3oool0:P3oool20000o`@0oooo00<0
o`000?ooo`3oool03P3oool20?l000L0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`080?ooo`80o`001`3oool010000?l0oooo0?oo
o`000?l40?ooo`030?l0003oool0o`0000D0oooo00H0003o0?ooo`3oool0
o`000?ooo`000?l20?ooo`070?l0003oool0003o0?ooo`3o0000oooo0000
o`020?ooo`040?l0003oool0oooo0000o`@0oooo00@0o`000?ooo`3oool0
o`00103oool010000?l0oooo0?ooo`000?l70?ooo`80o`002P3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool03P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
02T0oooo00@0003o0?ooo`3o0000o`00@@3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00X0oooo00D0003o0?ooo`3oool0oooo0000
o`0;0?ooo`80o`001`3oool00`3o0000oooo0?ooo`080?ooo`@0003o2`3o
ool00`3o0000oooo0?ooo`090?ooo`<0003o303oool00`3o0000oooo0?oo
o`060?ooo`030?l0003oool0oooo00T0oooo00@0003o0?ooo`3oool0003o
303oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo
001^0?ooo`80o`000P3oool00`000?l0oooo0?ooo`0W0?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool03@3oool00`3o0000oooo0?oo
o`080?ooo`050000o`3oool0oooo0?ooo`000?l02P3oool0103o0000oooo
0?ooo`3o00050?ooo`030000o`3oool0oooo0080oooo0P000?l00`3oool0
o`000?ooo`020?ooo`040?l0003oool0oooo0?ooo`80003o0`3oool03@3o
0000oooo0000o`3oool0o`000?ooo`000?l0oooo0?l0003oool0003o0?oo
o`3o00000P3oool00`000?l0oooo0000o`020?ooo`030?l0003oool0oooo
0080oooo00@0o`000?ooo`000?l0003o103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0o`0000/0oooo00D0003o0?ooo`3oool0oooo0000
o`0:0?ooo`030?l0003oool0oooo00`0oooo00<0o`000?ooo`3oool0103o
ool20000obT0oooo00@0003o0?ooo`3oool0oooo0P3o000o0?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00H0oooo0P3o00090?ooo`030?l0
003oool0oooo00@0oooo10000?l30?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`030000o`P0oooo
00<0o`000?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00/0oooo001/0?ooo`80o`00103o
ool00`000?l0oooo0?ooo`0U0?ooo`80003o203oool00`3o0000oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00X0oooo0`000?l;0?ooo`040?l0003o
ool0oooo0?ooo`80o`000P3oool00`000?l0oooo0?ooo`050?ooo`80003o
103oool20?l000040000o`3oool0oooo0000o`<0oooo00<0o`000000o`3o
00000P3o00001P000?l0o`000?l000000?l0oooo0?l000<0oooo00<0003o
0?ooo`000?l00P3o00050?ooo`80003o1P3oool010000?l0oooo0?ooo`3o
ool20?l000<0oooo00<0o`000?ooo`3oool02@3oool30000o``0oooo00<0
o`000?ooo`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo02D0oooo00<0003o0?ooo`3oool0103oool20?l003d0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`0:0?ooo`040?l0003oool0oooo0?ooo`80003o1`3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
0`3oool30000o`D0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo
001Z0?ooo`80o`001`3oool00`000?l0oooo0?ooo`0S0?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0<0?ooo`80003o2P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003o
ool0003o00H0oooo00@0o`000?ooo`3oool0003o103oool00`000?l0o`00
0?l000020?ooo`80003o00X0oooo0?l0003o0000003o0?ooo`3o0000003o
0?l0003oool0003o0P3o00000`3oool0003o0000o`020?ooo`030?l00000
0?l0oooo00@0oooo00<0003o0?ooo`3o00001`3oool00`000?l0oooo0?l0
00060?ooo`030?l0003oool0oooo00P0oooo0P000?l>0?ooo`80o`002@3o
ool00`3o0000oooo0?ooo`090?ooo`80003o9@3oool00`000?l0oooo0?oo
o`060?ooo`80o`00>`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00/0oooo00@0o`000?ooo`000?l0003o
2P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool01`3oool30000o`030?ooo`3o0000oooo00`0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0;0?ooo`00J03oool20?l000T0oooo00<0003o0?ooo`3oool08@3o
ool20000o`d0oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0<0?ooo`040000o`3oool0oooo0000o`P0oooo00<0o`000?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`040?l0003oool0oooo0?ooo`80
003o0P3oool010000?l0oooo0?ooo`3o00030?ooo`0=0000o`3o0000o`00
0?ooo`000?l0o`000000o`3o0000003o0?ooo`3o0000oooo0000o`030?oo
o`040?l0003oool0oooo0000o`80oooo0P000?l30?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?l0003oool01`3oool00`3o0000oooo0?ooo`06
0?ooo`040000o`3oool0oooo0000o`l0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo0240oooo00<0
003o0?ooo`3oool02@3oool20?l003T0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool00P3o000>0?ooo`030000o`3o0000oooo00/0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00X0oooo00<0003o0?l0003oool03@3oool20?l00080oooo00<0
003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02`3oool006H0oooo0P3o000<
0?ooo`030000o`3oool0oooo01h0oooo0P000?l@0?ooo`030?l0003oool0
oooo00@0oooo0P3o000>0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`040000o`3oool0
o`000?l000D0oooo00<0o`000?ooo`3oool00`3oool20000o`@0oooo0P3o
00003@3oool0o`000000o`3oool0o`000000o`3o0000003o0?l000000?l0
o`000?ooo`000?l0103o00030?ooo`<0003o1@3oool00`3o0000oooo0?oo
o`030?ooo`80o`0000<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo00d0oooo0P00
0?lQ0?ooo`030000o`3oool0oooo00/0oooo0P3o000g0?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3o0000oooo00d0oooo0P000?l00`3oool0o`000?oo
o`0;0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0:0?ooo`040?l0003oool0003o0000o`h0oooo
00<0o`000000o`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02`3oool006<0oooo0`3o
000>0?ooo`030000o`3oool0oooo01d0oooo00<0003o0?ooo`3oool0403o
ool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00L0oooo00@0003o0?ooo`3oool0oooo0`3o00000`3oool0o`00
0?ooo`060?ooo`@0003o0`3oool30?l00080003o0P3o00020000o`030?l0
00000?l0003o00<0o`000`3oool40000o`L0oooo00<0o`000?ooo`3o0000
0P3o00020?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo01d0oooo00<0003o0?ooo`3oool03P3oool20?l003D0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00T0oooo00<0o`000000o`000?l02`3oool20000o`@0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`030?ooo`X0o`00
1@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool02P3oool20000o`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00/0oooo001Q0?ooo`80o`004P3oool00`000?l0oooo0?oo
o`0K0?ooo`030000o`3oool0oooo0180oooo00D0o`000?ooo`3oool0oooo
0?l0000@0?ooo`030000o`3oool0oooo00D0oooo0P000?l00`3oool0o`00
0?ooo`080?ooo`030000o`3oool0oooo00D0oooo0`3o00060?ooo`040000
o`3oool0oooo0?ooo`@0003o0P3oool20?l000<0003o103o00020?ooo`@0
003o0`3oool00`000?l0oooo0?ooo`040?ooo`<0o`001P3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo0080003o1`3oool00`000?l0
oooo0?ooo`0>0?ooo`050?l0003oool0oooo0?ooo`3o00004`3oool20000
oad0oooo00<0003o0?ooo`3oool0403oool20?l003<0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00P0oooo00D0o`000?ooo`3oool0oooo0000o`090?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool02@3oool00`3o0000003o0?l00004
0?l000@0oooo00<0o`000?ooo`3oool00`3oool50?l000030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool00`3oool20000o`T0oooo00D0003o
0?ooo`3oool0oooo0?l0000;0?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0;0?ooo`00G`3oool2
0?l001@0oooo00<0003o0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0D
0?ooo`030?l0003oool0o`000100oooo00<0003o0?ooo`3oool0203oool2
0000o`T0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`02
0?l000<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000003o0000o`05
0000o`030?l000000?l0003o00<0003o00<0o`000?ooo`3oool0103oool2
0000o`<0oooo0P3o00000`3oool0o`000?ooo`060?ooo`030000o`3oool0
oooo00P0oooo0P000?l:0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3o00005P3oool00`000?l0oooo0?ooo`0I0?ooo`030000o`3oool0
oooo01<0oooo0P3o000a0?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo0`3o00000`3oool0003o0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?l0003o0000203oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0;
0?ooo`00G@3oool20?l001L0oooo00<0003o0?ooo`3oool05`3oool20000
oaP0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?oo
o`040?l0003oool0003o0000o`L0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`020?oooa40o`000P000?l00`3o0000003o0?l0000?
0?l000@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`80003o00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0603oool0
0`000?l0oooo0?ooo`0E0?ooo`80o`00;`3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool0203oool0103o0000oooo0?ooo`3oool30?l000@0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`040000o`3o
ool0oooo0?ooo`<0o`001@3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0;0?ooo`00F`3oool20?l001T0oooo00<0
003o0?ooo`3oool05P3oool00`000?l0oooo0?ooo`0G0?ooo`040?l0003o
ool0o`000?l000h0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`020?ooo`80003o103oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`020000o`030?l000000?l0003o0080o`000P000?l20?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00<0oooo0P000?l30?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool20?l000030?oo
o`3o0000oooo01L0oooo00<0003o0?ooo`3oool05P3oool00`000?l0oooo
0?ooo`0H0?ooo`80o`00;@3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l02`3oool0103o0000
oooo0?l0003o00070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`80o`000P3oool00`3o
0000oooo0?ooo`090?ooo`80003o0P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00/0oooo001I0?ooo`80
o`00703oool00`000?l0oooo0?ooo`0D0?ooo`030000o`3oool0oooo01L0
oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0103oool50000o`P0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`<0
003o0P3o00001@000?l0o`000000o`3o0000oooo0080o`000`000?l70?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool50000
o`H0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo0080oooo00<0o`000?ooo`3oool05P3oool00`00
0?l0oooo0?ooo`0E0?ooo`030000o`3oool0oooo01X0oooo0P3o000[0?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`000?l0303oool20?l000T0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo0`3o000=0?oo
o`80003o2@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0;0?oo
o`00E`3oool20?l001l0oooo00<0003o0?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0H0?ooo`030?l0003oool0oooo00<0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0
oooo0`000?l60?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool00P3oool30000o`<0o`0000L0oooo0000o`3oool0o`000000o`3o0000
003o0080oooo00<0o`000?ooo`3o00000`000?l40?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool30000o`X0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00<0oooo00<0o`000?ooo`3oool05`3oool20000oa@0oooo00<0003o
0?ooo`3oool07@3oool20?l002T0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
o`0000T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00L0oooo0`3o000=0?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool02`3oool0
05D0oooo0P3o000Q0?ooo`030000o`3oool0oooo0140oooo00<0003o0?oo
o`3oool0603oool00`3o0000oooo0?ooo`050?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`040000o`3oool0oooo0?ooo`D0003o00<0oooo0?l0003oool01@3oool6
0000o`<0oooo0P3o00020?ooo`060000o`3o0000oooo0000o`3oool0o`00
0`3oool20?l000<0oooo1P000?l60?ooo`030?l0003oool0003o00@0003o
0`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`030?l0
003oool0oooo01P0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo
0?ooo`0P0?ooo`80o`009`3oool00`000?l0o`000?l000040?l00080oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00T0oooo0P000?l00`3oool0003o0?ooo`080?ooo`80o`00
0`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo0080o`002P3oool00`000?l0oooo0000o`0:0?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool0103o0000oooo
0?ooo`3oool50?l000030000o`3oool0oooo00/0oooo001i0?ooo`030000
o`3oool0oooo00h0oooo0P000?lJ0?ooo`030?l0003oool0oooo00L0oooo
0P3o00060?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`060?ooo`P0003o00<0oooo0000o`3oool0
1@3oool03P3o0000oooo0?ooo`3o0000003o0?ooo`3o0000oooo0000o`3o
ool0o`000000o`3oool0o`000P3oool00`3o0000oooo0?ooo`030?ooo`80
003o00<0oooo0000o`000?l01P000?l80?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`040?ooo`80
o`002@3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo00l0
oooo00<0003o0?ooo`3oool0B@3oool00`000?l0oooo0?ooo`040?ooo`H0
o`001@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00<0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`020?ooo`@0003o00@0o`000000o`000?l0003o1@3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00<0o`000?oo
o`3oool01@3oool20000o`<0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00<0oooo1`3o00050?oo
o`030000o`3oool0oooo00/0oooo001j0?ooo`030000o`3oool0oooo00`0
oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool20000o`<0oooo0P3o00030?ooo`070000o`3o0000o`000?l0
003oool0003o0?ooo`020?l00080003o0`3oool20?l000<0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00X0oooo00<0o`000?ooo`3oool0603oool0
0`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo04X0oooo00<0003o
0?ooo`3oool01P3oool0103o0000oooo0?ooo`3oool40?l000030?ooo`00
0?l0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`D0003o103oool0103o0000oooo0?oo
o`3oool60000o`P0oooo00<0o`000?ooo`3oool01@3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00<0o`00
0`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00/0oooo
001k0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool06@3o
ool00`3o0000oooo0?ooo`0<0?ooo`80o`000P3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0oooo0?l000@0oooo
00<0003o0?ooo`3oool00`3o00000`000?l0o`000?l000030?ooo`030000
o`3oool0oooo0080oooo00@0o`000?ooo`3oool0003o203oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`020?l000h0oooo00<0o`000?ooo`3o
ool0603oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo04/0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`80
o`00203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool00P3o00080?ooo`030?l0003oool0oooo00@0
oooo0P000?l00`3oool0003o0?ooo`060?ooo`030?l0003oool0oooo00D0
oooo0`000?l70?ooo`030?l0003oool0oooo00H0oooo0P3o00020?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`<0o`001P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00/0oooo001l0?ooo`030000o`3oool0oooo00P0oooo
00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0?0?ooo`80o`00
3@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0o`000?l000040?ooo`050000
o`3oool0oooo0?ooo`3o00000P3oool010000?l0oooo0?ooo`3o00030?oo
o`030000o`3oool0oooo0080oooo0P3o00090?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0;0?oo
o`80o`004@3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo
00T0oooo00<0003o0?ooo`3oool0C03oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00@0003o0?ooo`3o0000o`001@3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?l0003oool02P3oool0103o0000oooo0?ooo`3oool20000o`<0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00<0003o0`3oool00`3o0000oooo0?ooo`090?ooo`030?l00000
0?l0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`040?ooo`80o`0000<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00/0oooo001m0?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0@
0?ooo`040000o`3o0000o`000?l000X0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0
o`000000o`3oool0103oool01@000?l0oooo0?ooo`3oool0o`000080oooo
00@0003o0?ooo`3oool0o`000`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3o0000oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo0`3o00000`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`1=0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool010000?l0oooo0?ooo`3oool30?l0
0080oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?oo
o`030?l000000?l0oooo00/0oooo00<0o`000000o`000?l01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool00`3oool30000o`030?l0003oool0oooo00T0oooo00<0003o0?l0
003oool0203oool00`000?l0oooo0?ooo`070?ooo`040?l0003oool0oooo
0?ooo`<0o`000`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool02`3oool007h0oooo00<0003o0?oo
o`3oool00`3oool20000oa`0oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`020?ooo`80o`001`3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool20?l0
00030?ooo`000?l0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0103o
0000oooo0?ooo`000?l20?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0000o`020?ooo`80o`001P3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool01@3o
ool20?l000@0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0I0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0CP3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool0103oool30?l000P0oooo00<0003o0?ooo`3oool0203o
ool0103o0000oooo0?ooo`000?l:0?ooo`030000o`3o0000oooo00L0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00H0oooo00<0o`000000o`3oool02@3oool010000?l0oooo
0?ooo`3o00090?ooo`030000o`3oool0oooo00L0oooo0`3o00060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0;0?ooo`00OP3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo01/0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`040?ooo`80o`001@3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00P0oooo00@0o`000?ooo`3oool0oooo0`3o00040?ooo`04
0000o`3oool0oooo0000o`@0oooo00D0o`000?ooo`3oool0oooo0000o`02
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`000?l01@3oool3
0?l000<0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo0080oooo0`3o00060?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool06@3oool20000o`D0oooo00<0003o
0?ooo`3oool0CP3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool0103o0000oooo0?l0003o
00060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`050?ooo`80003o0P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`060?ooo`040?l0003oool0003o0000o`L0oooo
00D0003o0?ooo`3oool0oooo0?l000090?ooo`030000o`3oool0oooo00D0
oooo0`3o00090?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0;0?ooo`00O`3oool010000?l0oooo
0?ooo`000?lM0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool01`3oool30?l000030?ooo`3o0000oooo00/0oooo00<0003o0?ooo`3o
ool0203oool40?l000P0oooo0P000?l50?ooo`050?l0003oool0oooo0?oo
o`000?l00`3oool00`3o0000oooo0?ooo`030?ooo`80003o203oool40?l0
00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`020?l0
00X0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0K0?oo
o`050000o`3oool0oooo0?ooo`000?l0D@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
103o0000oooo0?ooo`3oool20?l000<0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool00P3oool20?l000<0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool02`3oool00800oooo0P000?lN0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool02`3oool60?l000P0oooo00<0003o
0?ooo`3oool00P3oool70?l000/0oooo0P000?l50?ooo`050?l0003oool0
oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`030?ooo`80003o2P3o
ool80?l000@0oooo00<0003o0?ooo`3oool01P3oool60?l000`0oooo00<0
003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3o
ool0003o0580oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool30?l000030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`<0o`00103o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo0P00
0?l30?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`020?l000D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool02`3oool00800oooo0P000?lM0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`02
0?ooo`d0o`001`3oool00`3o0000oooo0?ooo`070?ooo`040000o`3oool0
oooo0000o`<0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00@0003o0?ooo`3oool0003o2@3oool00`3o0000
oooo0?ooo`050?ooo`d0o`000`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo0180oooo00<0o`000?ooo`3oool06`3oool00`000?l0
oooo0?ooo`1A0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?l0003o00001`3oool00`3o0000oooo0?ooo`060?ooo`04
0000o`3oool0003o0000o`L0oooo00<0o`000?ooo`3oool0103oool00`3o
0000003o0?l0000:0?l000030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0000o`080?ooo`030?l0003oool0oooo
00D0oooo0`3o00080?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00/0oooo001o0?ooo`040000o`3oool0oooo0000oa/0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo0080oooo0P000?l00`3oool0o`000?ooo`030?oo
o`030000o`3oool0oooo0080oooo00@0o`000?ooo`000?l0003o0`3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool06P3oool00`000?l0oooo0000o`1B
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool00P3o00050?ooo`030?l0003oool0oooo00L0oooo0P000?l9
0?ooo`030?l0003oool0oooo00<0o`0000<0oooo0000o`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`040000o`3o0000o`000?l000<0oooo00<0
o`000?ooo`3oool01`3oool20000o`T0oooo00<0o`000?ooo`3oool00`3o
ool20?l00080oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0;0?ooo`00O`3oool01@000?l0oooo0?ooo`3o
ool0003o01T0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0
o`000000o`000?l00`3oool01`000?l0oooo0?ooo`3oool0003o0?l00000
0?l01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0603oool01@000?l0
oooo0?ooo`3oool0003o0540oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo
0?ooo`3o00002@3oool010000?l0oooo0?ooo`000?l80?ooo`<0o`00103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00@0
003o0?ooo`3oool0oooo0P3o00000`3oool0o`000?ooo`070?ooo`040000
o`3oool0oooo0000o`T0oooo00D0o`000?ooo`3oool0oooo0?l000040?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool02`3oool007h0oooo00<0003o0?ooo`3oool00`3oool20000oaL0
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`00
0?l01`000?l20?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo01H0oooo0P000?l50?ooo`030000o`3oool0oooo04h0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`040?ooo`80o`0000<0oooo0?l0003oool0203oool01@000?l0
oooo0?ooo`3oool0003o00L0oooo0P3o00060?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?oo
o`80o`001`3oool01@000?l0oooo0?ooo`3oool0003o00X0oooo0`3o0006
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool02`3oool007d0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool03P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0D0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0C@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00L0oooo0P3o00080?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0103oool0103o0000oooo0?ooo`3o00050?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo0080o`001@3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00H0oooo0P3o00080?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool0
07`0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0B0?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool00P000?l80?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`060?ooo`80003o00<0oooo0?l0
003oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0C0?oo
o`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0C03oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool00P3o00050?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
o`0000D0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00H0oooo00<0003o0?ooo`3oool00`3o
ool20?l00080oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00/0oooo001k
0?ooo`030000o`3oool0oooo00X0oooo0P000?lA0?ooo`030?l0003oool0
oooo0180oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000000o`3oool0203oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0o`000?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0B
0?ooo`030?l0003oool0oooo0100oooo0P000?l<0?ooo`030000o`3oool0
oooo04/0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo0P3o0002
0?ooo`030000o`3oool0oooo00H0oooo0P000?l20?l000D0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`04
0?ooo`030?l000000?l0003o00L0oooo00@0003o0?ooo`3oool0oooo0P3o
00040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0;0?ooo`00NP3oool0
0`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool02P3oool20000o`030?l0003oool0
oooo00L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00L0oooo00<0o`000000o`3oool0303oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo00d0oooo00<0003o0?ooo`3oool0BP3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`3o0000oooo0000o`090?ooo`030?l000000?l0
oooo00D0oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3o0000oooo00P0oooo00<0003o0?ooo`3o00001`3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool007T0oooo00<0003o
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo01<0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00P0oooo0P000?l30?ooo`030?l0003oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool00P000?l;
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`1:0?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`80o`00203oool0103o0000oooo0?ooo`00
0?l60?ooo`030?l0003oool0oooo0080oooo10000?l00`3o0000003o0000
o`030000o`<0oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?oo
o`3o00080?ooo`80o`00203oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
2`3oool007T0oooo00<0003o0?ooo`3oool0403oool20000o``0oooo00<0
o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0B0?ooo`030?l0003oool0oooo00/0oooo0P000?lB0?ooo`030000o`3o
ool0oooo04T0oooo3`000?l70?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`040000o`3o
ool0o`000?l000D0oooo00D0o`000?ooo`3oool0oooo0000o`060?ooo`03
0?l0003oool0oooo00<0003o0`3oool00`3o0000oooo0?ooo`020?ooo`<0
003o00<0oooo0?l0003oool01@3oool01@000?l0oooo0?ooo`3oool0o`00
00D0oooo0P3o00000`3oool0003o0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0003o00`0003o3@3oool007P0oooo00<0003o0?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo01<0
oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`030?ooo`030?l0003oool0oooo00D0
oooo0P000?l70?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool04`3oool00`000?l0oooo0?ooo`180?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool90000o`L0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo0080oooo0P3o00030?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool0103oool01@3o0000003o0?ooo`3oool0003o
00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l000000?l0
oooo00@0oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`3o
ool20?l000@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo2P000?l50?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool007L0oooo00<0003o
0?ooo`3oool05@3oool20000o`P0oooo00<0o`000?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool00`3oool20000o`X0oooo00D0o`000?ooo`3oool0oooo0?l0
00090?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool00P3o
000:0?ooo`80003o103oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?oo
o`070?ooo`80003o5`3oool00`000?l0oooo0?ooo`170?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`040?l000000?l0003o0000o`@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo
0`3o00060?ooo`80003o0P3oool20000o`050?l0003oool0oooo0?ooo`00
0?l00`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?oo
o`000?l00P3oool20000o`H0oooo0`3o00060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01P3oool010000?l0oooo0?ooo`3oool3
0000o`030?ooo`3o0000oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00/0oooo001f0?oo
o`030000o`3oool0oooo01P0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo00l0oooo0P3o000?0?oo
o`050000o`3oool0oooo0?ooo`000?l03@3oool0103o0000oooo0?ooo`3o
00090?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o00003P3o
ool01@000?l0oooo0?ooo`3oool0003o00l0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0603oool00`000?l0oooo0?ooo`160?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`040?l0003oool0oooo0?ooo`L0003o1@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01P3oool20000o`<0oooo00@0o`000?ooo`3oool0003o0`3oool01@3o
0000oooo0?ooo`3oool0003o0080oooo00@0o`000?ooo`3oool0oooo0P00
0?l80?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`030?ooo`L0003o103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0;0?ooo`00M@3oool00`000?l0oooo0?ooo`0J
0?ooo`80003o103oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool03@3oool010000?l0oooo0000o`00
0?l?0?ooo`<0o`002@3oool00`000?l0oooo0?ooo`070?ooo`80o`00403o
ool30000oa00oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0D0?ooo`030?l0003oool0oooo0080oooo0P000?lL0?ooo`030000o`3o
ool0oooo04D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool010000?l0oooo0?ooo`3oool30000o`030?ooo`3o0000oooo00L0oooo
00<0003o0?ooo`3oool01P3oool0103o0000oooo0?l0003o00060?ooo`80
003o103oool0103o0000oooo0?ooo`000?l20?ooo`040?l0003oool0oooo
0000o`80oooo00<0o`000?ooo`3oool00P3oool20000o`H0oooo0P3o0000
0`3oool0o`000?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`000?l00P000?l30?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool02`3oool007D0oooo00<0003o0?oo
o`3oool0703oool20000o`030?ooo`3o0000oooo01H0oooo00<0003o0?oo
o`3oool0403oool00`3o0000oooo0?ooo`0=0?ooo`80003o4P3oool0103o
0000oooo0?l0003o00070?ooo`030000o`3oool0oooo00D0oooo103o000B
0?ooo`80003o3`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo01@0oooo00<0o`000?ooo`3oool00P000?lO0?ooo`030000o`3oool0
oooo04@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`<0003o1`3oool00`000?l0oooo0?ooo`06
0?ooo`050?l0003oool0oooo0?ooo`3o0000103oool00`000?l0oooo0000
o`040?ooo`040?l0003oool0oooo0000o`80oooo00@0o`000?ooo`3oool0
003o0P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0003o00@0
oooo00D0o`000?ooo`3oool0oooo0?l000080?ooo`030000o`3oool0oooo
00D0oooo0`000?l60?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool02`3oool007@0oooo00<0003o0?ooo`3o
ool07`3oool20000oaL0oooo00<0003o0?ooo`3oool0403oool00`3o0000
oooo0?ooo`0:0?ooo`<0003o00<0oooo0000o`3oool0403oool00`3o0000
oooo0?ooo`020?ooo`D0o`000P3oool00`000?l0oooo0?ooo`050?l000<0
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`030000o``0
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0E0?ooo`80
003o8P3oool00`000?l0oooo0?ooo`130?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0000o`060000o`P0oooo00<0o`000?ooo`3oool00`3oool20?l00003
0?ooo`000?l0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0000o`020?ooo`060?l0003oool0oooo0000o`3oool0o`00103oool0
10000?l0oooo0?ooo`000?l20?ooo`80o`001@3oool00`3o0000oooo0?oo
o`050?ooo`P0003o00<0oooo0?l0003oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00/0oooo001c
0?ooo`030000o`3oool0oooo0200oooo00<0o`000?ooo`000?l00P000?lD
0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool01P3oool4
0000o`@0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`06
0?ooo`<0o`0000@0003o0?l0003o0000o`00203oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00<0oooo0`000?l90?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool04P3oool30000o`030?l0003o
ool0oooo0240oooo00<0003o0?ooo`3oool0@`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool40000o`D0oooo00<0o`000?ooo`3oool01@3o
ool20?l000@0oooo0P000?l30?ooo`030?l000000?l0o`0000<0o`0000@0
003o0?ooo`3oool0o`000P3oool20000o`@0oooo0P3o00080?ooo`030?l0
003oool0oooo0080oooo10000?l70?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`0;0?ooo`00LP3oool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003o
ool0oooo0080oooo0P000?lB0?ooo`030000o`3oool0oooo0100oooo00<0
o`000?ooo`3oool00`3oool30000o`T0oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`070?ooo`<0003o1P3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0100oooo0P00
0?l40?ooo`030?l0003oool0oooo0240oooo00<0003o0?ooo`3oool0@P3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?oo
o`3oool30000o`030?ooo`3o0000oooo00L0oooo00@0003o0?ooo`3o0000
o`00103oool00`000?l0oooo0?ooo`020?l000050000o`3oool0o`000?oo
o`000?l00P3o00020?ooo`030000o`3oool0oooo0080oooo0P3o00000`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0003o0080003o0`3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0;0?oo
o`00LP3oool00`000?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo00D0
oooo10000?l=0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool00`000?l=0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02P3oool40000o`030?ooo`3o0000oooo0180
oooo00<0003o0?ooo`3oool0303oool40000o`H0oooo00<0o`000?ooo`3o
ool08P3oool00`000?l0oooo0?ooo`110?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo10000?l60?ooo`04
0000o`3oool0oooo0?ooo`80o`000`3oool02P000?l0o`000?ooo`3o0000
003o0?ooo`3o0000oooo0000o`3oool20?l000040000o`3oool0oooo0?oo
o`80o`000`3oool00`000?l0oooo0?ooo`040?ooo`@0003o1`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0;0?oo
o`00L@3oool00`000?l0oooo0?ooo`0Q0?ooo`030?l0003oool0oooo00T0
oooo10000?l90?ooo`030000o`3oool0oooo0140oooo0`000?l@0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool00P3oool4000000D0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00l0oooo0`000?lC0?ooo`030000o`3oool0oooo00L0
oooo10000?l;0?ooo`030?l0003oool0oooo0240oooo00<0003o0?ooo`3o
ool0@@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00<0003o0P3oool00`000?l0
oooo0?ooo`040?ooo`0C0?l0003oool0oooo0?l000000?l0oooo0?l00000
0?l0oooo0?l0003oool0003o0?l0003oool0003o0?ooo`3o0000oooo0?l0
00060?ooo`030000o`3oool0oooo00<0003o0P3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00/0oooo001`0?ooo`030000o`3oool0oooo0280oooo00<0o`00
0?ooo`3oool03@3oool70000o`80oooo00<0003o0?ooo`3oool02P3oool7
0000o`030?ooo`3o0000oooo0140oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`000?l01P000?l<0?ooo`030000o`3oool0
oooo00L0003o3`3oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0
oooo0400oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`<0003o1`3oool2
0?l00080oooo00T0003o0?ooo`3o0000003o0?l000000?l0oooo0?l00000
0?l00P3oool20?l000L0oooo0`000?l50?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool02`3oool006l0oooo00<0003o0?ooo`3oool08P3oool00`3o0000oooo
0?ooo`0E0?ooo`l0003o203oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000o`000000000000`0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00L0oooo
3`000?lF0?ooo`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0
?`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo1@000?l30?ooo`<0o`00
0P3oool01`000?l0o`000000o`3o0000003o0?l000000?l00P3oool00`3o
0000oooo0?l000030?ooo`D0003o203oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00/0oooo001_0?ooo`030000o`3oool0oooo0280oooo00<0o`000?ooo`3o
ool05`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo0180
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo0280
oooo00<0003o0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`030?ooo`80
o`001@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`020?ooo`H0003o0P3o00000`3oool0003o0000o`020?l00004
0000o`3oool0o`000?l000H0003o103oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool02`3oool006h0oooo00<0003o0?ooo`3o
ool08`3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0180
oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00@000000?ooo`3oool000001@3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool04P3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo
01L0oooo00<0o`000?ooo`3oool08`3oool00`000?l0oooo0?ooo`0n0?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo0080003o0`3o00060000o`80oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool02`3oool006d0oooo00<0003o0?ooo`3oool08`3oool00`3o0000
oooo0?ooo`0H0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00L0
oooo0P0000060?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo01<0
oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0S0?ooo`03
0000o`3oool0oooo03h0oooo00<0003o0?l0003o0000BP3o00020000od/0
o`0000<0003o0?ooo`3oool02`3oool006d0oooo00<0003o0?ooo`3oool0
8`3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo01<0oooo
00<0o`000?ooo`3oool0503oool01@000?l0oooo0?ooo`3oool0o`000140
oooo00<0003o0?ooo`3oool03`3oool01@3o0000oooo0?ooo`3oool0003o
01D0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0H0?oo
o`030?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool0?@3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0103o
0000oooo0?ooo`3oool30000o`040?l000000?l0o`000?l00080003o0`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`0;0?ooo`00K03oool00`000?l0oooo0?ooo`0T
0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool0503oool0
0`3o0000oooo0?ooo`0D0?ooo`80003o00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0003o01H0oooo00<0o`00
0?ooo`3oool0503oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0
oooo02@0oooo00<0003o0?ooo`3oool0?03oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool40000o`040?ooo`3o0000
oooo0000o`80o`0000<0oooo0?l0003oool010000?l70?ooo`80003o1`3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00/0oooo001[0?ooo`030000o`3oool0
oooo02@0oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?ooo`0D
0?ooo`030?l0003oool0oooo01H0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0@0?ooo`030?l000000?l0oooo01D0oooo00<0o`00
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0
oooo02@0oooo00<0003o0?ooo`3oool0?03oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool00P3oool30000o`030?l0003oool0
oooo0080o`0000L0oooo0000o`000?l0o`000000o`3o0000oooo0080o`00
0P3oool0103o0000003o0000o`000?l40?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`0;0?ooo`00JP3oool00`000?l0oooo
0?ooo`0U0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool0
5@3oool00`3o0000oooo0?ooo`0D0?ooo`040?l0003oool0003o0000oa00
oooo00<0003o0?ooo`3oool03P3oool20000o`030?ooo`3o0000oooo01D0
oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0I0?ooo`03
0?l0003oool0oooo02@0oooo00<0003o0?ooo`3oool0>`3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`000?l00P000?l40?ooo`80
o`0000/0oooo0000o`000?l0o`000000o`3o0000003o0?ooo`3o0000003o
0?ooo`020?l000@0oooo0`000?l00`3oool0003o0?ooo`070?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool02`3oool006X0oooo00<0003o0?ooo`3oool09@3o
ool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01D0oooo00<0
o`000?ooo`3oool0503oool0103o0000oooo0?ooo`3oool20000o`h0oooo
00<0003o0?ooo`3oool0303oool20000o`<0oooo00<0o`000?ooo`3oool0
503oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01T0oooo
00<0o`000?ooo`3oool09@3oool00`000?l0oooo0?ooo`0j0?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool00`3oool40000o`H0oooo0`3o000030000?l0oooo
0?l0003oool0003o0?l000000?l0oooo0?l0003oool0003o0?ooo`80o`00
1P3oool40000o`D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`0;0?ooo`00J@3o
ool00`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo01T0oooo00<0
003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0C0?ooo`030?l0003o
ool0oooo00@0oooo0`000?l;0?ooo`030000o`3oool0oooo00T0oooo0`00
0?l60?ooo`030?l0003oool0oooo0180oooo00<0o`000?ooo`3oool05P3o
ool00`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo02D0oooo00<0
003o0?ooo`3oool0>P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0003o0P3o
ool00`000?l0oooo0?ooo`030?ooo`80o`000P3oool03@000?l0oooo0?oo
o`3o0000003o0?ooo`3o0000oooo0000o`3oool0o`000?ooo`000?l00P3o
ool20?l000@0oooo00@0003o0?ooo`3oool0oooo0`000?l20?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool02`3oool006P0oooo00<0003o0?ooo`3oool09P3o
ool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo01H0oooo00<0
o`000?ooo`3oool04@3oool00`3o0000oooo0?ooo`080?ooo`<0003o203o
ool00`000?l0oooo0?ooo`060?ooo`<0003o2P3oool00`3o0000oooo0?oo
o`0A0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool06@3o
ool00`3o0000oooo0?ooo`0V0?ooo`030000o`3oool0oooo03T0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3oool0oooo
1`000?l60?ooo`030000o`3oool0oooo0080o`00103oool02P000?l0o`00
0?l0003oool0003o0?ooo`3o0000oooo0000o`3oool20?l000030000o`3o
ool0oooo0080oooo0P3o00020?ooo`030000o`3oool0oooo00@0oooo1`00
0?l30?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00/0oooo001X0?ooo`030000o`3oool0oooo02H0oooo00<0o`00
0?ooo`3oool06P3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0
oooo0100oooo00<0o`000?ooo`3oool0303oool40000o`@0oooo00@0003o
0?ooo`3oool0oooo1@000?l>0?ooo`030?l0003oool0oooo0100oooo00<0
o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003o
ool0oooo02L0oooo00<0003o0?ooo`3oool0>03oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool40000o`D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0o`000?l000050?ooo`030000o`3oool0oooo0080o`0000X0
003o0?l0003o0000o`000000o`3o0000oooo0?l0003oool0003o1@3oool2
0?l000030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool4
0000o`L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00/0oooo001W0?oo
o`030000o`3oool0oooo02L0oooo00<0o`000?ooo`3oool06P3oool00`00
0?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo00h0oooo00<0o`000?oo
o`3oool04@3oool80000oa<0oooo00<0o`000?ooo`3oool03`3oool00`3o
0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?oo
o`3oool09`3oool00`000?l0oooo0?ooo`0h0?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`030?ooo`<0003o203oool00`3o0000oooo0?ooo`050?oo
o`030?l000000?l0oooo00<0oooo0P000?l20?ooo`040?l0003oool0003o
0?ooo`<0o`0000@0oooo0000o`3oool0o`000P3oool20000o`@0oooo00<0
003o0?l0003oool01P3oool00`3o0000oooo0?ooo`060?ooo`<0003o1@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool006L0oooo00<0003o
0?ooo`3oool09`3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0
oooo01H0oooo00<0o`000?ooo`3oool03P3oool00`3o0000oooo0?ooo`0E
0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01/0oooo00<0o`00
0?ooo`3oool09`3oool00`000?l0oooo0?ooo`0g0?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0000o`030000o`80oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`030?ooo`80o`000P3oool010000?l0oooo0?ooo`00
0?l30?ooo`040?l0003oool0oooo0000o`80oooo00@0o`000?ooo`3oool0
003o0P3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00<0003o0?oo
o`3oool00P3o00050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool010000?l00`3oool0o`000?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool006H0
oooo00<0003o0?ooo`3oool0:03oool00`3o0000oooo0?ooo`0K0?ooo`03
0000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool0303oool00`3o0000
oooo0?ooo`0F0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo01/0
oooo00<0o`000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0g0?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool30000o`L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`020?l000@0oooo00<0003o0?ooo`000?l0103oool0103o0000
oooo0?ooo`000?l20?ooo`040?l0003oool0oooo0000o`80oooo00<0o`00
0?ooo`3oool00P3oool20000o`D0oooo0P3o00020?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool30000o`H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0;
0?ooo`00IP3oool00`000?l0oooo0?ooo`0X0?ooo`030?l0003oool0oooo
01/0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0:0?oo
o`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool05`3oool00`3o
0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?oo
o`3oool06`3oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo
03H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool70000
o`030?ooo`3o0000oooo00L0oooo00<0003o0?ooo`3oool01P3oool30?l0
00L0oooo0P000?l30?ooo`040?l0003oool0oooo0000o`<0oooo00@0o`00
0?ooo`3oool0003o0`3oool0103o0000oooo0?ooo`3oool20000o`L0oooo
0`3o00080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`000?l0
1P000?l70?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00/0oooo
001U0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?ooo`3oool06`3o
ool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo00T0oooo00<0
o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003o
ool0oooo00P0oooo00<0o`000?ooo`3oool06@3oool00`000?l0oooo0?oo
o`0K0?ooo`030?l0003oool0oooo02T0oooo00<0003o0?ooo`3oool0=@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`D0003o1`3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo0`3o
00080?ooo`<0003o00<0oooo0?l0003oool00P3oool01@000?l0oooo0?oo
o`3oool0o`0000<0oooo00H0003o0?ooo`3oool0oooo0?l0003oool30000
o`T0oooo0P3o00070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool40000o`@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool02`3oool006D0oooo00<0003o0?ooo`3oool0:@3oool00`3o0000
oooo0?ooo`0K0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01P0
oooo00<0o`000?ooo`3oool01`3oool00`3o0000oooo0?ooo`0J0?ooo`03
0000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool0:@3oool00`000?l0
oooo0?ooo`0e0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`H0003o103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool0103o0000oooo0?ooo`3o00060?ooo`80003o0`3oool00`00
0?l0o`000?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0
1P000?l0oooo0?ooo`3oool0o`000000o`<0oooo0P000?l60?ooo`040?l0
003oool0oooo0?l000D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`040000o`3oool0oooo0?ooo`H0003o1@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool02`3oool006@0oooo00<0003o0?ooo`3oool0:@3oool00`3o0000
oooo0?ooo`0L0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01T0
oooo00<0o`000?ooo`3oool01P3oool00`3o0000oooo0?ooo`0I0?ooo`03
0000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool0:P3oool00`000?l0
oooo0?ooo`0d0?ooo`030000o`3oool0oooo00@0oooo00@0o`000?ooo`3o
ool0oooo2@000?l00`3oool0o`000?ooo`070?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool2
0?l000@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030?l000000?l0003o0080oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`060000o`3oool0oooo0?ooo`000?l0o`001@3oool00`000?l0
oooo0?ooo`030?ooo`040?l0003oool0oooo0?ooo`80o`000`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`0:0000o`80oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`0;0?ooo`00I03oool00`000?l0
oooo0?ooo`0Y0?ooo`030?l0003oool0oooo01d0oooo00<0003o0?ooo`3o
ool06P3oool00`3o0000oooo0?ooo`040?ooo`030?l0003oool0oooo01X0
oooo00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`040?ooo`03
0?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool07@3oool00`3o0000
oooo0?ooo`0Y0?ooo`030000o`3oool0oooo03@0oooo2`000?l30?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00@0003o0?ooo`3o
ool0o`001P3oool01@3o0000oooo0?ooo`3oool0003o00H0oooo00<0o`00
0?ooo`3oool00`000?l30?ooo`040?l0003oool0oooo0?ooo`@0003o00<0
oooo0?l0003oool01@3oool01@000?l0oooo0?ooo`3oool0o`0000H0oooo
00<0o`000?ooo`000?l0203oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`020?ooo`X0003o3@3oool006@0oooo00<0003o0?ooo`3oool0:@3o
ool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo01/0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3o
ool0oooo01/0oooo00<0o`000?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0K0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool0:P3o
ool00`000?l0oooo0?ooo`0c0?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`80o`00203oool00`3o0000oooo0000o`060?ooo`030?l0003o
ool0oooo00<0oooo10000?l01P3o0000003o0000o`000?l0oooo0000o`@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?l000080?ooo`80
o`00203oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool02`3oool006<0oooo
00<0003o0?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0M0?ooo`030000
o`3oool0oooo01`0oooo00@0o`000?ooo`3oool0o`007P3oool00`000?l0
oooo0?ooo`0K0?ooo`050?l0003oool0oooo0?ooo`3o00007P3oool00`00
0?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo02X0oooo00<0003o0?oo
o`3oool0<`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool20?l0
00030?ooo`000?l0oooo00P0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01`3oool010000?l0oooo0?l0003o00050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0;0?ooo`00H`3oool00`000?l0oooo0?ooo`0Z
0?ooo`030?l0003oool0oooo01d0oooo00<0003o0?ooo`3oool07@3oool0
0`3o0000oooo0?l0000N0?ooo`030000o`3oool0oooo01`0oooo00<0o`00
0?ooo`3o00007P3oool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0
oooo02/0oooo00<0003o0?ooo`3oool0<P3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00@0o`00
0?ooo`3oool0oooo0P3o00030?ooo`030000o`3oool0oooo00H0oooo00@0
003o0?ooo`3o0000o`00103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P3o00000`3oool0003o
0?ooo`060?ooo`030000o`3oool0oooo0080oooo0P3o00030?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`0;0?ooo`00HP3oool00`000?l0oooo0?oo
o`0[0?ooo`030?l0003oool0oooo01h0oooo00<0003o0?ooo`3oool07@3o
ool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo01`0oooo0P3o
000O0?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0:`3o
ool00`000?l0oooo0?ooo`0b0?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool30?l000H0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`3o00001@3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo
0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`<0o`002@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00/0oooo001R0?ooo`030000
o`3oool0oooo02X0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo
0?ooo`0L0?ooo`030?l0003oool0o`0001h0oooo00<0003o0?ooo`3oool0
6`3oool0103o0000oooo0?ooo`3o000M0?ooo`030000o`3oool0oooo01l0
oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0a0?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool20?l000T0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`040?ooo`<0o`001P3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?l000060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool01`3oool20?l000L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0;0?ooo`00H@3oool00`000?l0oooo
0?ooo`0[0?ooo`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool0
6`3oool01@3o0000oooo0?ooo`3oool0o`0001d0oooo00<0003o0?ooo`3o
ool06P3oool00`3o0000oooo0?ooo`020?ooo`030?l0003oool0oooo01X0
oooo00<0003o0?ooo`3oool07`3oool00`3o0000oooo0?ooo`0/0?ooo`03
0000o`3oool0oooo0340oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`020?ooo`80o`000P3oool00`3o0000
oooo0?ooo`070?ooo`040000o`3oool0oooo0000o`P0oooo0P3o00050?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`040?ooo`80o`00203oool010000?l0oooo0?ooo`000?l9
0?ooo`030?l0003oool0oooo0080o`001@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00/0oooo001Q0?oo
o`030000o`3oool0oooo02/0oooo00<0o`000?ooo`3oool07`3oool00`00
0?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo00<0oooo0P3o000K0?oo
o`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0103oool00`3o
0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo0200oooo00<0o`000?oo
o`3oool0:`3oool00`000?l0oooo0?ooo`0a0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool00P3o00040?oo
o`030?l0003oool0oooo00P0oooo0P000?l90?ooo`030?l0003oool0o`00
0080o`000P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo00@0003o0?ooo`3oool0oooo0P3o00000`3oool0o`000?ooo`08
0?ooo`030000o`3oool0003o00T0oooo00<0o`000?ooo`3oool00P3oool2
0?l000<0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0;0?ooo`00H03oool00`000?l0oooo0?ooo`0/0?oo
o`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool05`3oool20?l0
00P0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0G0?oo
o`80o`00203oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo
0240oooo00<0o`000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0`0?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3o00001`3oool00`3o0000oooo0?ooo`070?ooo`80003o203oool00`3o
0000oooo0?ooo`030?ooo`80o`0000<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`030?ooo`040000o`3o0000o`000?l000@0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00D0oooo00<0o`000?ooo`000?l0203oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0;0?ooo`00H03oool00`000?l0oooo0?ooo`0/0?oo
o`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool05P3oool00`3o
0000oooo0?ooo`090?ooo`030?l0003oool0oooo01L0oooo00<0003o0?oo
o`3oool05P3oool00`3o0000oooo0?ooo`090?ooo`030?l0003oool0oooo
01H0oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?ooo`0/0?oo
o`030000o`3oool0oooo0300oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool20?l000P0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`020000o`H0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0o`000?l000090?l000030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0103oool20000o`030?ooo`000?l0oooo00L0oooo00<0o`000?oo
o`3oool01P3oool20?l000P0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool02`3oool005l0oooo00<0003o0?ooo`3oool0;@3oool00`3o0000
oooo0?ooo`0Q0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3o
ool02`3oool20?l001L0oooo00<0003o0?ooo`3oool0503oool20?l000d0
oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0Q0?ooo`03
0?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`030?ooo`80o`0000<0oooo0000o`3o
ool0203oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo0P000?l40?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?l000020?l000D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool02`3oool005l0oooo00<0003o0?ooo`3oool0;@3oool00`3o0000oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0
3P3oool30?l001@0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo
0?ooo`0>0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0
8P3oool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo02l0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3o00000P3o00030?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`050?ooo`050000o`3oool0oooo0?ooo`3o00001`3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01P3oool0103o0000oooo0?ooo`000?l70?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?oo
o`80o`000P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0;0?oo
o`00GP3oool00`000?l0oooo0?ooo`0^0?ooo`030?l0003oool0oooo0280
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0B0?ooo`80
o`004P3oool00`000?l0oooo0?ooo`0A0?ooo`80o`004P3oool00`3o0000
oooo0?ooo`0B0?ooo`030000o`3oool0oooo0280oooo00<0o`000?ooo`3o
ool0;P3oool00`000?l0oooo0?ooo`0^0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`80
o`001`3oool00`000?l0oooo0?ooo`080?ooo`040?l0003oool0oooo0000
o`T0oooo00<0003o0?ooo`3o0000203oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0000o`090?ooo`040000o`3oool0oooo0?l000T0oooo00<0003o
0?ooo`3oool01P3oool30?l000P0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00/0oooo001N0?oo
o`030000o`3oool0oooo02h0oooo00<0o`000?ooo`3oool08P3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01D0oooo0P3o000@0?oo
o`030000o`3oool0oooo00h0oooo0`3o000E0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool08P3oool00`3o0000oooo0?ooo`0^0?oo
o`030000o`3oool0oooo02h0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo0`3o00080?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`000?l02P3oool00`00
0?l0o`000?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00P0oooo00@0003o0?ooo`3oool0o`002@3oool00`000?l0oooo0?ooo`07
0?ooo`<0o`001P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool02`3oool005h0oooo00<0003o0?oo
o`3oool0;P3oool00`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool0603oool20?l000H0oooo0P0000060?oo
o`030000o`3oool0oooo00/0oooo0`3o000I0?ooo`80o`00403oool00`00
0?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo02h0oooo00<0003o0?oo
o`3oool0;P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00@0003o0?ooo`3oool0oooo0`3o00020?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`09
0?ooo`030?l000000?l0003o00H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo0P000?l0
0`3o0000oooo0?ooo`090?ooo`030000o`3o0000oooo00P0oooo00<0003o
0?ooo`3oool01`3oool0103o0000oooo0?ooo`3oool30?l000<0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00/0oooo001M0?ooo`030000o`3oool0oooo02l0oooo00<0o`00
0?ooo`3oool08`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo01/0oooo1@3o000010000000oooo0?ooo`0000050?ooo`030000o`3o
ool0oooo00L0oooo103o000N0?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool08`3oool00`3o0000oooo0?ooo`0_0?ooo`030000o`3o
ool0oooo02d0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`@0o`001P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00H0oooo0P000?l00`3oool0o`000?ooo`080?ooo`040?l0003o
ool0oooo0?ooo`<0003o0`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool20000o`<0oooo
00<0o`000?ooo`3oool0203oool00`3o0000003o0000o`070?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool40?l000P0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0;0?ooo`00G@3o
ool00`000?l0oooo0?ooo`0_0?ooo`030?l0003oool0oooo02@0oooo00<0
003o0?ooo`3oool02P3oool20?l002<0oooo2@3o00000`000?l0o`000?l0
00070?l002<0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0T0?ooo`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool0;@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo0080oooo0`3o
00000`3oool0003o0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`80o`001`3o
ool00`3o0000oooo0?ooo`040?ooo`@0003o1`3oool00`3o0000oooo0?oo
o`050?ooo`D0003o1@3oool00`3o0000oooo0?ooo`060?ooo`80o`000`3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0o`000?l000020?l000@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0;0?ooo`00G03oool0
0`000?l0oooo0?ooo`0`0?ooo`030?l0003oool0oooo02@0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0V0?ooo`030000003oool0
oooo00<0oooo00<0003o0?ooo`3oool0:`3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo02@0oooo00<0o`000?ooo`3oool0<03oool0
0`000?l0oooo0?ooo`0/0?ooo`030000o`3oool0oooo00H0oooo1@3o0004
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
003o00H0003o00<0o`000000o`000?l01@000?l00`3oool0003o0?ooo`08
0?ooo`030?l0003oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`@0o`00203oool0
0`000?l0oooo0?ooo`0;0?ooo`00G03oool00`000?l0oooo0?ooo`0`0?oo
o`030?l0003oool0oooo02D0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`0T0?ooo`040000003oool0oooo000000D0oooo00<0003o
0?ooo`3oool0;03oool20?l000T0oooo00<0003o0?ooo`3oool09@3oool0
0`3o0000oooo0?ooo`0`0?ooo`030000o`3oool0oooo02`0oooo00<0003o
0?l0003o00001`3o00090?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool02@3oool01@000?l0oooo0?ooo`3oool0003o00P0oooo00<0
o`000?ooo`3oool00P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`080?ooo`040?l0003oool0oooo0?ooo`80o`00203oool010000?l0oooo
0?ooo`000?l:0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool01P3oool90?l000030000o`3oool0oooo00/0oooo001L0?ooo`030000
o`3oool0oooo0300oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo02H0oooo0P0000060?ooo`030000
o`3oool0oooo02h0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`0U0?ooo`030?l0003oool0oooo0340oooo00<0003o0?ooo`3oool0
:`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0003o00X0oooo0P3o00000`3oool0o`000?ooo`090?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`080?ooo`040?l0003oool0o`000?l000/0oooo0P000?l;0?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00/0oooo001K0?ooo`030000
o`3oool0oooo0340oooo00<0o`000?ooo`3oool09P3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo02l0oooo00<0003o0?ooo`3oool0
;`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo02H0oooo
00<0o`000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0[0?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2`3oool20?l000T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00/0oooo001K0?ooo`030000o`3oool0oooo0340oooo00<0
o`000?ooo`3oool09`3oool010000?l0oooo0?ooo`3oool20?l00380oooo
00<0003o0?ooo`3oool0<03oool20?l000@0oooo00<0003o0?ooo`3oool0
9P3oool00`3o0000oooo0?ooo`0a0?ooo`030000o`3oool0oooo02/0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool20000o`d0oooo
00@0o`000?ooo`3o0000o`001`3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool30?l000d0
oooo0P000?l:0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00/0
oooo001K0?ooo`030000o`3oool0oooo0340oooo00<0o`000?ooo`3oool0
:03oool00`000?l0o`000?l0000d0?ooo`030000o`3oool0oooo0380oooo
0P3o00000`3oool0003o0?ooo`0W0?ooo`030?l0003oool0oooo0380oooo
00<0003o0?ooo`3oool0:`3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`060?ooo`040000o`3oool0oooo0000o``0oooo00D0o`000?ooo`3o
ool0oooo0?l000060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`80o`000`3oool00`3o
0000oooo0?ooo`080?ooo`80003o0P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00/0oooo001J0?ooo`03
0000o`3oool0oooo03<0oooo00<0o`000?ooo`3oool09`3oool00`3o0000
oooo0?ooo`0d0?ooo`030000o`3oool0oooo03@0oooo00<0o`000?ooo`3o
ool09`3oool00`3o0000oooo0?ooo`0c0?ooo`030000o`3oool0oooo02X0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00`3oool20000o`@0
oooo0P000?l90?ooo`030?l0003oool0oooo00<0oooo0`3o00030?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool010000?l0
oooo0?ooo`3oool20?l000D0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`030?ooo`80003o1@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0;0?ooo`00FP3oool00`000?l0oooo0?ooo`0c0?ooo`03
0?l0003oool0oooo02D0oooo0P3o00000`3oool0003o0?ooo`0d0?ooo`03
0000o`3oool0oooo03@0oooo00<0003o0?l0003o00009`3oool00`3o0000
oooo0?ooo`0c0?ooo`030000o`3oool0oooo02X0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00T0
oooo00D0o`000?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01`3oool30?l000030000o`3o0000oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`3o0000003o0?l000020?l0
00L0oooo00<0o`000?ooo`3oool01@3oool20000o`P0oooo00D0003o0?oo
o`3oool0oooo0?l0000;0?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0;0?ooo`00F@3oool00`00
0?l0oooo0?ooo`0d0?ooo`030?l0003oool0oooo02@0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0b0?ooo`030000o`3oool0oooo
03<0oooo00D0003o0?ooo`3oool0oooo0?l0000V0?ooo`030?l0003oool0
oooo03<0oooo00<0003o0?ooo`3oool0:P3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool0
103o0000oooo0?ooo`000?l:0?ooo`80003o1@3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0o`000140o`0000<0oooo0000o`3oool02P3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00T0oooo00@0
003o0?ooo`3oool0o`002P3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool02`3oool005T0oooo00<0
003o0?ooo`3oool0=03oool00`3o0000oooo0?ooo`0R0?ooo`80o`001P3o
ool00`000?l0oooo0?ooo`0a0?ooo`030000o`3oool0oooo0380oooo00<0
003o0?ooo`3oool00`3oool20?l002@0oooo00<0o`000?ooo`3oool0<`3o
ool00`000?l0oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l00000
0?l0oooo00`0oooo00D0003o0?ooo`3oool0oooo0?l0000<0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`090?ooo`040?l0003oool0oooo0?ooo`80003o3@3oool00`000?l0
o`000?ooo`0:0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0;0?ooo`00F@3oool00`000?l0oooo
0?ooo`0d0?ooo`030?l0003oool0oooo0200oooo0P3o00080?ooo`030000
o`3oool0oooo0340oooo00<0003o0?ooo`3oool0<P3oool00`000?l0oooo
0?ooo`050?ooo`80o`008P3oool00`3o0000oooo0?ooo`0d0?ooo`030000
o`3oool0oooo02T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0003o0?l0003oool0
3@3oool20000o`030?ooo`3o0000oooo00/0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00X0oooo
00<0o`000000o`000?l03`3oool00`3o0000003o0?ooo`090?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`0;0?ooo`00F03oool00`000?l0oooo0?ooo`0e0?ooo`030?l0003o
ool0oooo01l0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0`0?ooo`030000o`3oool0oooo0340oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0N0?ooo`030?l0003oool0oooo03D0oooo00<0
003o0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool01P3oool010000?l0oooo0?oo
o`3o000?0?ooo`030000o`3o0000oooo00/0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
0P000?l00`3o0000oooo0?ooo`0=0?ooo`040?l0003oool0oooo0000o`T0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00/0oooo001H0?ooo`030000o`3oool0oooo03D0oooo
00<0o`000?ooo`3oool07@3oool20?l000d0oooo00<0003o0?ooo`3oool0
;`3oool00`000?l0oooo0?ooo`0`0?ooo`030000o`3oool0oooo00X0oooo
0P3o000N0?ooo`030?l0003oool0oooo03D0oooo00<0003o0?ooo`3oool0
:@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool01P3oool010000?l0oooo0?ooo`3oool20?l000d0
oooo00<0o`000?ooo`000?l00P000?l80?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`80
003o0P3oool00`3o0000oooo0?ooo`0;0?ooo`80o`00103oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0;0?ooo`00F03oool00`000?l0oooo
0?ooo`0e0?ooo`030?l0003oool0oooo01/0oooo0P3o000@0?ooo`030000
o`3oool0oooo02h0oooo00<0003o0?ooo`3oool0;`3oool00`000?l0oooo
0?ooo`0=0?ooo`80o`00703oool00`3o0000oooo0?ooo`0f0?ooo`030000
o`3oool0oooo02P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`0:0?ooo`030?l0003oool0oooo0080oooo
0`000?l50?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`040?ooo`80003o1@3oool00`3o0000oooo
0?ooo`090?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02`3oool005P0oooo00<0003o0?ooo`3oool0=P3o
ool00`3o0000oooo0?ooo`0H0?ooo`80o`004`3oool00`000?l0oooo0?oo
o`0]0?ooo`030000o`3oool0oooo02d0oooo0P000?lB0?ooo`80o`006P3o
ool00`3o0000oooo0?ooo`0f0?ooo`030000o`3oool0oooo02P0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool01P3oool20?l000T0oooo00<0
o`000?ooo`3oool01P3oool30000o`80oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`090?ooo`040000o`3oool0oooo0?ooo`<0003o
1`3oool00`3o0000oooo0?ooo`070?ooo`80o`002@3oool01@000?l0oooo
0?ooo`3oool0003o00`0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0;0?ooo`00E`3oool00`000?l0oooo0?ooo`0g0?ooo`030?l0
003oool0oooo01H0oooo0P3o000F0?ooo`030000o`3oool0oooo02`0oooo
00<0003o0?ooo`3oool0;03oool00`000?l0oooo0?ooo`0D0?ooo`80o`00
603oool00`3o0000oooo0?ooo`0f0?ooo`030000o`3oool0oooo02P0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`050000
o`3oool0oooo0?ooo`000?l02`3oool00`3o0000oooo0?ooo`060?ooo`03
0?l0003oool0oooo00T0oooo1P000?l80?ooo`030?l0003oool0oooo00L0
oooo1P000?l;0?ooo`030?l0003oool0oooo00D0oooo00<0o`000?ooo`3o
ool02P3oool010000?l0oooo0?ooo`000?l<0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02`3oool005L0oooo00<0003o0?ooo`3o
ool0=`3oool00`3o0000oooo0?ooo`0D0?ooo`80o`00603oool00`000?l0
oooo0?ooo`0/0?ooo`030000o`3oool0oooo02/0oooo00<0003o0?ooo`3o
ool05`3oool20?l001H0oooo00<0o`000?ooo`3oool0=`3oool00`000?l0
oooo0?ooo`0W0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0000o`0=0?ooo`80o`001@3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo20000?l00`3o0000
003o0000o`070000o`<0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`030?ooo`80o`003P3oool20000o``0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0;0?ooo`00E`3oool00`000?l0oooo
0?ooo`0g0?ooo`030?l0003oool0oooo0180oooo0P3o000K0?ooo`030000
o`3oool0oooo02/0oooo00<0003o0?ooo`3oool0:P3oool00`000?l0oooo
0?ooo`0J0?ooo`80o`004`3oool00`3o0000oooo0?ooo`0h0?ooo`030000
o`3oool0oooo02L0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00h0oooo0P3o00030?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00@0o`000?ooo`3oool0
oooo0P3o000@0?ooo`80003o303oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00/0oooo001G0?ooo`030000o`3oool0oooo03L0oooo
00<0o`000?ooo`3oool0403oool20?l001h0oooo00<0003o0?ooo`3oool0
:P3oool00`000?l0oooo0?ooo`0Y0?ooo`030000o`3oool0oooo01d0oooo
0P3o000A0?ooo`030?l0003oool0oooo03P0oooo00<0003o0?ooo`3oool0
9`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00T0oooo
0P000?l00`3oool0003o0000o`0@0?ooo`<0o`003P3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
303oool30?l00100oooo0P000?l20?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`00E`3o
ool00`000?l0oooo0?ooo`0h0?ooo`030?l0003oool0oooo00`0oooo0`3o
000Q0?ooo`030000o`3oool0oooo02T0oooo00<0003o0?ooo`3oool0:03o
ool00`000?l0oooo0?ooo`0P0?ooo`<0o`003P3oool00`3o0000oooo0?oo
o`0i0?ooo`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo0P00
0?l@0?ooo`80o`003@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool20?l00140oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool005H0oooo00<0003o
0?ooo`3oool0>@3oool00`3o0000oooo0?ooo`0:0?ooo`80o`009@3oool2
0000obT0oooo00<0003o0?ooo`3oool09`3oool00`000?l0oooo0?ooo`0T
0?ooo`80o`00303oool00`3o0000oooo0?ooo`0i0?ooo`030000o`3oool0
oooo02H0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`040?l000T0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00P0oooo0`3o0000
0`3oool0o`000?ooo`0?0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00/0oooo001F0?ooo`030000o`3oool0oooo03T0oooo00<0o`000?oo
o`3oool0203oool20?l002T0oooo00<0003o0?ooo`3oool09P3oool00`00
0?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo02L0oooo0P3o000:0?oo
o`030?l0003oool0oooo03T0oooo00<0003o0?ooo`3oool09P3oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0203oool20000o``0oooo00<0o`000?ooo`3oool0103oool40?l0
00D0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00@0oooo103o00050?ooo`030?l0003oool0oooo
00/0oooo0P000?l90?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`00EP3oool00`000?l0
oooo0?ooo`0i0?ooo`030?l0003oool0oooo00H0oooo0P3o000/0?ooo`80
003o9P3oool00`000?l0oooo0?ooo`0T0?ooo`80003o;03oool20?l000L0
oooo00<0o`000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0V0?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`0:0?ooo`80003o2@3oool00`3o0000oooo0?ooo`090?ooo`<0
o`0000<0oooo0000o`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0o`0000<0o`002@3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00/0oooo001F0?ooo`030000
o`3oool0oooo03X0oooo00<0o`000?ooo`3oool00P3oool30?l00300oooo
00<0003o0?ooo`3oool08`3oool00`000?l0oooo0?ooo`0S0?ooo`030000
o`3oool0oooo02h0oooo0`3o00040?ooo`030?l0003oool0oooo03X0oooo
00<0003o0?ooo`3oool09P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00`0oooo00<0o`000000o`3o0000
0`3o00090?ooo`030?l0003oool0oooo00H0oooo1@3o00000`000?l0o`00
0?ooo`0=0?ooo`030?l0003oool0oooo00L0oooo0P000?l>0?ooo`050000
o`3oool0oooo0?ooo`3o0000403oool00`000?l0oooo0?ooo`0;0?ooo`00
EP3oool00`000?l0oooo0?ooo`0j0?ooo`030?l0003oool0o`000080o`00
=03oool20000ob<0oooo00<0003o0?ooo`3oool08@3oool20000oc@0oooo
0`3o00000`3oool0o`000?ooo`0l0?ooo`030000o`3oool0oooo02D0oooo
00<0003o0?ooo`3oool03`3oool0103o0000oooo0?ooo`000?lA0?ooo`80
003o1P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo0080
oooo4P3o00050?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool01@3oool20000oa40oooo00<0003o0?ooo`3o00004@3oool00`000?l0
oooo0?ooo`0;0?ooo`00E@3oool00`000?l0oooo0?ooo`0i0?ooo`@0o`00
>@3oool20000ob40oooo00<0003o0?ooo`3oool0803oool00`000?l0oooo
0?ooo`0g0?ooo`@0o`00>`3oool00`000?l0oooo0?ooo`0U0?ooo`030000
o`3oool0oooo0100oooo0P000?lD0?ooo`80003o0`3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0080oooo
0P000?lD0?ooo`030000o`3oool0oooo0100oooo00<0003o0?ooo`3oool0
2`3oool005D0oooo00<0003o0?ooo`3oool0=@3oool40?l000<0oooo00<0
o`000?ooo`3oool0>@3oool20000oal0oooo00<0003o0?ooo`3oool07P3o
ool20000oc/0oooo00<0o`000?ooo`3oool0103o000g0?ooo`030000o`3o
ool0oooo02D0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?l0
000F0?ooo`80003o00<0oooo0?l0003oool03`3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`020000oaD0oooo00<0o`000?ooo`000?l04@3o
ool00`000?l0oooo0?ooo`0;0?ooo`00E@3oool00`000?l0oooo0?ooo`0`
0?ooo`D0o`001`3oool00`3o0000oooo0?ooo`0k0?ooo`030000o`3oool0
oooo01`0oooo00<0003o0?ooo`3oool0703oool20000oc`0oooo00<0o`00
0?ooo`3oool01@3oool50?l00380oooo00<0003o0?ooo`3oool09@3oool0
0`000?l0oooo0?ooo`0>0?ooo`050000o`3oool0oooo0?ooo`3o00005`3o
ool010000?l0o`000000o`000?l>0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
00000?l0003o01H0oooo00D0o`000?ooo`3oool0oooo0000o`0@0?ooo`03
0000o`3oool0oooo00/0oooo001E0?ooo`@0o`00:@3oool60?l000`0oooo
00<0o`000?ooo`3oool0?03oool20000oa`0oooo00<0003o0?ooo`3oool0
6P3oool20000och0oooo00<0o`000?ooo`3oool02P3oool60?l002T0oooo
103o000W0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0
0`3oool20?l001D0oooo00@0o`000?ooo`3oool0oooo10000?l:0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0:0?ooo`@0003o00<0o`000?ooo`3oool0503oool20?l000D0
oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`00
F@3oool50?l001`0oooo203o000C0?ooo`030?l0003oool0oooo03d0oooo
0P000?lJ0?ooo`030000o`3oool0oooo01P0oooo0P000?lo0?ooo`030?l0
003oool0oooo0140oooo203o000L0?ooo`D0o`00:`3oool00`000?l0oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
4P3oool00`3o0000oooo0?ooo`050?ooo`<0003o1P3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
1@3oool40000o`D0oooo00<0o`000?ooo`3oool04@3oool20?l000P0oooo
00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`00GP3o
oolL0?l001/0oooo00<0o`000?ooo`3oool0?`3oool20000oaP0oooo00<0
003o0?ooo`3oool05P3oool20000od40oooo00<0o`000?ooo`3oool06@3o
oolL0?l00300oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?oo
o`080?ooo`80o`004P3oool00`3o0000oooo0?ooo`080?ooo`P0003o3@3o
ool00`3o0000oooo0?ooo`0<0?ooo`P0003o2@3oool00`3o0000oooo0?oo
o`0?0?ooo`80o`002`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00/0oooo002E0?ooo`030?l0003oool0oooo0440oooo0P000?lF
0?ooo`030000o`3oool0oooo01<0oooo0`000?m30?ooo`030?l0003oool0
oooo06D0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;
0?ooo`80o`00403oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
003o00`0003o00<0o`000000o`000?l03@000?l@0?ooo`030?l0003oool0
oooo00d0oooo0P3o000>0?ooo`030000o`3oool0oooo00X0oooo00<0003o
0?ooo`3oool02`3oool009H0oooo00<0o`000?ooo`3oool0@P3oool40000
oa80oooo00<0003o0?ooo`3oool03`3oool40000odD0oooo00<0o`000?oo
o`3oool0IP3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo
00h0oooo103o000;0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00l0oooo00<0o`000?ooo`3oool02@3oool30?l00140oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`00UP3oool00`3o0000
oooo0?ooo`160?ooo`@0003o1`3oool3000000@0oooo00<0003o0?ooo`3o
ool0303oool30000odT0oooo00<0o`000?ooo`3oool0IP3oool00`000?l0
oooo0?ooo`080?ooo`030000o`3oool0oooo01<0oooo0`3o00080?ooo`03
0?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3o
ool01P3oool30?l001D0oooo00<0003o0?ooo`3oool0203oool00`000?l0
oooo0?ooo`0;0?ooo`00UP3oool00`3o0000oooo0?ooo`1:0?ooo`@0003o
103oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo
1@000?m;0?ooo`030?l0003oool0oooo06L0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0G0?ooo`@0o`00103oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00<0oooo
0`3o000I0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0
2`3oool009L0oooo00<0o`000?ooo`3oool0C@3ooolD0000oe00oooo00<0
o`000?ooo`3oool0I`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo01`0oooo1@3o000A0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo00<0o`007@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00/0oooo002G0?ooo`030?l0003oool0oooo04h0oooo00@00000
0?ooo`3oool000001@3oool00`000?l0oooo0?ooo`1F0?ooo`030?l0003o
ool0oooo06P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0P0?ooo`030?l0003oool0o`0000@0o`00303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0203o
ool:0?l00240oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0;0?ooo`00V03oool00`3o0000oooo0?ooo`1>0?ooo`030000003oool0
000000D0oooo00<0003o0?ooo`3oool0EP3oool00`3o0000oooo0?ooo`1X
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool08@3oool0
0`3o0000oooo0?ooo`040?ooo``0o`0000<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0;0?ooo`80o`0000<0003o0?l0003o00001`3o0008
0?ooo`030?l0003oool0oooo0240oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0;0?ooo`00V03oool00`3o0000oooo0?ooo`1?0?oo
o`8000001@3oool00`000?l0oooo0?ooo`1F0?ooo`030?l0003oool0oooo
06P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0R0?oo
o`030?l0003oool0oooo0100oooo00<0003o0?l0003o00006P3o00020?oo
o`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool08P3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00/0oooo002I0?ooo`03
0?l0003oool0oooo05D0oooo00<0003o0?ooo`3oool0E@3oool00`3o0000
oooo0?ooo`1Y0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool08`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo02<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0;0?ooo`00V@3oool00`3o0000oooo0?ooo`1E0?ooo`030000
o`3oool0oooo05D0oooo00<0o`000?ooo`3oool0J@3oool01@000?l0oooo
0?ooo`3oool0003o02H0oooo00<0o`000?ooo`3oool03`3oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`0T0?ooo`050000o`3oool0oooo0?oo
o`000?l03@3oool009X0oooo00<0o`000?ooo`3oool0E03oool00`000?l0
oooo0?ooo`1D0?ooo`030?l0003oool0oooo06X0oooo00@0003o0?ooo`3o
ool0003o9`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo02D0oooo00@0003o0?ooo`3oool0003o3@3oool0
09X0oooo00<0o`000?ooo`3oool0E03oool00`000?l0oooo0?ooo`1D0?oo
o`030?l0003oool0oooo06<0oooo1@0000020?ooo`030000o`3oool0003o
02P0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03`3oool00`3o
0000oooo0?ooo`0V0?ooo`030000o`3oool0003o00d0oooo002K0?ooo`03
0?l0003oool0oooo05<0oooo00<0003o0?ooo`3oool0D`3oool00`3o0000
oooo0?ooo`1V0?ooo`030000003oool0oooo0080oooo0P000?lY0?ooo`03
0?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3o
ool09`3oool20000o`d0oooo002K0?ooo`030?l0003oool0oooo05<0oooo
00<0003o0?ooo`3oool0D`3oool00`3o0000oooo0?ooo`1V0?ooo`030000
003oool0oooo0080ooooV`000?l=0?ooo`00W03oool00`3o0000oooo0?oo
o`1B0?ooo`030000o`3oool0oooo0580oooo00<0o`000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0:D0oooo002M
0?ooo`030?l0003oool0oooo0540oooo00<0003o0?ooo`3oool0D@3oool0
0`3o0000oooo0?ooo`1X0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0Y@3oool009d0oooo00<0o`000?ooo`3oool0D@3oool00`00
0?l0oooo0?ooo`1A0?ooo`030?l0003oool0oooo06L0oooo0P0000040?oo
o`030000003oool0oooo0:D0oooo002N0?ooo`030?l0003oool0oooo0500
oooo00<0003o0?ooo`3oool0D03oool00`3o0000oooo0?ooo`1^0?ooo`03
0000003oool0oooo0:D0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{605, 175},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Solution.  The exterior angles of a square are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(\[Pi]\/2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(\[Pi]\/2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(\[Pi]\/2\)}]}]]],
  ",  and the formula for the derivative  ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " is  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\(\[Pi]\/2\)\)/\[Pi]\)\) \((z - \
x\_2)\)\^\(\(-\(\[Pi]\/2\)\)/\[Pi]\)\ \((z - x\_3)\)\^\(\(-\(\[Pi]\/2\)\)/\
\[Pi]\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z - \
\((\(-1\))\))\)\^\(-\(1\/2\)\)\) \(\((z - 
                  0)\)\^\(-\(1\/2\)\)\) \((z - 1)\)\^\(-\(1\/2\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(-\(1\/2\)\)\) \(z\^\(-\(1\/2\)\)\) \((z - 1)\)\^\(-\
\(1\/2\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(A\)\(\ \)\(\(\(\ \
\)\(1\)\)\/\(\(\((z + 
                        1)\)\^\(1\/2\)\) \(z\^\(1\/2\)\) \((z - \
1)\)\^\(1\/2\)\)\)\(\ \)\)\)\)}]],
  " \nintegrate and get \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \ B\ \  + \ \ A\ \(\[Integral]\(\(\(\ \)\(1\)\)\/\(\
\(\((z + 1)\)\^\(1\/2\)\) \(z\^\(1\/2\)\) \((z - 1)\)\^\(1\/2\)\)\) \
\[DifferentialD]z\)\)],
    AspectRatioFixed->True],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 6.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "We shall investigate two cases of this formula.\n\n(i)\t",
  Cell[BoxData[
      \(A\  = \ \(1\ \ \ and\ \ \ B\  = \ 0\)\)],
    AspectRatioFixed->True],
  "\n\n(ii)\t",
  Cell[BoxData[
      \(A\  = \ \(0.38137988175090654\ \ \ and\ \ \ B\  = \ 1\)\)],
    AspectRatioFixed->True]
}], "Text"],

Cell[BoxData[
    \(\(\(\(f[
          z_] = \[Integral]\(\(\(\ \)\(1\)\)\/\(\(\((z + 
                          1)\)\^\(1\/2\)\) \(z\^\(1\/2\)\) \((z - \
1)\)\^\(1\/2\)\)\) \[DifferentialD]z;\)\ \[IndentingNewLine]
    \(Needs["\<Graphics`Colors`\>"];\)\ \[IndentingNewLine]
    \(Needs["\<Graphics`ComplexMap`\>"];\)\ \[IndentingNewLine]
    \(CartesianMap[f, {\(-4\), 4, 0.5}, {0.00001, 4.00001, 0.5}, 
        PlotStyle \[Rule] {Blue, 
            Red}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-3\), 0, 1], 
            Range[0, 3, 1]}];\)\ \ \[IndentingNewLine]
    \(Print["\<The image of the upper half plane Im[z] > 0 under the \
mapping\>"];\)\ \[IndentingNewLine]
    \(Print["\<w = f[z] = \>", f[z]];\)\ \[IndentingNewLine]
    \(Print["\<The complete image is a square.\>"];\)\)\(\ \)\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \[IndentingNewLine]
    Needs["\<Graphics`ParametricPlot3D`\>"]\[IndentingNewLine]
    \(Needs["\<Graphics`Colors`\>"];\)\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\(f[
          z_]\  = \ \[Integral]\(\(\(\ \)\(1\)\)\/\(\(\((z + 
                          1)\)\^\(1\/2\)\) \(z\^\(1\/2\)\) \((z - \
1)\)\^\(1\/2\)\)\) \[DifferentialD]z;\)\ \[IndentingNewLine]
    \(F[z_] = 
        f[\(-\(\(\[ImaginaryI]\ \((1 + z)\)\)\/\(\(-1\) + 
                  z\)\)\)];\)\[IndentingNewLine]
    \(graph = 
        PolarMap[
          F, {0.0, 0.99999999999999, 0.0999999999999995}, {0, 
            2  \[Pi], \[Pi]\/12}, PlotStyle \[Rule] {Blue, Red}, 
          Ticks \[Rule] {Range[\(-3\), 0, 1], Range[0, 3, 1]}, 
          PlotRange \[Rule] All];\)\[IndentingNewLine]
    \(Print["\<The image of the upper half plane Im[z] > 0 under the \
mapping\>"];\)\ \[IndentingNewLine]
    \(Print["\<w = f[z] = \>", f[z]];\)\ \[IndentingNewLine]
    \(Print["\<The complete image is a square.\>"];\)\)\(\ \)\)\)], "Input"],

Cell["\<\
For our last construction we will start with the unit disk and map it onto \
the upper half plane, then onto the square.\
\>", "Text"],

Cell[BoxData[{
    \(\(Iden[z_] = z;\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        Iden, {0.0, 0.99999999999999, 0.0999999999999995}, {0, 
          2  \[Pi], \[Pi]\/12}, PlotStyle \[Rule] {Blue, Red}, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], 
            Range[\(-1\), 1, 1]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Start with the unit circle |z| < 1.\>"];\)\ \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(S[
          z_] = \(-\(\(\[ImaginaryI]\ \((1 + z)\)\)\/\(\(-1\) + 
                z\)\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[
        S, {0.0, 0.99999999999999, 0.0999999999999999}, {0, 
          2  \[Pi], \[Pi]\/12}, 
        Ticks \[Rule] \ {Range[\(-4\), 4, 1], Range[2, 4, 1]}, 
        PlotStyle \[Rule] {Blue, Red}, 
        PlotRange \[Rule] {{\(-4.375\), 4.375}, {0, 4.375}}, 
        AspectRatio \[Rule] 1\/2];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<The image of the the unit disk |z| < 1 under the \
mapping\>"];\)\ \), "\[IndentingNewLine]", 
    \(Print["\<w = S[z] = \>", S[z]]\), "\[IndentingNewLine]", 
    \(\(Print["\<is the upper half-plane  Im[w] > 0.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<    S[0] = \>", S[0]\ ];\)\), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \(\(\(\(f[z_]\  = \ 
        1 + \ 0.38137988175090654 \(\[Integral]\(\(\(\ \)\(1\)\)\/\(\(\@z\) \
\(\@\(z + 1\)\) \@\(z - 1\)\)\) \[DifferentialD]z\);\)\ \[IndentingNewLine]
    \(F[z_] = 
        f[\(-\(\(\[ImaginaryI]\ \((1 + z)\)\)\/\(\(-1\) + 
                  z\)\)\)];\)\[IndentingNewLine]
    \(square = 
        PolarMap[
          F, {0.0, 0.99999999999999, 0.0999999999999999}, {0, 
            2  \[Pi], \[Pi]\/12}, PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\[IndentingNewLine]
    \(polysqr = 
        Graphics[{Blue, 
            Line[{{0, 0}, {0, 1}, {1, 1}, {1, 0}, {0, 
                  0}}]}];\)\[IndentingNewLine]
    \(Show[square, polysqr, 
        Ticks \[Rule] {Range[\(-1\), 1, 1], Range[\(-1\), 1, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\[IndentingNewLine]
    \(Print["\<The image of the upper half plane Im[z] > 0 under the \
mapping\>"];\)\ \[IndentingNewLine]
    Print["\<w = f[z] = \>", f[z]]\[IndentingNewLine]
    \(Print["\<This a familiar square.\>"];\)\ \[IndentingNewLine]
    \(Print[\*"\"\<The center is  \!\(w\_0\) = \!\(\(1 + \[ImaginaryI]\)\/2\) \
= \>\"", Chop[N[\(1 + \[ImaginaryI]\)\/2]]\ ];\)\ \[IndentingNewLine]
    \(Print[\*"\"\<               \!\(w\_0\) = f[\[ImaginaryI]] = \>\"", 
        FullSimplify[f[\[ImaginaryI]]]\ ];\)\)\(\ \)\)\)], "Input"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Ideal Fluid Flow",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/FluidFlowBib.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Schwarz-Christoffel Transformation",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/SchwarzChristoffelBib.html"]\
, None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[187575, 3396, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 890666, 16175}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 134, 2, 33, "Text"],
Cell[2239, 66, 1784, 49, 135, "Text"],
Cell[4026, 117, 167306, 2746, 189, 167192, 2742, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[171335, 2865, 2246, 72, 166, "Text"],
Cell[173584, 2939, 966, 37, 109, "Text"],
Cell[174553, 2978, 3486, 105, 223, "Text",
  Evaluatable->False],
Cell[178042, 3085, 7434, 232, 301, "Text",
  Evaluatable->False],
Cell[185479, 3319, 870, 30, 33, "Text"],
Cell[186352, 3351, 872, 29, 33, "Text"],

Cell[CellGroupData[{
Cell[187249, 3384, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[187397, 3390, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[187575, 3396, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[187935, 3408, 471, 9, 49, "Text"],
Cell[188409, 3419, 412, 7, 71, "Text"],
Cell[188824, 3428, 2481, 58, 571, "Text"],
Cell[191308, 3488, 151, 6, 33, "Text"],

Cell[CellGroupData[{
Cell[191484, 3498, 101, 2, 33, "Text"],
Cell[191588, 3502, 412, 7, 71, "Text"],
Cell[192003, 3511, 412, 7, 136, "Input"],
Cell[192418, 3520, 633, 11, 171, "Input"],
Cell[193054, 3533, 718, 12, 222, "Input"],
Cell[193775, 3547, 398, 6, 124, "Input"],
Cell[194176, 3555, 788, 14, 195, "Input"],
Cell[194967, 3571, 576, 10, 185, "Input"],
Cell[195546, 3583, 808, 15, 239, "Input"],
Cell[196357, 3600, 500, 9, 145, "Input"],
Cell[196860, 3611, 791, 14, 238, "Input"],
Cell[197654, 3627, 624, 11, 159, "Input"],
Cell[198281, 3640, 848, 15, 183, "Input"]
}, Closed]],
Cell[199144, 3658, 787, 24, 52, "Text",
  Evaluatable->False],
Cell[199934, 3684, 60324, 992, 189, 60210, 988, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[260261, 4678, 1275, 41, 36, "Text"],
Cell[261539, 4721, 2398, 68, 259, "Text"],
Cell[263940, 4791, 1739, 44, 458, "Text"],

Cell[CellGroupData[{
Cell[265704, 4839, 113, 2, 33, "Text"],
Cell[265820, 4843, 198, 6, 43, "Text"],
Cell[266021, 4851, 647, 13, 235, "Input"],
Cell[266671, 4866, 530, 15, 52, "Text",
  Evaluatable->False],
Cell[267204, 4883, 625, 13, 235, "Input"],
Cell[267832, 4898, 106, 2, 33, "Text",
  Evaluatable->False],
Cell[267941, 4902, 815, 18, 272, "Input"],
Cell[268759, 4922, 132, 5, 33, "Text"],
Cell[268894, 4929, 800, 14, 195, "Input"],
Cell[269697, 4945, 238, 8, 36, "Text"]
}, Closed]],
Cell[269950, 4956, 646, 20, 53, "Text",
  Evaluatable->False],
Cell[270599, 4978, 4207, 121, 205, "Text"],
Cell[274809, 5101, 55062, 906, 137, 54948, 902, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[329874, 6009, 1972, 61, 36, "Text"],
Cell[331849, 6072, 2661, 68, 581, "Text"],

Cell[CellGroupData[{
Cell[334535, 6144, 113, 2, 33, "Text"],
Cell[334651, 6148, 230, 7, 43, "Text"],
Cell[334884, 6157, 702, 15, 235, "Input"],
Cell[335589, 6174, 200, 5, 33, "Text",
  Evaluatable->False],
Cell[335792, 6181, 626, 13, 235, "Input"],
Cell[336421, 6196, 106, 2, 33, "Text",
  Evaluatable->False],
Cell[336530, 6200, 797, 19, 254, "Input"],
Cell[337330, 6221, 195, 6, 33, "Text"],
Cell[337528, 6229, 1364, 27, 296, "Input"],
Cell[338895, 6258, 375, 14, 33, "Text"]
}, Closed]],
Cell[339285, 6275, 1300, 37, 52, "Text",
  Evaluatable->False],
Cell[340588, 6314, 2782, 80, 186, "Text"],
Cell[343373, 6396, 38701, 637, 189, 38587, 633, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[382077, 7035, 1997, 62, 36, "Text"],
Cell[384077, 7099, 1804, 39, 448, "Text"],
Cell[385884, 7140, 1082, 21, 282, "Text"],
Cell[386969, 7163, 889, 22, 156, "Text"],

Cell[CellGroupData[{
Cell[387883, 7189, 113, 2, 33, "Text"],
Cell[387999, 7193, 214, 6, 43, "Text"],
Cell[388216, 7201, 719, 16, 237, "Input"],
Cell[388938, 7219, 200, 5, 33, "Text",
  Evaluatable->False],
Cell[389141, 7226, 244, 6, 83, "Input"],
Cell[389388, 7234, 106, 2, 33, "Text",
  Evaluatable->False],
Cell[389497, 7238, 916, 21, 264, "Input"],
Cell[390416, 7261, 132, 5, 33, "Text"],
Cell[390551, 7268, 942, 16, 190, "Input"],
Cell[391496, 7286, 467, 13, 55, "Text"]
}, Closed]],
Cell[391978, 7302, 1130, 34, 59, "Text"],
Cell[393111, 7338, 48331, 795, 189, 48217, 791, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[441445, 8135, 1274, 41, 36, "Text"],
Cell[442722, 8178, 2678, 67, 506, "Text"],

Cell[CellGroupData[{
Cell[445425, 8249, 115, 2, 33, "Text"],
Cell[445543, 8253, 160, 6, 33, "Text"],
Cell[445706, 8261, 745, 15, 253, "Input"],
Cell[446454, 8278, 139, 4, 33, "Text",
  Evaluatable->False],
Cell[446596, 8284, 253, 6, 78, "Input"],
Cell[446852, 8292, 106, 2, 33, "Text",
  Evaluatable->False],
Cell[446961, 8296, 824, 18, 250, "Input"],
Cell[447788, 8316, 132, 5, 33, "Text"],
Cell[447923, 8323, 1271, 25, 278, "Input"]
}, Closed]],
Cell[449209, 8351, 2710, 75, 56, "Text"],
Cell[451922, 8428, 40698, 670, 189, 40584, 666, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[492623, 9100, 1941, 61, 36, "Text"],
Cell[494567, 9163, 3211, 81, 502, "Text"],

Cell[CellGroupData[{
Cell[497803, 9248, 115, 2, 33, "Text"],
Cell[497921, 9252, 160, 6, 33, "Text"],
Cell[498084, 9260, 819, 16, 293, "Input"],
Cell[498906, 9278, 139, 4, 33, "Text",
  Evaluatable->False],
Cell[499048, 9284, 220, 5, 83, "Input"],
Cell[499271, 9291, 106, 2, 33, "Text",
  Evaluatable->False],
Cell[499380, 9295, 812, 18, 250, "Input"],
Cell[500195, 9315, 132, 5, 33, "Text"],
Cell[500330, 9322, 1298, 26, 256, "Input"]
}, Closed]],
Cell[501643, 9351, 2397, 66, 56, "Text"],
Cell[504043, 9419, 59901, 985, 189, 59787, 981, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[563947, 10406, 1257, 41, 36, "Text"],
Cell[565207, 10449, 4424, 107, 897, "Text"],

Cell[CellGroupData[{
Cell[569656, 10560, 115, 2, 33, "Text"],
Cell[569774, 10564, 160, 6, 33, "Text"],
Cell[569937, 10572, 641, 13, 264, "Input"],
Cell[570581, 10587, 200, 5, 33, "Text",
  Evaluatable->False],
Cell[570784, 10594, 412, 9, 89, "Input"],
Cell[571199, 10605, 106, 2, 33, "Text",
  Evaluatable->False],
Cell[571308, 10609, 1213, 25, 270, "Input"],
Cell[572524, 10636, 132, 5, 33, "Text"],
Cell[572659, 10643, 894, 17, 182, "Input"],
Cell[573556, 10662, 174, 5, 71, "Text"],
Cell[573733, 10669, 754, 13, 194, "Input"]
}, Closed]],
Cell[574502, 10685, 2110, 60, 56, "Text"],
Cell[576615, 10747, 51320, 844, 189, 51206, 840, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[627938, 11593, 1250, 41, 36, "Text"],
Cell[629191, 11636, 2294, 63, 406, "Text"],

Cell[CellGroupData[{
Cell[631510, 11703, 115, 2, 33, "Text"],
Cell[631628, 11707, 160, 6, 33, "Text"],
Cell[631791, 11715, 670, 13, 223, "Input"],
Cell[632464, 11730, 200, 5, 33, "Text",
  Evaluatable->False],
Cell[632667, 11737, 224, 5, 87, "Input"],
Cell[632894, 11744, 106, 2, 33, "Text",
  Evaluatable->False],
Cell[633003, 11748, 682, 16, 210, "Input"],
Cell[633688, 11766, 132, 5, 33, "Text"],
Cell[633823, 11773, 686, 13, 164, "Input"]
}, Closed]],
Cell[634524, 11789, 922, 26, 71, "Text",
  Evaluatable->False],
Cell[635449, 11817, 114732, 1884, 189, 114618, 1880, "GraphicsData", \
"Bitmap", "Text",
  Evaluatable->False],
Cell[750184, 13703, 1845, 46, 298, "Text"],

Cell[CellGroupData[{
Cell[752054, 13753, 115, 2, 33, "Text"],
Cell[752172, 13757, 535, 16, 166, "Text"],
Cell[752710, 13775, 929, 17, 221, "Input"],
Cell[753642, 13794, 1002, 18, 221, "Input"],
Cell[754647, 13814, 146, 3, 33, "Text"],
Cell[754796, 13819, 521, 11, 145, "Input"],
Cell[755320, 13832, 869, 18, 212, "Input"],
Cell[756192, 13852, 1814, 36, 365, "Input"]
}, Closed]],
Cell[758021, 13891, 1204, 34, 71, "Text",
  Evaluatable->False],
Cell[759228, 13927, 121641, 1997, 189, 121527, 1993, "GraphicsData", \
"Bitmap", "Text",
  Evaluatable->False],
Cell[880872, 15926, 2350, 62, 297, "Text"],

Cell[CellGroupData[{
Cell[883247, 15992, 115, 2, 33, "Text"],
Cell[883365, 15996, 312, 9, 109, "Text"],
Cell[883680, 16007, 839, 15, 201, "Input"],
Cell[884522, 16024, 208, 3, 70, "Input"],
Cell[884733, 16029, 868, 17, 209, "Input"],
Cell[885604, 16048, 144, 3, 33, "Text"],
Cell[885751, 16053, 453, 9, 143, "Input"],
Cell[886207, 16064, 847, 17, 210, "Input"],
Cell[887057, 16083, 1376, 26, 293, "Input"]
}, Closed]],
Cell[888448, 16112, 290, 7, 30, "Text"],
Cell[888741, 16121, 278, 6, 33, "Text"],
Cell[889022, 16129, 307, 7, 33, "Text"],
Cell[889332, 16138, 257, 5, 33, "Text"],
Cell[889592, 16145, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

