(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    408698,       7489]*)
(*NotebookOutlinePosition[    409703,       7525]*)
(*  CellTagsIndexPosition[    409626,       7519]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["11.10  Image of a Fluid Flow",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tWe have already examined several two-dimensional fluid flows and have \
discovered that the image of a flow under a conformal transformation is a \
flow.   The conformal mapping ",
  Cell[BoxData[
      RowBox[{"w", "=", 
        RowBox[{
          RowBox[{"u", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}], "+", 
          RowBox[{"\[ImaginaryI]", " ", "v", 
            RowBox[{"(", 
              RowBox[{"x", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "y"}], ")"}]}]}]}]]],
  ",  which is obtained by using the Schwarz-Christoffel formula, allows us \
to find the streamlines for flows in domains in the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane that are bounded by straight-line segments.\n\n\tThe first \
technique is finding the image of a fluid flowing horizontally from left to \
right across the upper half plane  ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  ".  The image of the streamline  ",
  Cell[BoxData[
      \(\(-\[Infinity]\) < t < \[Infinity], \ y = c\)]],
  "  is a streamline given by the parametric equations \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"u", " ", "=", " ", 
          RowBox[{"u", 
            RowBox[{"(", 
              RowBox[{"t", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "c"}], ")"}], "   ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}]}]}], 
        StyleBox[" ",
          FontFamily->"Times New Roman"], 
        StyleBox[",",
          FontFamily->"Times New Roman"], "\[IndentingNewLine]", "\n", 
        RowBox[{"v", " ", "=", " ", 
          RowBox[{
            RowBox[{
              RowBox[{"v", 
                RowBox[{"(", 
                  RowBox[{"t", 
                    StyleBox[",",
                      FontFamily->"Times New Roman",
                      FontSize->12,
                      FontWeight->"Plain",
                      FontSlant->"Plain",
                      FontColor->GrayLevel[0],
                      FontVariations->{"Underline"->False,
                      "StrikeThrough"->False}], "c"}], ")"}], "   ", 
                StyleBox["for",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}]}], "  ", "-", "\[Infinity]"}], "<",
             "t", "<", 
            RowBox[{"\[Infinity]", 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[".",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}]}]]],
  "  \n\nand is oriented in the positive sense (counterclockwise).  The \
streamline  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"u", " ", "=", " ", 
          RowBox[{"u", 
            RowBox[{"(", 
              RowBox[{"t", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", 
        RowBox[{"v", " ", "=", " ", 
          RowBox[{"v", 
            RowBox[{"(", 
              RowBox[{"t", 
                StyleBox[",",
                  FontFamily->"Times New Roman",
                  FontSize->12,
                  FontWeight->"Plain",
                  FontSlant->"Plain",
                  FontColor->GrayLevel[0],
                  FontVariations->{"Underline"->False,
                  "StrikeThrough"->False}], "0"}], ")"}]}]}]}]]],
  "  for  ",
  Cell[BoxData[
      \(\(-\[Infinity]\) < t < \[Infinity]\)]],
  "  is considered to be the boundary wall for a containing vessel for the \
fluid flow."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 11.29.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the mapping  ",
  Cell[BoxData[
      \(w\  = \ \(1\/\[Pi]\) \((\((z\^2 - 1)\)\^\(1\/2\) + 
              Log \((z + \((z\^2 - 1)\)\^\(1\/2\))\))\)\)]],
  "  maps the upper half plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  onto the domain in the w-plane that lies above the boundary curve \
consisting of the rays  ",
  Cell[BoxData[
      RowBox[{\(u \[LessEqual] 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"v", "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "u"}], "\[GreaterEqual]", 
            "0"}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(v = 0\)}]]],
  " and the segment  ",
  Cell[BoxData[
      RowBox[{\(u = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\(-1\) \[LessEqual] v \[LessEqual] 
          0\)}]]],
  "   (see Figure 11.87)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008o0000/R000`400?l0
0000o`00003oo`3ooooo0?oood40oooo003o0?ooool0oooo@@3oool00?l0
ooooo`3ooom10?ooo`00o`3ooooo0?oood40oooo003o0?ooool0oooo@@3o
ool00?l0ooooo`3ooom10?ooo`00o`3ooooo0?oood40oooo003o0?ooool0
oooo@@3oool007<0oooo1@00002a0?ooo`D00000F03oool400000180oooo
2`000?nH0?ooo`00M@3oool00`000000oooo0?ooo`2c0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool07P3oool80000oi00oooo001e
0?ooo`030000003oool0oooo05H0oooo00<00?l00?ooo`3oool0FP3oool0
0`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02D0oooo1`000?n9
0?ooo`00K@3oool4000000@0oooo00<000000?ooo`3oool0EP3oool00`00
o`00oooo0?ooo`1J0?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool04@3oool;0?l000l0oooo20000?n10?ooo`00M@3oool00`000000
oooo0?ooo`1F0?ooo`03003o003oool0oooo05X0oooo00<000000?ooo`3o
ool0F03oool010000000oooo0?ooo`00000M0?ooo`l0o`00203oool70000
ogX0oooo001d0?ooo`800000F03oool00`00o`00oooo0?ooo`1I0?ooo`80
0000F`3oool2000002d0oooo1`3o00080?ooo`D0003oM@3oool00<h0oooo
00<00?l00?ooo`3oool0b`3oool;0000oaH0oooo1`3o00060?ooo`@0003o
L@3oool00<h0oooo00<00?l00?ooo`3oool0eP3oool?0000o`h0oooo1@3o
00050?ooo`<0003oKP3oool00<h0oooo00<00?l00?ooo`3oool0b`3oool4
0?l001H0oooo1`000?l<0?ooo`@0o`00103oool40000ofX0oooo003>0?oo
o`03003o003oool0oooo0<l0oooo3P3o000?0?ooo`L0003o2@3oool30?l0
00D0oooo0`000?mW0?ooo`00cP3oool00`00o`00oooo0?ooo`3M0?ooo`L0
o`003`3oool50000o`L0oooo103o00040?ooo`@0003oH`3oool00780oooo
G000o`2k0?l001<0oooo0`000?lF0?ooo`d0o`001`3oool40000o`L0oooo
0`3o00050?ooo`80003oH@3oool00780ooooG03`oo000`3o0000oooo0?oo
o`1J0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0503o
ool?0000oa@0oooo0`3o00080?ooo`<0003o1`3oool20?l000D0oooo0P00
0?mO0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo05X0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`0S0?ooo`h0003o2@3oool5
0?l000H0oooo0`000?l60?ooo`80o`001@3oool20000oed0oooo001b0?oo
oe`0l?o`00<0o`000?ooo`3oool0b`3oool:0?l001H0oooo1`000?l70?oo
o`D0o`00103oool30000o`D0oooo0P3o00050?ooo`80003oF`3oool00780
ooooG03`oo000`3o0000oooo0?ooo`3E0?ooo`l0o`003P3oool50000o`L0
oooo0`3o00040?ooo`80003o1@3oool20?l000D0oooo0`000?mH0?ooo`00
LP3ooomL0?3ol0030?l0003oool0oooo0>@0oooo3@3o00060?ooo`H0003o
103oool30?l000<0oooo0P000?l50?ooo`80o`001P3oool20000oeH0oooo
001b0?oooe`0l?o`00<0o`000?ooo`3oool0b`3ooolB0000oa@0oooo1@3o
00070?ooo`<0003o103oool20?l000<0oooo0`000?l40?ooo`80o`001P3o
ool30000oe<0oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool0g@3oool>
0000o`/0oooo0`3o00070?ooo`80003o103oool20?l000@0oooo0P000?l4
0?ooo`<0o`001P3oool30000oe00oooo001b0?oooe`0l?o`00<0o`000?oo
o`3oool0ZP3oool30000och0oooo1P000?l80?ooo`@0o`001@3oool20000
o`@0oooo0P3o00040?ooo`80003o1@3oool20?l000L0oooo0P000?m>0?oo
o`00LP3ooomL0?3ol0030?l0003oool0oooo07/0oooo;`000?lQ0?oooaT0
o`003@3oool80000o`@0oooo0`3o00040?ooo`80003o103oool20?l000@0
oooo0P000?l50?ooo`80o`001`3oool20000od`0oooo001b0?oooe`0l?o`
00<0o`000?ooo`3oool0I@3ooolF0000ofT0oooo3@3o00080?ooo`<0003o
103oool20?l000@0oooo0P000?l40?ooo`80o`00103oool20000o`D0oooo
0P3o00070?ooo`80003oBP3oool00780ooooG03`oo000`3o0000oooo0?oo
o`1D0?oooa40003oS03oool50?l000H0oooo0`000?l30?ooo`80o`00103o
ool20000o`@0oooo0P3o00040?ooo`80003o1@3oool20?l000L0oooo0`00
0?m70?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo04/0oooo2@000?mg
0?oooah0003o3@3oool50?l000@0oooo0`000?l20?ooo`80o`00103oool2
0000o`@0oooo00<0o`000?ooo`3oool00`3oool20000o`D0oooo0P3o0008
0?ooo`80003oA@3oool00780ooooG03`oo000`3o0000oooo0?ooo`120?oo
o`T0003oWP3oool<0000o`H0oooo0`3o00040?ooo`80003o0P3oool00`3o
0000oooo0?ooo`030?ooo`80003o0`3oool20?l000D0oooo0P000?l50?oo
o`80o`00203oool30000od80oooo001b0?oooe`0l?o`00<0o`000?ooo`3o
ool0>P3oool80000ohT0oooo2P3o000P0?ooo`H0003o0`3oool20?l000@0
oooo00<0003o0?ooo`3oool00P3o00050?ooo`030000o`3oool0oooo0080
oooo0P3o00050?ooo`80003o1@3oool20?l000T0oooo0P000?m00?ooo`00
LP3ooomL0?3ol0030?l0003oool0oooo03D0oooo1@000?nK0?oooa/0o`00
2`3oool40000o`040?ooo`3o0000o`000?l00080oooo00@0003o0?ooo`3o
ool0oooo0P3o00040?ooo`030000o`3oool0oooo00<0oooo0P3o00050?oo
o`80003o1@3oool30?l000P0oooo0`000?lm0?ooo`00LP3ooomL0?3ol003
0?l0003oool0oooo0300oooo1@000?me0?ooo`<0o`00@`3oool<0?l000<0
oooo0P000?l20?ooo`80o`0000<0oooo0000o`3oool00`3oool20?l000<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`80
003o1P3oool20?l000T0oooo10000?li0?ooo`00LP3ooomL0?3ol0030?l0
003oool0oooo02h0oooo0P000?mP0?oooaX0o`008@3ooolM0000oa@0oooo
103o00000`3oool0003o0?ooo`020?ooo`040?l0003oool0003o0000o`@0
oooo00@0o`000?ooo`3oool0oooo0P000?l50?ooo`80o`001P3oool20000
o`H0oooo0P3o000;0?ooo`@0003o=@3oool00780ooooG03`oo000`3o0000
oooo0?ooo`0[0?ooo`<0003oC@3ooolE0?l005P0oooo5@000?l30?ooo`03
0?l0003oool0003o0080oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo0P3o000=0?oo
o`<0003o<P3oool00780ooooG03`oo000`3o0000oooo0?ooo`0W0?ooo`@0
003o@P3oool>0?l00880oooo10000?l00`3o0000oooo0000o`020?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00@0oooo0P3o00060?ooo`80003o1`3oool30?l0
00d0oooo10000?l^0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo02@0
oooo0`000?ln0?ooo`P0o`00GP3ooole0?l000050000o`3oool0o`000?oo
o`000?l00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo0P000?l80?ooo`@0o`003@3oool40000obX0oooo001b0?oo
oe`0l?o`00<0o`000?ooo`3oool08P3oool20000ocT0oooo203o001V0?oo
oc@0l?o`00@0o`000000o`3oool0o`000P3oool010000?l0oooo0?ooo`3o
00030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool20000o`H0oooo0P3o00070?ooo`80003o2P3oool40?l000d0oooo1000
0?lV0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo0200oooo0P000?lc
0?ooo`P0o`00KP3ooold0?3ol0050?l0003oool0003o0?ooo`3o00000P3o
ool010000?l0oooo0?ooo`3o00030?ooo`80003o0`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool20000o``0oooo103o000=0?ooo`H0003o803oool00780ooooG03`
oo000`3o0000oooo0?ooo`0N0?ooo`80003o;P3oool70?l007H0oooo=03`
oo001@3o0000oooo0000o`3oool0o`0000<0oooo00@0003o0?ooo`3oool0
o`00103oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo0P000?l60?oo
o`80o`00203oool30000o`d0oooo103o000?0?ooo`D0003o6`3oool00780
ooooG03`oo000`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo02X0
oooo103o001m0?oooc@0l?o`00<0o`000?ooo`000?l00P3oool0103o0000
oooo0?ooo`000?l30?ooo`030?l0003oool0oooo0080oooo00@0003o0?oo
o`3oool0oooo0P3o00050?ooo`030000o`3oool0oooo00D0oooo0P3o0009
0?ooo`<0003o3P3oool40?l00100oooo1P000?lE0?ooo`00LP3ooomL0?3o
l0030?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool09P3oool50?l0
04d0oooo5`000?lM0?oooc@0l?o`00<0o`000?ooo`000?l00P3oool01@3o
0000oooo0?ooo`3oool0003o0080oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo0P000?l7
0?ooo`80o`002P3oool30000o`l0oooo103o000B0?ooo`P0003o3@3oool0
0780ooooG03`oo000`3o0000oooo0?ooo`0J0?ooo`80003o9@3oool40?l0
04D0oooo3@000?ld0?oooc@0l?o`00<0o`000?ooo`000?l00`3oool0103o
0000oooo0?ooo`000?l30?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00H0oooo0P3o000;0?ooo`<0003o403oool60?l001@0oooo1P000?l7
0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo01T0oooo00<0003o0?oo
o`3oool0803oool50?l003/0oooo3P000?m10?oooc@0l?o`00@0o`000?oo
o`3oool0003o0P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80o`001@3o
ool20000o`P0oooo0`3o000;0?ooo`@0003o4P3oool50?l001`0oooo001b
0?oooe`0l?o`00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0M
0?ooo`@0o`00>@3oool70000odl0oooo=03`oo00103o0000oooo0?ooo`00
0?l20?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool20000o`T0oooo0`3o000<0?ooo`H0003o4@3oool60?l001H0oooo
001b0?oooe`0l?o`00<0o`000?ooo`3oool05`3oool00`000?l0oooo0?oo
o`0L0?ooo`80o`00=P3oool70000oeH0oooo=03`oo00103o0000oooo0?oo
o`000?l30?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo0P3o00060?ooo`<0
003o2@3oool30?l000l0oooo10000?lC0?ooo`P0o`003P3oool00780oooo
G03`oo000`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo01X0oooo
0`3o000`0?ooo`P0003oG@3ooold0?3ol0040?l0003oool0oooo0000o`<0
oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`00
00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?oo
o`80003o2P3oool30?l00100oooo10000?lG0?ooo`H0o`00203oool00780
ooooG03`oo000`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01T0
oooo0P3o000/0?ooo`L0003oI@3ooold0?3ol0050?l0003oool0oooo0?oo
o`000?l00`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool0103oool20000o`D0oooo0P3o00080?ooo`<0003o2P3oool3
0?l00140oooo10000?lQ0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo
01@0oooo00<0003o0?ooo`3oool0603oool20?l002H0oooo20000?m<0?oo
o`<0o`007@3ooold0?3ol0050?l0003oool0oooo0?ooo`000?l00`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`80o`002@3oool3
0000o`X0oooo103o000A0?ooo`L0003o6P3oool00780ooooG03`oo000`3o
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01L0oooo0P3o000R0?oo
o`H0003oA`3oool=0?l00200oooo=03`oo001@3o0000oooo0?ooo`3oool0
003o00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`090?ooo`<0003o2`3oool40?l001@0oooo30000?l>
0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool05P3oool20?l00200oooo10000?m00?ooo`d0o`00;@3ooold0?3o
l0050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`80o`00303oool30000o``0oooo1@3o000K
0?ooo`H0003o203oool00780ooooG03`oo000`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool0703oool40000
ocH0oooo3P3o000j0?oooc@0l?o`00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`050?ooo`80003o1`3oool20?l000d0oooo0`000?l>
0?ooo`H0o`008`3oool00780ooooG03`oo000`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo01@0oooo0P3o000L0?ooo`<0003o=03oool60?l0
04P0oooo=03`oo000`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool30?l0
00d0oooo0`000?lA0?ooo`T0o`006P3oool00780ooooG03`oo000`3o0000
oooo0?ooo`0@0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3o
ool06@3oool30000oc00oooo1`3o001>0?oooc@0l?o`00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00P0oooo0`3o000=0?ooo`@0003o5P3oool90?l00140
oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0C0?ooo`030?l0003oool0oooo01L0oooo0`000?l/0?ooo`L0o`00
E@3ooold0?3ol0030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
0P3o00070?ooo`80003o2`3oool30?l000h0oooo1P000?lI0?ooo`D0o`00
303oool00780ooooG03`oo000`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo0180oooo0P3o000H0?ooo`80003o9`3oool80?l005`0oooo=03`
oo000`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo0P000?l<0?ooo`<0o`004@3oool60000oaP0oooo0`3o
00090?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool0403oool20?l001L0oooo0`000?lT0?ooo`D0o`00A03oool3
0000oad0oooo=03`oo000`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`80o`00203oool30000o``0oooo103o000C0?ooo`H0003o7P3oool0
0780ooooG03`oo000`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo
0100oooo00<0o`000?ooo`3oool05@3oool20000ob<0oooo103o000m0?oo
o``0003o803ooold0?3ol0030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool0203oool30000o`d0oooo1@3o000D0?oo
o`H0003o603oool00780ooooG03`oo000`3o0000oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0503oool20000ob00
oooo1@3o000d0?ooo`d0003o;03ooold0?3ol0030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00H0oooo0P3o000;0?ooo`<0003o3`3oool40?l001H0
oooo2@000?l?0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0D0?ooo`030000
o`3oool0oooo01X0oooo1P3o000b0?ooo`L0003o>@3ooold0?3ol0030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00L0oooo0P3o000<0?ooo`80003o
4@3oool40?l001/0oooo1P000?l90?ooo`00LP3ooomL0?3ol0030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0C0?ooo`80003o6`3oool20?l00340oooo1`000?m00?oooc@0l?o`00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0203oool20?l000`0oooo0P00
0?lC0?ooo`H0o`00903oool00780ooooG03`oo000`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool04P3oool2
0000oa/0oooo0P3o000]0?ooo`H0003oA`3ooold0?3ol0030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00T0oooo0P3o000<0?ooo`D0003o503oool9
0?l001/0oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool0603oool30?l002P0oooo1`000?m=0?oooc@0l?o`00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo0P000?l;0?ooo`80o`003`3oool60000oaL0oooo303o000?0?oo
o`00LP3ooomL0?3ol0030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0@0?ooo`80003o5`3oool40?l002@0
oooo1`000?mD0?oooc@0l?o`00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo0P000?l;0?ooo`80
o`004`3oool70000oa`0oooo1P3o00090?ooo`00LP3ooomL0?3ol0030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo01@0oooo0`3o000Q0?ooo`L0003o
?03oool30?l001`0oooo=03`oo000`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool20000o`/0oooo
0`3o000G0?ooo`H0003o9@3oool00780ooooG03`oo000`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03`3o
ool20000oaD0oooo0P3o000O0?ooo`D0003o=`3oool<0?l001l0oooo=03`
oo000`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`@0o`006@3o
ool90000oa`0oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00h0oooo0P000?lE
0?ooo`80o`007@3oool40000ocD0oooo1`3o000[0?oooc@0l?o`00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`80o`002P3oool2
0000o`l0oooo103o000N0?ooo`/0003o4@3oool00780ooooG03`oo000`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0C0?ooo`80o`006`3oool40000
ob`0oooo3@3o000b0?oooc@0l?o`00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo0`000?l@0?oo
o`L0o`008P3oool70000o`X0oooo001b0?oooe`0l?o`00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool04@3oool30?l001X0oooo0`000?lY0?ooo`L0
o`00?`3ooold0?3ol0030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0;0?ooo`<0003o503oool70?l002`0
oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
403oool20?l001X0oooo0`000?lV0?ooo`H0o`00AP3ooold0?3ol0030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool20?l000h0oooo
0P000?lI0?ooo`L0o`009@3oool00780ooooG03`oo000`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3o
ool20000oa40oooo0P3o000H0?ooo`@0003o8P3oool70?l004`0oooo=03`
oo000`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo0P3o
000>0?ooo`<0003o7@3oool90?l001`0oooo001b0?oooe`0l?o`00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool03`3oool20?l001H0oooo10000?lQ
0?ooo`D0o`00D`3ooold0?3ol0030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool0303oool20?l000l0oooo1P000?lP0?oooa80o`002P3oool0
0780ooooG03`oo000`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0>0?oo
o`80o`005P3oool20000ob40oooo103o000j0?ooo`<0003o6`3ooold0?3o
l0030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool03@3oool20?l0
01<0oooo1`000?le0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0503oool20000oah0
oooo1@3o000a0?ooo`d0003o7P3ooold0?3ol0030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool03P3oool20?l001P0oooo1`000?l^0?ooo`00
LP3ooomL0?3ol0030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool04P3oool30000oa/0oooo1@3o000`0?ooo`H0003o
:`3ooold0?3ol0030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
403oool30?l001`0oooo40000?lN0?ooo`00LP3ooomL0?3ol0030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00d0oooo0P3o000C0?ooo`80003o6`3o
ool30?l002h0oooo1`000?la0?oooc@0l?o`00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0B0?ooo`H0o`009P3oool<0000oa80oooo001b
0?oooe`0l?o`00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0A0?ooo`80003o6P3oool30?l002@0oooo3@000?lh
0?oooc@0l?o`00<0o`000?ooo`3oool03P3oool20000oaP0oooo1P3o000/
0?ooo`P0003o2P3oool00780ooooG03`oo000`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0;0?ooo`80o`004@3oool30000oaP0oooo103o000Q0?oo
o`H0003oA@3ooold0?3ol0030?l0003oool0oooo0100oooo0`000?lK0?oo
o`X0o`00=03oool00780ooooG03`oo000`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00l0oooo0P000?lH0?ooo`<0
o`00803oool50000od/0oooo=03`oo000`3o0000oooo0?ooo`0C0?ooo`<0
003o8P3oool70?l002d0oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0>0?ooo`80003o
5P3oool40?l00200oooo0`000?m@0?oooc@0l?o`00<0o`000?ooo`3oool0
5P3oool40000obD0oooo4@3o000D0?ooo`@00000103oool00780ooooG03`
oo000`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0:0?ooo`80o`003`3o
ool20000oaD0oooo0`3o000O0?ooo`D0003o;`3oool90?l001/0oooo=03`
oo000`3o0000oooo0?ooo`0J0?ooo`@0003o<P3ooolB0?l00080oooo00<0
00000?ooo`3oool01@3oool00780ooooG03`oo000`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00d0oooo0P000?lE
0?ooo`80o`007@3oool50000obh0oooo1P3o000T0?oooc@0l?o`00<0o`00
0?ooo`3oool07P3oool80000ocl0oooo00<000000?ooo`3oool0103oool0
0780ooooG03`oo000`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool04`3oool20?l0
01/0oooo10000?l]0?ooo`H0o`00:P3ooold0?3ol0030?l0003oool0oooo
02H0oooo1P000?lj0?ooo`030000003oool0oooo00<0oooo001b0?oooe`0
l?o`00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0<0?ooo`80003o4`3oool30?l001T0oooo10000?lZ0?ooo`L0
o`00<03ooold0?3ol0030?l0003oool0oooo02`0oooo4@000?lW0?ooo`04
0000003oool0oooo000000@0oooo001b0?oooe`0l?o`00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo0100oooo0`3o000G0?ooo`D0003o8`3oool;0?l003L0
oooo=03`oo000`3o0000oooo0?ooo`0m0?ooobD0003o0`3oool2000000D0
oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00l0oooo
0P3o000F0?ooo`@0003o9@3oool30?l00480oooo=03`oo000`3o0000oooo
0?ooo`1/0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0>0?ooo`80o`005@3oool30000ob@0oooo1@3o00150?oooc@0l?o`00<0
o`000?ooo`3oool0K03oool00780ooooG03`oo000`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00/0oooo0P000?l?
0?ooo`80o`00503oool30000ob40oooo1P3o001:0?oooc@0l?o`00<0o`00
0?ooo`3oool0K03oool00780ooooG03`oo000`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool03@3oool20?l001<0oooo0`000?lM0?ooo`L0o`00;@3oool90000
oaX0oooo=03`oo000`3o0000oooo0?ooo`1/0?ooo`00LP3ooomL0?3ol003
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo0140
oooo0P000?lK0?ooo`D0o`00;P3oool60000ob<0oooo=000o`1Z0?l000D0
oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`0:0?ooo`80003o3P3oool20?l00180oooo
0P000?lJ0?ooo`<0o`00;@3oool60000obT0oooo=03`oo000`3o0000oooo
0?ooo`1V0?ooo`030000003oool0oooo00<0oooo001b0?oooe`0l?o`00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00`0oooo0P3o000A0?ooo`<0003o6@3o
ool30?l002<0oooo3@000?l_0?oooc@0l?o`00<0o`000?ooo`3oool0K03o
ool00780ooooG03`oo000`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00T0oooo0P000?l=0?ooo`80o`00403oool3
0000oaT0oooo0`3o000Q0?ooo`D0003o?03ooold0?3ol0030?l0003oool0
oooo06`0oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00/0oooo0P3o000@0?ooo`80003o603oool40?l00240oooo0`000?m10?oo
oc@0l?o`00<0o`000?ooo`3oool0A03ooolN0000o`X0oooo001b0?oooe`0
l?o`00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool03P3oool20000oaD0oooo1@3o000Q0?ooo`@0003oA03ooold0?3ol003
0?l0003oool0oooo0300oooo50000?lX0?ooo`00LP3ooomL0?3ol0030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool20000o``0oooo0P3o000?0?ooo`80003o4`3oool40?l00200oooo
1P000?l/0?ooo`<0o`006@3ooold0?3ol0030?l0003oool0oooo02H0oooo
2P000?ll0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00d0oooo0P000?lC0?ooo`80o`007@3o
ool70000ob`0oooo1P3o000L0?oooc@0l?o`00<0o`000?ooo`3oool07P3o
ool80000odH0oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool20000oa<0oooo0P3o000J
0?ooo`D0003o9`3oool<0?l00280oooo=03`oo000`3o0000oooo0?ooo`0J
0?ooo`@0003o?P3oool60?l000X0oooo001b0?oooe`0l?o`00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00X0oooo0P3o000>0?ooo`030000o`3oool0oooo
0140oooo0P3o000I0?ooo`<0003o9@3oool70?l002h0oooo=03`oo000`3o
0000oooo0?ooo`0F0?ooo`@0003o;03ooolF0?l00100oooo001b0?oooe`0
l?o`00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool0303oool20000oa40oooo0`3o000H0?ooo`<0003o8P3oool60?l003D0
oooo=03`oo000`3o0000oooo0?ooo`0D0?ooo`80003o8P3oool>0?l002H0
oooo001b0?oooe`0l?o`00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0>0?ooo`<0o`00
603oool30000oal0oooo1P3o000k0?oooc@0l?o`00<0o`000?ooo`3oool0
4P3oool20000oa/0oooo2@3o000d0?ooo`00LP3ooomL0?3ol0030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`080?ooo`80o`003@3oool20000o`l0oooo0P3o
000G0?ooo`@0003o703oool60?l00440oooo=03`oo000`3o0000oooo0?oo
o`0?0?ooo`<0003o5`3oool60?l003d0oooo001b0?oooe`0l?o`00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00L0oooo0P3o000=0?ooo`80003o3`3oool2
0?l001@0oooo1@000?lK0?ooo`D0o`00A`3ooold0?3ol0030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool04P3oool60?l002H0oooo4`000?l:
0?ooo`00LP3ooomL0?3ol0030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00/0oooo0P000?l?0?ooo`80o`004`3oool30000
oad0oooo0`3o000[0?ooo`P0003o6@3ooold0?3ol0030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool0403oool30?l00280oooo2P000?lM0?oo
o`00LP3ooomL0?3ol0030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00X0oooo0P000?l?0?ooo`80o`004`3oool20000oa`0
oooo103o000X0?ooo`H0003o8@3ooold0?3ol0030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool03`3oool20?l001L0oooo3P000?lW0?ooo`00
LP3ooomL0?3ol0050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`80o`002`3oool20000o`l0
oooo0P3o000C0?ooo`80003o6@3oool50?l002H0oooo1P000?lW0?oooc@0
l?o`00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0=0?ooo`<0
o`00503oool50000ocD0oooo001b0?oooe`0l?o`00D0o`000?ooo`3oool0
oooo0000o`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=0?ooo`80
o`004`3oool20000oaP0oooo0`3o000U0?ooo`H0003o;@3ooold0?3ol003
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0303oool20?l001<0
oooo10000?lZ0?ooo`H0o`002P3oool00780ooooG03`oo001@3o0000oooo
0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`090?ooo`80003o3P3oool20?l00180
oooo0`000?lF0?ooo`@0o`008P3oool60000oc<0oooo=03`oo000`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo0P3o000B0?ooo`<0
003o6@3ooolE0?l00100oooo001b0?oooe`0l?o`00D0o`000?ooo`3oool0
oooo0000o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool0203oool20000o`h0oooo0P3o000A0?ooo`<0
003o503oool50?l001l0oooo1`000?li0?oooc@0l?o`00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00h0
oooo10000?lE0?ooo`L0o`009@3oool00780ooooG03`oo00103o0000oooo
0?ooo`000?l40?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`80003o203oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00`0oooo0P3o000@0?ooo`<0
003o503oool30?l001h0oooo1P000?m00?oooc@0l?o`00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`090?ooo`80o`003@3oool40000oa80
oooo1`3o000/0?ooo`00LP3ooomL0?3ol0040?l0003oool0oooo0000o`<0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool03@3oool30000oa@0oooo0`3o000L0?ooo`D0003oAP3ooold0?3ol003
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0:0?ooo`<0003o4@3oool50?l002<0oooo1P000?l:0?ooo`00
LP3ooomL0?3ol0040?l0003oool0oooo0000o`<0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`80
003o3@3oool20?l000h0oooo0P000?lD0?ooo`<0o`006P3oool50000od/0
oooo=03`oo000`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool02@3oool20000oa40oooo0`3o000L0?ooo``0
003o403oool00780ooooG03`oo000`3o0000oooo0000o`030?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0;0?ooo`80o`003P3oool20000oa<0oooo
0`3o000I0?ooo`@0003oD03ooold0?3ol0030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01P3oool20?l000X0oooo0P000?l@0?ooo`<0o`00
5`3oool80000oa`0oooo001b0?oooe`0l?o`00<0o`000?ooo`000?l00`3o
ool01@3o0000oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`80o`002@3oool00`000?l0oooo
0?ooo`0:0?ooo`80o`003P3oool20000oa80oooo0`3o000H0?ooo`@0003o
E03ooold0?3ol0030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`080?ooo`80003o3P3oool40?l001<0oooo
1`000?lT0?ooo`00LP3ooomM0?l000050?ooo`000?l0oooo0?ooo`3o0000
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool30000oa40oooo
0`3o000G0?ooo`@0003oF03ooold0?3ol0030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00/0oooo0`3o000A0?ooo`H0003o703oool60?l000T0oooo
003?0?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`070?ooo`80003o2`3oool20?l000`0oooo
0P000?lA0?ooo`<0o`005`3oool30000oe`0oooo=03`oo000`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`@0o`003`3oool50000oaX0oooo
203o000?0?ooo`00cP3oool20000o`80oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02P3oool20000oa00oooo0`3o000G0?ooo`<0003o
G`3ooold0?3ol0030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`070?ooo`80003o2@3oool20?l000l0oooo
10000?lI0?ooo`H0o`005`3oool00<P0oooo1P000?l20?ooo`80o`000`3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00T0oooo0P3o000;0?ooo`80003o403oool20?l001L0oooo0`00
0?mR0?oooc@0l?o`00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3o
ool20?l000h0oooo0`000?lD0?ooo`T0o`007@3oool00;d0oooo2`000?l7
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool20000o`X0oooo0P3o000;0?ooo`80003o403oool2
0?l001D0oooo10000?mU0?oooc@0l?o`00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo0P000?l8
0?ooo`80o`00303oool40000o`l0oooo203o000V0?ooo`00RP3ooolc0000
o`l0oooo0`3o00040?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00h0oooo0P3o000B0?ooo`D0003oJ@3ooold0?3o
l0030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo0P3o000;0?oo
o`<0003o3`3oool40?l001l0oooo1P000?l90?ooo`00LP3ooolH0000ocl0
oooo0`3o00060?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool0203oool20?l000/0oooo0P000?l?0?ooo`80
o`004@3oool30000ofh0oooo=03`oo000`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo0`000?l>0?ooo`@0
o`00603oool;0000o`l0oooo00330?ooo`H0o`001`3oool20000o`@0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo0P000?l90?ooo`80o`002`3oool20000o`h0oooo
0`3o000@0?ooo`<0003oL@3ooold0?3ol0030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo0P3o00090?ooo`80003o303oool50?l001<0oooo
2@000?lJ0?ooo`00_@3oool60?l000X0oooo0`000?l50?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3o
ool20000o`h0oooo0P3o000A0?ooo`80003oM03ooold0?3ol0030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3o
ool20000o``0oooo0P3o000B0?ooo`H0003o8`3oool00:`0oooo4@3o000=
0?ooo`<0003o1P3oool20?l000H0oooo00<0003o0?ooo`3oool0103oool2
0?l000L0oooo00<0003o0?ooo`3oool01`3oool20?l000X0oooo0P000?l>
0?ooo`80o`00403oool30000ogH0oooo=03`oo000`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`80o`00203oool20000o``0oooo0P3o000?
0?ooo`D0003o6`3oool50?l000T0oooo002:0?ooob80o`006`3oool30000
o`P0oooo00<0o`000?ooo`3oool0103oool20000o`H0oooo00<0o`000?oo
o`3oool01@3oool20000o`P0oooo0P3o000:0?ooo`80003o3P3oool20?l0
00l0oooo0`000?mi0?oooc@0l?o`00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`060?ooo`80003o2`3oool30?l0
00h0oooo0`000?lE0?ooo`/0o`003P3oool00780oooo603o000h0?ooo`D0
003o2@3oool20?l000D0oooo0P000?l70?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`80
003o3P3oool20?l000l0oooo0P000?ml0?oooc@0l?o`00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00T0oooo0P3o000=0?ooo`@0003o3`3oool90?l001T0
oooo002m0?ooo`D0003o303oool20?l000D0oooo0P000?l70?ooo`80o`00
1`3oool00`000?l0oooo0?ooo`060?ooo`80o`002@3oool20000o`h0oooo
0P3o000?0?ooo`80003oOP3ooold0?3ol0030?l0003oool0oooo0080oooo
00D0003o0?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool01@3oool20000o`T0oooo0`3o000:0?ooo`D0
003o3@3oool60?l00280oooo002d0?ooo`T0003o3`3oool20?l000H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`80003o
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00`0oooo
0P3o000?0?ooo`80003oP03ooold0?3ol0050?l0003oool0oooo0?ooo`00
0?l0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`<0
o`002P3oool30000o`d0oooo1@3o000J0?ooo`H0003o203oool00:@0oooo
40000?lD0?ooo`@0o`001P3oool20000o`L0oooo0P3o00070?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`0:0?ooo`<0o`003`3oool20000oh80oooo=03`oo001@3o0000oooo
0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool20?l000X0oooo0`000?l<0?ooo`@0o`005`3oool80000o`h0
oooo002:0?oooaX0003o7`3oool50?l000P0oooo0P000?l70?ooo`80o`00
203oool00`000?l0oooo0?ooo`060?ooo`80o`002@3oool20000o`/0oooo
0P3o000?0?ooo`<0003oQ03ooold0?3ol0050?l0003oool0oooo0?ooo`00
0?l00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00L0oooo0`000?l;0?ooo`@0o`005@3oool60000oaH0
oooo001b0?oooaP0003o<P3oool70?l000/0oooo0P000?l70?ooo`80o`00
203oool20000o`P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`090?ooo`80o`003P3oool30000ohL0oooo=03`oo001@3o0000oooo
0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`030?l0003oool0oooo00@0oooo0P000?l60?ooo`80o`00203oool20000
o`X0oooo103o000C0?ooo`H0003o703oool00;@0oooo203o000@0?ooo`80
003o1`3oool20?l000T0oooo00<0003o0?ooo`3oool01P3oool20?l000T0
oooo0P000?l:0?ooo`80o`003P3oool20000ohX0oooo=03`oo00103o0000
oooo0?ooo`000?l30?ooo`030?l0003oool0oooo0080oooo00D0003o0?oo
o`3oool0oooo0?l000060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool20000o`X0oooo0P3o000A0?ooo`H0003o5@3oool5
0?l000P0oooo002]0?ooo`L0o`005P3oool20000o`L0oooo0P3o00090?oo
o`80003o1`3oool20?l000T0oooo0P000?l:0?ooo`80o`003@3oool30000
oh`0oooo=03`oo00103o0000oooo0?ooo`000?l30?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool20000o`X0oooo0P3o
000?0?ooo`@0003o4`3oool80?l000d0oooo002T0?ooo`T0o`005`3oool6
0000o`L0oooo0P3o00090?ooo`80003o1`3oool20?l000T0oooo0P000?l;
0?ooo`030?l0003oool0oooo00/0oooo0P000?n?0?oooc@0l?o`00@0o`00
0?ooo`3oool0003o0`3oool0103o0000oooo0?ooo`000?l40?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool20?l000L0oooo
00<0003o0?ooo`3oool01`3oool30?l000d0oooo10000?lA0?ooo`H0o`00
5@3oool008X0oooo6P3o000K0?ooo`D0003o2P3oool30?l000T0oooo0P00
0?l70?ooo`80o`002@3oool20000o`/0oooo0P3o000<0?ooo`80003oT@3o
oold0?3ol0040?l0003oool0oooo0000o`80oooo00D0o`000?ooo`3oool0
oooo0000o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00`3oool20?l000L0oooo0P000?l80?ooo`80o`00303oool40000o`l0
oooo1P3o000K0?ooo`00LP3ooolH0?l00340oooo10000?l=0?ooo`80o`00
2@3oool30000o`P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`090?ooo`80o`00303oool20000oi<0oooo=03`oo000`3o0000oooo
0000o`030?ooo`040?l0003oool0oooo0000o`<0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00D0
oooo0P000?l70?ooo`<0o`002`3oool30000o`d0oooo1P3o000D0?ooo`H0
003o1`3oool00;D0oooo1P000?l?0?ooo`80o`002@3oool20000o`T0oooo
0P3o00090?ooo`80003o2P3oool20?l000`0oooo0P000?nE0?oooc@0l?o`
00<0o`000?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l20?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool20?l000H0
oooo0P000?l70?ooo`80o`002`3oool30000o``0oooo103o000B0?ooo`P0
003o3@3oool00:d0oooo20000?lB0?ooo`<0o`002@3oool20000o`T0oooo
0P3o00090?ooo`80003o2P3oool20?l000`0oooo0P000?nG0?oooc@0l?o`
00<0o`000?ooo`000?l00P3oool0103o0000oooo0?ooo`000?l30?ooo`03
0?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0oooo0P3o00060?oo
o`80003o1P3oool30?l000X0oooo0`000?l;0?ooo`@0o`00403oool60000
oaD0oooo002L0?oooa40003o5P3oool40?l000T0oooo0`000?l90?ooo`80
o`002@3oool20000o`X0oooo0P3o000<0?ooo`80003oV@3ooold0?3ol003
0?l0003oool0003o0080oooo00@0o`000?ooo`3oool0003o0P3oool00`3o
0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00001`3oool0
0`000?l0oooo0?ooo`040?ooo`80o`002P3oool30000o`X0oooo103o000?
0?ooo`D0003o6`3oool008X0oooo4P000?lQ0?ooo`H0o`002`3oool20000
o`X0oooo0P3o00090?ooo`80003o2P3oool20?l000`0oooo0P000?nK0?oo
oc@0l?o`00D0o`000?ooo`000?l0oooo0?l000020?ooo`040000o`3oool0
oooo0?l000<0oooo0P000?l30?ooo`030?l0003oool0oooo00@0oooo0P00
0?l50?ooo`80o`002@3oool30000o`X0oooo0`3o000=0?ooo`H0003o803o
ool007P0oooo4P000?l[0?ooo`P0o`003P3oool30000o`X0oooo0P3o000:
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool2
0000oid0oooo=03`oo00103o0000oooo0000o`3o00020?ooo`040000o`3o
ool0oooo0?l000<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo0P3o00090?ooo`80003o
2@3oool40?l000`0oooo10000?lV0?ooo`00LP3oool60000ocD0oooo203o
000C0?ooo`<0003o2`3oool20?l000X0oooo0P000?l:0?ooo`80o`002P3o
ool30000oil0oooo=@3o00000`000?l0oooo0?l000020?ooo`030000o`3o
ool0o`0000<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`80003o1@3oool00`3o0000oooo0?ooo`060?ooo`<0003o1`3o
ool40?l000`0oooo10000?lZ0?ooo`00Y03oool90?l001L0oooo10000?l<
0?ooo`80o`002P3oool20000o`X0oooo0P3o000:0?ooo`80003oe@3oool3
0000o`040?l0003oool0oooo0000o`80oooo00@0o`000?ooo`3oool0003o
103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
0P3o00070?ooo`80003o1`3oool30?l000`0oooo10000?l^0?ooo`00W03o
ool80?l001`0oooo10000?l=0?ooo`<0o`002P3oool20000o`X0oooo0P3o
000:0?ooo`80003ob`3oool=0000o`030?ooo`3o0000oooo0080003o0P3o
ool0103o0000oooo0?ooo`000?l40?ooo`030?l0003oool0oooo0080oooo
0P000?l50?ooo`030?l0003oool0oooo00D0oooo0P000?l70?ooo`80o`00
303oool30000oc80oooo002C0?ooo`T0o`00803oool40000o`d0oooo103o
000:0?ooo`<0003o2P3oool20?l000X0oooo0P000?nV0?ooobL0003o303o
ool20?l000030?ooo`000?l0oooo0080oooo00@0o`000?ooo`3oool0003o
103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo
0P3o00060?ooo`80003o1`3oool20?l000X0oooo10000?le0?ooo`00N03o
oolK0?l002<0oooo1P000?l=0?ooo`@0o`00303oool20000o`X0oooo0`3o
000:0?ooo`80003odP3oool90?l000030?ooo`000?l0003o00<0oooo00@0
o`000?ooo`3oool0003o0`3oool20?l000@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`80003o1`3oool20?l000P0oooo
10000?li0?ooo`00LP3oool60?l003H0oooo20000?lA0?ooo`80o`003@3o
ool30000o`X0oooo0P3o000;0?ooo`80003o``3ooolA0?l000P0oooo0P00
0?l30?ooo`80o`000P3oool00`000?l0oooo0?ooo`020?l000@0oooo0P00
0?l40?ooo`80o`001@3oool20000o`L0oooo0P3o00070?ooo`<0003o?@3o
ool00:D0oooo2@000?lF0?ooo`<0o`00303oool30000o`X0oooo0`3o000;
0?ooo`80003o[03ooolI0?l001@0oooo1@000?l40?ooo`060?l0003oool0
oooo0?ooo`000?l0oooo0P3o00050?ooo`030000o`3oool0oooo0080oooo
0P3o00050?ooo`80003o1`3oool20?l000L0oooo0P000?m00?ooo`00W03o
ool90000oaX0oooo1@3o000<0?ooo`<0003o2P3oool30?l000`0oooo0P00
0?o?0?ooo``0003o1P3oool30?l000060?ooo`000?l0003o0000o`3oool0
o`001@3oool20000o`<0oooo0P3o00060?ooo`030000o`3oool0oooo00D0
oooo0P3o00060?ooo`<0003o@P3oool009<0oooo2@000?lM0?ooo`H0o`00
3P3oool30000o`/0oooo0P3o000=0?ooo`80003o^P3ooolG0000o`d0oooo
1@3o0000103oool0003o0000o`000?l20?ooo`80o`00103oool20000o`@0
oooo00<0o`000?ooo`3oool0103oool20000o`D0oooo0`3o00060?ooo`80
003oA@3oool00880oooo4@000?lR0?ooo`@0o`004@3oool30000o``0oooo
0P3o000<0?ooo`<0003o/P3oool:0000oa`0oooo203o00030?ooo`<0003o
0`3oool20?l000@0oooo0P000?l40?ooo`80o`001@3oool20000o`D0oooo
0P3o00060?ooo`<0003oA`3oool00780oooo40000?l/0?ooo`L0o`004@3o
ool40000o`d0oooo0P3o000<0?ooo`80003ocP3oool=0?l000P0oooo0`00
0?l50?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool20?l000D0oooo0P000?l50?ooo`80o`001P3oool20000odX0oooo002U
0?ooo`T0o`00503oool40000o`h0oooo0`3o000;0?ooo`<0003o]`3ooolI
0?l000h0oooo1`000?l60?ooo`80o`00103oool20000o`<0oooo0P3o0005
0?ooo`80003o1@3oool20?l000H0oooo0P000?m<0?ooo`00W@3oool80?l0
01T0oooo10000?l@0?ooo`80o`002`3oool30000omX0oooo1`000?l80?oo
o`D0o`00103oool20000o`<0oooo0P3o00050?ooo`80003o1@3oool20?l0
00H0oooo0P000?m>0?ooo`00U03oool90?l001d0oooo10000?lA0?ooo`<0
o`002`3oool20000oll0oooo3P000?l;0?ooo`@0o`001P3oool30000o`<0
oooo0P3o00050?ooo`80003o1@3oool20?l000H0oooo0P000?m@0?ooo`00
PP3ooolB0?l00280oooo10000?lA0?ooo`@0o`00303oool20000okl0oooo
4P000?lE0?ooo`@0o`001`3oool30000o`@0oooo0P3o00050?ooo`80003o
1@3oool20?l000H0oooo0P000?mB0?ooo`00LP3oool@0?l002d0oooo1`00
0?lA0?ooo`@0o`003P3oool20000omX0oooo3P3o00080?ooo`<0003o103o
ool30?l000D0oooo0P000?l50?ooo`80o`001P3oool20000oe@0oooo002V
0?ooo`T0003o503oool40?l000h0oooo10000?o>0?ooo`h0o`003P3oool8
0000o`@0oooo0`3o00060?ooo`80003o103oool30?l000H0oooo0P000?mF
0?ooo`00W@3oool90000oaT0oooo103o000>0?ooo`@0003oa`3oool;0?l0
01D0oooo1`000?l90?ooo`<0o`001`3oool20000o`<0oooo0`3o00060?oo
o`<0003oF03oool009@0oooo2@000?lK0?ooo`L0o`003P3oool40000on@0
oooo1`000?l<0?ooo`@0o`001`3oool30000o`<0oooo0P3o00070?ooo`80
003oF`3oool008/0oooo2@000?lN0?ooo`H0o`004P3oool30000omX0oooo
3P000?l?0?ooo`@0o`00203oool30000o`@0oooo0P3o00060?ooo`<0003o
G@3oool007T0oooo4P000?lS0?ooo`@0o`005@3oool30000om80oooo2`00
0?lF0?ooo`L0o`001`3oool50000o`@0oooo0`3o00050?ooo`<0003oH03o
ool00780oooo1`000?l^0?ooo`L0o`005P3oool30000onL0oooo3`3o0007
0?ooo`L0003o1@3oool40?l000H0oooo0P000?mS0?ooo`00WP3oool90?l0
01T0oooo10000?oL0?ooo`h0o`003`3oool70000o`T0oooo0`3o00080?oo
o`80003oI@3oool009D0oooo2@3o000K0?ooo`L0003og03oool40?l001H0
oooo1`000?l<0?ooo`@0o`00203oool30000ofL0oooo002<0?ooo`T0o`00
7@3oool70000ooH0oooo1`000?l>0?ooo`D0o`00203oool40000ofX0oooo
001i0?oooa<0o`008P3oool40000onh0oooo3`000?l>0?ooo`L0o`00203o
ool50000ofh0oooo001b0?ooo`L0o`00;P3oool70000onh0oooo10000?lF
0?ooo`L0o`002P3oool50000og<0oooo002N0?ooo`T0003oo`3oool90?oo
o`L0o`003@3oool40000ogP0oooo002E0?ooo`T0003oo`3oool30?ooo`l0
o`003`3oool50000og`0oooo002<0?ooo`T0003oo`3oool80?ooo`@0o`00
5`3oool70000oh40oooo00230?ooo`T0003oo`3ooolM0?ooo`l0003oR03o
ool007@0oooo3`000?oo0?oooaX0oooo30000?nG0?ooo`00LP3oool20000
ool0ooooc03oool00?l0ooooo`3ooom10?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{575, 178},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.87",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/fluidflowimage/\
FluidFlowImageFigures/mat1187.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  (a) Flow over a step.\n\t\t\t\t\t(b) Flow around a blunt object."
}], "Text"],

Cell[TextData[{
  "Hint:  Set  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 1\)}]]],
  "  and   ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \(-\[ImaginaryI]\)\)}]]],
  ".  In the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  "-plane ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = 0\)}]]],
  ", and the exterior angles are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(-\(\[Pi]\/2\)\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(\[Pi]\/2\)}]}]]],
  ",  and the formula for the derivative ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " is  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z - \
\((\(-1\))\))\)\^\(\(-\((\(-\(\[Pi]\/2\)\))\)\)/\[Pi]\)\) \((z - \
1)\)\^\(\(-\((\[Pi]\/2)\)\)/\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(1\/2\)\) \((z - 1)\)\^\(-\(1\/2\)\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \((z + \
1)\)\^\(1\/2\)\/\((z - 1)\)\^\(1\/2\)\)\)\)}]],
  "\n"
}], "Text"],

Cell[TextData[{
  "Integrate and get  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\ \  = \ \ B\ \  + \ \ A\ \(\[Integral]\(\((z + \
1)\)\^\(1\/2\)\/\((z - 1)\)\^\(1\/2\)\) \[DifferentialD]z\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(B\ \  + \ 
          A\ \((\((z\^2 - 1)\)\^\(1\/2\) + 
                Log \((z + \((z\^2 - 1)\)\^\(1\/2\))\))\)\)\)\)}]],
  " \n\nSolve for the coefficients A and B and obtain \n\n\t\t\t",
  Cell[BoxData[
      \(w\  = \ \(f \((z)\)\ \  = \ \(1\/\[Pi]\) \((\((z\^2 - 1)\)\^\(1\/2\) \
+ Log \((z + \((z\^2 - 1)\)\^\(1\/2\))\))\)\)\)]]
}], "Text"],

Cell[TextData[{
  "It maps the upper half-plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  "  onto the domain in the w plane that lies above the boundary curve \
consisting of the rays  ",
  Cell[BoxData[
      RowBox[{\(u \[LessEqual] 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{"v", "=", 
          RowBox[{
            RowBox[{"1", "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "u"}], "\[GreaterEqual]", 
            "0"}]}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(v = 0\)}]]],
  " and the segment  ",
  Cell[BoxData[
      RowBox[{\(u = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(\(-1\) \[LessEqual] v \[LessEqual] 
          0\)}]]],
  ".  Furthermore, the image of horizontal streamlines in the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane are curves in the w plane given by the parametric equation \n\n\t\t\
",
  Cell[BoxData[{
      \(\(\(w\ \  = \ \ \(u\  + \ \[ImaginaryI]\ v\ \  = \ \ f \((t + \
\[ImaginaryI]\ c)\)\)\)\(\ \ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\ \ \)\(\(1\/\[Pi]\) \((\((\((t + \[ImaginaryI]\ \
c)\)\^2 - 1)\)\^\(1\/2\) + 
              Log \((t + \[ImaginaryI]\ c + \((\((t + \[ImaginaryI]\ c)\)\^2 \
- 1)\)\^\(1\/2\))\))\)\)\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
      \(\ \ \ \ \(\(=\)\(\ \ \)\(\(1\/\[Pi]\) \((\((\ t\^2 - c\^2 - 1 + \ \
\[ImaginaryI]\ 2  c\ t)\)\^\(1\/2\) + 
              Log \((t + \[ImaginaryI]\ c + \((\ t\^2 - c\^2 - 1 + \ \
\[ImaginaryI]\ 2  c\ t)\)\^\(1\/2\))\))\)\)\)\)}]],
  "\n\nfor  ",
  Cell[BoxData[
      \(\(-\[Infinity]\) < t < \[Infinity]\)]],
  ".  The new flow is that of a step in the bed of a deep stream and is \
illustrated in Figure 11.87(a).  The function ",
  Cell[BoxData[
      \(w = f \((z)\)\)]],
  " is also defined for values of ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " in the lower half-plane, and the images of horizontal streamlines that \
lie above or below the ",
  StyleBox["x",
    FontFamily->"Courier New"],
  " axis are mapped onto streamlines that flow past a long rectangular \
obstacle, which is illustrated in Figure 11.87(b)."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.29.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Use the Schwarz Christoffel formula, enter the formula  ",
  Cell[BoxData[
      \(\(f'\)[z] = \(A \((z + 1)\)\^\(1\/2\)\)\/\((z - 1)\)\^\(1\/2\)\)],
    AspectRatioFixed->True],
  "  and integrate it to construct  f(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[A, B, z, f, f1, F];\)\ \), "\n", 
    \(\(f1[
          z_]\  = \ \(A \((z + 1)\)\^\(1\/2\)\)\/\((z - 1)\)\^\(1\/2\);\)\ \
\), "\n", 
    \(\(f[z_]\  = \ 
        B\  + \ A \(\[Integral]\(\((z + 1)\)\^\(1\/2\)\/\((z - 1)\)\^\(1\/2\)\
\) \[DifferentialD]z\);\)\ \), "\n", 
    \(\(Print["\<f'[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = B + \[Integral] \>", 
        f1[z], "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
This is one, formula for the integral.   However, we will use the following \
form of the integral to continue the computations.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f1[
          z_]\  = \ \(A\ \((z\  + \ 1)\)\)\/\@\(z\^2\  - \ 1\);\)\ \), "\n", 
    \(\(F[z_]\  = \ 
        B\  + \ \[Integral]\(\(A\ \((z\  + \ 
                        1)\)\)\/\@\(z\^2\  - \ 1\)\) \[DifferentialD]z;\)\ \
\), "\n", 
    \(\(Print["\<f'[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = B + \[Integral] \>", 
        f1[z], "\< \[DifferentialD]z\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< f[z] = \>", F[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["Now solve for the coefficients  A  and  B.", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(eq1\  = \ F[\(-1\)]\  \[Equal] \ \ 0;\)\ \), "\n", 
    \(\(eq2\  = \ \ F[1]\  \[Equal] \ \(-\[ImaginaryI]\);\)\ \), "\n", 
    \(\(solset\  = \ Solve[{eq1, eq2}, {A, B}];\)\ \), "\n", 
    \(\(f[z_]\  = \ 
        ReplaceAll[F[z], 
          solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\
\)\ \), "\n", 
    \(\(Print[eq1];\)\ \), "\n", 
    \(\(Print[eq2];\)\ \), "\n", 
    \(\(Print[
        solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)];\)\
\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<f[z] = B + A \!\(\@\(\(-1\) + z\^2\)\)+ A Log[z+\!\(\@\(\
\(-1\) + z\^2\)\)]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Unfortunately, the branch cuts don't work out right and we will have to do \
this one by hand.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[z_]\  = \ 
        ReplaceAll[F[z], {A \[Rule] 1\/\[Pi], B \[Rule] 0}];\)\ \), "\n", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
Using this formula in the book we form the two branches of the function.  \
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(Clear[f1, f2];\)\ \), "\n", 
    \(\(f1[
          z_]\  = \ \(\(\ \)\(\@\((z\^2 - 1)\) + Log[z + \@\(z\^2 - \
1\)]\)\)\/\[Pi];\)\ \), "\n", 
    \(\(f2[
          z_]\  = \ \(\(-\@\((z\^2 - 1)\)\) + Log[z - \@\(z\^2 - \
1\)]\)\/\[Pi];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_1\)[z] = \>\"", f1[z]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_2\)[z] = \>\"", 
        f2[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph conformal mapping  w = f(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(g1\  = \ 
        CartesianMap[
          f1, {0, 2, 0.25}, {0.00001, 1.20001, 
            0.2}, \[IndentingNewLine]PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(g2\  = \ 
        CartesianMap[
          f2, {\(-6.00001\), \(-0.00001\), 0.25}, \[IndentingNewLine]{\ 
            0.00001, 1.20001, 0.2}, PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(Show[g1, g2, Ticks \[Rule] {Range[\(-1\), 1, 0.5], Range[0, 1, 0.5]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0,\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<is the domain that lies above the boundary curve \
consisting\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<of the rays u\[LessEqual]0,v=1 and u\[GreaterEqual]0,v=0 and \
the segment u=0,-1\[LessEqual]v\[LessEqual]0,\>"];\)\ \), "\n", 
    \(\(Print["\<where  w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        Table[{Re[f1[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f1[x + \[ImaginaryI]\ 0.2  k]]}, {k, 1, 11, 2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {x, 0, 4}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[f1[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f1[x + \[ImaginaryI]\ 0.2  k]]}, {k, 2, 11, 2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {x, 0, 4}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns3\  = \ 
        Table[{Re[f2[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f2[x + \[ImaginaryI]\ 0.2  k]]}, {k, 1, 11, 2}];\)\ \), "\n", 
    \(\(graph3 = 
        ParametricPlot[Evaluate[eqns3], {x, \(-9\), 0}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns4\  = \ 
        Table[{Re[f2[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f2[x + \[ImaginaryI]\ 0.2  k]]}, {k, 2, 11, 2}];\)\ \), "\n", 
    \(\(graph4 = 
        ParametricPlot[Evaluate[eqns4], {x, \(-9\), 0}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Red, 
            Line[{{\(-1\), 1}, {0, 1}, {0, 0}, {2, 
                  0}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, graph4, boundary, 
        PlotRange \[Rule] {{\(-1\), 2}, {\(-0.1\), 1.6}}, 
        AspectRatio \[Rule] 1.8\/3, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0, 1, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0,\>"];\)\ \), "\n\
", 
    \(\(Print["\<under w = f[z] = \>", f1[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We have shown that the mapping  ",
  Cell[BoxData[
      \(w = \(1\/\[Pi]\) \((\@\(z\^2 - 1\) + 
                Log[z + \@\(z\^2 - 1\)])\) - \[ImaginaryI]\)]],
  "  maps the upper half plane ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  onto the domain in the w-plane that lies above the boundary curve \
consisting of the rays  ",
  Cell[BoxData[
      \(u \[LessEqual] 0, v = 1\ \ and\ \ u \[GreaterEqual] 0, v = 0\)]],
  " and the segment  ",
  Cell[BoxData[
      \(u = 0, \(-1\) \[LessEqual] v \[LessEqual] 0\)]],
  ".    "
}], "Text"],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  Here is another function that produces the desired result.  The graph is \
drawn parametrically in this case."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[BoxData[{
    \(\(f[
          z_]\  = \ \(\[ImaginaryI] \@\( 1\  - \ z\^2\)\  + \ \(\[ImaginaryI]\
\ \[Pi]\)\/2\  - \ \[ImaginaryI]\ ArcSin[z]\)\/\[Pi];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.2  k]]}, {k, 1, 11, 2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {x, \(-9\), 4}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.2  k]]}, {k, 2, 11, 2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {x, \(-9\), 4}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Red, 
            Line[{{\(-1\), 1}, {0, 1}, {0, 0}, {2, 
                  0}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, boundary, 
        PlotRange \[Rule] {{\(-1\), 2}, {\(-0.1\), 1.6}}, 
        AspectRatio \[Rule] 1.8\/3, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0, 1, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0,\>"];\)\ \), "\n\
", 
    \(\(Print["\<under w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[
          z_]\  = \ \(\[ImaginaryI] \@\( 1\  - \ z\^2\)\  + \ \(\[ImaginaryI]\
\ \[Pi]\)\/2\  - \ \[ImaginaryI]\ ArcSin[z]\)\/\[Pi];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.2  k]]}, {k, 1, 11, 2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {x, \(-9\), 4}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.2  k]]}, {k, 2, 11, 2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {x, \(-9\), 4}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns3\  = \ 
        Table[{Re[
              f[x + \[ImaginaryI]\ 0.2  k]], \(-Im[
                f[x + \[ImaginaryI]\ 0.2  k]]\)}, {k, 1, 11, 
            2}];\)\ \), "\n", 
    \(\(graph3 = 
        ParametricPlot[Evaluate[eqns3], {x, \(-9\), 4}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns4\  = \ 
        Table[{Re[
              f[x + \[ImaginaryI]\ 0.2  k]], \(-Im[
                f[x + \[ImaginaryI]\ 0.2  k]]\)}, {k, 2, 11, 
            2}];\)\ \), "\n", 
    \(\(graph4 = 
        ParametricPlot[Evaluate[eqns4], {x, \(-9\), 4}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Red, Line[{{\(-1\), 1}, {0, 1}, {0, 0}, {2, 0}}], 
            Line[{{\(-1\), \(-1\)}, {0, \(-1\)}, {0, 0}, {2, 
                  0}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, graph4, boundary, 
        PlotRange \[Rule] {{\(-1\), 2}, {\(-1.6\), 1.6}}, 
        AspectRatio \[Rule] 3.2\/3, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0, 1, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the z-plane,\>"];\)\ \), "\n", 
    \(\(Print["\<under w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Also, we have shown that the mapping  ",
  Cell[BoxData[
      \(w = \(\(\[ImaginaryI]\ \[Pi]\)\/2 + \[ImaginaryI]\ \@\(1 - z\^2\) - \
\[ImaginaryI]\ ArcSin[z]\)\/\[Pi]\)]],
  "  maps the upper half plane ",
  Cell[BoxData[
      \(Im[z] > 0\)]],
  "  onto the domain in the w-plane that lies above the boundary curve \
consisting of the rays  ",
  Cell[BoxData[
      \(u \[LessEqual] 0, v = 1\ \ and\ \ u \[GreaterEqual] 0, v = 0\)]],
  " and the segment  ",
  Cell[BoxData[
      \(u = 0, \(-1\) \[LessEqual] v \[LessEqual] 0\)]],
  ".    "
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Figure 11.88 to find the flow over the vertical segment from ",
  Cell[BoxData[
      RowBox[{"0", " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "\[ImaginaryI]"}]]],
  "."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900000/R000`400?l0
0000o`00003oo`3ooooo0?oood80oooo003o0?ooool0oooo@P3oool00?l0
ooooo`3ooom20?ooo`00o`3ooooo0?oood80oooo003o0?ooool0oooo@P3o
ool00?l0ooooo`3ooom20?ooo`00o`3ooooo0?oood80oooo001c0?ooo`@0
0000K@3oool500000=P0oooo1@00001[0?ooo`@000002`3oool007<0oooo
00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`3J0?ooo`030000
003oool0oooo06/0oooo00<000000?ooo`3oool0303oool007@0oooo00<0
00000?ooo`3oool0K`3oool00`000000oooo0?ooo`1Z0?ooo`030?l0003o
ool0oooo06d0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?oo
o`0;0?ooo`00K@3oool4000000@0oooo00<000000?ooo`3oool0IP3oool4
000000@0oooo00<000000?ooo`3oool0JP3oool00`3o0000oooo0?ooo`1]
0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool02P3oool0
07<0oooo00@000000?ooo`3oool00000K`3oool00`000000oooo0?ooo`1Z
0?ooo`030?l0003oool0oooo06d0oooo00<000000?ooo`3oool0J`3oool0
10000000oooo0?ooo`00000;0?ooo`00M03oool2000006l0oooo0P00001/
0?ooo`030?l0003oool0oooo06`0oooo0P00001^0?ooo`800000303oool0
0?l0ooooE03oool00`3o0000oooo0?ooo`3Z0?ooo`00o`3ooomD0?ooo`03
0?l0003oool0oooo0>X0oooo003o0?oooe@0oooo00<0o`000?ooo`3oool0
jP3oool00?l0ooooE03oool00`3o0000oooo0?ooo`3Z0?ooo`00o`3ooomD
0?ooo`030?l0003oool0oooo0>X0oooo003o0?oooe@0oooo00<0o`000?oo
o`3oool0jP3oool00?l0ooooE03oool00`3o0000oooo0?ooo`3Z0?ooo`00
LP3ooooo0?l00<<0o`00303oool00780oooo00<000000?ooo`3oool0KP3o
ool00`000000oooo0?ooo`1]0?ooo`030?l0003oool0oooo06d0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`0:0?ooo`00LP3oool0
0`000000oooo0?ooo`1^0?ooo`030000003oool0oooo06d0oooo00<0o`00
0?ooo`3oool0K@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo00X0oooo001b0?ooo`030000003oool0oooo06h0oooo00<000000?oo
o`3oool0K@3oool00`3o0000oooo0?ooo`1]0?ooo`030000003oool0oooo
06d0oooo00<000000?ooo`3oool02P3oool00?l0ooooE03oool00`3o0000
oooo0?ooo`3Z0?ooo`00o`3ooomD0?ooo`030?l0003oool0oooo0>X0oooo
003o0?oooe@0oooo00<0o`000?ooo`3oool0jP3oool00?l0ooooE03oool0
0`3o0000oooo0?ooo`3Z0?ooo`00o`3ooomD0?ooo`030?l0003oool0oooo
0>X0oooo003o0?oooe@0oooo00<0o`000?ooo`3oool0jP3oool00780oooo
@0000?nQ0?ooo`030?l0003oool0oooo09l0oooo?`000?l<0?ooo`00/P3o
oolL0000ohD0oooo00<0o`000?ooo`3oool0P`3ooolL0000od/0oooo003>
0?oooaL0003oKP3oool00`3o0000oooo0?ooo`1[0?oooaP0003oI`3oool0
0>D0oooo4@000?mM0?ooo`030?l0003oool0oooo05/0oooo40000?mo0?oo
o`00mP3oool70000oeH0oooo00<0o`000?ooo`3oool0E03oool70000ohl0
oooo003m0?ooo`H0003oD03oool00`3o0000oooo0?ooo`1=0?ooo`L0003o
UP3oool00?l0oooo103oool50000od/0oooo00<0o`000?ooo`3oool0B03o
ool50000oid0oooo003o0?ooo`T0oooo10000?m70?ooo`030?l0003oool0
oooo04D0oooo0`000?nR0?ooo`00o`3oool=0?ooo`@0003o@`3oool00`3o
0000oooo0?ooo`110?ooo`@0003oY@3oool00780oooo4P3o002<0?ooo`@0
003o?`3oool00`3o0000oooo0?ooo`0m0?ooo`@0003oS03ooolA0?l000`0
oooo00240?ooobX0o`00IP3oool20000ocd0oooo00<0o`000?ooo`3oool0
>`3oool20000ofH0oooo:P3o000M0?ooo`00[P3oool@0?l005P0oooo0P00
0?lk0?ooo`030?l0003oool0oooo03T0oooo0P000?mH0?oooa00o`00A`3o
ool00;h0oooo303o001>0?ooo`030000o`3oool0oooo03P0oooo00<0o`00
0?ooo`3oool0>03oool00`000?l0oooo0?ooo`1<0?ooo``0o`00E`3oool0
0<X0oooo2`3o00140?ooo`80003o>03oool00`3o0000oooo0?ooo`0f0?oo
o`80003oA03oool;0?l006<0oooo003E0?ooo`T0o`00?@3oool20000ocH0
oooo00<0o`000?ooo`3oool0=03oool20000ocd0oooo2@3o001^0?ooo`00
gP3oool<0?l003<0oooo00<0003o0?ooo`3oool0<`3oool00`3o0000oooo
0?ooo`0c0?ooo`030000o`3oool0oooo0340oooo303o001g0?ooo`00jP3o
ool50?l002l0oooo0P000?lc0?ooo`030?l0003oool0oooo0340oooo0P00
0?l_0?ooo`D0o`00P`3oool00>l0oooo103o000]0?ooo`030000o`3oool0
oooo0300oooo00<0o`000?ooo`3oool0<03oool00`000?l0oooo0?ooo`0[
0?ooo`@0o`00R03oool00?<0oooo0`3o000[0?ooo`030000o`3oool0oooo
02l0oooo00<0o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0Y0?oo
o`<0o`00S03oool00780oooo90000?mP0?ooo`@0o`009`3oool00`000?l0
oooo0?ooo`0_0?ooo`030?l0003oool0oooo02h0oooo00<0003o0?ooo`3o
ool09P3oool40?l00600oooo8`000?l<0?ooo`00UP3oool@0000oe@0oooo
0`3o000U0?ooo`030000o`3oool0oooo02h0oooo00<0o`000?ooo`3oool0
;P3oool00`000?l0oooo0?ooo`0R0?ooo`@0o`00E03oool@0000obl0oooo
002V0?ooo`X0003oC@3oool20?l002@0oooo00<0003o0?ooo`3oool0;@3o
ool00`3o0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0240oooo0P3o
001=0?ooo`/0003o?`3oool00;00oooo4`000?ll0?ooo`80o`008`3oool0
0`000?l0oooo0?ooo`0/0?ooo`030?l0003oool0oooo02`0oooo00<0003o
0?ooo`3oool0803oool20?l003d0oooo4P000?m:0?ooo`00``3oool50000
ocT0oooo0P3o000Q0?ooo`030000o`3oool0oooo02`0oooo00<0o`000?oo
o`3oool0;03oool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo
03L0oooo1P000?mL0?ooo`00b03oool70000oc@0oooo0P3o000P0?ooo`03
0000o`3oool0oooo02/0oooo00<0o`000?ooo`3oool0:`3oool00`000?l0
oooo0?ooo`0N0?ooo`80o`00<`3oool70000of80oooo003?0?ooo`P0003o
;P3oool20?l001h0oooo00<0003o0?ooo`3oool0:`3oool00`3o0000oooo
0?ooo`0[0?ooo`030000o`3oool0oooo01`0oooo0P3o000^0?ooo`L0003o
J@3oool00=L0oooo1P000?lZ0?ooo`030?l0003oool0oooo01`0oooo00<0
003o0?ooo`3oool0:P3oool00`3o0000oooo0?ooo`0Z0?ooo`030000o`3o
ool0oooo01/0oooo0P3o000Z0?ooo`H0003oL03oool00=d0oooo1@000?lV
0?ooo`80o`007@3oool00`000?l0oooo0?ooo`0Y0?ooo`030?l0003oool0
oooo02T0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0U
0?ooo`D0003oMP3oool00780oooo303o001T0?ooo`@0003o903oool00`3o
0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo02T0oooo00<0o`000?oo
o`3oool0:@3oool00`000?l0oooo0?ooo`0I0?ooo`80o`00903oool40000
of<0oooo303o000<0?ooo`00OP3ooolE0?l005<0oooo0`000?lR0?ooo`80
o`006`3oool00`000?l0oooo0?ooo`0X0?ooo`030?l0003oool0oooo02P0
oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0Q0?ooo`<0
003oD`3ooolD0?l001P0oooo002C0?oooa00o`00AP3oool30000ob40oooo
00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0X0?ooo`030?l0
003oool0oooo02P0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo
0?ooo`0O0?ooo`<0003oAP3oool@0?l002`0oooo002S0?ooo`X0o`00?`3o
ool30000oal0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?oo
o`0W0?ooo`030?l0003oool0oooo02L0oooo00<0003o0?ooo`3oool0603o
ool00`3o0000oooo0?ooo`0M0?ooo`<0003o?`3oool:0?l003`0oooo002]
0?ooo`X0o`00>03oool40000oa`0oooo00<0o`000?ooo`3oool0603oool0
0`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo02H0oooo00<0003o
0?ooo`3oool0603oool00`3o0000oooo0?ooo`0J0?ooo`@0003o=`3oool;
0?l004H0oooo002g0?ooo`X0o`00<P3oool20000oa/0oooo00<0o`000?oo
o`3oool05`3oool00`000?l0oooo0?ooo`0V0?ooo`030?l0003oool0oooo
02H0oooo00<0003o0?ooo`3oool05P3oool20?l001/0oooo0P000?la0?oo
o`X0o`00D@3oool00<40oooo203o000/0?ooo`80003o6P3oool00`3o0000
oooo0?ooo`0G0?ooo`030000o`3oool0oooo02D0oooo00<0o`000?ooo`3o
ool09@3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo01T0
oooo0P000?l[0?ooo`P0o`00F`3oool00<T0oooo1@3o000Y0?ooo`80003o
6@3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo02D0oooo
00<0o`000?ooo`3oool0903oool00`000?l0oooo0?ooo`0F0?ooo`030?l0
003oool0oooo01P0oooo0P000?lX0?ooo`D0o`00H`3oool00<h0oooo1@3o
000V0?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool05P3o
ool00`000?l0oooo0?ooo`0T0?ooo`030?l0003oool0oooo02@0oooo00<0
003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3o
ool0oooo02<0oooo1@3o001X0?ooo`00LP3oool00`000?l0oooo0?ooo`1N
0?ooo`D0o`008P3oool20000oaP0oooo00<0o`000?ooo`3oool05P3oool0
0`000?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo02<0oooo00<0003o
0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0G0?ooo`80003o8P3oool4
0?l00600oooo00<0003o0?ooo`3oool02P3oool007<0oooo6@000?m<0?oo
o`@0o`00803oool20000oaH0oooo00<0o`000?ooo`3oool05P3oool00`00
0?l0oooo0?ooo`0S0?ooo`030?l0003oool0oooo02<0oooo00<0003o0?oo
o`3oool05@3oool00`3o0000oooo0?ooo`0E0?ooo`80003o803oool40?l0
04`0oooo60000?l=0?ooo`00S03oool:0000odH0oooo0`3o000O0?ooo`03
0000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool05P3oool00`000?l0
oooo0?ooo`0R0?ooo`030?l0003oool0oooo0280oooo00<0003o0?ooo`3o
ool05@3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01d0
oooo0`3o00160?ooo`X0003o9@3oool009H0oooo2P000?lo0?ooo`<0o`00
7@3oool20000oaD0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo
0?ooo`0R0?ooo`030?l0003oool0oooo0240oooo00<0003o0?ooo`3oool0
5@3oool00`3o0000oooo0?ooo`0D0?ooo`80003o703oool40?l003l0oooo
2P000?l_0?ooo`00X03oool:0000ocP0oooo0`3o000L0?ooo`80003o503o
ool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo0240oooo00<0
o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003o
ool0oooo01<0oooo0P000?lK0?ooo`<0o`00>@3oool:0000ocT0oooo002Z
0?ooo`T0003o<P3oool20?l001`0oooo00<0003o0?ooo`3oool04P3oool0
0`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0240oooo00<0o`00
0?ooo`3oool0803oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0
oooo0180oooo00<0003o0?ooo`3oool06@3oool20?l003<0oooo2@000?m3
0?ooo`00/`3oool:0000obX0oooo0`3o000J0?ooo`030000o`3oool0oooo
0180oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0P0?oo
o`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0503oool00`3o
0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo01P0oooo0P3o000[0?oo
o`X0003oC03oool00;d0oooo20000?lU0?ooo`80o`006@3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3o
ool0803oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo01@0
oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0G0?ooo`80
o`009@3oool80000oeH0oooo00350?ooo`D0003o8P3oool20?l001P0oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0D0?ooo`030000
o`3oool0oooo01l0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo
0?ooo`0C0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0
5P3oool20?l00280oooo1@000?mN0?ooo`00bP3oool40000ob00oooo0P3o
000G0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`0O0?ooo`030?l0003oool0oooo01h0oooo00<0
003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo01D0oooo0P3o000P0?ooo`@0003oH`3oool00780oooo2P3o001B
0?ooo`<0003o7`3oool20?l001H0oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01h0oooo00<0o`00
0?ooo`3oool07P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool0503oool20?l001l0oooo0`000?mB
0?ooo`T0o`00303oool007`0oooo3P3o00170?ooo`<0003o7P3oool20?l0
01D0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0B0?oo
o`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool07@3oool00`00
0?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool04`3oool20?l001d0oooo10000?m70?ooo`h0o`005@3oool008X0
oooo2P3o00100?ooo`<0003o7@3oool20?l001@0oooo00<0003o0?ooo`3o
ool0403oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01d0
oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0C0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04P3oool20?l001`0
oooo0`000?m10?ooo`X0o`008`3oool009@0oooo2P3o000i0?ooo`<0003o
703oool20?l001<0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo
0?ooo`0B0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool0
703oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool04@3oool20?l001/0oooo0`000?lj0?ooo`X0o`00
;@3oool009h0oooo2P3o000b0?ooo`@0003o6P3oool20?l00180oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3o
ool0oooo01`0oooo00<0o`000?ooo`3oool0703oool00`000?l0oooo0?oo
o`0B0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0403o
ool20?l001X0oooo0`000?lc0?ooo`X0o`00=`3oool00:P0oooo1`3o000_
0?ooo`<0003o6@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0L
0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool04P3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0100oooo00<0o`00
0?ooo`3oool05`3oool30000obh0oooo203o00110?ooo`00[`3oool60?l0
02`0oooo0`000?lG0?ooo`80o`004@3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool06`3oool00`3o
0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo0180oooo00<0o`000?oo
o`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`80o`005`3oool30000
ob/0oooo1P3o00190?ooo`00]@3oool60?l002T0oooo0`000?lF0?ooo`03
0?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3o
ool06P3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0D0?ooo`<0
003o:03oool60?l004l0oooo002k0?ooo`H0o`009P3oool20000oaD0oooo
0P3o000@0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo01X0oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00h0oooo0P3o000E0?ooo`80003o9@3oool60?l005D0oooo
001b0?ooo`T0003oAP3oool50?l002<0oooo0P000?lE0?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3oool06@3o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00l0oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0C0?ooo`80003o8P3o
ool50?l004H0oooo2@000?l<0?ooo`00N`3oool>0000ocd0oooo1@3o000P
0?ooo`80003o503oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00l0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0I
0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool04P3oool20000oal0oooo1@3o000m0?ooo`h0003o5@3oool0
08T0oooo2P000?lh0?ooo`@0o`007P3oool20000oa<0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0H0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0140oooo0P000?lM0?oo
o`@0o`00>@3oool90000ob<0oooo002C0?ooo`T0003o<`3oool40?l001`0
oooo0P000?lB0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo01P0
oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0@0?ooo`80003o6`3oool40?l003@0oooo2@000?l/0?ooo`00
W03oool90000obh0oooo0`3o000K0?ooo`80003o4@3oool20?l000h0oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo01P0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
3@3oool20?l00140oooo0P000?lJ0?ooo`<0o`00;P3oool:0000ocD0oooo
002U0?ooo`L0003o:P3oool30?l001X0oooo00<0003o0?ooo`3oool0403o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0G0?ooo`030?l0003o
ool0oooo01L0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03`3o
ool20000oaT0oooo0`3o000Z0?ooo`L0003o?`3oool00:`0oooo1@000?lX
0?ooo`@0o`005`3oool20000oa40oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool05P3oool3
0?l002P0oooo1@000?m60?ooo`00/@3oool50000obL0oooo0`3o000F0?oo
o`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo0100oooo00<0003o0?oo
o`3oool05P3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo
00l0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo00h0oooo0P000?lF0?ooo`<0o`009`3oool40000
od/0oooo002f0?ooo`D0003o9@3oool30?l001@0oooo00<0003o0?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0403oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0C0?ooo`<0o`009@3oool50000odl0
oooo002k0?ooo`D0003o8`3oool20?l001<0oooo0P000?l@0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool0
5@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`80003o
503oool20?l002<0oooo1@000?mD0?ooo`00LP3oool90?l004D0oooo1000
0?lQ0?ooo`80o`004`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0?0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool0503o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo0180oooo0P3o000Q0?ooo`@0003oA@3oool80?l000`0oooo001k
0?ooo`d0o`00?03oool40000oal0oooo0P3o000B0?ooo`80003o3`3oool2
0?l000d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0503oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool20?l000l0oooo00<0003o0?ooo`3oool04@3oool2
0?l001h0oooo1@000?ll0?ooo`d0o`00503oool008P0oooo2@3o000g0?oo
o`@0003o7@3oool20?l00180oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo
01<0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool20000
oa80oooo0P3o000L0?ooo`@0003o>03oool90?l00240oooo002A0?ooo`T0
o`00<P3oool40000oa/0oooo0P3o000A0?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool04`3oool00`3o0000
oooo0?ooo`0C0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool0403oool20?l001X0oooo10000?lc0?ooo`T0
o`00:P3oool009X0oooo2@3o000]0?ooo`<0003o6P3oool20?l00100oooo
0P000?l?0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01<0oooo
00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo0`3o000I0?ooo`<0003o
;P3oool90?l003<0oooo002S0?ooo`P0o`00:03oool30000oaT0oooo0P3o
000@0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo0P000?l?0?ooo`80o`006@3o
ool30000obT0oooo203o000l0?ooo`00Z`3oool60?l002D0oooo10000?lG
0?ooo`80o`003`3oool20000o`h0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool2
0?l001P0oooo0`000?lV0?ooo`H0o`00A03oool00;40oooo1P3o000S0?oo
o`<0003o5P3oool20?l000l0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0140oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00X0oooo0P3o000>0?ooo`030000o`3oool0oooo
00`0oooo0P3o000G0?ooo`<0003o8P3oool70?l004X0oooo002g0?ooo`H0
o`00803oool30000oaD0oooo0P3o000>0?ooo`80003o3@3oool20?l000/0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0403oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`0<0?ooo`80003o3@3oool20?l001H0
oooo0`000?lO0?ooo`H0o`00D@3oool00780oooo20000?m30?ooo`@0o`00
7`3oool30000oa@0oooo0P3o000>0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool20?l001D0oooo0`000?lN0?ooo`@0o`00
A03oool70000o``0oooo001j0?ooo``0003o>`3oool50?l001d0oooo0P00
0?lD0?ooo`80o`003@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool04`3oool20000oad0oooo103o
000l0?ooo``0003o4`3oool008H0oooo2@000?lg0?ooo`@0o`006`3oool2
0000oa@0oooo00<0o`000?ooo`3oool02`3oool20000o`d0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo0P000?l<
0?ooo`80o`00503oool20000oa/0oooo103o000g0?ooo`T0003o7`3oool0
08l0oooo2@000?lb0?ooo`@0o`006@3oool20000oa<0oooo0P3o000=0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?oo
o`80o`003@3oool00`000?l0oooo0?ooo`0:0?ooo`80o`00503oool20000
oaT0oooo103o000b0?ooo`T0003o:03oool009P0oooo2@000?l]0?ooo`<0
o`00603oool30000oa80oooo0P3o000<0?ooo`80003o303oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02`3oool20000o``0
oooo00<0o`000?ooo`3oool04@3oool30000oaP0oooo0`3o000/0?ooo`X0
003o<@3oool00:40oooo20000?lX0?ooo`<0o`00603oool20000oa80oooo
0P3o000<0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
2P3oool20?l00180oooo0P000?lH0?ooo`<0o`00:03oool70000oc/0oooo
002Y0?ooo`H0003o9@3oool30?l001L0oooo0P000?lB0?ooo`030?l0003o
ool0oooo00X0oooo0P000?l;0?ooo`80o`002P3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00X0oooo0P000?l<0?ooo`030?l0003oool0oooo0100oooo0P00
0?lG0?ooo`<0o`009@3oool60000od80oooo002_0?ooo`H0003o8P3oool3
0?l001H0oooo0P000?lA0?ooo`80o`00303oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool0203oool20?l000`0oooo00<0003o
0?ooo`3oool02P3oool20?l00140oooo0P000?lF0?ooo`<0o`008P3oool6
0000odP0oooo002e0?ooo`H0003o7`3oool30?l001D0oooo0P000?lA0?oo
o`80o`002`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00T0oooo0P3o000A0?ooo`80003o5@3oool30?l001l0oooo1P000?m>0?oo
o`00LP3oool70?l00480oooo10000?lN0?ooo`<0o`00503oool20000oa40
oooo00<0o`000?ooo`3oool02@3oool20000o`/0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo0P000?l;0?ooo`03
0?l0003oool0oooo00l0oooo0P000?lD0?ooo`<0o`007P3oool40000od40
oooo1`3o000<0?ooo`00N@3oool;0?l003/0oooo1@000?lL0?ooo`80o`00
503oool20000oa00oooo0P3o000;0?ooo`030000o`3oool0oooo00T0oooo
0P3o00090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`090?ooo`80o`00403oool20000oa<0oooo0`3o000L0?ooo`D0003o
>P3oool;0?l001<0oooo00240?ooo`T0o`00=`3oool40000oaX0oooo0`3o
000C0?ooo`80003o403oool00`3o0000oooo0?ooo`090?ooo`80003o2`3o
ool00`3o0000oooo0?ooo`070?ooo`80003o2@3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo0P00
0?l90?ooo`80o`002`3oool20000o`/0oooo00<0o`000?ooo`3oool03P3o
ool20000oa<0oooo0P3o000K0?ooo`@0003o=P3oool90?l001h0oooo002=
0?ooo`T0o`00<P3oool40000oaT0oooo0P3o000C0?ooo`80003o3`3oool2
0?l000/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`09
0?ooo`80o`003`3oool20000oa80oooo0`3o000I0?ooo`@0003o<@3oool9
0?l002L0oooo002F0?ooo`X0o`00;03oool30000oaP0oooo0`3o000B0?oo
o`80003o3`3oool00`3o0000oooo0?ooo`090?ooo`80003o2P3oool20?l0
00T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`80003o2`3oool00`3o
0000oooo0?ooo`0=0?ooo`80003o4@3oool30?l001T0oooo0`000?l/0?oo
o`T0o`00<03oool00:00oooo1`3o000X0?ooo`<0003o603oool30?l00140
oooo0P000?l>0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo0P3o000;0?ooo`03
0000o`3oool0oooo00T0oooo0P3o000>0?ooo`80003o4@3oool20?l001T0
oooo0`000?lX0?ooo`L0o`00>@3oool00:L0oooo103o000W0?ooo`<0003o
603oool20?l00140oooo0P000?l=0?ooo`80o`002`3oool20000o`X0oooo
0P3o00080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool20000o`X0oooo
0P3o000>0?ooo`80003o403oool30?l001P0oooo0`000?lV0?ooo`D0o`00
@03oool00:/0oooo1@3o000U0?ooo`<0003o5`3oool30?l00100oooo0P00
0?l=0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203o
ool20000o`/0oooo00<0o`000?ooo`3oool0303oool20000o`l0oooo0`3o
000H0?ooo`<0003o9@3oool40?l004D0oooo002`0?ooo`@0o`00903oool3
0000oaL0oooo0P3o000@0?ooo`030000o`3oool0oooo00/0oooo0P3o000;
0?ooo`80003o2P3oool00`3o0000oooo0?ooo`060?ooo`80003o203oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00H0oooo0P000?l80?ooo`80o`002P3oool00`000?l0oooo0?ooo`09
0?ooo`80o`003@3oool20000o`l0oooo0P3o000H0?ooo`<0003o8`3oool5
0?l004T0oooo001b0?ooo`H0003o?03oool50?l00280oooo0`000?lF0?oo
o`80o`003`3oool20000o`d0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`080?ooo`80o`00203oool00`000?l0oooo0?ooo`060?oo
o`80o`00203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool20000
o`/0oooo00<0o`000?ooo`3oool02`3oool20000o`l0oooo0P3o000G0?oo
o`<0003o8@3oool50?l003`0oooo1P000?l<0?ooo`00N03oool;0000ocH0
oooo1P3o000O0?ooo`<0003o5@3oool20?l000l0oooo0P000?l<0?ooo`80
o`002`3oool20000o`X0oooo00<0o`000?ooo`3oool01P3oool20000o`P0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool20000o`/0oooo0P3o000<0?ooo`80003o3`3oool20?l001H0
oooo0`000?lN0?ooo`H0o`00=P3oool;0000oa80oooo00230?ooo`T0003o
<`3oool60?l001`0oooo0`000?lD0?ooo`80o`003`3oool20000o``0oooo
00<0o`000?ooo`3oool02P3oool20000o`T0oooo0P3o00080?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`80003o203oool20?l000T0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`80003o
3`3oool20?l001D0oooo0`000?lK0?ooo`H0o`00=03oool80000oad0oooo
002<0?ooo`L0003o<P3oool50?l001X0oooo0`000?lC0?ooo`80o`003`3o
ool20000o`/0oooo0P3o000<0?ooo`030000o`3oool0oooo00P0oooo0P3o
00070?ooo`80003o1`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3o
ool20?l000T0oooo0P000?l;0?ooo`80o`002`3oool20000o`l0oooo0P3o
000C0?ooo`@0003o6P3oool40?l003<0oooo1`000?lU0?ooo`00T`3oool6
0000oc40oooo103o000I0?ooo`<0003o4P3oool20?l000l0oooo0P000?l;
0?ooo`80o`002`3oool20000o`X0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo0P000?l;0?ooo`80o`002`3oool2
0000o`l0oooo0P3o000B0?ooo`<0003o6P3oool40?l00340oooo1P000?l/
0?ooo`00V@3oool60000obl0oooo0`3o000I0?ooo`<0003o4@3oool20?l0
00l0oooo0P000?l;0?ooo`80o`002`3oool20000o`T0oooo0P3o00070?oo
o`80003o1P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?oo
o`80o`001P3oool20000o`L0oooo0P3o00090?ooo`030000o`3oool0oooo
00T0oooo0P3o000;0?ooo`80003o3`3oool20?l00140oooo0`000?lJ0?oo
o`<0o`00;`3oool60000oc80oooo002O0?ooo`L0003o:`3oool40?l001P0
oooo0`000?l@0?ooo`<0o`003P3oool20000o`/0oooo0P3o000;0?ooo`80
003o2@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0
oooo0P3o00050?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`030?ooo`80o`001`3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo0P000?l:0?ooo`80
o`002`3oool20000o`h0oooo0`3o000@0?ooo`<0003o6@3oool40?l002/0
oooo1`000?lh0?ooo`00YP3oool60000obT0oooo103o000G0?ooo`80003o
4@3oool20?l000h0oooo0`000?l:0?ooo`80o`002`3oool20000o`P0oooo
0P3o00070?ooo`80003o1P3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`03
0?l0003oool0oooo00D0oooo0P000?l70?ooo`80o`00203oool20000o`X0
oooo0P3o000:0?ooo`<0003o3P3oool20?l00140oooo0P000?lH0?ooo`@0
o`00:@3oool60000ocl0oooo002/0?ooo`H0003o9`3oool30?l001H0oooo
0`000?l@0?ooo`<0o`003P3oool20000o`X0oooo0P3o000;0?ooo`80003o
203oool20?l000L0oooo0P000?l50?ooo`030?l0003oool0oooo0080oooo
0P000?l30?ooo`030?l0003oool0oooo0080003o103oool00`3o0000oooo
0?ooo`040?ooo`80003o1`3oool20?l000P0oooo0P000?l:0?ooo`80o`00
2P3oool20000o`h0oooo0`3o000@0?ooo`<0003o5`3oool30?l002L0oooo
1P000?m50?ooo`00/P3oool60000ob@0oooo0`3o000F0?ooo`80003o4@3o
ool20?l000h0oooo0P000?l:0?ooo`80o`002`3oool20000o`P0oooo0P3o
00070?ooo`80003o103oool30?l000<0oooo0P000?l0103oool0o`000?oo
o`000?l40?ooo`<0o`00103oool20000o`L0oooo0P3o00080?ooo`80003o
2P3oool20?l000X0oooo0P000?l>0?ooo`80o`004@3oool20000oaL0oooo
0`3o000T0?ooo`H0003oB`3oool00;P0oooo1P000?lQ0?ooo`<0o`005@3o
ool20000oa40oooo0P3o000>0?ooo`80003o2P3oool20?l000/0oooo0P00
0?l80?ooo`<0o`001P3oool20000o`D0oooo0`3o0000103oool0003o0000
o`3o00020000o`040?ooo`3o0000o`000?l000@0oooo0`000?l50?ooo`@0
o`00203oool20000o`X0oooo0P3o000:0?ooo`80003o3P3oool20?l00140
oooo0P000?lF0?ooo`<0o`008@3oool60000oe40oooo002n0?ooo`H0003o
7P3oool40?l001<0oooo0`000?l@0?ooo`<0o`003@3oool30000o`T0oooo
0P3o000;0?ooo`80003o2@3oool30?l000D0oooo0`000?l50?ooo`L0o`00
1@3oool20000o`D0oooo0`3o000:0?ooo`80003o2P3oool20?l000X0oooo
0P000?l=0?ooo`<0o`00403oool30000oa@0oooo103o000N0?ooo`H0003o
E`3oool00<@0oooo10000?lN0?ooo`<0o`004`3oool20000oa40oooo0P3o
000>0?ooo`80003o2@3oool30?l000X0oooo0`000?l90?ooo`<0o`001@3o
oolA0000o`@0oooo0`3o000:0?ooo`<0003o2@3oool30?l000X0oooo0P00
0?l=0?ooo`80o`004@3oool20000oa@0oooo0`3o000M0?ooo`D0003oG@3o
ool00<P0oooo10000?lM0?ooo`<0o`004P3oool30000oa00oooo0`3o000=
0?ooo`80003o2P3oool20?l000/0oooo10000?l80?ooo`<0o`00503oool3
0?l000T0oooo10000?l:0?ooo`80o`002`3oool20000o``0oooo0`3o000@
0?ooo`<0003o4`3oool30?l001`0oooo10000?mR0?ooo`00c03oool40000
oa`0oooo0`3o000B0?ooo`<0003o403oool20?l000d0oooo0`000?l90?oo
o`<0o`00303oool30000o`P0oooo203o00040?ooo`P0o`002@3oool30000
o`/0oooo0`3o000:0?ooo`<0003o303oool20?l00100oooo0`000?lC0?oo
o`<0o`00703oool30000ofH0oooo003@0?ooo`@0003o6`3oool30?l00180
oooo0`000?l?0?ooo`<0o`003@3oool20000o`X0oooo0P3o000=0?ooo`<0
003o3@3oool50?l000`0oooo10000?l<0?ooo`80o`002`3oool20000o``0
oooo0`3o000?0?ooo`<0003o4`3oool30?l001/0oooo10000?mY0?ooo`00
e03oool40000oaX0oooo0`3o000B0?ooo`<0003o3`3oool30?l000`0oooo
0`000?l90?ooo`<0o`003@3oool40000oaL0oooo0`000?l=0?ooo`<0o`00
2P3oool30000o`/0oooo0`3o000@0?ooo`80003o4`3oool30?l001X0oooo
10000?m]0?ooo`00f03oool30000oaX0oooo0P3o000C0?ooo`<0003o3`3o
ool20?l000d0oooo0`000?l90?ooo`@0o`003@3ooolG0000o``0oooo103o
000:0?ooo`<0003o303oool20?l00100oooo0`000?lC0?ooo`80o`006P3o
ool30000og40oooo003K0?ooo`@0003o603oool30?l001<0oooo0`000?l>
0?ooo`<0o`003@3oool20000o`/0oooo103o000X0?ooo`@0o`00303oool2
0000o``0oooo0`3o000?0?ooo`<0003o4`3oool30?l001P0oooo10000?md
0?ooo`00g`3oool30000oaP0oooo0`3o000C0?ooo`<0003o3P3oool30?l0
00`0oooo0`000?l<0?ooo`P0o`006@3oool70?l000d0oooo0`000?l;0?oo
o`<0o`003`3oool30000oa<0oooo0`3o000G0?ooo`@0003oN03oool00>80
oooo10000?lG0?ooo`<0o`004`3oool20000o`l0oooo0`3o000<0?ooo`<0
003o4@3ooolI0?l00140oooo0`000?l;0?ooo`<0o`00403oool20000oa<0
oooo0`3o000F0?ooo`@0003oO03oool00>H0oooo10000?lF0?ooo`<0o`00
4P3oool30000o`l0oooo0`3o000<0?ooo`@0003o<`3oool40000o`/0oooo
0`3o000@0?ooo`<0003o4P3oool30?l001D0oooo10000?n00?ooo`00jP3o
ool30000oaH0oooo0`3o000B0?ooo`<0003o3`3oool40?l000`0oooo2000
0?lS0?ooo`P0003o2`3oool40?l00100oooo0`000?lB0?ooo`<0o`005@3o
ool30000oh@0oooo003]0?ooo`@0003o5@3oool20?l001<0oooo0P000?lA
0?ooo`<0o`004@3oool40000oa/0oooo10000?l@0?ooo`<0o`004P3oool2
0000oa80oooo0`3o000D0?ooo`@0003oQ`3oool00?40oooo0`000?lD0?oo
o`<0o`004P3oool30000oa40oooo103o000A0?oooa/0003o403oool40?l0
0180oooo0`000?lA0?ooo`<0o`00503oool30000oh/0oooo003d0?ooo`<0
003o503oool30?l00180oooo0`000?lB0?ooo`@0o`00=03oool40?l00180
oooo10000?lA0?ooo`<0o`00503oool30000ohh0oooo003g0?ooo`@0003o
4`3oool30?l00180oooo10000?lB0?ooo`@0o`00;03oool40?l00180oooo
10000?lB0?ooo`<0o`004`3oool40000oi40oooo003k0?ooo`<0003o4`3o
ool40?l00180oooo10000?lB0?ooo`T0o`006`3oool80?l00180oooo1000
0?lC0?ooo`<0o`004`3oool30000oiD0oooo003n0?ooo`@0003o4`3oool3
0?l001<0oooo10000?lG0?oooa/0o`005P3oool40000oa@0oooo0`3o000B
0?ooo`@0003oV03oool00?l0oooo0`3oool30000oa<0oooo0`3o000D0?oo
o`D0003o?P3oool50000oa@0oooo103o000B0?ooo`<0003oW03oool00?l0
oooo1P3oool40000oa80oooo103o000E0?ooo`@0003o=P3oool40000oaH0
oooo0`3o000B0?ooo`@0003oW`3oool00?l0oooo2P3oool40000oa80oooo
103o000E0?ooo`T0003o9@3oool80000oaH0oooo103o000A0?ooo`@0003o
X`3oool00?l0oooo3P3oool30000oa<0oooo1P3o000H0?ooo`T0003o4`3o
ool90000oaP0oooo1P3o000B0?ooo`<0003oY`3oool00?l0oooo4@3oool4
0000oaD0oooo1P3o000K0?oooa<0003o6`3oool60?l001D0oooo0`000?nZ
0?ooo`00o`3ooolE0?ooo`<0003o603oool50?l003l0oooo1@3o000H0?oo
o`<0003o[@3oool00?l0oooo603oool30000oaX0oooo103o000g0?ooo`@0
o`006@3oool40000ok00oooo003o0?oooa/0oooo10000?lJ0?ooo`T0o`00
9@3oool90?l001X0oooo0`000?nd0?ooo`00o`3ooolO0?ooo`@0003o7`3o
ool;0?l000l0oooo2`3o000O0?ooo`@0003o]`3oool00?l0oooo8`3oool6
0000ob@0oooo3`3o000T0?ooo`H0003o^`3oool00?l0oooo:@3oool60000
od/0oooo1P000?o10?ooo`00o`3oool_0?ooo`L0003o?@3oool70000olL0
oooo003o0?ooocH0oooo1`000?l_0?ooo`L0003ocP3oool00?l0oooo?@3o
ool90000oad0oooo2@000?oE0?ooo`00o`3ooom60?oooad0003ogP3oool0
0?l0ooooo`3ooom20?ooo`00o`3ooooo0?oood80oooo003o0?ooool0oooo
@P3oool00?l0ooooo`3ooom20?ooo`00o`3ooooo0?oood80oooo003o0?oo
ool0oooo@P3oool00?l0ooooo`3ooom20?ooo`00o`3ooooo0?oood80oooo
003o0?ooool0oooo@P3oool00?l0ooooo`3ooom20?ooo`00o`3ooooo0?oo
od80oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{576, 178},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.88",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/fluidflowimage/\
FluidFlowImageFigures/mat1188.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Flow over the vertical segment from ",
  Cell[BoxData[
      RowBox[{"0", " ", 
        StyleBox["to",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "\[ImaginaryI]"}]]],
  "."
}], "Text"],

Cell[TextData[{
  "Solution.  Set  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_3 = 1\)}]]],
  ".  In the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  "-plane ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_3 = 0\)}]]],
  ", and the exterior angles are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(\[Pi]\/2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(-\[Pi]\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "3"], "=", \(\[Pi]\/2\)}]}]]],
  ",  and the formula for the derivative ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " is  \n\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\ \((z - x\_3)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z - \
\((\(-1\))\))\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - \
0)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\ \((z - 1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\)\
\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \
\((z)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\ \((z - \
1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(\(-\(\[Pi]\/2\)\)/\[Pi]\)\) \((z)\)\^\(\(-\((\(-\
\[Pi]\))\)\)/\[Pi]\)\ \((z - 1)\)\^\(\(-\(\[Pi]\/2\)\)/\[Pi]\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(-\(1\/2\)\)\) \((z)\)\^1\ \((z - \
1)\)\^\(-\(1\/2\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ z \((z\^2 - \
1)\)\^\(-\(1\/2\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ z\/\((z\^2 - 1)\)\^\
\(1\/2\)\)\)\)}]]
}], "Text"],

Cell[TextData[{
  "Integrate and get  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\ \  = \ \ B\ \  + \ \ A\ \(\[Integral]\(z\/\((z\^2 - 1)\
\)\^\(1\/2\)\) \[DifferentialD]z\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(B\ \  + \ \ \((z\^2 - 1)\)\
\^\(1\/2\)\)\)\)}]],
  " \n\nSolve for the coefficients A and B and obtain \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \((z\^2 - 1)\)\^\(1\/2\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(Print[\*"\"\<B + A \[Integral]\!\(z\/\((z\^2 - 1)\)\^\(1\/2\)\)\
\[DifferentialD]z = \>\"", 
      B\ \  + \ \ A\ \(\[Integral]\(z\/\((z\^2 - 1)\)\^\(1\/2\)\) \
\[DifferentialD]z\)]\)], "Input"],

Cell[BoxData[{
    \(\(f[
          z_]\  = \ \((z\^2 - 1)\)\^\(1\/2\)\ ;\)\ \), "\[IndentingNewLine]", \

    \(\(Print["\< f[z] = \>", f[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[-1] = \>", f[\(-1\)]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[0] = \>", f[0]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[1] = \>", f[1]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[
          z_]\  = \ \((z\^2 - 1)\)\^\(1\/2\)\ ;\)\ \), "\[IndentingNewLine]", \

    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.075  k]]}, {k, 1, 11, 
            2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {x, 0, 4}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{\(-Re[f[x + \[ImaginaryI]\ 0.2  k]]\), 
            Im[f[x + \[ImaginaryI]\ 0.075  k]]}, {k, 1, 11, 
            2}];\)\ \), "\[IndentingNewLine]", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {x, 0, 4}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns3\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.075  k]]}, {k, 2, 11, 
            2}];\)\ \), "\n", 
    \(\(graph3 = 
        ParametricPlot[Evaluate[eqns3], {x, 0, 4}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns4\  = \ 
        Table[{\(-Re[f[x + \[ImaginaryI]\ 0.2  k]]\), 
            Im[f[x + \[ImaginaryI]\ 0.075  k]]}, {k, 2, 11, 
            2}];\)\ \), "\n", 
    \(\(graph4 = 
        ParametricPlot[Evaluate[eqns4], {x, 0, 4}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Red, Line[{{\(-2\), 0}, {2, 0}}], 
            Line[{{0, 1}, {0, \(-1\)}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, graph4, boundary, 
        PlotRange \[Rule] {{\(-2\), 2}, {\(-0.1\), 1.4}}, 
        AspectRatio \[Rule] 1.5\/4, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0, 2, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow across the upper half plane Im[z] > 0,\
\>"];\)\ \), "\n", 
    \(\(Print["\<under w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Figure 11.89 to find the flow around an infinitely long rectangular \
barrier."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/R000`400?l0
0000o`00003oo`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?oo
o`00^03ooolC0000oeD0oooo002a0?ooo`L0003o4`3oool70000odh0oooo
002^0?ooo`<0003o8@3oool40000odX0oooo002Z0?ooo`@0003o3`3oool:
0?l000l0oooo10000?m60?ooo`00YP3oool40000o`T0oooo2P3o000:0?oo
o`X0o`002@3oool40000od80oooo002S0?ooo`<0003o2@3oool40?l001h0
oooo0`3o000:0?ooo`<0003o?`3oool00:40oooo0P000?l90?ooo`<0o`00
4@3oool40000oa00oooo103o00090?ooo`80003o?@3oool009h0oooo0`00
0?l70?ooo`@0o`002`3oool:0000o`80oooo2P000?l;0?ooo`@0o`001`3o
ool20000oc/0oooo002L0?ooo`80003o1`3oool30?l000T0oooo1P000?lF
0?ooo`H0003o2@3oool20?l000L0oooo0P000?li0?ooo`00VP3oool20000
o`L0oooo0P3o00080?ooo`@0003o8P3oool30000o`P0oooo0P3o00070?oo
o`80003o=`3oool009P0oooo0P000?l70?ooo`80o`001`3oool30000o`/0
oooo503o000:0?ooo`@0003o1P3oool20?l000L0oooo0P000?le0?ooo`00
UP3oool20000o`L0oooo0P3o00070?ooo`80003o203oool60?l001@0oooo
1P3o00080?ooo`80003o1P3oool20?l000L0oooo0P000?lc0?ooo`00U@3o
ool00`000?l0oooo0?ooo`050?ooo`80o`001`3oool20000o`L0oooo0`3o
000P0?ooo`<0o`001`3oool20000o`H0oooo0P3o00070?ooo`80003o<@3o
ool009<0oooo0P000?l60?ooo`80o`001`3oool20000o`H0oooo0`3o000:
0?oooa80003o2P3oool30?l000H0oooo0P000?l60?ooo`80o`001`3oool2
0000obl0oooo002B0?ooo`030000o`3oool0oooo00@0oooo0P3o00070?oo
o`80003o1P3oool20?l000P0oooo1@000?lB0?ooo`D0003o203oool20?l0
00H0oooo0P000?l60?ooo`80o`001`3oool00`000?l0oooo0?ooo`0/0?oo
o`00T@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0
oooo0P000?l60?ooo`80o`001`3oool30000oa`0oooo0`000?l70?ooo`80
o`001P3oool20000o`H0oooo0P3o00060?ooo`030000o`3oool0oooo02/0
oooo002?0?ooo`80003o1P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo0P3o00060?ooo`<0003o1`3ooolD0?l000L0oooo
0P000?l70?ooo`80o`001P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo0P000?l[0?ooo`00SP3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo0P000?l60?ooo`030?l0003o
ool0oooo00<0oooo0`000?l70?ooo`<0o`00503oool30?l000H0oooo0`00
0?l60?ooo`030?l0003oool0oooo00@0oooo0P000?l60?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0:03oool008d0oooo00<0003o
0?ooo`3oool0103oool20?l000H0oooo00<0003o0?ooo`3oool0103oool2
0?l000@0oooo0P000?l50?ooo`D0o`002P3oool50000o`/0oooo103o0005
0?ooo`80003o1@3oool20?l000H0oooo00<0003o0?ooo`3oool0103oool2
0?l000H0oooo00<0003o0?ooo`3oool09`3oool008`0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`80003o1@3oool20?l0
00@0oooo0P000?l50?ooo`80o`002@3oool70000o`@0oooo1`000?l80?oo
o`<0o`00103oool20000o`D0oooo0P3o00050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0V0?oo
o`00RP3oool20000o`H0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`80o`001@3oool00`000?l0oooo0?ooo`030?ooo`80
o`001P3oool50000oa80oooo1@000?l60?ooo`80o`00103oool20000o`D0
oooo0P3o00040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool20000obH0oooo00290?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo0P000?l40?ooo`80o`001P3oool20000o`T0oooo
2P3o00090?ooo`80003o1P3oool20?l000@0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`020?ooo`80003o1P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo02<0oooo001l0?ooo`8000002P3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo0P00
0?l50?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?ooo`80003o1P3oool50?l000X0oooo1@3o
00060?ooo`80003o1P3oool00`3o0000oooo0?ooo`020?ooo`80003o1@3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?ooo`8000005P3o
ool007/0oooo00@000000?ooo`3oool00000203oool00`000?l0oooo0?oo
o`040?ooo`80o`001@3oool00`000?l0oooo0?ooo`030?ooo`80o`001@3o
ool00`000?l0oooo0?ooo`020?ooo`80o`001@3oool20000o`@0oooo103o
000D0?ooo`@0o`00103oool20000o`D0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool20?l000H0oooo00<0003o0?ooo`3oool0203o
ool010000000oooo0?ooo`00000E0?ooo`00OP3oool00`000000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`80003o103o
ool20?l000H0oooo40000?l60?ooo`80o`00103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0:0?ooo`030000003o
ool0oooo01<0oooo001e0?ooo`@000000`3oool2000000L0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool20000o`@0oooo00<0o`00
0?ooo`3oool00P3oool20000o`@0oooo0P3o00030?ooo`D0003o403oool5
0000o`<0oooo0P3o00030?ooo`80003o103oool00`3o0000oooo0?ooo`03
0?ooo`80003o103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`07
0?ooo`8000005P3oool007`0oooo00<000000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00<0oooo00@0o`000?ooo`3oool0oooo0P000?l50?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool0603oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo0P000?l30?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`03
0?ooo`80003o1P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00H0oooo00<000000?ooo`3oool05@3oool007`0oooo0`0000030?oo
o`80003o1P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`050?l0003oool0oooo0?ooo`000?l01@3oool20?l000030?ooo`000?l0
003o0080003o103ooolD0?l000@0oooo0`000?l20?ooo`80o`00103oool0
10000?l0oooo0?ooo`3oool20?l000D0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool20000o`H0oooo0`00000E0?ooo`00P@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`80o`000P3o
ool00`000?l0oooo0?ooo`030?ooo`<0o`00503oool30?l000@0oooo0P00
0?l20?ooo`80o`000`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool20?l000D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo01/0oooo00200?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool010000?l0oooo0?oo
o`3oool30?l000H0oooo3P000?l60?ooo`<0o`000P3oool00`000?l0oooo
0?ooo`020?ooo`040?l0003oool0oooo0000o`D0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo01X0oooo001o0?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool010000?l0
oooo0?ooo`3o00020?ooo`L0003o3P3oool70000o`80oooo00@0o`000?oo
o`3oool0003o0`3oool01@3o0000oooo0?ooo`3oool0003o00D0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo01T0oooo001n0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P000?l20?ooo`040?l0003oool0003o0000oa/0oooo0`00
0?l01@3oool0o`000?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0
oooo0000o`050?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0H0?ooo`00
K03oool?003o00X0oooo00<0o`000?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo00<0o`000?ooo`3oool0
103oool0103o0000oooo0?ooo`3ooolN0?l000040000o`3oool0oooo0?l0
0080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00l00?l0203oool0
07X0oooo00<000000?ooo`000?l01`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00D0003o0?oo
o`3oool0oooo0?l000030?ooo`040000o`3oool0oooo0?l00080oooo00<0
003o0?ooo`3o00003@3`oo000`00o`00l?o`0?3ol00<0?3ol0050?l0003o
ool0003o0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`0000<0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`00
00005P3oool007/0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o0080
oooo00H0o`000?ooo`3oool0003o0?ooo`3o000=0?3ol003003o003`oo00
l?o`00`0l?o`00<0o`000?ooo`000?l00P3oool0103o0000oooo0?ooo`00
0?l30?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool05P3oool007/0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`040000
o`3oool0oooo0?l000<0oooo00<0003o0?ooo`3o00003@3`oo000`00o`00
l?o`0?3ol00<0?3ol0030?l0003oool0003o0080oooo00D0o`000?ooo`3o
ool0oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool05@3oool007X0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool01@3o
0000oooo0?ooo`3oool0003o0080oooo00@0o`000?ooo`3oool0003o0P3o
ool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00<0
o`000?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l30?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool0503oool007T0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?oo
o`3oool0003o00<0oooo00@0o`000?ooo`3oool0003o0P3oool00`3o0000
l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00@0o`000?ooo`3o
ool0003o0P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0o`00
0?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0C0?ooo`00N03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00@0003o0?ooo`3oool0o`00
0`3oool010000?l0oooo0?ooo`3o000=0?3ol003003o003`oo00l?o`00`0
l?o`00@0o`000?ooo`3oool0003o0P3oool01@3o0000oooo0?ooo`3oool0
003o00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0B0?ooo`00M`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?oo
o`050?l0003oool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3o
ool0003o0080oooo00<0o`000?3ol03`oo002`3`oo000`00o`00l?o`0?3o
l00<0?3ol0040?l0003oool0oooo0000o`80oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool04@3oool007H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01000
0?l0oooo0?ooo`3o000=0?3ol003003o003`oo00l?o`00`0l?o`00@0o`00
0?ooo`3oool0003o0P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`0@0?ooo`00MP3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o0080
oooo00<0o`000?3ol03`oo002`3`oo000`00o`00l?o`0?3ol00<0?3ol004
0?l0003oool0oooo0000o`<0oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0403oool007D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?oo
o`3oool0o`0000d0l?o`00<00?l00?3ol03`oo00303`oo00103o0000oooo
0?ooo`000?l30?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00l0oooo001d0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3o
ool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool0
0`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00D0o`00
0?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00h0oooo001c0?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`00
0?l00`3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0
l?o`00D0o`000?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00d0oooo001c0?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000l?o`0?3ol00;
0?3ol003003o003`oo00l?o`00`0l?o`00D0o`000?ooo`3oool0oooo0000
o`030?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00d0oooo001b0?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0
oooo0?l0000=0?3ol003003o003`oo00l?o`00`0l?o`00D0o`000?ooo`3o
ool0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00`0oooo001a0?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0000=0?3o
l003003o003`oo00l?o`00`0l?o`00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00/0oooo001`0?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l0000=0?3ol003003o003`oo00l?o`00`0l?o`00D0
o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`00
0?l01@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00X0oooo001`0?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`050?l0
003oool0oooo0?ooo`000?l0103oool00`3o0000l?o`0?3ol00;0?3ol003
003o003`oo00l?o`00`0l?o`00D0o`000?ooo`3oool0oooo0000o`040?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00X0oooo001_0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00P3oool00`3o0000l?o`0?3ol00;0?3ol003
003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool00P3oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00T0oooo001^0?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00P3oool00`3o0000l?o`0?3ol00;0?3ol003
003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00T0oooo001^0?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000l?o`
0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo
001]0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00L0oooo001]0?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00
l?o`00`0l?o`00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00L0oooo001/0?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000l?o`0?3ol00;0?3o
l003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo001c0?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?3ol03`oo002`3`oo000`00o`00
l?o`0?3ol00<0?3ol0030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool03@3oool00780oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000l?o`
0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`0<0?ooo`00LP3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l00?3ol03`oo00303`
oo000`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00`0oooo001a
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?3ol03`oo002`3`oo00
0`00o`00l?o`0?3ol00<0?3ol0030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool02`3oool00700oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o
0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`0;0?ooo`00L03oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l00?3ol03`
oo00303`oo000`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00X0
oooo001_0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?3ol03`oo00
2`3`oo000`00o`00l?o`0?3ol00<0?3ol0030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool02P3oool006l0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`090?ooo`00KP3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l0
0?3ol03`oo00303`oo000`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00T0oooo001^0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?3o
l03`oo002`3`oo000`00o`00l?o`0?3ol00<0?3ol0030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0203oool006d0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0
l?o`00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`00
K@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003`oo00l?o`00/0l?o`
00<00?l00?3ol03`oo00303`oo000`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00L0oooo001/0?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?3ol03`oo002`3`oo000`00o`00l?o`0?3ol00<0?3ol0030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool006`0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00
l?o`00`0l?o`00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`00L`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`
00`0l?o`00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool03@3oool007<0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?3ol03`
oo002`3`oo000`00o`00l?o`0?3ol00<0?3ol0030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00d0
oooo001b0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l00?3ol03`oo00
303`oo000`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`0<0?ooo`00LP3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000l?o`0?3o
l00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0303o
ool00740oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?3ol03`oo002`3`oo000`00o`00l?o`0?3ol00<
0?3ol0030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00/0oooo001a0?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003`oo00l?o`
00/0l?o`00<00?l00?3ol03`oo00303`oo000`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0;0?oo
o`00L03oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0
l?o`00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool02P3oool00700oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?3ol03`oo00
2`3`oo000`00o`00l?o`0?3ol00<0?3ol0030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00X0oooo
001_0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l00?3ol03`oo00303`
oo000`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`090?ooo`00K`3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000l?o`0?3ol00;
0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool02@3oool0
06h0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?3ol03`oo002`3`oo000`00o`00l?o`0?3ol00<0?3o
l0030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00P0oooo001^0?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003`oo00l?o`00/0
l?o`00<00?l00?3ol03`oo00303`oo000`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`00
K@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
103oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01`3oool006d0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?3ol03`oo002`3`
oo000`00o`00l?o`0?3ol00<0?3ol0030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo001/
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l00?3ol03`oo00303`oo00
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000l?o`0?3ol00;0?3o
l003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool006`0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?3ol03`oo002`3`oo000`00o`00l?o`0?3ol00<0?3ol003
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00H0oooo001d0?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00h0oooo
001d0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000l?o`0?3o
l00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00h0oooo001c0?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00
l?o`00`0l?o`00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00d0oooo001c0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00d0oooo001b0?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000l?o`0?3ol00;0?3ol003
003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00`0oooo001b0?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00`0oooo
001b0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000l?o`0?3o
l00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00`0oooo001a0?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00
l?o`00`0l?o`00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00/0oooo001a0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00/0oooo001a0?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000l?o`0?3ol00;0?3ol003
003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00/0oooo001`0?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00X0oooo
001`0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000l?o`0?3o
l00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00X0oooo001_0?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00
l?o`00`0l?o`00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00T0oooo001_0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo001_0?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000l?o`0?3ol00;0?3ol003
003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00T0oooo001^0?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo
001^0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000l?o`0?3o
l00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00P0oooo001^0?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00
l?o`00`0l?o`00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00P0oooo001]0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo001]0?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000l?o`0?3ol00;0?3ol003
003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00L0oooo001]0?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
001/0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000l?o`0?3o
l00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo001/0?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00
l?o`00`0l?o`00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo001e0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?3ol03`oo002`3`oo000`00
o`00l?o`0?3ol00<0?3ol0030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool03`3oool007D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0
l?o`00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`0?0?ooo`00M03oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003`oo00l?o`00/0l?o`00<00?l00?3ol03`oo00303`oo000`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00h0oooo001d0?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?3ol03`oo002`3`
oo000`00o`00l?o`0?3ol00<0?3ol0030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool03P3o
ool007<0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00
l?o`00`0l?o`00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`0=0?ooo`00L`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003`oo00l?o`00/0l?o`00<00?l00?3ol03`oo00303`oo000`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00d0oooo001c0?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?3ol03`
oo002`3`oo000`00o`00l?o`0?3ol00<0?3ol0030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool03@3oool00780oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000l?o`0?3ol00;0?3ol003003o
003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0=0?ooo`00LP3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l00?3ol03`oo00303`
oo000`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00`0oooo001b0?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?3ol03`oo002`3`oo000`00o`00l?o`0?3ol00<0?3ol0030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool0303oool00780oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000l?o`0?3ol00;0?3o
l003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0<0?oo
o`00L@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l00?3ol03`
oo00303`oo000`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00`0oooo001a0?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?3ol03`oo002`3`oo000`00o`00l?o`0?3ol00<0?3ol0030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool02`3oool00740oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000l?o`0?3o
l00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0;0?ooo`00L@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l0
0?3ol03`oo00303`oo000`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00/0oooo001`0?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?3ol03`oo002`3`oo000`00o`00l?o`0?3ol00<0?3o
l0030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool02`3oool00700oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`0:0?ooo`00L03oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003`oo00l?o`00/0l?o`
00<00?l00?3ol03`oo00303`oo000`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00X0oooo
001`0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?3ol03`oo002`3`oo000`00o`00l?o`0?3o
l00<0?3ol0030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool02P3oool006l0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0:0?ooo`00K`3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003`oo00l?o`
00/0l?o`00<00?l00?3ol03`oo00303`oo000`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00T0oooo001_0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?3ol03`oo002`3`oo000`00o`00
l?o`0?3ol00<0?3ol0030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool02@3oool006l0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`090?ooo`00KP3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003`
oo00l?o`00/0l?o`00<00?l00?3ol03`oo00303`oo000`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo001^0?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?3ol03`oo002`3`oo00
0`00o`00l?o`0?3ol00<0?3ol0030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool0
06h0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`
00`0l?o`00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`00KP3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003`oo00l?o`00/0l?o`00<00?l00?3ol03`oo00303`oo000`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00P0oooo001]0?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?3ol03`oo00
2`3`oo000`00o`00l?o`0?3ol00<0?3ol0030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
1`3oool006d0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`
oo00l?o`00`0l?o`00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`00K@3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l00?3ol03`oo00303`oo00
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00L0oooo001]0?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?3o
l03`oo002`3`oo000`00o`00l?o`0?3ol00<0?3ol0030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01`3oool006`0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000l?o`0?3ol00;0?3ol003
003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l00?3ol03`oo00
303`oo000`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00H0oooo001f0?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003`oo00l?o`00/0l?o`00<0
0?l00?3ol03`oo00303`oo000`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0@0?ooo`00MP3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00
l?o`00`0l?o`00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0403oool007D0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?3ol03`oo002`3`oo000`00o`00l?o`0?3ol00<0?3o
l0030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
0100oooo001e0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003`oo00l?o`00/0l?o`00<00?l00?3ol03`oo00303`oo000`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0?0?ooo`00
M@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000l?o`
0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool03`3oool007D0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?3ol03`oo002`3`
oo000`00o`00l?o`0?3ol00<0?3ol0030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00l0oooo001e0?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l0
0?3ol03`oo00303`oo000`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`0?0?ooo`00M03oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`
00`0l?o`00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool03P3oool007@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?3ol03`oo002`3`oo000`00o`00l?o`0?3ol00<0?3ol003
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00h0
oooo001d0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0
003`oo00l?o`00/0l?o`00<00?l00?3ol03`oo00303`oo000`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0>0?ooo`00M03o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000l?o`0?3o
l00;0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool03P3oool007<0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?3ol03`oo002`3`oo00
0`00o`00l?o`0?3ol00<0?3ol0030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00d0oooo001c0?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l00?3o
l03`oo00303`oo000`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`0=0?ooo`00L`3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0
l?o`00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool03@3oool007<0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?3ol03`oo002`3`oo000`00o`00l?o`0?3ol00<0?3ol0030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00d0oooo
001b0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003`
oo00l?o`00/0l?o`00<00?l00?3ol03`oo00303`oo000`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0<0?ooo`00LP3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000l?o`0?3ol00;
0?3ol003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool0303oool00780oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?3ol03`oo002`3`oo000`00
o`00l?o`0?3ol00<0?3ol0030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00`0oooo001b0?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l00?3ol03`
oo00303`oo000`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`0<0?ooo`00L@3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
203oool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2`3oool00740oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?3ol03`oo002`3`oo000`00o`00l?o`0?3ol00<0?3ol0030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00/0oooo001a
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003`oo00
l?o`00/0l?o`00<00?l00?3ol03`oo00303`oo000`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`0;0?ooo`00L@3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000l?o`0?3ol00;0?3o
l003003o003`oo00l?o`00`0l?o`00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool02`3oool00740oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?3ol03`oo002`3`oo000`00o`00
l?o`0?3ol00<0?3ol0030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00/0oooo001`0?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`080?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l00?3ol03`oo00
303`oo000`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`0;0?ooo`00L03oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000l?o`0?3ol00;0?3ol003003o003`oo00l?o`00`0l?o`00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3o
ool00700oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?3ol03`oo002`3`oo000`00o`00l?o`0?3ol00<0?3ol0030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo001`0?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003`oo00l?o`
00/0l?o`00<00?l00?3ol03`oo00303`oo000`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{288, 178},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.89",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/fluidflowimage/\
FluidFlowImageFigures/mat1189.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Flow around an infinitely long rectangular barrier."
}], "Text"],

Cell[TextData[{
  "Solution.  Set  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 1\)}]]],
  ".  In the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  "-plane ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 1\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \(-1\)\)}]]],
  ", and the exterior angles are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(-\(\[Pi]\/2\)\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(-\(\[Pi]\/2\)\)}]}]]],
  ",  and the formula for the derivative ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " is  \n\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \((z - \
\((\(-1\))\))\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\ \((z - 1)\)\^\(\(-\[Alpha]\_2\)/\
\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z + 
                  1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - 1)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \((z + 1)\)\^\(\(-\
\((\(-\(\[Pi]\/2\)\))\)\)/\[Pi]\)\ \((z - \
1)\)\^\(\(-\((\(-\(\[Pi]\/2\)\))\)\)/\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \((z + \
1)\)\^\(1\/2\)\ \((z - 1)\)\^\(1\/2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ \((z\^2 - 1)\)\^\(1\
\/2\)\)\)\)}]]
}], "Text"],

Cell[TextData[{
  "Integrate and get  \n\n\t\t\t",
  Cell[BoxData[{
      \(f \((z)\)\ \  = \ \ B\ \  + \ \ A\ \(\[Integral]\(\((z\^2 - 
                        1)\)\^\(1\/2\)\) \[DifferentialD]z\)\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(B\_1\ \  + \ \ A\_1\ \(\
\[Integral]\((1 - 
                    z\^2\()\^\(1\/2\)\)\) \[DifferentialD]z\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(B\_1\ \  + \ \ A\_1\ \
\((1\/2\ z\ \((1 - z\^2\()\^\(1\/2\)\)\) + \(1\/2\) Arczin\ z)\)\)\)\)}]],
  "  \n\nSolve for the coefficients ",
  Cell[BoxData[
      \(A\_1\)]],
  " and ",
  Cell[BoxData[
      \(B\_1\)]],
  " and obtain \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \(-\ \(2\/\[Pi]\)\) 
            z \((1 - z\^2\()\^\(1\/2\)\)\)\  - \ \(2\/\[Pi]\) Arcsin\ z\)]],
  " "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(Print[\*"\"\<B + A \[Integral](1-\!\(z\^2\)\!\(\()\^\(1\/2\)\)\)\
\[DifferentialD]z = \>\"", 
      B\ \  + \ \ A\ \(\[Integral]\(\((1 - 
                      z\^2)\)\^\(1\/2\)\) \[DifferentialD]z\)]\)], "Input"],

Cell[BoxData[{
    \(\(f[
          z_]\  = \ \(-\(2\/\[Pi]\)\) 
            z \((1 - z\^2)\)\^\(1\/2\) - \(2\/\[Pi]\) 
            ArcSin[z]\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = \>", f[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[-1] = \>", f[\(-1\)]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[1] = \>", f[1]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[
          z_]\  = \ \(-\(2\/\[Pi]\)\) 
            z \((1 - z\^2)\)\^\(1\/2\) - \(2\/\[Pi]\) 
            ArcSin[z]\ ;\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.075  k]]}, {k, 1, 11, 
            2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {x, 0, 4}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{\(-Re[f[x + \[ImaginaryI]\ 0.2  k]]\), 
            Im[f[x + \[ImaginaryI]\ 0.075  k]]}, {k, 1, 11, 
            2}];\)\ \), "\[IndentingNewLine]", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {x, 0, 4}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns3\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.075  k]]}, {k, 2, 11, 
            2}];\)\ \), "\n", 
    \(\(graph3 = 
        ParametricPlot[Evaluate[eqns3], {x, 0, 4}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns4\  = \ 
        Table[{\(-Re[f[x + \[ImaginaryI]\ 0.2  k]]\), 
            Im[f[x + \[ImaginaryI]\ 0.075  k]]}, {k, 2, 11, 
            2}];\)\ \), "\n", 
    \(\(graph4 = 
        ParametricPlot[Evaluate[eqns4], {x, 0, 4}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Red, 
            Line[{{1, 5}, {1, 0}, {\(-1\), 0}, {\(-1\), 
                  5}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, graph4, boundary, 
        PlotRange \[Rule] {{\(-6\), 6}, {\(-1.2\), 5}}, 
        AspectRatio \[Rule] 1\/1, 
        Ticks \[Rule] {Range[\(-5\), 5, 2], Range[0, 5, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow across the upper half plane Im[z] > 0,\
\>"];\)\ \), "\n", 
    \(\(Print["\<under w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Figure 11.90 to find the flow around"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;o0000/R000`400?l0
0000o`00003oo`3ooooo0?ooool0oooo0P3oool00?l0ooooo`3ooooo0?oo
o`80oooo003o0?ooool0ooooo`3oool20?ooo`00o`3ooooo0?ooool0oooo
0P3oool00?l0ooooo`3ooooo0?ooo`80oooo003o0?ooool0ooooo`3oool2
0?ooo`00o`3ooooo0?ooool0oooo0P3oool00?l0ooooJ`3oool500000?l0
ooooT@3oool00?l0ooooK@3oool00`000000oooo0?ooo`3o0?oooi40oooo
003o0?ooofd0oooo00<000000?ooo`3oool0o`3ooonA0?ooo`00o`3ooom]
0?ooo`030000003oool0oooo0?l0oooo3@3ooolJ0000ofX0oooo003o0?oo
ofd0oooo00<000000?ooo`3oool0o`3oool:0?ooo`<0003o1`3oool>0?l0
00D0oooo1P000?mT0?ooo`00o`3ooom/0?ooo`800000o`3oool80?ooo`@0
003o0`3oool70?l000h0oooo203o00030?ooo`<0003oH@3oool00?l0oooo
o`3oooma0?ooo`D0003o0P3oool50?l000@0oooo5@000?l40?ooo`<0o`00
0`3oool40000oed0oooo003o0?ooool0ooooK@3oool40000o`<0oooo103o
00050?ooo`@0003o103oool?0?l00080oooo1P000?l0103oool0o`000?l0
003o00040?ooo`80003oF`3oool00?l0ooooo`3ooomZ0?ooo`<0003o103o
ool30?l000@0oooo1@000?l20?ooo`H0o`00103oool80000o`<0oooo1@3o
00030?ooo`<0003o00<0oooo0?l0003o00000P3o00020?ooo`80003oF@3o
ool00?l0ooooo`3ooomV0?ooo`@0003o103oool30?l000@0oooo0`000?l4
0?ooo`<0o`000`3oool80000o`L0oooo1P000?l20?ooo`<0o`000`3oool2
0000o`<0oooo0P3o00020?ooo`80003oE`3oool00?l0ooooo`3ooomS0?oo
o`<0003o1@3oool30?l000@0oooo0`000?l30?ooo`@0o`000P3oool40000
o`80oooo4@3o00020?ooo`<0003o0P3oool20?l000<0oooo0P000?l30?oo
o`80o`000P3oool30000oe@0oooo003o0?ooool0ooooH@3oool20000o`@0
oooo103o00030?ooo`@0003o0P3oool40?l00080oooo10000?l30?ooo`<0
o`000`3oool50000o`@0o`001@000?l40?l000050?ooo`000?l0003o0000
o`3oool00P3o00030?ooo`80003o0`3oool20?l000<0oooo0P000?mB0?oo
o`00dP3oool00`000000oooo0?ooo`3o0?ooohP0oooo0`000?l30?ooo`<0
o`00103oool30000o`@0oooo0P3o00030?ooo`<0003o1@3oool20?l000H0
003o1P3o00030000o`@0o`000P3oool20000o`030?ooo`3o0000o`000080
oooo0`000?l20?l000<0oooo0P000?l30?ooo`80o`000`3oool20000oe00
oooo001O0?ooool0o`00PP3o001i0?ooo`<0003o103oool20?l000D0oooo
0P000?l50?ooo`80o`000P3oool30000o`D0oooo0`3o00020000o`@0oooo
0P3o0000103oool0003o0000o`000?l60?l000<0003o0P3o00020?ooo`80
003o00<0oooo0?l0003o00000`3oool20000o`80o`000`3oool20000o`<0
oooo0P3o00030?ooo`80003oCP3oool00=<0oooo00<0o`000?ooo`3oool0
UP3oool00`000000oooo0?ooo`3X0?ooo`80003o103oool30?l000D0oooo
0P000?l40?ooo`<0o`000P3oool20000o`D0oooo0`3o00030000o`<0oooo
0`3o0000103oool0003o0000o`3oool20?l00080003o00D0o`000?ooo`00
0?l0oooo0?l000020?ooo`040000o`3oool0o`000?l00080oooo0P000?l0
0`3oool0o`000?l000030?ooo`80003o0P3o00030?ooo`80003o0`3oool0
0`3o0000oooo0?ooo`020?ooo`80003oC03oool00=@0oooo00<0o`000?oo
o`3oool0U@3oool00`000000oooo0?ooo`3U0?ooo`<0003o0`3oool30?l0
00D0oooo0`000?l20?ooo`@0o`000`3oool20000o`@0oooo0`3o00000`3o
ool0003o0000o`040?ooo`80o`000P3oool20000o`030?ooo`3o0000o`00
0080003o00D0oooo0?l0003oool0oooo0000o`020?ooo`040?l0003oool0
oooo0000o`80oooo0P3o00020?ooo`80003o00<0oooo0?l0003o00000`3o
ool00`000?l0oooo0?l000040?ooo`80003o0P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo04T0oooo003E0?ooo`030?l0003oool0
oooo0?l0ooooNP3oool30000o`@0oooo0P3o00060?ooo`80003o0`3oool2
0?l000@0oooo0`000?l30?ooo`<0o`000P3oool20000o`@0oooo0P3o0002
0?ooo`80003o0P3oool00`3o0000oooo0000o`020?ooo`050?l0003oool0
oooo0?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l30?ooo`050?l0
003oool0oooo0?ooo`000?l00P3oool0103o0000oooo0?ooo`3oool20000
o`80o`00103oool00`000?l0oooo0?ooo`020?l000@0oooo0P000?m90?oo
o`00eP3oool00`3o0000oooo0?ooo`3o0?ooogL0oooo0P000?l40?ooo`<0
o`001@3oool30000o`<0oooo0P3o00040?ooo`80003o103oool20?l000<0
oooo0P000?l40?ooo`80o`000P3oool20000o`80oooo0P3o00001@3oool0
003o0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l00003
0?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool010000?l0oooo0?oo
o`3o00040?ooo`030000o`3oool0o`0000@0oooo00D0003o0?ooo`3oool0
oooo0?l000050?ooo`030000o`3oool0oooo04H0oooo001O0?ooo`L0003o
L@3oool00`3o0000oooo0?ooo`3o0?ooog<0oooo0`000?l40?ooo`80o`00
1@3oool30000o`@0oooo0P3o00030?ooo`<0003o0`3oool30?l000<0oooo
0P000?l40?ooo`80o`000P3oool20000o`<0oooo00@0o`000?ooo`000?l0
003o0P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0oooo
0?ooo`000?l00P3oool20?l000<0oooo00@0003o0?ooo`3o0000o`000`3o
ool20000o`80oooo0P3o00040?ooo`80003oAP3oool006H0oooo>@000?li
0?ooo`030?l0003oool0oooo0=40oooo=0000?mY0?ooo`<0003o1@3oool2
0?l000D0oooo0P000?l50?ooo`80o`000`3oool20000o`@0oooo0P3o0005
0?ooo`030000o`3oool0oooo0080oooo0P3o00020?ooo`80003o0`3oool2
0?l000030?ooo`000?l0oooo0080oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o0000
0`3oool010000?l0oooo0?ooo`3o00040?ooo`040000o`3oool0oooo0?oo
o`80o`00103oool20000od@0oooo002O0?oooa<0003o9`3oool00`3o0000
oooo0?ooo`2a0?oooal0003oVP3oool30000o`D0oooo0`3o00050?ooo`80
003o1@3oool20?l000<0oooo0P000?l40?ooo`80o`001@3oool20000o`<0
oooo0P3o00020?ooo`80003o0`3oool20?l00080oooo00D0003o0?ooo`3o
ool0oooo0?l000070?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o
0?ooo`3oool0oooo0?l000030?ooo`80003o00<0oooo0?l0003oool00`3o
ool20000o`<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`110?ooo`00/P3oool90000oal0oooo00<0o`000?ooo`3oool0Y@3oool;
0000okL0oooo0P000?l60?ooo`80o`001P3oool20000o`D0oooo0P3o0003
0?ooo`80003o103oool20?l000D0oooo0P000?l30?ooo`80o`000`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080003o0`3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`040000o`3oool0o`000?l000@0
oooo00@0003o0?ooo`3oool0oooo0P3o00040?ooo`80003o@@3oool00;/0
oooo1P000?lJ0?ooo`030?l0003oool0oooo09T0oooo2`000?o00?ooo`80
003o1P3oool20?l000H0oooo0P000?l50?ooo`80o`000`3oool20000o`D0
oooo00<0o`000?ooo`3oool0103oool010000?l0oooo0?ooo`3oool20?l0
00<0oooo0P000?l40?ooo`040?l0003oool0oooo0000o`@0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00<0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?oo
o`3o00040?ooo`030000o`3oool0oooo0080oooo0P3o00040?ooo`030000
o`3oool0oooo03h0oooo00310?ooo`80003o6@3oool00`3o0000oooo0?oo
o`2@0?ooo`P0003ob@3oool20000o`D0oooo0`3o00060?ooo`80003o1@3o
ool20?l000<0oooo0P000?l50?ooo`80o`001@3oool20000o`80oooo0P3o
00040?ooo`030000o`3oool0oooo0080oooo0P3o00020?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo
0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool010000?l0
oooo0?ooo`3o00040?ooo`80003o103oool00`3o0000oooo0?ooo`020?oo
o`80003o?P3oool005l0oooo1`3o001M0?ooo`<0003o5`3oool00`3o0000
oooo0?ooo`290?ooo`H0003ocP3oool30000o`D0oooo0P3o00070?ooo`80
003o1@3oool20?l000<0oooo0P000?l50?ooo`80o`001@3oool20000o`80
oooo0P3o00040?ooo`80003o103oool01@3o0000oooo0?ooo`3oool0003o
00@0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool01@3o
0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?l000@0oooo00<0003o0?ooo`3oool00P3oool2
0?l000@0oooo0P000?ll0?ooo`00IP3ooolV0?l003X0oooo0P000?lF0?oo
o`030?l0003oool0oooo0880oooo1P000?mF0?ooob40o`00F`3oool20000
o`H0oooo0P3o00070?ooo`80003o1@3oool20?l000<0oooo0P000?l50?oo
o`80o`001@3oool20000o`<0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`030?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`030?ooo`80o`00
103oool20000ocX0oooo002<0?oooa40o`00:`3oool20000oaD0oooo00<0
o`000?ooo`3oool0O03oool50000od/0oooo4@3o001j0?ooo`80003o1P3o
ool20?l000L0oooo0P000?l50?ooo`80o`000`3oool20000o`H0oooo00<0
o`000?ooo`3oool00`3oool20000o`<0oooo0P3o00040?ooo`80003o103o
ool20?l000<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`000?l0
0`3oool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool20000o`D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`0g0?ooo`00W@3oool80?l002D0oooo0P000?lD0?ooo`030?l0
003oool0oooo07T0oooo0P000?m40?ooo``0o`00R03oool30000o`H0oooo
0P3o00060?ooo`<0003o1@3oool20?l000@0oooo00<0003o0?ooo`3oool0
103oool20?l000@0oooo0P000?l40?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o
00001@3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00<0003o0?oo
o`3oool00`3oool20?l000@0oooo0P000?lg0?ooo`00Y@3oool90?l001h0
oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`1e0?ooo`<0
003o=03ooolB0?l00940oooo0`000?l70?ooo`80o`001P3oool20000o`H0
oooo0P3o00040?ooo`80003o1@3oool20?l000@0oooo0P000?l40?ooo`80
o`001@3oool00`000?l0oooo0?ooo`020?ooo`80o`00103oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`00
00D0oooo00@0003o0?ooo`3oool0oooo0P3o00040?ooo`030000o`3oool0
oooo00@0oooo0P3o00040?ooo`80003o=@3oool00:h0oooo203o000G0?oo
o`80003o4`3oool00`3o0000oooo0?ooo`1b0?ooo`80003o<@3oool60?l0
0:40oooo0P000?l80?ooo`80o`001P3oool20000o`H0oooo0P3o00050?oo
o`030000o`3oool0oooo00<0oooo0P3o00040?ooo`80003o1@3oool00`3o
0000oooo0?ooo`030?ooo`80003o103oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo
0?ooo`3o0000103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo0080oooo0P000?l60?ooo`80o`00103oool20000oc<0oooo001O0?oo
o`H0003oD@3oool30?l001H0oooo0P000?lB0?ooo`030?l0003oool0oooo
06l0oooo0P000?l_0?ooo`@0o`00Y03oool30000o`L0oooo0`3o00050?oo
o`<0003o1P3oool20?l000D0oooo0P000?l50?ooo`030?l0003oool0oooo
0080oooo0P000?l50?ooo`80o`001@3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo0`000?l`0?oo
o`00I@3ooolJ0000ocX0oooo0P3o000F0?ooo`030000o`3oool0oooo0100
oooo00<0o`000?ooo`3oool0K@3oool00`000?l0oooo0?ooo`0V0?ooo`T0
o`00BP3oool@0000od/0oooo0`000?l80?ooo`80o`001P3oool20000o`L0
oooo0P3o00050?ooo`80003o1@3oool20?l000@0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080
oooo0P3o00050?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo0P000?l60?ooo`80
o`001P3oool20000obh0oooo001o0?oooa<0003o:@3oool20?l001D0oooo
0P000?lA0?ooo`030?l0003oool0oooo06X0oooo0P000?lU0?ooo`@0o`00
>`3ooolH0000oeP0oooo0`000?l80?ooo`<0o`001P3oool20000o`L0oooo
0P3o00060?ooo`030000o`3oool0oooo00<0oooo0P3o00040?ooo`80003o
1@3oool20?l000D0oooo0P000?l40?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo
0P3o00050?ooo`030000o`3oool0oooo00D0oooo0P3o00060?ooo`<0003o
:`3oool00980oooo20000?lS0?ooo`80o`005@3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo06P0oooo00<0003o0?ooo`3oool08`3o
ool20?l003L0oooo20000?m]0?ooo`<0003o2@3oool20?l000H0oooo0`00
0?l70?ooo`80o`001P3oool20000o`@0oooo0P3o00050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`020?ooo`80o`001@3oool20000o`@0oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo0P000?l70?ooo`80o`001`3o
ool30000obP0oooo002J0?ooo`P0003o7@3oool20?l001@0oooo00<0003o
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`1U0?ooo`80003o8`3oool3
0?l002h0oooo2`000?mb0?ooo`<0003o2@3oool30?l000H0oooo0P000?l8
0?ooo`80o`001P3oool20000o`D0oooo00<0o`000?ooo`3oool00`3oool2
0000o`D0oooo0P3o00050?ooo`80003o103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo0P000?l70?ooo`80o`00203oool2
0000obH0oooo002R0?ooo`L0003o603oool20?l001<0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`1S0?ooo`030000o`3oool0oooo
0200oooo0`3o000V0?ooo`/0003oN@3oool40000o`X0oooo0P3o00070?oo
o`80003o203oool20?l000H0oooo0P000?l50?ooo`80o`00103oool20000
o`H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`80o`00203oool30000ob<0oooo001O0?ooo`H0
o`00A03oool50000oaD0oooo0P3o000B0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool0H@3oool00`000?l0oooo0?ooo`0O0?ooo`80
o`008`3oool60000oh40oooo0`000?l;0?ooo`<0o`001`3oool20000o`L0
oooo0`3o00060?ooo`80003o1@3oool20?l000D0oooo00<0003o0?ooo`3o
ool0103oool20?l000D0oooo0P000?l50?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo0P3o00060?ooo`80003o203oool20?l000T0oooo1@000?lN0?ooo`00
I@3ooolH0?l00340oooo10000?lC0?ooo`80o`004@3oool20000oa00oooo
00<0o`000?ooo`3oool0H03oool00`000?l0oooo0?ooo`0M0?ooo`80o`00
8@3oool40000och0oooo3P3o000f0?ooo`D0003o2`3oool30?l000P0oooo
0P000?l70?ooo`80o`001`3oool20000o`D0oooo0P3o00050?ooo`80003o
1P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
0P3o00060?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
5@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo0P000?l80?ooo`80o`00
303oool60000oaP0oooo001m0?ooo`/0o`00:P3oool30000oa80oooo0P3o
000A0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0GP3o
ool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0oooo01h0oooo0`00
0?lc0?ooo`l0o`00?P3oool60000o`d0oooo0`3o00090?ooo`80003o1`3o
ool20?l000L0oooo0P000?l60?ooo`030?l0003oool0oooo00<0oooo0P00
0?l60?ooo`80o`001@3oool20000o`D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo01H0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo0P000?l60?ooo`030?l0003o
ool0oooo00H0oooo0P000?l80?ooo`<0o`003`3oool40000oa@0oooo0028
0?ooo`P0o`009@3oool20000oa80oooo0P3o000@0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0K
0?ooo`80o`007@3oool40000ob/0oooo2`3o00190?ooo`@0003o3`3oool4
0?l000X0oooo0P000?l70?ooo`80o`001`3oool20000o`H0oooo0P3o0005
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo0P3o0008
0?ooo`80003o2@3oool40?l000l0oooo1P000?l>0?ooo`00T03oool80?l0
01l0oooo0P000?lB0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool03P3oool00`3o0000oooo0?ooo`1K0?ooo`030000o`3oool0oooo
01/0oooo00<0o`000?ooo`3oool06@3oool40000obL0oooo203o001>0?oo
o`H0003o403oool30?l000/0oooo0`000?l60?ooo`<0o`001`3oool20000
o`H0oooo0P3o00050?ooo`80003o1P3oool20?l000D0oooo0P000?l60?oo
o`030?l0003oool0oooo00@0oooo0P000?l50?ooo`030?l0003oool0oooo
01P0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`80003o2`3oool40?l0
0140oooo1@000?l90?ooo`00V03oool70?l001X0oooo0P000?lA0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`1I0?ooo`030000o`3oool0oooo01X0oooo0P3o000J0?ooo`80
003o903oool70?l004h0oooo20000?lA0?ooo`D0o`002P3oool40000o`L0
oooo0P3o00080?ooo`80003o1P3oool20?l000D0oooo0P000?l70?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool06P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool20000o`H0
oooo0P3o00090?ooo`80003o3@3oool40?l001/0oooo001O0?ooo`D0003o
>`3oool50?l001L0oooo0P000?l@0?ooo`80o`003`3oool20000o`l0oooo
00<0o`000?ooo`3oool0F03oool00`000?l0oooo0?ooo`0H0?ooo`80o`00
6P3oool20000oal0oooo1`3o001@0?ooo`D0003o4`3oool60?l000/0oooo
10000?l90?ooo`80o`00203oool20000o`L0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`80o`001P3oool00`000?l0oooo
0?ooo`040?ooo`80o`001P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo01/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool20?l000T0oooo0`000?l>0?ooo`H0o`00
5@3oool006@0oooo60000?lX0?ooo`@0o`005@3oool20000oa00oooo00<0
o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo05H0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?oo
o`0H0?ooo`80003o703oool50?l00340oooo3@000?l]0?ooo`@0o`003`3o
ool20000o`X0oooo0`3o00080?ooo`80003o1`3oool20?l000D0oooo0P00
0?l70?ooo`030?l0003oool0oooo00@0oooo0P000?l60?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`0L0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`80003o1`3o
ool20?l000X0oooo10000?l@0?ooo`L0o`003P3oool007`0oooo2P000?lR
0?ooo`@0o`004`3oool20000o`l0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo05D0oooo00<0003o
0?ooo`3oool0603oool00`3o0000oooo0?ooo`0F0?ooo`80003o6P3oool4
0?l002/0oooo2`000?ld0?ooo`H0o`00403oool30000o`X0oooo0P3o0009
0?ooo`80003o1`3oool20?l000D0oooo0P000?l70?ooo`80o`001P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool2
0?l000L0oooo0P000?l70?ooo`80o`00303oool50000oa80oooo1@3o0009
0?ooo`00QP3oool70000oal0oooo1@3o000@0?ooo`80003o3P3oool20?l0
00l0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`1C0?oo
o`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool05@3oool20000
oaT0oooo0`3o000Y0?ooo`H0003o=`3oool80?l00140oooo1@000?l;0?oo
o`80o`002@3oool20000o`L0oooo0P3o00060?ooo`030000o`3oool0oooo
00D0oooo0P3o00070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool20000o`H0oooo00<0o`000?ooo`3oool07P3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool20000o`L0oooo103o000=0?oo
o`@0003o703oool008d0oooo20000?lL0?ooo`80o`00403oool20000o`h0
oooo00<0o`000?ooo`3oool03@3oool20000o`h0oooo00<0o`000?ooo`3o
ool0DP3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo01<0
oooo0P000?lG0?ooo`@0o`009@3oool70000ocL0oooo1P3o000C0?ooo`H0
003o303oool40?l000T0oooo0P000?l70?ooo`80o`001P3oool20000o`L0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`80
o`001P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0200
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool0203oool40?l000d0oooo1`000?lE0?ooo`00U@3oool50000oaT0oooo
0P3o000@0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0540oooo
00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0B0?ooo`80003o
5P3oool30?l002<0oooo1P000?mC0?ooo`@0003o3P3oool40?l000X0oooo
0`000?l70?ooo`80o`001P3oool20000o`L0oooo0P3o00070?ooo`80003o
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool08@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo0P3o00080?ooo`80003o
303oool20?l00180oooo20000?l=0?ooo`00G`3oool>0?l002d0oooo1000
0?lG0?ooo`80o`003`3oool20000o`d0oooo0P3o000?0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0C`3oool00`000?l0oooo0?oo
o`0G0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0503o
ool20?l001l0oooo1`000?mC0?ooo`H0003o3P3oool40?l000`0oooo0P00
0?l80?ooo`80o`001`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool08P3o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool20000o``0oooo0`3o
000G0?ooo`@0003o2@3oool006d0oooo2P3o000W0?ooo`@0003o5@3oool2
0?l000l0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0CP3oool0
0`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo0140oooo0P000?lE
0?ooo`80o`006`3oool60000obT0oooo2@3o000K0?ooo`d0003o403oool4
0?l000d0oooo0`000?l80?ooo`80o`001`3oool20000o`L0oooo0P3o0008
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo02<0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00P0oooo0P000?l=0?ooo`H0o`007P3oool0
07L0oooo1P3o000U0?ooo`@0003o4`3oool20?l000h0oooo0P000?l=0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`1=0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?oo
o`3oool0403oool00`000?l0oooo0?ooo`0C0?ooo`80o`00603oool50000
ob@0oooo2`3o000R0?ooo`80003o603oool50?l000h0oooo0`000?l80?oo
o`<0o`001`3oool20000o`P0oooo00<0o`000?ooo`3oool01P3oool20000
o`H0oooo0P3o00060?ooo`80003o203oool00`3o0000oooo0?ooo`0S0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01P3oool20?l000X0oooo0`000?l@0?ooo`H0o`00603oool007d0
oooo1`3o000R0?ooo`@0003o4@3oool20?l000h0oooo00<0003o0?ooo`3o
ool02`3oool20?l000h0oooo0P000?l=0?ooo`030?l0003oool0oooo04/0
oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo0180oooo0P3o000F0?ooo`@0003o8P3oool70?l004<0
oooo103o000?0?ooo`@0003o2@3oool20?l000T0oooo00<0003o0?ooo`3o
ool01P3oool20?l000P0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool09@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02P3oool50000oa40
oooo103o000D0?ooo`00Q03oool70?l001l0oooo10000?l?0?ooo`030?l0
003oool0oooo00`0oooo0P000?l=0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`1:0?ooo`030000
o`3oool0oooo01D0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0A0?ooo`80o`005@3oool30000ob00oooo1P3o00140?ooo`H0o`00
3P3oool50000o`/0oooo0P3o00090?ooo`80003o203oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo02H0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool20000o`P0oooo
0P3o000?0?ooo`D0003o403oool;0?l000T0oooo002;0?ooo`L0o`00703o
ool20000o`h0oooo0P3o000>0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo04T0oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?oo
o`0?0?ooo`030000o`3oool0oooo0100oooo0P3o000C0?ooo`@0003o7@3o
ool60?l003X0oooo403o000@0?ooo`@0003o3P3oool20?l000T0oooo0P00
0?l80?ooo`80o`00203oool20000o`H0oooo0P3o00070?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool09`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo0`3o
000A0?ooo`@0003o803oool005l0oooo30000?lW0?ooo`L0o`005`3oool2
0000o`h0oooo0P3o000=0?ooo`80003o303oool20?l000h0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`180?ooo`030000o`3oool0
oooo01@0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?
0?ooo`80o`004`3oool20000oaX0oooo1`3o001I0?ooo`L0003o3`3oool3
0?l000T0oooo0P000?l80?ooo`80o`00203oool20000o`L0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo02P0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`090?ooo`@0o`004@3oool60000oaX0oooo001[0?oo
o`X0003o903oool50?l001@0oooo0`000?l=0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0AP3oool00`00
0?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`0A0?ooo`80003o5`3oool50?l0
02/0oooo0`000?lZ0?ooo`P0003o503oool20?l000X0oooo0P000?l90?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`80003o2@3oool00`3o0000oooo0?ooo`0Z0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo0P000?l=0?oo
o`D0o`004P3oool80000oa80oooo001e0?ooo`H0003o8`3oool30?l001@0
oooo0P000?l<0?ooo`80o`003@3oool20000o``0oooo00<0o`000?ooo`3o
ool0303oool20000o``0oooo00<0o`000?ooo`3oool0A@3oool00`000?l0
oooo0?ooo`0D0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0@0?ooo`80003o5@3oool40?l002H0
oooo2P000?lU0?ooo`P0003o6@3oool30?l000T0oooo0`000?l90?ooo`80
o`00203oool20000o`L0oooo0P3o00070?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01`3oool20?l000X0
oooo0P000?l@0?ooo`D0o`005@3oool90000o`T0oooo001k0?ooo`L0003o
7`3oool40?l00180oooo0P000?l<0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02P3oool20?l000h0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`140?ooo`030000o`3oool0oooo01@0oooo
00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0=0?ooo`80o`00
403oool30000oa@0oooo0`3o000P0?ooo`X0003o9P3oool90000oad0oooo
103o000:0?ooo`80003o2`3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
0P3o000:0?ooo`@0003o4@3oool40?l002<0oooo00220?ooo`L0003o703o
ool30?l00140oooo0P000?l;0?ooo`80o`003@3oool20000o``0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo0480oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03P3o
ool20000oa@0oooo0`3o000M0?ooo`H0003oC@3oool90?l000/0oooo0`00
0?l;0?ooo`80o`00203oool20000o`P0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo02d0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool20000oa<0oooo103o
000O0?ooo`00R@3oool60000oaT0oooo0`3o000@0?ooo`80003o2`3oool2
0?l000d0oooo00<0003o0?ooo`3oool02P3oool20?l000d0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`110?ooo`030000o`3oool0
oooo01@0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo00d0oooo0P000?lB0?ooo`@0o`006P3oool6
0000odl0oooo103o000B0?ooo`80003o303oool20?l000P0oooo0P000?l8
0?ooo`80o`00203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo02l0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`09
0?ooo`80003o2`3oool20?l000d0oooo0`000?lD0?ooo`L0o`00603oool0
05l0oooo2`3o000U0?ooo`@0003o603oool20?l00100oooo0P000?l;0?oo
o`030?l0003oool0oooo00/0oooo0P000?l<0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`100?oo
o`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo0P000?lA0?oo
o`<0o`006P3oool40000odH0oooo3`3o000C0?ooo`<0003o303oool20?l0
00T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0<03oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool02P3oool20?l000h0oooo1@000?lF0?ooo`l0o`002@3oool006X0
oooo2@3o000P0?ooo`@0003o5P3oool30?l000l0oooo00<0003o0?ooo`3o
ool02@3oool20?l000d0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool0?`3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00l0oooo0P3o000I0?ooo`@0003o903oool30?l001T0
oooo2P3o000N0?ooo`@0003o303oool30?l000T0oooo0P000?l90?ooo`03
0?l0003oool0oooo00H0oooo0P000?l:0?ooo`030?l0003oool0oooo0340
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00/0oooo0P3o000A0?ooo`@0003o:P3oool007<0oooo
1P3o000N0?ooo`D0003o503oool30?l000d0oooo0P000?l;0?ooo`80o`00
303oool20000o`/0oooo0P3o000<0?ooo`80003o2`3oool00`3o0000oooo
0?ooo`0m0?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool03P3oool20?l001D0oooo1P000?lR0?ooo`H0o`00
>`3oool90000o`h0oooo0P3o000:0?ooo`80003o2@3oool20?l000P0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0c0?ooo`030000
o`3oool0oooo00h0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`@0o`004@3oool90000ob40oooo001i0?ooo`L0o`00703o
ool40000oa<0oooo0P3o000=0?ooo`80003o2`3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo03`0oooo00<0
003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool20000o`l0oooo0P3o
000B0?ooo`D0003o8@3oool70?l003`0oooo1@000?lD0?ooo`<0o`002`3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0d0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?ooo`3oool02`3oool20000oa00oooo1@3o
000E0?ooo`H0003o6`3oool00800oooo1`3o000I0?ooo`@0003o4@3oool2
0?l000d0oooo0P000?l:0?ooo`80o`00303oool20000o`/0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo03/0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0=0?ooo`80o`004@3oool30000ob00oooo1P3o000d
0?ooo`l0003o5@3oool40?l000`0oooo0P000?l90?ooo`80o`002@3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo03H0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`80003o4`3oool4
0?l001L0oooo3`000?l<0?ooo`00Q`3oool60?l001L0oooo10000?l?0?oo
o`80o`003@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool02@3oool20?l000`0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0j0?ooo`030000o`3oool0oooo
01<0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool20?l0
0140oooo0P000?lL0?ooo`L0o`00;`3oool;0000oal0oooo1@3o000>0?oo
o`80003o2P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo00h0oooo0P000?lE0?ooo`@0o`008P3oool30000
o`T0oooo001O0?ooo`X0003o903oool40?l001L0oooo0P000?l?0?ooo`80
o`00303oool20000o`X0oooo0P3o000<0?ooo`80003o2`3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool0>03oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00/0oooo0P3o000A0?ooo`80003o5`3oool70?l005/0
oooo1@3o000A0?ooo`80003o2`3oool00`3o0000oooo0?ooo`070?ooo`80
003o2`3oool00`3o0000oooo0?ooo`0i0?ooo`030000o`3oool0oooo00l0
oooo0P3o000@0?ooo`80003o5`3oool50?l002T0oooo001Y0?ooo`T0003o
7`3oool40?l001D0oooo0P000?l?0?ooo`80o`00303oool20000o`X0oooo
0P3o000<0?ooo`030000o`3oool0oooo00T0oooo0P3o000;0?ooo`80003o
2P3oool20?l003P0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0:0?ooo`80o`004@3oool20000oa@0oooo
1@3o001H0?ooo`X0o`00503oool20000o`/0oooo0P3o00090?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0>`3oool00`000?l0oooo
0?ooo`0@0?ooo`80o`00403oool40000oaP0oooo3@3o000L0?ooo`00LP3o
ool60000oad0oooo103o000C0?ooo`80003o3`3oool20?l000`0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`80003o2`3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool03`3o
ool20000oa<0oooo0`3o000S0?ooo`H0003o9@3oool?0?l001/0oooo0`00
0?l<0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0l0?ooo`030000o`3oool0oooo0180oooo0P3o
000B0?ooo`D0003o803oool@0?l000`0oooo001h0?ooo`H0003o6`3oool4
0?l00140oooo0P000?l?0?ooo`80o`002`3oool20000o`X0oooo0P3o000<
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo03@0oooo00<0003o
0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00h0oooo0P000?lB0?ooo`<0o`00703oool:
0000oal0oooo303o000U0?ooo`D0003o3@3oool20?l000X0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0n0?ooo`030000o`3oool0
oooo01<0oooo00<0o`000?ooo`3oool0503oool50000ob/0oooo0`3o0009
0?ooo`00OP3oool60000oaT0oooo103o000?0?ooo`<0003o3P3oool20?l0
00/0oooo0P000?l:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool02@3oool20?l000/0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0c0?ooo`030000o`3oool0oooo0180oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02@3oool20?l000l0oooo0P000?lA0?oo
o`<0o`006@3oool60000oeD0oooo1@000?l@0?ooo`80o`002`3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo03l0oooo00<0003o0?oo
o`3oool0503oool30?l001P0oooo1`000?l`0?ooo`00Q03oool60000oaL0
oooo103o000>0?ooo`80003o3P3oool20?l000/0oooo0P000?l90?ooo`80
o`002`3oool20000o`/0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo0340oooo00<0003o0?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00d0oooo0P000?l@0?ooo`<0o`005P3oool60000oe40
oooo2P000?lC0?ooo`80o`002`3oool20000o``0oooo00<0o`000?ooo`3o
ool0@@3oool20000oaL0oooo1@3o000J0?oooa@0003o703oool005l0oooo
1P3o000U0?ooo`H0003o5@3oool20?l000h0oooo0P000?l>0?ooo`80o`00
2`3oool00`000?l0oooo0?ooo`080?ooo`80o`002`3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0`0?ooo`030000o`3oool0oooo0180oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0<0?ooo`80003o3`3oool30?l001D0oooo10000?m20?oooaD0003o
6P3oool30?l000`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`140?ooo`030000o`3oool0oooo01T0oooo0`3o000[0?oooa00003o
303oool006D0oooo203o000S0?ooo`D0003o4P3oool20?l000h0oooo0P00
0?l>0?ooo`80o`002P3oool20000o`X0oooo00<0o`000?ooo`3oool02@3o
ool20000o`X0oooo0P3o000:0?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02`3o
ool20000o`h0oooo0`3o000D0?ooo`@0003o>@3oool=0000obX0oooo1@3o
000>0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0AP3o
ool00`000?l0oooo0?ooo`0K0?ooo`@0o`00=`3oool30000o`T0oooo001]
0?ooo`P0o`00803oool30000oa40oooo0`3o000=0?ooo`80003o3P3oool2
0?l000X0oooo0P000?l90?ooo`80o`002`3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00P0oooo0P000?l:0?ooo`030?l0003oool0
oooo02h0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo0P000?l=
0?ooo`<0o`004`3oool40000oah0oooo1P3o001;0?ooo`D0o`004@3oool2
0000o`d0oooo00<0o`000?ooo`3oool0B03oool40000oad0oooo2`3o000h
0?ooo`00M@3oool80?l001/0oooo0`000?lA0?ooo`80o`003@3oool20000
o`h0oooo0P3o000:0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool02@3oool20000o`X0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo02d0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?oo
o`80o`002`3oool20000o`d0oooo0P3o000C0?ooo`<0003o6@3oool90?l0
04P0oooo2@3o000E0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0C@3oool20000obH0oooo3P3o000Z0?ooo`00O@3oool60?l001P0
oooo0`000?l@0?ooo`<0o`00303oool30000o`d0oooo0P3o00090?ooo`80
003o2@3oool20?l000/0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0:`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool20000o`d0
oooo0P3o000B0?ooo`<0003o5P3oool60?l003D0oooo703o000L0?ooo`80
003o3P3oool00`3o0000oooo0?ooo`1@0?ooo`80003o<P3ooolM0?l000d0
oooo001O0?ooo`@0003o803oool60?l001D0oooo0`000?l@0?ooo`80o`00
3@3oool20000o`d0oooo00<0o`000?ooo`3oool0203oool20000o`T0oooo
00<0o`000?ooo`3oool02@3oool20000o`T0oooo0P3o000:0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0:P3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`80o`00
4@3oool30000oa@0oooo1@3o000^0?ooo`d0o`00=@3oool30000o`l0oooo
00<0o`000?ooo`3oool0D`3oool80000odL0oooo103o00090?ooo`00H`3o
ool80000oah0oooo1P3o000B0?ooo`<0003o3`3oool20?l000d0oooo0P00
0?l<0?ooo`80o`002P3oool00`000?l0oooo0?ooo`070?ooo`80o`002`3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0Y0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo0P3o
000@0?ooo`<0003o4`3oool40?l00700oooo1@000?lA0?ooo`030?l0003o
ool0oooo05`0oooo1P000?m>0?ooo`00J`3oool80000oa`0oooo103o000A
0?ooo`<0003o3P3oool30?l000`0oooo0P000?l<0?ooo`80o`002@3oool2
0000o`T0oooo0P3o000:0?ooo`80003o2@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0:03oool0
0`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool0203oool20000o`/0oooo0P3o000?
0?ooo`<0003o4P3oool40?l006/0oooo2@000?lE0?ooo`030?l0003oool0
oooo06<0oooo50000?lj0?ooo`00L`3oool70000oaT0oooo0`3o000A0?oo
o`<0003o3P3oool20?l000`0oooo0P000?l<0?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo02L0oooo00<0003o0?oo
o`3oool0403oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool20?l0
00l0oooo0P000?lA0?ooo`@0o`007P3oool40000oc40oooo70000?lM0?oo
o`030?l0003oool0oooo07P0oooo90000?lF0?ooo`00NP3oool40000oaP0
oooo0`3o000A0?ooo`<0003o3@3oool20?l000`0oooo0P000?l;0?ooo`80
o`002@3oool20000o`T0oooo0P3o000:0?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0203oool20000o`T0oooo00<0o`000?ooo`3o
ool09P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00`0oooo0`000?l@0?ooo`<0
o`00703oool60000oad0oooo60000?lh0?ooo`030?l0003oool0oooo09d0
oooo3@000?l90?ooo`00OP3oool40000oaL0oooo0`3o000A0?ooo`80003o
3@3oool20?l000`0oooo0P000?l;0?ooo`030?l0003oool0oooo00P0oooo
0P000?l90?ooo`030?l0003oool0oooo00P0oooo0P000?l80?ooo`80o`00
2P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo02D0oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00L0oooo0P000?l:0?ooo`80o`00
3@3oool20000oa00oooo0`3o000H0?ooo`L0003oLP3oool00`3o0000oooo
0?ooo`2d0?ooo`00PP3oool50000oaD0oooo0`3o000@0?ooo`<0003o303o
ool30?l000/0oooo0P000?l:0?ooo`80o`002P3oool00`000?l0oooo0?oo
o`070?ooo`80o`002P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0T0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02`3oool20000o`l0oooo0`3o
000E0?ooo`H0003oN03oool00`3o0000oooo0?ooo`2e0?ooo`00Q`3oool6
0000oa80oooo0`3o000@0?ooo`80003o3@3oool20?l000/0oooo0P000?l:
0?ooo`80o`002@3oool20000o`T0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0R0?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo0P3o000<
0?ooo`80003o3P3oool30?l001<0oooo1@000?mm0?ooo`030?l0003oool0
oooo0;H0oooo002=0?ooo`@0003o4@3oool30?l000l0oooo0`000?l<0?oo
o`80o`002`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00P0oooo0P000?l80?ooo`80o`002@3oool20000o`P0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
0240oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo0P000?l:0?oo
o`030?l0003oool0oooo00X0oooo0P000?l>0?ooo`80o`004P3oool40000
ocD0ooooo@3o00090?ooo`00T@3oool40000oa00oooo0`3o000?0?ooo`<0
003o2`3oool20?l000X0oooo0P000?l:0?ooo`80o`002P3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`080?ooo`80o`002`3oool20000o`d0
oooo0`3o000@0?ooo`@0003oQP3oool00`3o0000oooo0?ooo`2f0?ooo`00
U@3oool30000oa00oooo0`3o000?0?ooo`80003o2`3oool20?l000X0oooo
0P000?l:0?ooo`030?l0003oool0oooo00P0oooo0P000?l80?ooo`80o`00
2@3oool20000o`L0oooo0P3o00090?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo
0P000?l<0?ooo`<0o`003`3oool40000oh/0oooo00<0o`000?ooo`3oool0
]@3oool009P0oooo10000?l?0?ooo`80o`003`3oool30000o`X0oooo0P3o
000:0?ooo`80003o2@3oool20?l000X0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo01h0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01`3oool20?l000X0oooo0P000?l<0?ooo`80o`003`3o
ool30000oi00oooo00<0o`000?ooo`3oool0]03oool009`0oooo10000?l=
0?ooo`<0o`003`3oool20000o`X0oooo0P3o000:0?ooo`030000o`3oool0
oooo00P0oooo0P3o00090?ooo`80003o203oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo01d0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`080?ooo`80003o303oool20?l000l0oooo0P000?m4
0?oooc00003o803oool00`3o0000oooo0?ooo`200?ooobX0003o2@3oool0
0:00oooo0`000?l=0?ooo`80o`003`3oool20000o`X0oooo0P3o00090?oo
o`80003o2P3oool00`3o0000oooo0?ooo`080?ooo`80003o1`3oool20?l0
00T0oooo0P000?l70?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`0:0?ooo`80o`003P3oool30000
ogH0oooo30000?lE0?ooo`030?l0003oool0oooo06/0oooo50000?lc0?oo
o`00X`3oool40000o`/0oooo0`3o000>0?ooo`80003o2P3oool20?l000T0
oooo0P000?l90?ooo`80o`002P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01@3oool20?l000P0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0K0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01`3oool20000o`/0oooo0P3o000=0?ooo`<0
003oQ@3oool60000oa00oooo00<0o`000?ooo`3oool0GP3oool<0000odL0
oooo002W0?ooo`<0003o2`3oool30?l000d0oooo0P000?l:0?ooo`80o`00
2@3oool20000o`T0oooo0P3o00090?ooo`80003o1`3oool20?l000T0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`80003o
203oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo0P3o00080?ooo`80003o
2`3oool20?l000d0oooo0P000?m<0?ooo`@0o`00?P3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo05T0oooo10000?mC0?ooo`00ZP3o
ool30000o`/0oooo0P3o000=0?ooo`80003o2P3oool20?l000T0oooo00<0
003o0?ooo`3oool0203oool20?l000T0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`80003o1`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0603o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool02@3o
ool20?l000d0oooo0P000?mB0?oooal0o`00803oool30000o`h0oooo00<0
o`000?ooo`3oool0E03oool40000obd0oooo8@3o00090?ooo`00[@3oool2
0000o`/0oooo0`3o000<0?ooo`80003o2P3oool20?l000P0oooo0P000?l:
0?ooo`030?l0003oool0oooo00L0oooo0P000?l70?ooo`80o`002@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool20000o`X0oooo0P3o000<0?ooo`<0003oL`3oool;
0?l001P0oooo0P000?l=0?ooo`030?l0003oool0oooo04l0oooo10000?lT
0?ooo`d0o`00:P3oool00:l0oooo0`000?l;0?ooo`80o`00303oool20000
o`X0oooo0P3o00080?ooo`80003o2@3oool20?l000T0oooo0P000?l70?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool20?l0
00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0F0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00X0oooo0P000?n10?ooo`T0o`004@3oool20000
o``0oooo00<0o`000?ooo`3oool0C03oool20000ob80oooo1P3o000g0?oo
o`00/P3oool30000o`X0oooo0`3o000;0?ooo`80003o2P3oool20?l000P0
oooo0P000?l90?ooo`80o`002@3oool00`000?l0oooo0?ooo`050?ooo`80
o`00203oool20000o`L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`80003o2P3oool20?l000X0oooo0`000?mE0?ooo`@0
003o<`3oool50?l000h0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`190?ooo`80003o6P3oool:0?l003d0oooo002e0?ooo`<0003o
2P3oool20?l000/0oooo0P000?l:0?ooo`030?l0003oool0oooo00L0oooo
0P000?l90?ooo`80o`00203oool20000o`L0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0D0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`80o`00
2P3oool20000oe`0oooo6@000?lO0?ooo`<0o`00303oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo04H0oooo0P000?lI0?ooo`<0o`00
:`3ooolC0000o`T0oooo002h0?ooo`80003o2P3oool20?l000/0oooo0P00
0?l90?ooo`80o`002@3oool20000o`T0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`050?ooo`80o`00203oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`070?ooo`80o`002P3oool20000ogL0oooo2P00
0?lH0?ooo`80o`002`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo04<0oooo0P000?lH0?ooo`<0o`008P3oool<0000oa`0oooo002j
0?ooo`<0003o2@3oool30?l000X0oooo0P000?l90?ooo`80o`002@3oool2
0000o`P0oooo0P3o00080?ooo`80003o1`3oool00`3o0000oooo0?ooo`06
0?ooo`80003o1P3oool20?l000L0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo0P3o00060?ooo`80003o203oool2
0?l000X0oooo0P000?n30?ooo`X0003o403oool20?l000X0oooo0P000?l;
0?ooo`030?l0003oool0oooo0440oooo00<0003o0?ooo`3oool05@3oool3
0?l001h0oooo1`000?lX0?ooo`00_@3oool30000o`T0oooo0P3o000:0?oo
o`80003o2@3oool20?l000T0oooo0P000?l80?ooo`80o`00203oool20000
o`H0oooo0P3o00080?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool20000o`L0oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool20?l0
00X0oooo0P000?mN0?ooo`/0o`009P3oool40000o`h0oooo0P3o000:0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0?`3oool00`00
0?l0oooo0?ooo`0D0?ooo`80o`00503oool=0000obl0oooo00300?ooo`80
003o2@3oool20?l000X0oooo0P000?l90?ooo`80o`002@3oool20000o`P0
oooo0P3o00080?ooo`80003o1P3oool20?l000L0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`80
003oJ`3oool90?l00240oooo10000?l<0?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0m0?ooo`03
0000o`3oool0oooo0180oooo0`3o000B0?ooo`@0003o803ooolC0?l000T0
oooo00320?ooo`80003o2@3oool20?l000X0oooo0P000?l90?ooo`80o`00
2@3oool20000o`P0oooo00<0o`000?ooo`3oool01`3oool20000o`H0oooo
00<0o`000?ooo`3oool01@3oool20000o`H0oooo0P3o00070?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo0P000?l70?ooo`80o`002@3oool20000ogH0oooo
4@3o000D0?ooo`80003o2`3oool20?l000T0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0l0?ooo`030000o`3oool0oooo0100oooo
0P3o000C0?ooo`80003o7@3oool70?l001`0oooo00340?ooo`<0003o203o
ool30?l000T0oooo0P000?l90?ooo`80o`002@3oool20000o`L0oooo0P3o
00090?ooo`030000o`3oool0oooo00@0oooo0P3o00070?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool20000ohT0oooo1@3o000A0?ooo`80003o2`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0>P3o
ool00`000?l0oooo0?ooo`0?0?ooo`80o`004@3oool40000oaD0oooo2P3o
000S0?ooo`00a`3oool20000o`T0oooo0P3o00090?ooo`80003o2@3oool2
0?l000T0oooo0P000?l70?ooo`80o`00203oool20000o`H0oooo00<0o`00
0?ooo`3oool01@3oool20000o`H0oooo0P3o00060?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01@3oool20?l000P0oooo0P000?mV
0?ooo`X0003o803oool40?l000l0oooo0P000?l:0?ooo`030?l0003oool0
oooo00L0oooo0P000?l:0?ooo`030?l0003oool0oooo03T0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0>0?ooo`<0003o5@3oool4
0?l002d0oooo00390?ooo`80003o2@3oool20?l000T0oooo0P000?l90?oo
o`80o`002@3oool20000o`L0oooo0P3o00080?ooo`80003o1@3oool20?l0
00L0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`80003o1P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo0P3o00050?oo
o`80003o1`3oool00`3o0000oooo0?ooo`060?ooo`80003oLP3oool90000
oa/0oooo103o000=0?ooo`80003o2@3oool20?l000T0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`0g0?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool03@3oool20000oa<0oooo1@3o000O0?oo
o`T0003o2@3oool00</0oooo0P000?l90?ooo`<0o`00203oool30000o`P0
oooo0P3o00090?ooo`80003o1`3oool20?l000P0oooo0P000?l50?ooo`03
0?l0003oool0oooo00D0oooo0P000?l60?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`80
o`001`3oool20000ogd0oooo30000?lC0?ooo`@0o`002`3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0e0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0>0?ooo`D0
o`005@3oool?0000oa80oooo003=0?ooo`<0003o2@3oool20?l000T0oooo
0P000?l80?ooo`80o`002@3oool20000o`L0oooo0P3o00080?ooo`80003o
103oool20?l000L0oooo00<0003o0?ooo`3oool0103oool20?l000H0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo0P000?n;0?ooo`T0003o3P3oool20?l000X0oooo
0P000?l90?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`0d0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool02`3oool20000o`h0oooo0`3o000F0?ooo`@0003o
8@3oool00=00oooo0P000?l90?ooo`<0o`00203oool20000o`P0oooo0`3o
00080?ooo`80003o1`3oool20?l000P0oooo00<0003o0?ooo`3oool00`3o
ool20?l000H0oooo0P000?l60?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool20000o`L0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`1/0?ooo`T0o`007`3oool40000o``0oooo0`3o
00090?ooo`030000o`3oool0oooo00L0oooo0P3o00080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0<P3oool00`000?l0oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool20?l00180oooo1`000?lU0?ooo`00dP3oool20000o`X0oooo0P3o0008
0?ooo`80003o2@3oool20?l000P0oooo0P000?l70?ooo`80o`001`3oool2
0000o`D0oooo0P3o00060?ooo`80003o1@3oool20?l000D0oooo0P000?l5
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool20?l000D0oooo00<0003o
0?ooo`3oool01@3oool20?l000H0oooo0P000?mh0?ooo`T0o`006P3oool2
0000o`d0oooo0P3o00080?ooo`80003o2@3oool00`3o0000oooo0?ooo`06
0?ooo`80003o2@3oool00`3o0000oooo0?ooo`0a0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;
0?ooo`80o`003P3oool60000oad0oooo1P3o00090?ooo`00e03oool30000
o`T0oooo0P3o00080?ooo`80003o2@3oool20?l000P0oooo0P000?l70?oo
o`80o`001`3oool20000o`D0oooo0P3o00060?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool20000
oh<0oooo2`3o000A0?ooo`<0003o303oool20?l000P0oooo00<0003o0?oo
o`3oool01`3oool20?l000P0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`0`0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`80o`00303oool40000
oaX0oooo2@3o000?0?ooo`00e`3oool20000o`T0oooo0`3o00070?ooo`<0
003o203oool30?l000L0oooo0P000?l70?ooo`80o`001`3oool20000o`D0
oooo0P3o00050?ooo`80003o1@3oool20?l000D0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`020?ooo`80003o1@3oool00`3o0000oooo0?ooo`030?ooo`80
003o1P3oool20?l000H0oooo00<0003o0?ooo`3oool0SP3oool40?l00100
oooo0`000?l;0?ooo`80o`001`3oool20000o`T0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo02h0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00T0oooo0P3o000<0?ooo`80003o5P3oool80?l001P0
oooo003I0?ooo`<0003o2@3oool20?l000P0oooo0P000?l90?ooo`80o`00
1`3oool20000o`L0oooo0P3o00070?ooo`030000o`3oool0oooo00@0oooo
0P3o00050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`020?ooo`80o`00103oool00`000?l0oooo0?ooo`030?ooo`80o`00
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
0P000?md0?ooo`P0003o6@3oool50?l000h0oooo0P000?l;0?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
;@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`80003o
4@3oool70?l00200oooo003L0?ooo`80003o2@3oool30?l000L0oooo0`00
0?l80?ooo`<0o`001P3oool30000o`H0oooo0P3o00060?ooo`80003o1P3o
ool20?l000@0oooo0P000?l50?ooo`80o`00103oool20000o`@0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo0P00
0?l60?ooo`80o`001P3oool00`000?l0oooo0?ooo`1l0?ooo`P0003o5P3o
ool40?l000`0oooo0`000?l90?ooo`80o`001`3oool20000o`P0oooo0P3o
00070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0;03o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0203oool20?l000/0oooo0P000?l>0?ooo`D0o`005P3o
ool80000o`T0oooo003N0?ooo`80003o2P3oool20?l000P0oooo0P000?l9
0?ooo`80o`001`3oool20000o`H0oooo0P3o00060?ooo`80003o1P3oool2
0?l000@0oooo0P000?l50?ooo`80o`00103oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool2
0000ohL0oooo2@000?lA0?ooo`@0o`002`3oool20000o`T0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0[
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo0P000?l<
0?ooo`@0o`004`3oool80000oa40oooo003P0?ooo`<0003o2@3oool30?l0
00L0oooo0`000?l80?ooo`80o`001`3oool20000o`H0oooo0P3o00060?oo
o`80003o1P3oool20?l000@0oooo0P000?l50?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo0P3o00050?ooo`030000o`3oool0oooo00@0oooo0P3o00050?oo
o`80003oTP3oool70000o`h0oooo103o00090?ooo`80003o203oool20?l0
00L0oooo0P000?l80?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo0P000?l<0?ooo`80o`00403oool70000
oaT0oooo003S0?ooo`80003o2P3oool20?l000P0oooo0P000?l80?ooo`<0
o`001P3oool30000o`D0oooo0`3o00050?ooo`80003o1P3oool20?l000@0
oooo0P000?l40?ooo`80o`000`3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool20000o`<0oooo0P3o00040?ooo`80003o103oool00`3o0000
oooo0?ooo`030?ooo`80003o1P3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo07T0oooo1`3o000I0?ooo`@0003o3P3oool20?l000T0
oooo0P000?l80?ooo`80o`001`3oool00`000?l0oooo0?ooo`060?ooo`80
o`001P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo02P0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool20000o`/0
oooo0`3o000>0?ooo`@0003o803oool00>D0oooo0`000?l90?ooo`80o`00
203oool30000o`P0oooo0P3o00070?ooo`80003o1P3oool20?l000D0oooo
0P000?l60?ooo`<0o`000`3oool20000o`@0oooo0P3o00020?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo
0?ooo`3oool0o`0000D0oooo0P000?l30?ooo`80o`00103oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool20?l000D0oooo00<0003o0?ooo`3oool0103oool20?l000D0
oooo0P000?n30?ooo`P0o`005@3oool40000o``0oooo0P3o00090?ooo`80
003o203oool00`3o0000oooo0?ooo`050?ooo`80003o203oool00`3o0000
oooo0?ooo`040?ooo`80003o203oool00`3o0000oooo0?ooo`0W0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool02@3oool20?l000`0oooo1@000?lG0?ooo`@0o`002@3oool00>P0oooo
0P000?l90?ooo`<0o`00203oool20000o`P0oooo0P3o00070?ooo`<0003o
1@3oool20?l000D0oooo0P000?l70?ooo`80o`000`3oool20000o`@0oooo
0P3o00000`3oool0003o0?ooo`030?ooo`030?l0003oool0oooo0080oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool20000o`@0oooo00<0o`000?ooo`3o
ool00P3oool20000o`@0oooo00<0o`000?ooo`3oool00`3oool20000o`D0
oooo0P3o00060?ooo`030000o`3oool0oooo08/0oooo2@3o000@0?ooo`@0
003o2P3oool20?l000T0oooo00<0003o0?ooo`3oool01P3oool20?l000L0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool09P3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`060?ooo`80003o2P3oool20?l000X0
oooo10000?lD0?ooo`P0o`003@3oool00>X0oooo0`000?l90?ooo`80o`00
203oool30000o`L0oooo0P3o00080?ooo`80003o1@3oool30?l000@0oooo
0P000?l70?ooo`80o`000`3oool20000o`@0oooo0P3o00020000o`<0oooo
00D0o`000?ooo`3oool0oooo0000o`020?ooo`030?l0003oool0oooo0080
oooo00@0003o0?ooo`3oool0oooo0P3o00040?ooo`030000o`3oool0oooo
0080oooo0P3o00040?ooo`030000o`3oool0oooo0080oooo0P3o00050?oo
o`030000o`3oool0oooo00<0oooo0P3o00060?ooo`80003oU`3oool60?l0
00h0oooo10000?l80?ooo`80o`00203oool20000o`P0oooo00<0o`000?oo
o`3oool01@3oool20000o`L0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo02@0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?oo
o`80o`002@3oool30000oa40oooo1`3o000E0?ooo`00k@3oool30000o`P0
oooo0`3o00080?ooo`80003o1`3oool30?l000L0oooo0P000?l60?ooo`<0
o`000`3oool30000o`H0oooo0`3o00020?ooo`<0003o0`3oool20?l00080
003o0P3oool01@3o0000oooo0000o`000?l0oooo0080o`000`3oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo0P000?l30?ooo`80o`00103oool2
0000o`@0oooo00<0o`000?ooo`3oool00`3oool20000o`@0oooo0P3o0006
0?ooo`80003oP@3oool60000oaP0oooo103o000>0?ooo`80003o203oool2
0?l000P0oooo0P000?l70?ooo`80o`001`3oool00`000?l0oooo0?ooo`05
0?ooo`80o`001P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo02<0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`070?ooo`80o`002@3oool20000oa00oooo103o000L
0?ooo`00l03oool30000o`P0oooo0P3o00080?ooo`<0003o1`3oool20?l0
00L0oooo0`000?l60?ooo`<0o`000`3oool40000o`D0oooo103o00000`3o
ool0003o0000o`030?ooo`80o`000`000?l00`3o0000003o0?l000020?l0
0080oooo0P000?l20?ooo`80o`000`3oool20000o`<0oooo0P3o00050?oo
o`030000o`3oool0oooo0080oooo0P3o00040?ooo`80003o103oool20?l0
00L0oooo00<0003o0?ooo`3oool0Q`3oool80000oa@0oooo1@3o000;0?oo
o`<0003o1`3oool20?l000P0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
0280oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`80o`002@3oool20000o`h0oooo103o000C0?oo
o`@0003o2@3oool00?<0oooo0P000?l80?ooo`80o`002@3oool20000o`L0
oooo0`3o00070?ooo`<0003o1P3oool30?l000@0oooo10000?l50?ooo`<0
o`001@000?l60?l000@0003o0P3oool20?l00080oooo0`000?l40?ooo`03
0?l0003oool0oooo00<0oooo0P000?l30?ooo`80o`00103oool20000o`D0
oooo00<0o`000?ooo`3oool01@3oool20000oi80oooo20000?lA0?ooo`@0
o`002P3oool20000o`L0oooo0P3o00070?ooo`80003o1`3oool20?l000H0
oooo0P000?l70?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`80003o303oool40?l000l0oooo20000?l=0?ooo`00
m@3oool30000o`L0oooo0`3o00080?ooo`<0003o1`3oool20?l000P0oooo
0`000?l60?ooo`@0o`00103oool40000o`@0oooo1@3o00000`3oool0003o
0000o`030000o`030?ooo`3o0000o`0000<0o`000P3oool20000o`D0oooo
0P3o00030?ooo`<0003o0`3oool20?l000@0oooo0P000?l50?ooo`80o`00
1P3oool20000oi`0oooo1P000?l?0?ooo`@0o`00203oool20000o`L0oooo
0P3o00070?ooo`80003o1`3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo0P3o00050?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool0803oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo0P3o00080?ooo`80003o
2P3oool40?l000`0oooo1`000?lE0?ooo`00n03oool30000o`L0oooo103o
00070?ooo`<0003o1P3oool40?l000L0oooo0`000?l70?ooo`<0o`001@3o
ool30000o`D0oooo203o00020?ooo`D0003o103oool30?l000<0oooo0P00
0?l30?ooo`<0o`000`3oool30000o`D0oooo0P3o00060?ooo`80003oR03o
ool50?l001L0oooo10000?l?0?ooo`80o`00203oool20000o`L0oooo0P3o
00070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool20000o`L0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo01l0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo0P000?l:0?ooo`80o`00303oool40000oa`0oooo003k
0?ooo`<0003o203oool40?l000H0oooo10000?l60?ooo`D0o`001@3oool4
0000o`H0oooo0`3o00050?ooo`l0003o1@3oool40?l00080oooo10000?l3
0?ooo`80o`00103oool20000o`H0oooo0P3o00060?ooo`80003oS`3oool8
0?l001<0oooo10000?l=0?ooo`80o`00203oool20000o`L0oooo0P3o0006
0?ooo`80003o1P3oool20?l000L0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool07@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool2
0000o`T0oooo0`3o000:0?ooo`@0003o4`3oool40?l000T0oooo003n0?oo
o`<0003o2@3oool30?l000L0oooo0`000?l80?ooo`@0o`001@3oool40000
o`D0oooo2P3o00060?ooo`T0o`000P3oool40000o`@0oooo0`3o00030?oo
o`<0003o1P3oool20?l000D0oooo0`000?nI0?ooo`P0o`003`3oool40000
o`/0oooo0`3o00070?ooo`80003o1`3oool20?l000H0oooo0P000?l60?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`030?ooo`80003o1`3oool00`3o0000oooo0?ooo`0L0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool20?l000H0oooo0P000?l90?ooo`80o`002@3oool40000
o`l0oooo203o000=0?ooo`00o`3oool20?ooo`@0003o203oool30?l000L0
oooo0`000?l90?ooo`@0o`001@3oool40000o`X0oooo1`3o00070?ooo`@0
003o1P3oool20?l000@0oooo0P000?l60?ooo`<0o`001@3oool20000ohl0
oooo10000?lA0?ooo`H0o`003@3oool40000o`X0oooo0P3o00070?ooo`80
003o1`3oool20?l000H0oooo00<0003o0?ooo`3oool0103oool20?l000H0
oooo0P000?l60?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo0P3o00070?ooo`@0
003o3P3oool50?l001D0oooo003o0?ooo`H0oooo10000?l70?ooo`<0o`00
1`3oool40000o`T0oooo1@3o00040?oooaP0003o1`3oool30?l000<0oooo
0`000?l60?ooo`80o`001@3oool30000oiD0oooo20000?l?0?ooo`@0o`00
3@3oool40000o`P0oooo0P3o00070?ooo`80003o1`3oool20?l000D0oooo
0P000?l60?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool20?l000D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`0J0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo0P3o00070?ooo`80003o3P3oool40?l001X0oooo
003o0?ooo`X0oooo0`000?l70?ooo`@0o`001`3oool40000o`X0oooo103o
000H0?ooo`L0o`00103oool20000o`H0oooo0`3o00050?ooo`80003oX03o
ool60000o`d0oooo103o000=0?ooo`@0003o1P3oool20?l000L0oooo0P00
0?l70?ooo`030?l0003oool0oooo00@0oooo0P000?l50?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0603o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool20000o`L0oooo0P3o
00070?ooo`80003o303oool40?l00140oooo10000?l90?ooo`00o`3oool=
0?ooo`<0003o203oool50?l000H0oooo10000?l:0?oooaP0o`001`3oool4
0000o`H0oooo0P3o00050?ooo`<0003oZ03oool40000o`d0oooo103o000=
0?ooo`80003o1P3oool30?l000H0oooo0P000?l60?ooo`80o`001P3oool0
0`000?l0oooo0?ooo`030?ooo`80o`001P3oool20000o`H0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo01L0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`80003o303oool2
0?l000l0oooo1P000?l=0?ooo`00o`3oool@0?ooo`<0003o2P3oool50?l0
00D0oooo2@000?lL0?ooo`@0003o1P3oool40?l000@0oooo0`000?n_0?oo
o`H0003o2`3oool40?l000/0oooo0P000?l70?ooo`80o`001P3oool20000
o`H0oooo00<0o`000?ooo`3oool0103oool20000o`D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00<0oooo0P000?l60?ooo`030?l0003oool0oooo01H0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool20?l0
00H0oooo0P000?l;0?ooo`<0o`003@3oool40000oa<0oooo003o0?oooa<0
oooo10000?l;0?ooo`@0o`002P3ooolL0000o`H0oooo103o00050?ooo`<0
003o^03oool60000o`T0oooo103o00090?ooo`80003o1`3oool20?l000H0
oooo0P000?l50?ooo`80o`001P3oool20000o`@0oooo0P3o00060?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo00<0oooo0P000?l70?ooo`030?l0003oool0oooo00@0
oooo0P000?l:0?ooo`<0o`00303oool40000oaL0oooo003o0?oooaL0oooo
1P000?l90?ooo`D0o`008P3oool50?l000H0oooo0`000?o10?ooo`<0003o
2P3oool40?l000L0oooo0P000?l70?ooo`80o`001P3oool20000o`D0oooo
0P3o00060?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool20000o`D0oooo0P3o00050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`050?ooo`80o`001@3oool20000o`T0oooo
0`3o000;0?ooo`@0003o6`3oool00?l0oooo7@3oool50000o`T0oooo2P3o
000?0?ooo`T0o`00203oool30000olL0oooo0`000?l;0?ooo`80o`001`3o
ool20000o`L0oooo0P3o00060?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool20000o`@0oooo0P3o00060?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool0103oool20?l000H0oooo00<0
003o0?ooo`3oool01P3oool30?l000X0oooo10000?lO0?ooo`00dP3oool0
0`00o`00oooo0?ooo`1<0?ooo`@0003o3`3oool?0?l000d0oooo10000?o=
0?ooo`@0003o2@3oool30?l000H0oooo0P000?l70?ooo`80o`001@3oool2
0000o`D0oooo0P3o00060?ooo`80003o103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0180oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`80003o1`3oool20?l000T0oooo10000?lS
0?ooo`00dP3oool00`00o`00oooo0?ooo`1@0?ooo`P0003o6P3oool90000
omD0oooo0`000?l90?ooo`80o`001P3oool20000o`L0oooo0P3o00050?oo
o`80003o1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
0080oooo0P3o00050?ooo`80003o1@3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool20?l0
00L0oooo10000?lW0?ooo`00dP3oool00`00o`00oooo0?ooo`1H0?oooaX0
003oh@3oool30000o`P0oooo0`3o00050?ooo`80003o1`3oool20?l000D0
oooo0P000?l40?ooo`80o`001P3oool20000o`@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`80o`00103oool20000o`D0
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`030?ooo`80o`001@3oool20000o`H0
oooo0P3o00070?ooo`80003o:`3oool00=80oooo00<00?l00?ooo`3oool0
o`3ooomG0?ooo`80003o2@3oool20?l000D0oooo0P000?l70?ooo`80o`00
1@3oool00`000?l0oooo0?ooo`030?ooo`80o`001P3oool00`000?l0oooo
0?ooo`020?ooo`80o`001@3oool20000o`D0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`80003o1P3oool20?l000H0oooo
0`000?l]0?ooo`00dP3oool00`00o`00oooo0?ooo`3o0?oooeT0oooo0P00
0?l90?ooo`<0o`00103oool20000o`L0oooo0P3o00040?ooo`80003o1@3o
ool20?l000D0oooo0P000?l40?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`80003o<03oool00=80oooo00<00?l00?ooo`3oool0o`3ooomK
0?ooo`<0003o2@3oool20?l000@0oooo0P000?l70?ooo`80o`00103oool2
0000o`D0oooo00<0o`000?ooo`3oool0103oool20000o`<0oooo0P3o0005
0?ooo`80003o103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo0P00
0?l60?ooo`80o`001@3oool20000oc80oooo003B0?ooo`03003o003oool0
oooo0?l0ooooGP3oool20000o`T0oooo0P3o00040?ooo`80003o1`3oool2
0?l000@0oooo0P000?l40?ooo`80o`001P3oool00`000?l0oooo0?ooo`02
0?ooo`80o`001@3oool20000o`<0oooo0P3o00040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00001@3o
ool010000?l0oooo0?ooo`3oool20?l000@0oooo00<0003o0?ooo`3oool0
103oool20?l000D0oooo0P000?ld0?ooo`00dP3oool00`00o`00oooo0?oo
o`3o0?ooof00oooo0P000?l90?ooo`80o`00103oool20000o`L0oooo0P3o
00040?ooo`80003o103oool20?l000D0oooo0P000?l40?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`3o00001@3oool01@000?l0oooo0?ooo`3oool0o`0000D0
oooo00<0003o0?ooo`3oool00`3oool20?l000D0oooo0P000?lf0?ooo`00
dP3oool00`00o`00oooo0?ooo`3o0?ooof80oooo0`000?l80?ooo`80o`00
103oool30000o`H0oooo0P3o00040?ooo`80003o103oool20?l000D0oooo
0P000?l30?ooo`80o`001@3oool20000o`<0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`03
0?l0003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`80003o1@3oool00`3o0000oooo0?ooo`030?ooo`80003o>03oool00=80
oooo00<00?l00?ooo`3oool0o`3ooomU0?ooo`80003o203oool20?l000D0
oooo0P000?l60?ooo`80o`00103oool20000o`@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`020?ooo`80o`001@3oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo0P000?l40?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`03
0?ooo`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`030000o`3oool0oooo00<0oooo0P3o00040?ooo`80003o>P3o
ool00=80oooo00<00?l00?ooo`3oool0o`3ooomW0?ooo`<0003o1`3oool2
0?l000D0oooo0P000?l60?ooo`80o`00103oool20000o`<0oooo0P3o0005
0?ooo`80003o103oool20?l000@0oooo0P000?l20?ooo`80o`00103oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00P3o00040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0j0?ooo`00dP3oool00`00o`00oooo0?ooo`3o0?ooofX0oooo0`000?l6
0?ooo`<0o`00103oool30000o`D0oooo0P3o00040?ooo`80003o0`3oool2
0?l000D0oooo0P000?l40?ooo`030?l0003oool0oooo00<0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool010000?l0oooo0?ooo`3o00040?oo
o`80003o103oool20?l000D0oooo00<0003o0?ooo`3oool0>`3oool00=80
oooo00<00?l00?ooo`3oool0o`3ooom]0?ooo`80003o1`3oool20?l000D0
oooo0P000?l50?ooo`80o`00103oool20000o`<0oooo0P3o00050?ooo`80
003o0`3oool20?l000@0oooo0P000?l20?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o
0000oooo0?ooo`020?ooo`040000o`3oool0oooo0?l000@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`80003o?P3oool0
0=80oooo00<00?l00?ooo`3oool0o`3ooom_0?ooo`<0003o1P3oool20?l0
00D0oooo0P000?l50?ooo`80o`00103oool20000o`<0oooo0P3o00050?oo
o`030000o`3oool0oooo0080oooo0P3o00040?ooo`030000o`3oool0oooo
0080o`000`3oool20000o`<0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00D0003o0?oo
o`3oool0oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool010000?l0oooo0?ooo`3o00040?ooo`030000o`3oool0oooo0080oooo
0P3o00050?ooo`030000o`3oool0oooo03h0oooo003B0?ooo`03003o003o
ool0oooo0?l0ooooLP3oool30000o`D0oooo0`3o00040?ooo`<0003o103o
ool20?l000@0oooo0P000?l30?ooo`80o`00103oool20000o`@0oooo0P3o
00030?ooo`80003o0P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`3o00001`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool010000?l0oooo0?ooo`3o0003
0?ooo`80003o103oool00`3o0000oooo0?ooo`030?ooo`80003o@@3oool0
0=80oooo00<00?l00?ooo`3oool0o`3ooome0?ooo`80003o1P3oool20?l0
00D0oooo0P000?l40?ooo`80o`00103oool20000o`<0oooo0`3o00030?oo
o`80003o103oool20?l000<0oooo00<0003o0?ooo`3oool00P3o00030?oo
o`050000o`3oool0oooo0?ooo`3o00001P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool20000o`030?oo
o`3o0000o`0000<0oooo00<0003o0?ooo`3oool00P3oool20?l000@0oooo
0P000?m30?ooo`00dP3oool00`00o`00oooo0?ooo`3o0?ooogL0oooo0P00
0?l60?ooo`80o`001@3oool20000o`@0oooo0P3o00040?ooo`<0003o0`3o
ool20?l000<0oooo0P000?l40?ooo`80o`000P3oool20000o`80oooo0P3o
00020?ooo`80003o0P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`050?l0
003oool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0003o
0080oooo00@0o`000?ooo`3oool0oooo0P000?l40?ooo`030?l0003oool0
oooo0080oooo0P000?m50?ooo`00dP3oool00`00o`00oooo0?ooo`3o0?oo
ogT0oooo0`000?l50?ooo`<0o`00103oool20000o`@0oooo0P3o00050?oo
o`80003o0`3oool20?l000<0oooo0P000?l40?ooo`040?l0003oool0oooo
0?ooo`80003o0P3oool20?l00080oooo00@0003o0?ooo`3oool0o`00103o
ool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0
oooo0?l000030?ooo`030000o`3oool0oooo0080o`000`3oool010000?l0
oooo0?ooo`3o00030?ooo`030000o`3oool0oooo0080oooo0P3o00040?oo
o`030000o`3oool0oooo04D0oooo003B0?ooo`03003o003oool0oooo0?l0
ooooO03oool20000o`H0oooo0P3o00040?ooo`80003o103oool30?l000@0
oooo0P000?l30?ooo`80o`000`3oool30000o`80oooo0P3o00030?ooo`80
003o0P3oool20?l000050?ooo`000?l0oooo0?ooo`3o00000`3oool01@00
0?l0oooo0?ooo`3oool0o`000080oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`040000o`3oool0oooo0?l000<0oooo0P000?l20?ooo`050?l0
003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`80
003oB03oool00=80oooo00<00?l00?ooo`3oool0o`3ooomn0?ooo`80003o
1P3oool30?l000<0oooo0P000?l50?ooo`@0o`000P3oool30000o`80oooo
0P3o00040?ooo`80003o0P3oool20?l000<0oooo0P000?l20?ooo`80o`00
00@0003o0?ooo`3oool0o`000P3oool010000?l0oooo0?ooo`3o00020?oo
o`050000o`3oool0oooo0?ooo`3o00000P3oool20000o`80oooo00D0o`00
0?ooo`3oool0oooo0000o`020?ooo`80o`000P3oool20000o`<0oooo0P3o
00030?ooo`80003oBP3oool00=80oooo00<00?l00?ooo`3oool0o`3ooon0
0?ooo`<0003o1P3oool30?l00080oooo0`000?l60?ooo`80o`000`3oool2
0000o`80oooo0`3o00030?ooo`<0003o00<0oooo0?l0003o00000`3oool2
0000o`80oooo00T0o`000000o`000?l0oooo0?l0003oool0003o0?ooo`3o
00000P3oool01P000?l0oooo0?ooo`3oool0o`000?ooo`80003o0P3oool2
0?l00080oooo0P000?l00`3oool0o`000?l000030?ooo`040000o`3oool0
oooo0?ooo`80o`000`3oool20000od`0oooo003B0?ooo`03003o003oool0
oooo0?l0ooooP`3oool30000o`H0oooo0P3o00030?ooo`@0003o103oool2
0?l000<0oooo0`000?l20?ooo`<0o`000`3oool20000o`030?ooo`3o0000
o`000080o`0000@0oooo0000o`000?l0003o103o000010000?l0o`000?l0
003o00020000o`060?ooo`3o0000o`000?l0003oool0003o0P3oool20?l0
0080oooo0P000?l00`3oool0o`000?l000030?ooo`80003o0P3oool20?l0
00<0oooo0P000?m>0?ooo`00dP3oool00`00o`00oooo0?ooo`3o0?ooohH0
oooo10000?l40?ooo`<0o`00103oool30000o`<0oooo0P3o00040?ooo`<0
003o0P3oool40?l000030?ooo`000?l0003o00<0003o103o00000`3oool0
003o0000o`030?l00080003o0`3o00001@3oool0003o0000o`000?l0oooo
0080o`000P3oool20000o`030?ooo`3o0000o`0000<0oooo0P000?l30?oo
o`040?l0003oool0oooo0?ooo`80003oD03oool00=80oooo00<00?l00?oo
o`3oool0o`3ooon:0?ooo`<0003o103oool40?l000<0oooo10000?l0103o
ool0o`000?l0003o00040?ooo`@0003o0P3oool30?l000<0oooo10000?l8
0?l000@0003o0P3oool20?l00080oooo0P000?l00`3oool0o`000?l00002
0?ooo`<0003o0`3oool20?l00080oooo0P000?mB0?ooo`00dP3oool00`00
o`00oooo0?ooo`3o0?ooohd0oooo0`000?l50?ooo`<0o`00103oool30000
o`040?ooo`3o0000o`000?l000D0oooo10000?l00`3oool0o`000?l00004
0?l000030?ooo`000?l0003o00D0003o00<0oooo0?l0003o0000103o0004
0000o`<0o`000P3oool20000o`@0oooo0P3o00020?ooo`80003oE03oool0
0=80oooo00<00?l00?ooo`3oool0o`3ooon@0?ooo`80003o1P3oool30?l0
00@0oooo0`000?l00`3oool0o`000?l000020?l000D0oooo1P000?l00`3o
ool0o`000?l000070?l000030?ooo`000?l0003o0080003o0P3oool30?l0
00<0oooo0P000?l30?ooo`<0o`000P3oool20000oeH0oooo003B0?ooo`03
003o003oool0oooo0?l0ooooTP3oool20000o`L0oooo0`3o00040?ooo`@0
003o00<0oooo0?l0003o00001P3o00030?ooo`/0003o0`3oool30?l000<0
oooo0`000?l00`3oool0o`000?l000020?l000<0oooo0P000?mH0?ooo`00
dP3oool00`00o`00oooo0?ooo`3o0?oooi@0oooo1@000?l50?ooo`@0o`00
103oool50000o`@0oooo4@3o00030?ooo`<0003o00@0oooo0?l0003o0000
o`00103oool30000oeX0oooo003B0?ooo`03003o003oool0oooo0?l0oooo
V@3oool50000o`@0oooo103o00050?ooo`T0003o1@3oool:0000o`040?oo
o`3o0000o`000?l000<0oooo10000?mM0?ooo`00b03oool5000000D0oooo
00<00?l00?ooo`3oool0o`3ooonN0?ooo`<0003o1@3oool70?l000H0oooo
1P000?l50?ooo`H0o`000`3oool30000of40oooo003:0?ooo`030000003o
ool0oooo00D0oooo00<00?l00?ooo`3oool0o`3ooonQ0?ooo`@0003o203o
oolA0?l000H0oooo0`000?mT0?ooo`00bP3oool00`000000oooo0?ooo`05
0?ooo`04003o00000000000000000?l0ooooY03oool;0000o`X0oooo2P00
0?mW0?ooo`00bP3oool00`000000oooo0?ooo`3o0?oookP0oooo2P000?ma
0?ooo`00bP3oool00`000000oooo0?ooo`3o0?ooool0oooo=03oool00<T0
oooo0P00003o0?ooool0oooo=P3oool00?l0ooooo`3ooooo0?ooo`80oooo
0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{767, 178},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.90",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/fluidflowimage/\
FluidFlowImageFigures/mat1190.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  (a) Flow around one inclined segment in the upper half-plane.\n\t\t\t\t\t\
(b) Flow around two inclined segments forming a \"V\" in the plane."
}], "Text"],

Cell[TextData[{
  "Solution.  Set  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-\(\(1 - \[Alpha]\)\/\[Alpha]\)\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_3 = 1\)}]]],
  ".  In the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  "-plane ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          
          "StrikeThrough"->
            False}], \(w\_2 = \[ExponentialE]\^\(\[ImaginaryI]\ \[Alpha]\ \
\[Pi]\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_3 = 0\)}]]],
  ", and the exterior angles are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", "\[Alpha]\[Pi]"}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(-\[Pi]\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "3"], "=", \(\((1 - \[Alpha])\)\ \[Pi]\)}]}]]],
  ",  and the formula for the derivative ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " is  \n\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\ \((z - x\_3)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \((z - \((\(-\(\(1 \
- \[Alpha]\)\/\[Alpha]\)\))\))\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\ \
\(\((z)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\) \((z - 1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\
\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z + \(1 - \
\[Alpha]\)\/\[Alpha])\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \
\(\((z)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\) \((z - 1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\
\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \((z + \(1 - \
\[Alpha]\)\/\[Alpha])\)\^\(\(-\((\[Alpha]\ \[Pi])\)\)/\[Pi]\)\ \
\(\((z)\)\^\(\(-\((\(-\[Pi]\))\)\)/\[Pi]\)\) \((z - 1)\)\^\(\(-\((\((1 - \
\[Alpha])\)\ \[Pi])\)\)/\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \((z + \(1 - \
\[Alpha]\)\/\[Alpha])\)\^\(-\[Alpha]\)\ \((z)\) \((z - 1)\)\^\(\[Alpha] - 1\)\
\)\)\)}]]
}], "Text"],

Cell[TextData[{
  "Integrate and get  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\ \  = \ \ B\ \  + \ \ A\ \(\[Integral]\((z + \(1 - \
\[Alpha]\)\/\[Alpha])\)\^\(-\[Alpha]\)\ \((z)\) \(\((z - 1)\)\^\(\[Alpha] - 
                      1\)\) \[DifferentialD]z\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(B + 
          A\ \((\(-1\) + z)\)\^\[Alpha]\ \((z + \(1 - \[Alpha]\)\/\[Alpha])\)\
\^\(-\[Alpha]\)\ \((z - \(\(-1\) + \[Alpha]\)\/\[Alpha])\)\)\)\)}]],
  " \n\nSolve for the coefficients A and B and obtain \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \(\((z - 
                  1)\)\^\[Alpha]\) \((1 + \(\[Alpha]\ z\)\/\((1 - \
\[Alpha])\))\)\^\(1 - \[Alpha]\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(Print[\*"\"\<B + A \[Integral]\!\(\((z + \(1 - \
\[Alpha]\)\/\[Alpha])\)\^\(-\[Alpha]\)\)(z)\!\(\((\(-1\) + z)\)\^\(\[Alpha] - \
1\)\)\[DifferentialD]z = \>\"", 
      B\ \  + \ \ A\ \(\[Integral]\(\((z + \(1 - \[Alpha]\)\/\[Alpha])\)\^\(-\
\[Alpha]\)\) \((z)\) \(\((\(-1\) + z)\)\^\(\[Alpha] - 
                    1\)\) \[DifferentialD]z\)]\)], "Input"],

Cell[BoxData[{
    \(\(\[Alpha]\  = \ 1\/4;\)\), "\[IndentingNewLine]", 
    \(\(f[
          z_]\  = \ \(\((\[Alpha]\/\(1 - \[Alpha]\))\)\^\(1 - \[Alpha]\)\) \(\
\[Integral]\(\((z + \(1 - \[Alpha]\)\/\[Alpha])\)\^\(-\[Alpha]\)\) \((z)\) \(\
\((\(-1\) + z)\)\^\(\[Alpha] - 
                    1\)\) \[DifferentialD]z\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = \>", f[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<f[-\!\(\(1 - \[Alpha]\)\/\[Alpha]\)] = \>\"", 
        f[\(-\(\(1 - \[Alpha]\)\/\[Alpha]\)\)]\ ];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\< f[0] = \>", f[0]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< f[1] = \>", 
        Simplify[f[1]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(\[Alpha]\  = \ 1\/4;\)\), "\[IndentingNewLine]", 
    \(\(f[
          z_] = \(\((z - 
                  1)\)\^\[Alpha]\) \((1 + \(\[Alpha]\ z\)\/\((1 - \
\[Alpha])\))\)\^\(1 - \[Alpha]\)\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.075  k]]}, {k, 1, 11, 
            2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {x, \(-4.75\), 4}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] 
            Identity];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(eqns3\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.075  k]]}, {k, 2, 11, 
            2}];\)\ \), "\n", 
    \(\(graph3 = 
        ParametricPlot[Evaluate[eqns3], {x, \(-4.75\), 4}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Red, Line[{{\(-1\), 0}, {2, 0}}], 
            Line[{{0, 0}, {Cos[\[Alpha]\ \[Pi]], 
                  Sin[\[Alpha]\ \[Pi]]}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph3, boundary, 
        PlotRange \[Rule] {{\(-0.75\), 1.75}, {\(-0.001\), 1.0}}, 
        AspectRatio \[Rule] 1\/2.5, 
        Ticks \[Rule] {Range[\(-5\), 5, 2], Range[0, 5, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow across the upper half plane Im[z] > 0,\
\>"];\)\ \), "\n", 
    \(\(Print["\<under w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(\[Alpha]\  = \ 1\/4;\)\), "\[IndentingNewLine]", 
    \(\(f[
          z_] = \(\((z - 
                  1)\)\^\[Alpha]\) \((1 + \(\[Alpha]\ z\)\/\((1 - \
\[Alpha])\))\)\^\(1 - \[Alpha]\)\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.075  k]]}, {k, 1, 11, 
            2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {x, \(-4.75\), 4}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] 
            Identity];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[
              f[x + \[ImaginaryI]\ 0.2  k]], \(-Im[
                f[x + \[ImaginaryI]\ 0.075  k]]\)}, {k, 1, 11, 
            2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {x, \(-4.75\), 4}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] 
            Identity];\)\ \ \ \), "\[IndentingNewLine]", 
    \(\(eqns3\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.075  k]]}, {k, 2, 11, 
            2}];\)\ \), "\n", 
    \(\(graph3 = 
        ParametricPlot[Evaluate[eqns3], {x, \(-4.75\), 4}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns4\  = \ 
        Table[{Re[
              f[x + \[ImaginaryI]\ 0.2  k]], \(-Im[
                f[x + \[ImaginaryI]\ 0.075  k]]\)}, {k, 2, 11, 
            2}];\)\ \), "\n", 
    \(\(graph4 = 
        ParametricPlot[Evaluate[eqns4], {x, \(-4.75\), 4}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Red, 
            Line[{{0, 0}, {Cos[\[Alpha]\ \[Pi]], Sin[\[Alpha]\ \[Pi]]}}], 
            Line[{{\(-1\), 0}, {2, 0}}], 
            Line[{{0, 0}, {Cos[\(-\[Alpha]\)\ \[Pi]], 
                  Sin[\(-\[Alpha]\)\ \[Pi]]}}]}];\)\), "\[IndentingNewLine]", \

    \(\(Show[graph1, graph2, graph3, graph4, boundary, 
        PlotRange \[Rule] {{\(-0.75\), 1.75}, {\(-0.85\), 0.85}}, 
        AspectRatio \[Rule] 1.7\/2.5, 
        Ticks \[Rule] {Range[\(-5\), 5, 2], Range[0, 5, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow across the z-plane,\>"];\)\ \), "\n", 
    \(\(Print["\<under w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Figure 11.91 to find the flow over a dam. "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007=0000/R000`400?l0
0000o`00003oo`3oooo>0?ooo`00o`3oooo>0?ooo`00o`3oooo>0?ooo`00
o`3oooo>0?ooo`00o`3oooo>0?ooo`00o`3oooo>0?ooo`00K03ooonX0?3o
l0030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0@0?oo
o`030000o`3oool0oooo01D0oooo001/0?ooojP0l?o`00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool03`3oool00`000?l0
oooo0?ooo`0@0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool05@3oool006`0ooooZ03`oo000`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo
00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0F0?ooo`00K03o
oonX0?3ol0030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo01H0oooo001/0?ooojP0l?o`00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool05`3oool006`0ooooZ03`oo000`3o0000oooo0?ooo`0>0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00l0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0G0?oo
o`00K03ooonX0?3ol0030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0@0?ooo`030000o`3oool0oooo01L0oooo001/0?ooojP0l?o`
00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00l0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool0603oool006`0ooooZ03`oo000`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0H0?ooo`00K03ooonX0?3ol0030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00l0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0?
0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo01T0oooo001/0?oo
ojP0l?o`00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03`3oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool06@3oool006`0ooooZ03`oo000`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0403oool00`000?l0
oooo0?ooo`0I0?ooo`00K03ooonX0?3ol0030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool01P3oool006`0ooooZ03`oo000`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0@0?ooo`030?l0003oool0oooo00L0oooo001/0?ooojP0l?o`00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`070?ooo`00K03ooonX0?3o
l0030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0?0?oo
o`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0203oool006`0
ooooZ03`oo000`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0
oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00P0
oooo001/0?ooojP0l?o`00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
003oool0oooo00l0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo
0?ooo`090?ooo`00K03ooonX0?3ol0030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0100oooo00<0
o`000?ooo`3oool02@3oool006`0ooooZ03`oo000`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00l0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0?
0?ooo`030?l0003oool0oooo00X0oooo001/0?ooojP0l?o`00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?oo
o`3oool0403oool00`3o0000oooo0?ooo`0:0?ooo`00K03ooonX0?3ol003
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool02`3oool006`0oooo
Z03`oo000`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00/0oooo
001/0?ooojP0l?o`00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?oo
o`0<0?ooo`00K03ooonX0?3ol0030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<0o`00
0?ooo`3oool0303oool006`0ooooZ03`oo000`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool03P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo
00l0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo00d0oooo001/0?ooojP0l?o`00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`0=0?ooo`00K03ooonX0?3ol0030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00h0oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00l0oooo00<0o`000?ooo`3oool03P3oool006`0ooooZ03`
oo000`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00h0oooo001/
0?ooojP0l?o`00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0?
0?ooo`00K03ooonX0?3ol0030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool03`3oool006`0ooooZ03`oo000`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo0100oooo001/0?ooojP0l?o`00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`0@0?ooo`00K03ooonX0?3ol0030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool04@3oool006`0ooooZ03`oo00
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0140oooo001/0?oo
ojP0l?o`00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00l0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0B0?oo
o`00K03ooonX0?3ol0030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3o
ool04P3oool006`0ooooZ03`oo000`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo01<0oooo001/0?ooojP0l?o`00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`0C0?ooo`00K03ooonX0?3ol0030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool0503oool006`0ooooZ03`oo000`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo01@0oooo001/0?ooojP0
l?o`00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0E0?ooo`00
K03ooonX0?3ol0030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
5@3oool006`0ooooZ03`oo000`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo01H0oooo001/0?ooojP0l?o`00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`0F0?ooo`00K03ooonX0?3ol0030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool05`3oool006`0ooooZ03`oo000`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo01L0oooo001/0?ooojP0l?o`
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0H0?ooo`00K03o
oonX0?3ol0030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0603o
ool006`0ooooZ03`oo000`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool01P3oool006`0ooooZ03`oo000`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?oo
o`3oool01`3oool006`0ooooZ03`oo000`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0
oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool006`0oooo
Z03`oo000`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool0203oool006`0ooooZ@3o000=0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3oool02@3oool00?l0oooo5@3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool02@3oool00?l0oooo5@3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool02P3oool00?l0
oooo5@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool02P3oool00?l0oooo5@3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
2`3oool00?l0oooo5@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool0303oool00?l0oooo5@3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool0303oool00?l0oooo5@3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03@3oool00?l0
oooo5@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool03P3oool00?l0oooo5@3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
3P3oool006`0ooooCP000?mJ0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0?0?ooo`00^P3oool>
0000od`0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo0100oooo00380?ooo`/0003o@@3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?oo
o`3oool0403oool00=<0oooo1P000?lk0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0A0?ooo`00
f@3oool50000ocH0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo0140oooo003N0?ooo`<0003o<`3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool04P3oool00>40oooo0P000?la0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0C
0?ooo`00h`3oool20000obl0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01<0oooo003U0?ooo`80
003o;@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool0503oool006`0oooo603o001S0?ooo`80003o
:`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo
00<0003o0?ooo`3oool05@3oool008@0oooo:P3o000k0?ooo`030000o`3o
ool0oooo02P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo01D0oooo002^0?ooo`P0o`00=03oool0
0`000?l0oooo0?ooo`0W0?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0F0?ooo`00]P3oool;0?l0
02X0oooo00<0003o0?ooo`3oool09P3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool05`3oool00<40
oooo1@3o000V0?ooo`030000o`3oool0oooo02D0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01L0
oooo00360?ooo`D0o`008P3oool00`000?l0oooo0?ooo`0T0?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo
0?ooo`0H0?ooo`00b`3oool40?l001l0oooo00<0003o0?ooo`3oool08`3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool06@3oool00<l0oooo103o000K0?ooo`030000o`3oool0
oooo02<0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo01T0oooo003C0?ooo`80o`006P3oool00`00
0?l0oooo0?ooo`0R0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`0J0?ooo`00e@3oool20?l001T0
oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool06P3oool006`0oooo
7`000?m<0?ooo`80o`00603oool00`000?l0oooo0?ooo`0P0?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0K0?ooo`00R`3ooolK0000oc<0oooo0P3o000F0?ooo`030000o`3o
ool0oooo0200oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo01`0oooo002V0?ooo`/0003o:P3oool0
0`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo01l0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo01`0oooo002a0?ooo`X0003o8@3oool00`3o0000oooo0?ooo`0D0?oo
o`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01d0oooo002k0?ooo`D0
003o7@3oool20?l001@0oooo00<0003o0?ooo`3oool07P3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool07P3oool00<00oooo10000?lK0?ooo`030?l0003oool0oooo0180oooo
00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool07`3oool00<@0oooo1000
0?lH0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool07@3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool07`3oool00<P0oooo0P000?lG0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0803oool0
0<X0oooo0`000?lE0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool06`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool08@3oool00<d0oooo0P000?lD0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool06`3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool08P3oool006`0oooo9@3o000n0?ooo`80003o4`3oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo02<0oooo
002A0?oooa<0o`00;@3oool20000oa80oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0T0?ooo`00Y03oool7
0?l002P0oooo0P000?lA0?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool06@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool0903oool00:/0oooo203o000R0?oo
o`80003o3`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
01T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo02D0oooo002c0?ooo`H0o`007P3oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3o
ool0603oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool09P3oool00;T0oooo1@3o000J0?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo
0?ooo`0H0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`0W0?ooo`00_P3oool50?l001H0oooo0P00
0?l>0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool05`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool0:03oool00<<0oooo103o000D0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0G
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0X0?ooo`00a`3oool30?l00180oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo
01H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo02T0oooo003:0?ooo`80o`004@3oool20000o``0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0F0?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`0Z0?ooo`00K03oool]0000oc<0oooo0P3o000A0?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0E0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`0[0?ooo`00V@3oool<0000obT0oooo0P3o
000@0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0/0?ooo`00Y@3oool<
0000oal0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0503oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0;@3oool00;40oooo10000?lL0?ooo`80o`003`3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0503oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool0;@3oool00;D0oooo1@000?lI0?ooo`80
o`003P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0;P3oool00;X0oooo
10000?lG0?ooo`80o`003@3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
;`3oool00;h0oooo10000?lE0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo0180oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo0300oooo00320?ooo`@0003o4P3oool2
0?l000`0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo0340oooo00360?oo
o`@0003o403oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0b0?ooo`00bP3oool20000o`l0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0<`3oool006`0oooo
>03o000X0?ooo`80003o3P3oool20?l000/0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0100oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo03@0oooo002T0?ooo`L0o`008`3oool30000o`d0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0=@3o
ool00:/0oooo2`3o000K0?ooo`80003o303oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0f0?ooo`00]P3oool60?l0
01L0oooo0`000?l:0?ooo`80o`002P3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool03`3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0=`3oool00;`0oooo103o000F0?ooo`80003o2P3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0h0?ooo`00
`03oool50?l001<0oooo0P000?l90?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00h0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo03T0oooo00350?ooo`@0o`004@3o
ool20000o`P0oooo0P3o00090?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0j0?ooo`00b@3oool40?l000l0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0k
0?ooo`00c@3oool20?l000h0oooo0P000?l80?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo03`0oooo001/0?oooc80
003o<@3oool20?l000h0oooo0P000?l70?ooo`80o`00203oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0?@3oool009h0oooo4@000?lR0?ooo`<0o`00
3@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo03h0oooo002_0?ooo`P0003o7@3o
ool20?l000`0oooo0P000?l70?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo03l0oooo002g0?ooo`L0003o603oool2
0?l000`0oooo00<0003o0?ooo`3oool01@3oool20?l000L0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo0400oooo002n0?ooo`@0003o5P3oool30?l0
00X0oooo0P000?l70?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00X0oooo0P000?l=0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0@@3oool00<80oooo10000?lE0?ooo`80o`002P3oool20000o`H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0;0?ooo`80o`003P3oool00`000?l0oooo0?ooo`120?ooo`00
aP3oool40000oa<0oooo0P3o000:0?ooo`030000o`3oool0oooo00@0oooo
0P3o00060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`130?ooo`00bP3o
ool40000oa40oooo0P3o00090?ooo`80003o1P3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo0P000?l;0?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo04@0oooo003>0?ooo`@0003o3`3oool3
0?l000P0oooo0P000?l50?ooo`80o`001@3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool0A@3oool00=80oooo0`000?l?0?ooo`80o`00203oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo0P000?l50?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0:0?ooo`80o`003P3oool20000odP0oooo001/0?oood80
o`009`3oool40000o`d0oooo0P3o00070?ooo`80003o1@3oool20?l000D0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo04P0oooo002^0?ooo`h0o`00
7@3oool30000o``0oooo0P3o00070?ooo`80003o1@3oool20?l000@0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo04T0oooo002l0?ooo`P0o`00603o
ool30000o`/0oooo0`3o00060?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00P3oool20000o`@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`090?ooo`80003o2`3oool20?l000l0oooo00<0
003o0?ooo`3oool0BP3oool00<@0oooo1`3o000D0?ooo`80003o303oool2
0?l000D0oooo0P000?l50?ooo`80o`00103oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool20?l000T0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`1;
0?ooo`00b`3oool40?l00180oooo0`000?l;0?ooo`80o`001@3oool20000
o`D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool01@3o
0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo0P000?l8
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool03@3oool20000odh0oooo003?0?ooo`@0o`004@3oool30000
o`X0oooo0P3o00050?ooo`80003o103oool20?l000<0oooo00<0003o0?oo
o`3oool00P3oool20?l000@0oooo00<0003o0?ooo`3oool00`3oool01@3o
0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`80003o2`3oool2
0?l000/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo04h0oooo003C0?ooo`@0o`00403oool30000
o`T0oooo0`3o00040?ooo`80003o103oool20?l00080oooo0P000?l40?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0103o
0000oooo0?ooo`000?l40?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00H0oooo0P3o00090?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`80o`003P3oool2
0000oe40oooo003G0?ooo`@0o`003`3oool30000o`T0oooo0P3o00040?oo
o`80003o103oool20?l00080oooo00<0003o0?ooo`3oool00P3oool01@3o
0000oooo0?ooo`3oool0003o00@0oooo00@0o`000?ooo`3oool0003o0`3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo0P3o
00050?ooo`80003o203oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00T0oooo0P3o000;0?ooo`80003o2`3oool00`3o0000oooo0?oo
o`0<0?ooo`80003oD`3oool00=/0oooo103o000>0?ooo`80003o2@3oool2
0?l000@0oooo0`000?l30?ooo`80o`0000<0oooo0000o`000?l00`3oool2
0?l00080oooo00L0003o0?ooo`3oool0oooo0?l0003oool0003o00<0oooo
00<0o`000?ooo`3oool00P3oool20000o`@0oooo0P3o00050?ooo`80003o
203oool20?l000T0oooo0P000?l;0?ooo`030?l0003oool0oooo00T0oooo
0P000?l<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
D`3oool007P0oooo>P000?l]0?ooo`@0o`00303oool30000o`P0oooo0P3o
00050?ooo`80003o0`3oool20?l000030?ooo`000?l0003o0080003o00@0
oooo0?l0003o0000oooo0P000?l01@3oool0o`000000o`000?l0oooo0080
o`000`3oool20000o`@0oooo0P3o00050?ooo`80003o2@3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo0P3o000;0?ooo`03
0000o`3oool0oooo00X0oooo0P3o000=0?ooo`80003oEP3oool006`0oooo
30000?lj0?oooa00003o8@3oool40?l000/0oooo0`000?l70?ooo`80o`00
1@3oool30000o`80oooo0P3o00030?ooo`80003o00<0oooo0?l0003o0000
1P3o00030?ooo`80003o103oool20?l000H0oooo00<0003o0?ooo`3oool0
1`3oool20?l000T0oooo0P000?l:0?ooo`80o`002`3oool20000o``0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`1F0?ooo`00`P3o
ool80000oad0oooo103o000:0?ooo`<0003o1P3oool20?l000H0oooo0P00
0?l20?ooo`<0o`000P3oool<0000o`@0oooo0P3o00060?ooo`80003o203o
ool20?l000T0oooo0P000?l:0?ooo`80o`002`3oool20000o``0oooo0P3o
000=0?ooo`80003oF@3oool00<X0oooo20000?lI0?ooo`@0o`002@3oool3
0000o`D0oooo103o00040?ooo`80003o0`3oool60?l000L0oooo1@3o0005
0?ooo`<0003o203oool20?l000T0oooo0P000?l:0?ooo`80o`00303oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo0P000?mK
0?ooo`00dP3oool70000oaH0oooo0`3o00090?ooo`@0003o1@3oool40?l0
0080oooo1@000?l40?ooo`L0o`00203oool20000o`P0oooo0`3o00090?oo
o`80003o2P3oool20?l000`0oooo0P000?l<0?ooo`80o`00303oool20000
oed0oooo003I0?ooo`D0003o503oool40?l000T0oooo0`000?l60?ooo`<0
o`00103ooolC0000o`P0oooo0P3o000:0?ooo`80003o2@3oool30?l000`0
oooo0P000?l=0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool0G@3oool00=h0oooo1@000?lC0?ooo`@0o`00203oool30000o`H0oooo
1@3o000G0?ooo`<0o`002@3oool30000o`T0oooo0P3o000=0?ooo`80003o
3@3oool20?l000`0oooo0P000?mP0?ooo`00h`3oool50000oa80oooo103o
00070?ooo`<0003o203ooolG0?l000X0oooo0P000?l90?ooo`<0o`003@3o
ool20000o`d0oooo0P3o000<0?ooo`80003oHP3oool00>P0oooo1@000?lA
0?ooo`<0o`001`3oool70000oah0oooo10000?l90?ooo`80o`003P3oool2
0000o`d0oooo0P3o000<0?ooo`80003oI03oool00900oooo;03o000a0?oo
o`D0003o3`3oool30?l000/0oooo1P000?l@0?ooo`P0003o2P3oool30?l0
00d0oooo0`000?l=0?ooo`80o`003@3oool00`000?l0oooo0?ooo`1T0?oo
o`00L`3ooolM0?l002`0oooo4`3o000S0?ooo`D0003o3@3oool50?l000`0
oooo40000?l@0?ooo`80o`003P3oool20000o`d0oooo0`3o000=0?ooo`80
003oI`3oool006`0oooo1`3o001L0?ooo`T0o`007`3oool50000o`d0oooo
1@3o000S0?ooo`@0o`003@3oool30000o``0oooo0`3o000>0?ooo`80003o
J@3oool00=P0oooo203o000L0?ooo`H0003o303oool90?l00140oooo2@3o
000=0?ooo`@0003o3@3oool20?l000l0oooo0P000?m[0?ooo`00h03oool7
0?l001/0oooo1@000?l@0?oooa40o`004@3oool50000o`h0oooo0`3o000?
0?ooo`80003oK@3oool00>L0oooo1`3o000I0?ooo`D0003o9`3oool60000
oa00oooo0`3o000?0?ooo`<0003oK`3oool00>h0oooo203o000F0?ooo`P0
003o6`3oool40000oa<0oooo0`3o000@0?ooo`80003oLP3oool00?H0oooo
203o000F0?oooa/0003o4`3oool40?l00100oooo0`000?md0?ooo`00oP3o
ool80?l003H0oooo1P3o000A0?ooo`<0003oM`3oool00940oooo@`000?lb
0?ooo`P0o`00:03oool60?l001<0oooo10000?mj0?ooo`00P@3oool@0000
od<0oooo4P000?lX0?ooo`P0o`006`3oool50?l001D0oooo10000?mn0?oo
o`00L`3oool>0000ofD0oooo20000?lX0?oooa/0o`005P3oool40000oh80
oooo001/0?ooo`L0003oN`3oool90000odd0oooo0`000?n60?ooo`00m`3o
ool80000od00oooo1@000?n90?ooo`00o`3oool?0000obX0oooo1`000?n>
0?ooo`00o`3oool?0?ooobX0003oU@3oool00?l0oooocP3oool00?l0oooo
cP3oool00?l0oooocP3oool00?l0oooocP3oool00?l0oooocP3oool00?l0
oooocP3oool00?l0oooocP3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{461, 178},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.91",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/fluidflowimage/\
FluidFlowImageFigures/mat1191.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Flow over a dam. "
}], "Text"],

Cell[TextData[{
  "Solution.  Set  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 1\)}]]],
  ".  In the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  "-plane ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \[ImaginaryI]\)}]]],
  ", and the exterior angles are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(\[Pi]\/2\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(-\[Pi]\)}]}]]],
  ",  and the formula for the derivative ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " is  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z - 
                  0)\)\^\(\(-\(\[Pi]\/2\)\)/\[Pi]\)\) \((z - \
1)\)\^\(\(-\((\(-\[Pi]\))\)\)/\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ \
\(z\^\(-\(1\/2\)\)\) \((z - 1)\)\^1\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ \
\(z\^\(-\(1\/2\)\)\) \((z - 1)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \((z\^\(1\/2\)\  - \ 
              z\^\(-\(1\/2\)\))\)\)\)\)}]]
}], "Text"],

Cell[TextData[{
  "Integrate and get  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\ \  = \ \ B\ \  + \ \ A\ \(\[Integral]\((z\^\(1\/2\)\  \
- \ z\^\(-\(1\/2\)\))\) \[DifferentialD]z\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(B + 
          A\ \((\(-2\)\ \@z + \(2\ z\^\(3/2\)\)\/3)\)\)\)\)}]],
  " \n\nSolve for the coefficients A and B and obtain \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \(\(-\[ImaginaryI]\)\/2\) \(z\^\(1\/2\)\) \((z - 
              3)\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[
    \(Print[\*"\"\<B + A \[Integral](\!\(z\^\(1\/2\)\) - \!\(z\^\(-\(1\/2\)\)\
\))\[DifferentialD]z = \>\"", 
      B\ \  + \ \ A\ \(\[Integral]\((z\^\(1\/2\)\  - \ 
                  z\^\(-\(1\/2\)\))\) \[DifferentialD]z\)]\)], "Input"],

Cell[BoxData[{
    \(\(f[
          z_]\  = \ \(\(-\[ImaginaryI]\)\/2\) \(z\^\(1\/2\)\) \((z - 
              3)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[0] = \>", f[0]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[1] = \>", f[1]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[{
    \(\(f[
          z_] = \(\(-\[ImaginaryI]\)\/2\) \(z\^\(1\/2\)\) \((z - 
              3)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.075  k]]}, {k, 1, 11, 
            2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {x, \(-4\), 4}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns3\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.075  k]]}, {k, 2, 11, 
            2}];\)\ \), "\n", 
    \(\(graph3 = 
        ParametricPlot[Evaluate[eqns3], {x, \(-4\), 4}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Red, Line[{{\(-2\), 0}, {0, 0}}], 
            Line[{{0, 1}, {0, \(-1\)}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph3, boundary, 
        PlotRange \[Rule] {{\(-2\), 2.1}, {\(-0.6\), 1.35}}, 
        AspectRatio \[Rule] 2\/4, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0, 2, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow across the upper half plane Im[z] > 0,\
\>"];\)\ \), "\n", 
    \(\(Print["\<under w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 5.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use Figure 11.92 to find the flow around"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:30000/R000`400?l0
0000o`00003oo`3ooooo0?ooohD0oooo003o0?ooool0ooooQ@3oool00?l0
ooooo`3ooon50?ooo`00o`3ooooo0?ooohD0oooo003o0?ooool0ooooQ@3o
ool00?l0ooooo`3ooon50?ooo`00o`3ooooo0?ooohD0oooo002C0?ooo`@0
0000@@3oool500000880oooo1@0000100?ooo`@00000b03oool;0000o`P0
oooo002C0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
Q03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0:`0oooo
7@000?lC0?ooo`00U03oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo08@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`2O0?ooo``0003o<03oool008d0oooo100000040?ooo`030000003oool0
oooo03X0oooo100000040?ooo`030000003oool0oooo08@0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`2B0?ooo``0003o?03oool0
09<0oooo00@000000?ooo`3oool00000@`3oool00`000000oooo0?ooo`24
0?ooo`030000003oool0oooo0400oooo00@000000?ooo`3oool00000R`3o
ool80000ocD0oooo2`3o00080?ooo`00U03oool2000004<0oooo0P000011
0?ooo`03003o003oool0oooo0440oooo0P0000130?ooo`800000QP3oool6
0000obd0oooo403o000C0?ooo`00o`3ooolM0?ooo`03003o003oool0oooo
0?l0oooo2P3oool50000oa`0oooo5`3o000S0?ooo`00o`3ooolM0?ooo`03
003o003oool0oooo0?l0oooo103oool60000oaP0oooo2@3o000j0?ooo`00
o`3ooolM0?ooo`03003o003oool0oooo0?h0oooo1@000?lH0?ooo`H0o`00
;`3oool<0000o`P0oooo003o0?oooad0oooo00<00?l00?ooo`3oool0n03o
ool60000oa@0oooo2@3o000U0?oooa00003o503oool00?l0oooo7@3oool0
0`00o`00oooo0?ooo`3b0?ooo`H0003o4P3oool80?l002<0oooo2`000?lT
0?ooo`00o`3ooolM0?ooo`03003o003oool0oooo0>`0oooo1P000?lB0?oo
o`H0o`00803oool;0000obl0oooo001=0?ooohX0o`00d000o`1O0?ooo`D0
003o4`3oool50?l001X0oooo30000?lj0?ooo`00TP3oool00`000000oooo
0?ooo`120?ooo`030000003o0000l?o`0480l?o`00<00?l00?3ol03`oo00
Q`3`oo000`000000oooo0?ooo`1H0?ooo`D0003o4`3oool50?l001D0oooo
2P000?l]0?oooa40o`00203oool00980oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?l000120?3ol003003o003`oo00l?o`08L0l?o`00<0
00000?ooo`3oool0D`3oool50000oa@0oooo103o000B0?ooo`P0003o8@3o
oolF0?l001T0oooo003J0?ooo`030?l0003`oo00l?o`03l0l?o`00<00?l0
0?3ol03`oo00Q`3`oo1A0?ooo`D0003o503oool50?l00100oooo1P000?lN
0?ooo`/0o`00;`3oool00=/0oooo00<0o`000?3ol03`oo00?P3`oo000`00
o`00l?o`0?3ol0270?3ol4`0oooo1@000?lD0?ooo`D0o`003`3oool60000
oaT0oooo2`3o000j0?ooo`00g03oool00`3o0000l?o`0?3ol00m0?3ol003
003o003`oo00l?o`08L0l?o`A`3oool50000oa@0oooo1@3o000>0?ooo`H0
003o5@3oool:0?l003<0oooo2P000?l80?ooo`00g@3oool00`3o0000l?o`
0?3ol00l0?3ol003003o003`oo00l?o`08L0l?o`@`3oool40000oaD0oooo
103o000>0?ooo`D0003o4`3oool80?l002@0oooo6@000?lB0?ooo`00gP3o
ool00`3o0000l?o`0?3ol00k0?3ol003003o003`oo00l?o`08L0l?o`?`3o
ool40000oa@0oooo1@3o000>0?ooo`@0003o4P3oool60?l00240oooo2`00
0?l[0?ooo`00g`3oool00`3o0000l?o`0?3ol00j0?3ol003003o003`oo00
l?o`08L0l?o`=`3oool80000oa<0oooo1@3o000?0?ooo`@0003o4@3oool5
0?l001/0oooo30000?lf0?ooo`00h03oool00`3o0000l?o`0?3ol00i0?3o
l003003o003`oo00l?o`08L0l?o`;@3oool:0000oaL0oooo103o000@0?oo
o`@0003o4@3oool40?l001D0oooo2`000?le0?ooo`D0o`00203oool004d0
oooo1P000?n>0?ooo`030?l0003`oo00l?o`03P0l?o`00<00?l00?3ol03`
oo00Q`3`oo0V0?ooo`L0003o7@3oool40?l00100oooo10000?lA0?ooo`@0
o`004@3oool80000ob00oooo803o000=0?ooo`00D`3ooold0000oe/0oooo
00<0o`000?3ol03`oo00=`3`oo000`00o`00l?o`0?3ol0270?3ol1h0oooo
20000?lP0?ooo`@0o`00403oool40000oa80oooo0`3o000?0?ooo`H0003o
7@3oool;0?l002d0oooo00270?oooaX0003o@P3oool00`3o0000l?o`0?3o
l00f0?3ol003003o003`oo00l?o`08L0l?o`6P3oool40000ob@0oooo103o
000@0?ooo`@0003o4P3oool40?l000d0oooo1@000?lI0?ooo`X0o`00>03o
ool00:40oooo40000?lc0?ooo`030?l0003`oo00l?o`03D0l?o`00<00?l0
0?3ol03`oo00Q`3`oo0l0?ooo`H0o`00403oool40000oa80oooo103o000=
0?ooo`@0003o503oool:0?l00480oooo002a0?ooo`H0003o;P3oool00`3o
0000l?o`0?3ol00d0?3ol003003o003`oo00l?o`08L0l?o`=P3oool60?l0
0180oooo10000?lB0?ooo`@0o`003@3oool40000oa00oooo203o000[0?oo
oaT0003o203oool00;L0oooo1P000?lY0?ooo`030?l0003`oo00l?o`03<0
l?o`00<00?l00?3ol03`oo00Q`3`oo0/0?ooo`X0o`005@3oool30000oa80
oooo103o000>0?ooo`<0003o3P3oool60?l001h0oooo5@000?lQ0?ooo`00
_@3oool50000obD0oooo00<0o`000?3ol03`oo00<P3`oo000`00o`00l?o`
0?3ol0270?3ol200oooo303o000K0?ooo`@0003o4@3oool40?l000h0oooo
10000?l<0?ooo`D0o`005P3oool>0000ocH0oooo00320?ooo`@0003o8P3o
ool00`3o0000l?o`0?3ol00a0?3ol003003o003`oo00l?o`08L0l?o`6P3o
ool60?l002<0oooo10000?lA0?ooo`@0o`003P3oool40000o``0oooo103o
000D0?ooo`L0003oA03oool00<H0oooo0`000?lP0?ooo`030?l0003`oo00
l?o`0300l?o`00<00?l00?3ol03`oo00Q`3`oo0m0?ooo`H0003o4@3oool4
0?l000l0oooo0`000?l<0?ooo`@0o`00403oool80000ocH0oooo3@3o0008
0?ooo`00b@3oool20000oal0oooo00<0o`000?3ol03`oo00;`3`oo000`00
o`00l?o`0?3ol0270?3ol3L0oooo1P000?lC0?ooo`@0o`00403oool30000
o`/0oooo103o000>0?ooo`H0003o6`3ooolS0?l001D0oooo003;0?ooo`80
003o7P3oool00`3o0000l?o`0?3ol00^0?3ol003003o003`oo00l?o`08L0
l?o`<03oool70000oaD0oooo103o000A0?ooo`<0003o2`3oool30?l000h0
oooo10000?lD0?ooo`d0o`00>03oool004d0oooo803o001P0?ooo`80003o
7@3oool00`3o0000l?o`0?3ol00]0?3ol003003o003`oo00l?o`08L0l?o`
:P3oool60000oaP0oooo103o000B0?ooo`<0003o303oool20?l000h0oooo
0`000?l>0?ooo`X0o`00A@3oool006d0oooo6@3o00190?ooo`80003o703o
ool00`3o0000l?o`0?3ol00/0?3ol003003o003`oo00l?o`08L0l?o`8@3o
ool90000oaX0oooo103o000B0?ooo`@0003o303oool30?l000`0oooo1000
0?l<0?ooo`D0o`00?@3oool:0000o`P0oooo00260?ooo`X0o`00@@3oool0
0`000?l0oooo0?ooo`0J0?ooo`030?l0003`oo00l?o`02/0l?o`00<00?l0
0?3ol03`oo00Q`3`oo0J0?ooo`L0003o7@3oool60?l001<0oooo0`000?l=
0?ooo`<0o`002P3oool50000o`/0oooo1@3o000K0?ooobL0003o4P3oool0
0900oooo3P3o000d0?ooo`80003o6`3oool00`3o0000l?o`0?3ol00Z0?3o
l003003o003`oo00l?o`08L0l?o`>03oool60?l001H0oooo0`000?l=0?oo
o`<0o`002`3oool20000o``0oooo103o000B0?ooo`h0003o>@3oool009h0
oooo1P3o000`0?ooo`80003o6P3oool00`3o0000l?o`0?3ol00Y0?3ol003
003o003`oo00l?o`08L0l?o`<@3oool70?l001T0oooo0`000?l=0?ooo`<0
o`00303oool20000o`/0oooo0`3o000<0?ooo`X0003oA`3oool00:@0oooo
1`3o000[0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?3ol03`oo00
:03`oo000`00o`00l?o`0?3ol0270?3ol2X0oooo1`3o000M0?ooo`<0003o
3@3oool30?l000d0oooo0P000?l:0?ooo`<0o`002P3oool50000oe40oooo
002[0?ooo`L0o`009@3oool20000oaT0oooo00<0o`000?3ol03`oo009`3`
oo000`00o`00l?o`0?3ol0270?3ol240oooo2@3o000P0?ooo`@0003o3@3o
ool30?l000h0oooo0P000?l:0?ooo`80o`002@3oool40000ob00oooo;P3o
00080?ooo`00/P3oool50?l00280oooo0P000?lH0?ooo`030?l0003`oo00
l?o`02H0l?o`00<00?l00?3ol03`oo00Q`3`oo0J0?ooo`L0o`009@3oool4
0000o`h0oooo0`3o000>0?ooo`<0003o2@3oool30?l000T0oooo0P000?l?
0?oooaD0o`00=P3oool00;L0oooo103o000P0?ooo`030000o`3oool0oooo
01H0oooo00<0o`000?3ol03`oo009@3`oo000`00o`00l?o`0?3ol0270?3o
l400oooo1P000?l?0?ooo`<0o`003`3oool20000o`X0oooo0P3o00090?oo
o`<0003o2@3oool80?l004/0oooo002k0?ooo`@0o`007@3oool20000oaL0
oooo00<0o`000?3ol03`oo00903`oo000`00o`00l?o`0?3ol0270?3ol3T0
oooo1`000?lB0?ooo`<0o`003`3oool30000o`X0oooo0P3o00080?ooo`<0
003o203oool40?l005<0oooo001=0?oooa40003oH@3oool20?l001d0oooo
00<0003o0?ooo`3oool05@3oool00`3o0000l?o`0?3ol00S0?3ol003003o
003`oo00l?o`08L0l?o`<P3oool70000oaH0oooo0`3o000?0?ooo`<0003o
2`3oool20?l000P0oooo0P000?l80?ooo`<0o`006@3ooolf0000o`P0oooo
001N0?ooo`d0003oEP3oool20?l001`0oooo00<0003o0?ooo`3oool05@3o
ool00`3o0000l?o`0?3ol00R0?3ol003003o003`oo00l?o`08L0l?o`:`3o
ool70000oaX0oooo0`3o000@0?ooo`80003o303oool20?l000P0oooo0P00
0?l80?ooo`80o`002P3ooolB0000och0oooo001[0?oooaP0003o@03oool2
0?l001/0oooo0P000?lF0?ooo`030?l0003`oo00l?o`0240l?o`00<00?l0
0?3ol03`oo00Q`3`oo0R0?ooo`T0003o703oool50?l00100oooo0`000?l;
0?ooo`<0o`00203oool20000o`P0oooo0P3o00060?ooo`H0003oD03oool0
08<0oooo2P000?lh0?ooo`80o`006`3oool00`000?l0oooo0?ooo`0D0?oo
o`030?l0003`oo00l?o`0200l?o`00<00?l00?3ol03`oo00Q`3`oo0J0?oo
o`P0003o7`3oool60?l00180oooo0`000?l<0?ooo`80o`002@3oool20000
o`P0oooo0P3o00070?ooo`030000o`3oool0oooo05@0oooo002=0?ooo`L0
003o<`3oool20?l001X0oooo00<0003o0?ooo`3oool0503oool00`3o0000
l?o`0?3ol00O0?3ol003003o003`oo00l?o`08L0l?o`?@3oool40?l001H0
oooo0P000?l=0?ooo`80o`002@3oool20000o`T0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`020?ooo`03003o003o0000o`0004P0
o`00203oool009@0oooo1P000?l_0?ooo`80o`006@3oool20000oaD0oooo
00<0o`000?3ol03`oo007P3`oo000`00o`00l?o`0?3ol0270?3ol3T0oooo
103o000G0?ooo`<0003o303oool30?l000X0oooo00<0003o0?ooo`3oool0
1`3oool20?l000L0oooo0P000?l40?ooo`030?l00000o`00l?o`04P0l?o`
2@3oool009X0oooo1P000?l[0?ooo`80o`006@3oool00`000?l0oooo0?oo
o`0C0?ooo`030?l0003`oo00l?o`01d0l?o`00<00?l00?3ol03`oo00Q`3`
oo0]0?ooo``0o`00603oool30000o`d0oooo0P3o000;0?ooo`80003o203o
ool20?l000L0oooo0P000?l50?ooo`030?l0003`oo000?l004T0l?o`2@3o
ool00:00oooo1`000?lV0?ooo`80o`00603oool00`000?l0oooo0?ooo`0C
0?ooo`030?l0003`oo00l?o`01`0l?o`00<00?l00?3ol03`oo00Q`3`oo0S
0?ooo`X0o`00803oool40000o`d0oooo0`3o000;0?ooo`80003o203oool2
0?l000P0oooo00<0003o0?ooo`3oool0103oool0103o0000l?o`0?3ol000
o`190?3ol0T0oooo002W0?ooo`D0003o8`3oool20?l001L0oooo0P000?lD
0?ooo`030?l0003`oo00l?o`01/0l?o`00<00?l00?3ol03`oo00Q`3`oo0J
0?ooo`T0o`009@3oool50000o`l0oooo0P3o000<0?ooo`80003o203oool2
0?l000P0oooo0P000?l60?ooo`050?l0003`oo00l?o`0?3ol000o`00B@3`
oo090?ooo`00[03oool40000ob40oooo00<0o`000?ooo`3oool05P3oool0
0`000?l0oooo0?ooo`0B0?ooo`030?l0003`oo00l?o`01X0l?o`00<00?l0
0?3ol03`oo00Q`3`oo120?ooo`H0003o4P3oool20?l000`0oooo0P000?l8
0?ooo`80o`002@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003`oo00
l?o`0080l?o`00<00?l00?3ol03`oo00A`3`oo090?ooo`00C@3oool50?l0
05h0oooo0`000?lO0?ooo`80o`005`3oool00`000?l0oooo0?ooo`0B0?oo
o`030?l0003`oo00l?o`01T0l?o`00<00?l00?3ol03`oo00Q`3`oo0l0?oo
o`H0003o5@3oool30?l000`0oooo0P000?l80?ooo`80o`002P3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003`oo00l?o`00<0l?o`00<00?l00?3o
l03`oo00A`3`oo090?ooo`00DP3ooolG0?l004X0oooo0`000?lN0?ooo`80
o`005P3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003`oo00l?o`01P0
l?o`00<00?l00?3ol03`oo00Q`3`oo0e0?ooo`L0003o6@3oool20?l000`0
oooo0`000?l90?ooo`030?l0003oool0oooo00P0oooo0P000?l70?ooo`03
0?l0003`oo00l?o`00@0l?o`00<00?l00?3ol03`oo00A`3`oo090?ooo`00
J@3oool=0?l00400oooo10000?lL0?ooo`030?l0003oool0oooo01@0oooo
0P000?lC0?ooo`030?l0003`oo00l?o`01L0l?o`00<00?l00?3ol03`oo00
Q`3`oo0^0?ooo`L0003o7@3oool30?l000`0oooo0P000?l:0?ooo`80o`00
2P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003`oo00l?o`00D0l?o`
00<00?l00?3ol03`oo00A`3`oo090?ooo`00MP3oool<0?l003P0oooo0`00
0?lJ0?ooo`80o`005P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003`
oo00l?o`01H0l?o`00<00?l00?3ol03`oo00Q`3`oo0T0?ooo`X0003o8@3o
ool30?l000d0oooo0P000?l:0?ooo`80o`002`3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003`oo00l?o`00H0l?o`00<00?l00?3ol03`oo00A`3`
oo090?ooo`00PP3oool80?l003<0oooo0`000?lI0?ooo`80o`005@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003`oo00l?o`01D0l?o`00<00?l0
0?3ol03`oo00Q`3`oo0J0?ooo`X0003o9P3oool50?l000h0oooo0P000?l;
0?ooo`030?l0003oool0oooo00T0oooo0P000?l80?ooo`030?l0003`oo00
l?o`00L0l?o`00<00?l00?3ol03`oo00A`3`oo090?ooo`00RP3oool60?l0
0300oooo0P000?lI0?ooo`80o`00503oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003`oo00l?o`01@0l?o`00<00?l00?3ol03`oo00Q`3`oo130?oo
o`L0o`004@3oool20000o`/0oooo0P3o000;0?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?3ol03`oo00203`oo000`00o`00l?o`0?3ol0170?3o
l0T0oooo002@0?ooo`L0o`00:`3oool20000oaT0oooo00<0o`000?ooo`3o
ool04P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003`oo00l?o`01<0
l?o`00<00?l00?3ol03`oo00Q`3`oo0m0?ooo`H0o`005P3oool20000o``0
oooo00<0o`000?ooo`3oool02@3oool20000o`T0oooo00<0o`000?3ol03`
oo002@3`oo000`00o`00l?o`0?3ol0170?3ol0T0oooo002G0?ooo`H0o`00
9`3oool20000oaP0oooo0P3o000C0?ooo`80003o4P3oool00`3o0000l?o`
0?3ol00B0?3ol003003o003`oo00l?o`08L0l?o`=`3oool60?l001T0oooo
0`000?l<0?ooo`80o`002`3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003`oo00l?o`00X0l?o`00<00?l00?3ol03`oo00A`3`oo090?ooo`00W@3o
ool50?l002@0oooo0P000?lH0?ooo`80o`004`3oool00`000?l0oooo0?oo
o`0@0?ooo`030?l0003`oo00l?o`0140l?o`00<00?l00?3ol03`oo00Q`3`
oo0Y0?ooo`h0o`007@3oool20000o`h0oooo00<0o`000?ooo`3oool02@3o
ool20000o`X0oooo00<0o`000?3ol03`oo002`3`oo000`00o`00l?o`0?3o
l0170?3ol0T0oooo002R0?ooo`@0o`008P3oool20000oaP0oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003`oo00
l?o`0100l?o`00<00?l00?3ol03`oo00Q`3`oo0J0?ooo`l0o`00:@3oool2
0000o`h0oooo0P3o000;0?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?3ol03`oo00303`oo000`00o`00l?o`0?3ol0170?3ol0T0oooo002V0?oo
o`@0o`00803oool30000oaH0oooo0P3o000B0?ooo`030000o`3oool0oooo
0100oooo00<0o`000?3ol03`oo003`3`oo000`00o`00l?o`0?3ol0270?3o
l4l0oooo0`000?l?0?ooo`030?l0003oool0oooo00T0oooo0P000?l;0?oo
o`030?l0003`oo00l?o`00d0l?o`00<00?l00?3ol03`oo00A`3`oo090?oo
o`00C@3ooolB0000od/0oooo103o000O0?ooo`80003o5P3oool20?l00140
oooo0P000?lA0?ooo`030?l0003`oo00l?o`00h0l?o`00<00?l00?3ol03`
oo00Q`3`oo150?ooo`X0003o403oool20?l000/0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000l?o`0?3ol00>0?3ol003003o003`oo00l?o`04L0
l?o`2@3oool005l0oooo40000?lo0?ooo`@0o`007@3oool20000oaH0oooo
00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
003`oo00l?o`00d0l?o`00<00?l00?3ol03`oo00Q`3`oo0n0?ooo`L0003o
603oool20?l000`0oooo00<0003o0?ooo`3oool02P3oool00`3o0000l?o`
0?3ol00?0?3ol003003o003`oo00l?o`04L0l?o`2@3oool006l0oooo1`00
0?ll0?ooo`@0o`006`3oool20000oaD0oooo0P3o000A0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?3ol03`oo00303`oo000`00o`00l?o`0?3o
l0270?3ol3L0oooo1`000?lM0?ooo`80o`003@3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003`oo00l?o`0100l?o`00<00?l00?3ol03`oo00A`3`
oo090?ooo`00MP3oool90000ocL0oooo0`3o000J0?ooo`80003o5@3oool2
0?l00100oooo0P000?l@0?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l0
0?3ol03`oo00Q`3`oo0S0?oooa@0003o8P3oool20?l000d0oooo0P000?l<
0?ooo`030?l0003`oo00l?o`0140l?o`00<00?l00?3ol03`oo00A`3`oo09
0?ooo`00O`3oool90000oc40oooo0P3o000J0?ooo`80003o5@3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?3o
l03`oo002P3`oo000`00o`00l?o`0?3ol0270?3ol1X0oooo2@000?lb0?oo
o`@0o`003P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003`oo00l?o`
0180l?o`00<00?l00?3ol03`oo00A`3`oo090?ooo`00R03oool60000obd0
oooo0P3o000J0?ooo`80003o503oool20?l00100oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000l?o`0?3ol0090?3ol003003o003`oo00l?o`08L0
l?o`D@3oool40?l00140oooo00<0003o0?ooo`3oool02`3oool00`3o0000
l?o`0?3ol00C0?3ol003003o003`oo00l?o`04L0l?o`2@3oool008h0oooo
1P000?lY0?ooo`<0o`006@3oool20000oa@0oooo0P3o000?0?ooo`80003o
3`3oool00`3o0000l?o`0?3ol0080?3ol003003o003`oo00l?o`08L0l?o`
C@3oool40?l001<0oooo0P000?l=0?ooo`030?l0003`oo00l?o`01@0l?o`
00<00?l00?3ol03`oo00A`3`oo090?ooo`00U03oool60000obH0oooo0P3o
000I0?ooo`80003o503oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?3ol03`oo001`3`oo000`00o`00l?o`0?3o
l0270?3ol4L0oooo1P3o000F0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?3ol03`oo005@3`oo000`00o`00l?o`0?3ol0170?3ol0T0oooo002J
0?ooo`D0003o8`3oool20?l001T0oooo00<0003o0?ooo`3oool04P3oool2
0?l000l0oooo0P000?l>0?ooo`030?l0003`oo00l?o`00H0l?o`00<00?l0
0?3ol03`oo00Q`3`oo0h0?ooo`l0o`006P3oool20000o`h0oooo00<0o`00
0?3ol03`oo005P3`oo000`00o`00l?o`0?3ol0170?3ol0T0oooo002O0?oo
o`@0003o8@3oool30?l001L0oooo0P000?lD0?ooo`80o`003`3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003`oo00l?o`00D0l?o`00<00?l00?3o
l03`oo00Q`3`oo0J0?oooah0o`009`3oool20000o`l0oooo00<0o`000?3o
l03`oo005`3`oo000`00o`00l?o`0?3ol0170?3ol0T0oooo001=0?ooo`X0
o`00C03oool40000ob00oooo0P3o000G0?ooo`80003o503oool00`3o0000
oooo0?ooo`0=0?ooo`80003o3@3oool00`3o0000l?o`0?3ol0040?3ol003
003o003`oo00l?o`08L0l?o`GP3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003`oo00l?o`01P0l?o`00<00?l00?3ol03`oo00A`3`oo090?ooo`00
E`3oool<0?l004@0oooo10000?lN0?ooo`80o`005`3oool20000oa<0oooo
0P3o000?0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?3ol03`oo00
0`3`oo000`00o`00l?o`0?3ol0270?3ol5T0oooo1@000?l@0?ooo`030?l0
003`oo00l?o`01T0l?o`00<00?l00?3ol03`oo00A`3`oo090?ooo`00H`3o
ool=0?l003/0oooo10000?lL0?ooo`80o`005`3oool20000oa<0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003`
oo00l?o`0080l?o`00<00?l00?3ol03`oo00Q`3`oo1G0?ooo`80003o503o
ool00`3o0000l?o`0?3ol00J0?3ol003003o003`oo00l?o`04L0l?o`2@3o
ool00700oooo2@3o000f0?ooo`@0003o6P3oool30?l001H0oooo00<0003o
0?ooo`3oool04@3oool20?l000h0oooo0P000?l<0?ooo`050?l0003`oo00
l?o`0?3ol000o`00R@3`oo1>0?ooo`T0003o5@3oool00`3o0000l?o`0?3o
l00K0?3ol003003o003`oo00l?o`04L0l?o`2@3oool007T0oooo1P3o000d
0?ooo`@0003o6@3oool20?l001D0oooo0P000?lC0?ooo`80o`003P3oool0
0`000?l0oooo0?ooo`0:0?ooo`040?l0003`oo00l?o`003o08T0l?o`>@3o
oolE0000oad0oooo00<0o`000?3ol03`oo00703`oo000`00o`00l?o`0?3o
l0170?3ol0T0oooo001o0?ooo`H0o`00<P3oool20000oaT0oooo0P3o000E
0?ooo`80003o4`3oool00`3o0000oooo0?ooo`0<0?ooo`80003o2`3oool0
0`3o0000l?o`003o00290?3ol1X0oooo7`000?la0?ooo`030?l0003`oo00
l?o`01d0l?o`00<00?l00?3ol03`oo00A`3`oo090?ooo`00Q@3oool60?l0
02h0oooo0`000?lH0?ooo`<0o`00503oool20000oa80oooo0P3o000>0?oo
o`030000o`3oool0oooo00T0oooo00<0o`00003o003`oo00R03`oo1Y0?oo
o`030?l0003`oo00l?o`01h0l?o`00<00?l00?3ol03`oo00A`3`oo090?oo
o`00R`3oool60?l002/0oooo0`000?lH0?ooo`80o`00503oool20000oa80
oooo0P3o000=0?ooo`80003o2P3oool00`00o`00o`000?l000280?l006L0
oooo00<0o`000?3ol03`oo007`3`oo000`00o`00l?o`0?3ol0170?3ol0T0
oooo002A0?ooo`H0o`00:03oool20000oaP0oooo0P3o000D0?ooo`80003o
4P3oool00`3o0000oooo0?ooo`0<0?ooo`80003on@3oool00`3o0000l?o`
0?3ol00P0?3ol003003o003`oo00l?o`04L0l?o`2@3oool009L0oooo1P3o
000T0?ooo`<0003o5`3oool30?l001<0oooo0P000?lA0?ooo`80o`003P3o
ool20000ooH0oooo00<0o`000?3ol03`oo008@3`oo000`00o`00l?o`0?3o
l0170?3ol0T0oooo001=0?ooo`T0003oA`3oool60?l00240oooo0P000?lH
0?ooo`80o`004`3oool20000oa40oooo0P3o000>0?ooo`<0003ol@3oool0
0`00o`00o`000?3ol00S0?3ol003003o003`oo00l?o`04L0l?o`2@3oool0
05H0oooo30000?m10?ooo`D0o`007P3oool30000oaL0oooo0P3o000C0?oo
o`80003o4@3oool20?l000l0oooo0P000?nU0?ooodX0o`00L@00o`080?oo
o`00HP3oool:0000oc`0oooo0`3o000N0?ooo`80003o5`3oool30?l00180
oooo0`000?l@0?ooo`80o`003`3oool:0000onH0oooo00<0o`000?3ol03`
oo008P3`oo000`00o`00l?o`0?3ol0170?3ol0T0oooo001/0?ooo`P0003o
=`3oool30?l001d0oooo0`000?lG0?ooo`80o`004`3oool20000oa00oooo
0P3o000G0?ooo`h0003of@3oool00`3o0000l?o`0?3ol00Q0?3ol003003o
003`oo00l?o`04L0l?o`2@3oool007@0oooo20000?lb0?ooo`<0o`007@3o
ool30000oaH0oooo0P3o000C0?ooo`80003o403oool20?l002<0oooo=000
0?nV0?ooo`030?l0003`oo00l?o`0200l?o`00<00?l00?3ol03`oo00A`3`
oo090?ooo`00O03oool70000obh0oooo0`3o000M0?ooo`80003o5P3oool2
0?l001<0oooo0P000?l@0?ooo`@0o`00D`3ooom00000ofL0oooo00<0o`00
0?3ol03`oo007`3`oo000`00o`00l?o`0?3ol0170?3ol0T0oooo00230?oo
o`H0003o:`3oool30?l001`0oooo0`000?lE0?ooo`80o`004`3oool30000
oa40oooo103o002X0?oooa40003o?P3oool00`3o0000l?o`0?3ol00N0?3o
l003003o003`oo00l?o`04L0l?o`2@3oool008T0oooo1`000?lW0?ooo`<0
o`00703oool20000oaD0oooo0`3o000C0?ooo`80003o4`3oool40?l00;D0
oooo7`000?lP0?ooo`030?l0003`oo00l?o`01d0l?o`00<00?l00?3ol03`
oo00A`3`oo090?ooo`00T03oool60000ob@0oooo0`3o000K0?ooo`<0003o
5@3oool20?l001<0oooo0`000?lD0?ooo`@0o`00d03oool90000oaP0oooo
00<0o`000?3ol03`oo00703`oo000`00o`00l?o`0?3ol0170?3ol0T0oooo
002F0?ooo`D0003o8P3oool30?l001/0oooo0`000?lD0?ooo`80o`00503o
ool30000oaD0oooo2`3o003>0?ooo`H0003o4`3oool00`3o0000l?o`0?3o
l00K0?3ol003003o003`oo00l?o`04L0l?o`2@3oool004d0oooo1`3o0017
0?ooo`@0003o8@3oool30?l001/0oooo0P000?lD0?ooo`80o`005@3oool2
0000oah0oooo4@3o00330?ooo`80003o4P3oool00`3o0000l?o`0?3ol00J
0?3ol003003o003`oo00l?o`04L0l?o`2@3oool005@0oooo303o000o0?oo
o`@0003o803oool30?l001X0oooo0`000?lC0?ooo`<0o`00503oool30000
ob`0oooo5P3o002_0?ooo`80003o4@3oool00`3o0000l?o`0?3ol00I0?3o
l003003o003`oo00l?o`04L0l?o`2@3oool00600oooo2P3o000i0?ooo`@0
003o7`3oool40?l001T0oooo0P000?lD0?ooo`<0o`00503oool40000och0
oooo>P3o000d0?oooaL0o`00;03oool20000oa00oooo00<0o`000?3ol03`
oo00603`oo000`00o`00l?o`0?3ol0170?3ol0T0oooo001Z0?ooo`P0o`00
=@3oool40000oal0oooo0`3o000H0?ooo`<0003o503oool40?l001@0oooo
10000?md0?oooa/0o`00<03oool@0?l001h0oooo0P000?l?0?ooo`030?l0
003`oo00l?o`01L0l?o`00<00?l00?3ol03`oo00A`3`oo090?ooo`00LP3o
ool80?l00340oooo10000?lN0?ooo`<0o`00603oool30000oaD0oooo0`3o
000E0?ooo`L0003ob03oool60?l001X0oooo0P000?l>0?ooo`030?l0003`
oo00l?o`01H0l?o`00<00?l00?3ol03`oo00A`3`oo090?ooo`00NP3oool7
0?l002h0oooo0`000?lN0?ooo`<0o`00603oool20000oaH0oooo0`3o000I
0?ooo`T0003oa@3oool90?l001<0oooo0P000?l=0?ooo`030?l0003`oo00
l?o`01D0l?o`00<00?l00?3ol03`oo00A`3`oo090?ooo`00P@3oool60?l0
02/0oooo0`000?lN0?ooo`<0o`005`3oool30000oaH0oooo0P3o000P0?oo
o`X0003oa03oool40?l00140oooo0P000?l<0?ooo`030?l0003`oo00l?o`
01@0l?o`00<00?l00?3ol03`oo00A`3`oo090?ooo`00Q`3oool60?l002P0
oooo10000?lM0?ooo`<0o`005`3oool30000oaD0oooo0`3o000W0?ooo`T0
003oQ@3oool30000ocL0oooo0`3o000@0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?3ol03`oo004`3`oo000`00o`00l?o`0?3ol0170?3ol0T0
oooo002=0?ooo`H0o`009P3oool30000oad0oooo0`3o000G0?ooo`80003o
5P3oool40?l002`0oooo4@000?mg0?oooa<0003o9`3oool20?l000l0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000l?o`0?3ol00B0?3ol003003o
003`oo00l?o`04L0l?o`2@3oool009<0oooo1P3o000S0?ooo`<0003o7@3o
ool30?l001H0oooo0`000?lG0?ooo`D0o`00>03ooolI0000og40oooo3P00
0?lK0?ooo`<0o`003@3oool20000o`/0oooo00<0o`000?3ol03`oo004@3`
oo000`00o`00l?o`0?3ol0170?3ol0T0oooo001=0?ooo`H0003oAP3oool5
0?l00240oooo10000?lL0?ooo`<0o`005P3oool40000oaP0oooo1@3o001<
0?ooobh0003oD@3oool70000oaL0oooo0P3o000=0?ooo`030000o`3oool0
oooo00T0oooo0P3o000A0?3ol003003o003`oo00l?o`04L0l?o`2@3oool0
05<0oooo2`000?m00?ooo`@0o`008@3oool30000oa`0oooo0`3o000G0?oo
o`@0003o6@3oool40?l007H0oooo50000?m40?ooo`D0003o503oool20?l0
00`0oooo00<0003o0?ooo`3oool02P3oool00`3o0000l?o`0?3ol00>0?3o
l003003o003`oo00l?o`04L0l?o`2@3oool005h0oooo2P000?lj0?ooo`D0
o`007`3oool30000oa`0oooo0`3o000H0?ooo`<0003o6P3oool70?l00<`0
oooo10000?lB0?ooo`80o`002`3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003`oo00l?o`00d0l?o`00<00?l00?3ol03`oo00A`3`oo090?ooo`00
J03oool80000ocL0oooo1@3o000M0?ooo`<0003o703oool40?l001L0oooo
10000?lM0?ooo`T0o`00T`3oool80?l002`0oooo10000?l@0?ooo`80o`00
2P3oool20000o`/0oooo00<0o`000?3ol03`oo00303`oo000`00o`00l?o`
0?3ol0170?3ol0T0oooo001`0?ooo`P0003o=03oool40?l001`0oooo1000
0?lL0?ooo`<0o`00603oool40000ob80oooo2@3o002B0?ooo`h0o`008P3o
ool40000o`h0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003`oo00l?o`00/0l?o`00<00?l00?3ol03`oo00A`3`
oo090?ooo`00N03oool70000oc40oooo103o000L0?ooo`<0003o703oool3
0?l001T0oooo10000?lW0?oooaL0o`00R@3oool<0?l001X0oooo0`000?l<
0?ooo`80o`002P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003`oo00
l?o`00X0l?o`00<00?l00?3ol03`oo00A`3`oo090?ooo`00O`3oool60000
obl0oooo0`3o000L0?ooo`<0003o703oool30?l001X0oooo1@000?li0?oo
oa<0o`00PP3oool70?l001H0oooo0P000?l<0?ooo`030?l0003oool0oooo
00P0oooo0P000?l:0?ooo`030?l0003`oo00l?o`00T0l?o`00<00?l00?3o
l03`oo00A`3`oo090?ooo`00Q@3oool60000ob`0oooo103o000K0?ooo`@0
003o6`3oool40?l001/0oooo1@000?m70?oooa80o`00M`3oool50?l001<0
oooo0P000?l;0?ooo`80o`002P3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003`oo00l?o`00P0l?o`00<00?l00?3ol03`oo00A`3`oo090?ooo`00
R`3oool60000obX0oooo0`3o000L0?ooo`<0003o703oool40?l001`0oooo
1@000?mD0?oooa`0o`00H03oool40?l00140oooo0P000?l;0?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000l?o`
0?3ol0070?3ol003003o003`oo00l?o`04L0l?o`2@3oool00940oooo1P00
0?lW0?ooo`@0o`006`3oool30000oad0oooo0`3o000N0?ooo`L0003oJ@3o
oolI0?l001T0oooo2P000?lX0?ooo`@0o`003`3oool20000o`X0oooo0P3o
00090?ooo`80003o2@3oool00`3o0000l?o`0?3ol0060?3ol003003o003`
oo00l?o`04L0l?o`2@3oool004d0oooo1P3o00140?ooo`@0003o9`3oool3
0?l001/0oooo10000?lL0?ooo`@0o`008@3oool:0000oi/0oooo4@000?lK
0?ooo`D0o`00303oool20000o`X0oooo0P3o00090?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?3ol03`oo001@3`oo000`00o`00l?o`0?3ol017
0?3ol0T0oooo001C0?ooo`X0o`00?P3oool50000obD0oooo103o000K0?oo
o`@0003o703oool40?l002L0oooo2@000?nS0?ooo`H0003o6P3oool20?l0
00`0oooo0P000?l:0?ooo`030?l0003oool0oooo00L0oooo0P000?l80?oo
o`030?l0003`oo00l?o`00@0l?o`00<00?l00?3ol03`oo00A`3`oo090?oo
o`00G@3oool90?l003X0oooo1@000?lT0?ooo`<0o`00703oool40000oa`0
oooo103o000/0?ooo`X0003oW`3oool60000oaH0oooo0P3o000<0?ooo`80
003o2@3oool20?l000T0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
l?o`0?3ol0030?3ol003003o003`oo00l?o`04L0l?o`2@3oool006H0oooo
203o000g0?ooo`@0003o8`3oool40?l001`0oooo10000?lL0?ooo`D0o`00
<@3oool?0000oiH0oooo1@000?lC0?ooo`80o`00303oool20000o`T0oooo
00<0o`000?ooo`3oool01`3oool20000o`L0oooo00<0o`000?3ol03`oo00
0P3`oo000`00o`00l?o`0?3ol0170?3ol0T0oooo001^0?ooo`P0o`00<`3o
ool40000ob<0oooo0`3o000M0?ooo`@0003o7@3oool50?l003/0oooo4`00
0?mL0?ooo`T0o`008`3oool40000oa40oooo0P3o000<0?ooo`030000o`3o
ool0oooo00L0oooo0P3o00090?ooo`030000o`3oool0oooo00D0oooo00D0
o`000?3ol03`oo00l?o`003o00190?3ol0T0oooo001f0?ooo`L0o`00<03o
ool40000ob80oooo103o000M0?ooo`@0003o7P3oool60?l004P0oooo5000
0?mA0?ooo`X0o`007@3oool30000oa00oooo0P3o000;0?ooo`80003o2@3o
ool20?l000P0oooo0P000?l60?ooo`040?l0003`oo00l?o`003o04T0l?o`
2@3oool007d0oooo1P3o000^0?ooo`@0003o8P3oool30?l001h0oooo0`00
0?lQ0?ooo`H0o`00EP3ooolV0000ocD0oooo1P3o000J0?ooo`@0003o3P3o
ool30?l000X0oooo0P000?l90?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool0103oool00`3o0000l?o`003o00190?3ol0T0oooo0023
0?ooo`H0o`00;03oool40000ob40oooo103o000M0?ooo`@0003o8`3oool6
0?l007H0oooo2@000?lb0?ooo`L0o`005`3oool30000o`h0oooo0P3o000:
0?ooo`80003o203oool20?l000P0oooo0P000?l50?ooo`030?l00000o`00
l?o`04P0l?o`2@3oool008T0oooo1P3o000Z0?ooo`@0003o8@3oool40?l0
01d0oooo0`000?lV0?ooo`H0o`00/P3oool60?l001@0oooo0P000?l>0?oo
o`80o`002P3oool20000o`P0oooo0P3o00080?ooo`030000o`3oool0oooo
00<0oooo00<00?l00?l0003o0000B03o00080?ooo`00S`3oool60?l002P0
oooo10000?lQ0?ooo`@0o`00703oool40000obP0oooo3@3o002[0?ooo`L0
o`003`3oool30000o`d0oooo0P3o000:0?ooo`80003o203oool20?l000L0
oooo0P000?mF0?ooo`00C@3oool50000od<0oooo1P3o000V0?ooo`@0003o
8@3oool40?l001`0oooo10000?la0?ooo`l0o`00MP3oool70000obH0oooo
1@3o000=0?ooo`<0003o303oool20?l000X0oooo0P000?l80?ooo`80o`00
1`3oool40000oe80oooo001B0?ooo`P0003o@@3oool60?l002@0oooo1000
0?lQ0?ooo`@0o`00703oool60000ocX0oooo2@3o001d0?ooo`d0003o7P3o
ool30?l000d0oooo0P000?l<0?ooo`<0o`002@3oool20000o`P0oooo0`3o
00080?ooo`/0003oA`3oool005X0oooo20000?lo0?ooo`H0o`008P3oool4
0000ob40oooo103o000N0?ooo`D0003o?P3oool>0?l007<0oooo2`000?lF
0?ooo`<0o`00303oool30000o``0oooo0`3o00080?ooo`80003o2@3oool2
0?l00140oooo?`000?l80?ooo`00HP3oool90000oc`0oooo1@3o000Q0?oo
o`@0003o8@3oool40?l001l0oooo1P000?m60?ooobP0o`00EP3oool50000
oa@0oooo0`3o000<0?ooo`<0003o303oool20?l000P0oooo0`000?l80?oo
o`@0o`00E03oool006/0oooo20000?li0?ooo`@0o`008@3oool40000ob40
oooo103o000Q0?ooo`L0003oI`3ooolD0?l004L0oooo10000?lC0?ooo`<0
o`00303oool20000o``0oooo0`3o00080?ooo`@0003o203oool50?l004l0
oooo001c0?ooo`P0003o=@3oool40?l00240oooo10000?lQ0?ooo`@0o`00
903oool:0000og40oooo2P3o000I0?ooo`H0o`008P3oool30000oa<0oooo
0`3o000;0?ooo`<0003o303oool30?l000T0oooo0P000?l;0?oooa80o`00
?@3oool007/0oooo1`000?lb0?ooo`@0o`008@3oool40000ob40oooo103o
000Z0?ooo`X0003oT03oool:0?l001/0oooo10000?lB0?ooo`<0o`002`3o
ool30000o``0oooo0P3o00090?ooo`@0003o6@3oool`0?l000d0oooo0022
0?ooo`P0003o;P3oool40?l00240oooo1@000?lP0?ooo`D0o`00;`3oool:
0000oi00oooo1`3o000H0?ooo`@0003o4@3oool30?l000/0oooo0`000?l;
0?ooo`<0o`002P3oool40000odD0oooo1@3o00080?ooo`00RP3oool60000
ob`0oooo1@3o000Q0?ooo`D0003o803oool50?l003@0oooo2`000?n<0?oo
o`L0o`005@3oool40000oa00oooo0`3o000;0?ooo`80003o303oool30?l0
00/0oooo1@000?m=0?ooo`00T03oool60000ob/0oooo103o000R0?ooo`@0
003o8@3oool60?l003T0oooo2`000?n80?ooo`H0o`004`3oool40000o`l0
oooo0`3o000:0?ooo`<0003o303oool40?l000`0oooo3`000?ln0?ooo`00
UP3oool60000obT0oooo103o000R0?ooo`D0003o8P3oool50?l003l0oooo
3`000?mK0?ooo`<0003o8@3oool60?l00140oooo0`000?l?0?ooo`<0o`00
2P3oool30000o`d0oooo1@3o000F0?oooa`0003o8P3oool009`0oooo1P00
0?lW0?ooo`@0o`008`3oool50000ob80oooo1`3o00170?ooobH0003o>03o
ool60000ob40oooo103o000@0?ooo`@0003o3P3oool30?l000X0oooo0`00
0?l?0?ooo`D0o`00;@3ooolJ0000o`P0oooo002R0?ooo`H0003o9@3oool4
0?l002@0oooo1@000?lT0?ooo`X0o`00H`3ooolB0000ob`0oooo2P000?lK
0?ooo`@0o`00403oool40000o`d0oooo0P3o000;0?ooo`@0003o403oool5
0?l004X0oooo002X0?ooo`@0003o9@3oool50?l002@0oooo1@000?lY0?oo
o`X0o`00J`3oool:0000ob`0oooo2P000?lE0?ooo`@0o`00403oool30000
o``0oooo0`3o000<0?ooo`H0003o3`3ooolA0?l003T0oooo002/0?ooo`D0
003o9@3oool50?l002@0oooo1@000?l^0?ooo`X0o`00X@3oool60000oa<0
oooo103o000?0?ooo`@0003o2`3oool30?l000l0oooo1@000?lK0?oooa@0
o`009@3oool00;40oooo1@000?lU0?ooo`D0o`00903oool60000oc80oooo
2P3o002M0?ooo`D0003o4P3oool40?l000l0oooo0`000?l;0?ooo`@0o`00
403oool60000obT0oooo7@3o00080?ooo`00]P3oool40000obH0oooo1@3o
000U0?ooo`D0003o=`3oool90?l00740oooo1P3o000R0?ooo`@0003o4P3o
ool40?l000h0oooo10000?l;0?ooo`@0o`004P3oool50000odT0oooo002j
0?ooo`D0003o9P3oool40?l002H0oooo1P000?lj0?ooo`h0o`00J@3oool9
0?l001d0oooo10000?lB0?ooo`@0o`003P3oool40000o`/0oooo1@3o000B
0?ooo`X0003o?`3oool00;l0oooo10000?lV0?ooo`D0o`009`3oool60000
od80oooo5@3o001M0?ooo`H0o`006`3oool40000oa80oooo103o000>0?oo
o`<0003o3@3oool60?l001H0oooo4`000?l/0?ooo`00``3oool50000obH0
oooo1@3o000X0?ooo`H0003oD@3ooolE0?l004h0oooo1`3o000H0?ooo`@0
003o4P3oool30?l000h0oooo10000?l?0?ooo`H0o`008`3ooolT0000o`P0
oooo00380?ooo`D0003o9P3oool50?l002T0oooo1P000?mP0?oooa@0o`00
@@3oool60?l001H0oooo10000?lA0?ooo`@0o`003P3oool40000oa40oooo
1@3o001:0?ooo`00c@3oool40000obL0oooo1@3o000Z0?ooo`P0003oK03o
ool<0?l001T0oooo10000?lN0?ooo`H0o`00503oool40000oa40oooo103o
000>0?ooo`@0003o4P3oool80?l00480oooo003A0?ooo`D0003o9`3oool5
0?l002d0oooo2P000?n;0?ooo`L0003o7@3oool60?l00180oooo10000?lA
0?ooo`@0o`003P3oool60000oa@0oooo503o000^0?ooo`00eP3oool60000
obH0oooo1@3o000b0?ooo`/0003oQ`3oool80000oa/0oooo1P3o000@0?oo
o`@0003o4@3oool40?l00100oooo1P000?lR0?oooaH0o`00603oool00=`0
oooo1@000?lV0?ooo`D0o`00>03oool;0000oh@0oooo1P000?lK0?ooo`@0
o`00403oool40000oa40oooo103o000B0?ooo`H0003o<P3oool@0?l000P0
oooo003Q0?ooo`D0003o9P3oool50?l003h0oooo40000?mj0?ooo`H0003o
6@3oool50?l000l0oooo10000?lA0?ooo`@0o`00503oool80000od80oooo
003V0?ooo`H0003o9@3oool80?l004H0oooo50000?m/0?ooo`L0003o5`3o
ool50?l000h0oooo10000?lA0?ooo`H0o`005P3ooolF0000ob`0oooo003/
0?ooo`D0003o:03oool;0?l004l0oooo4`000?mP0?ooo`H0003o5P3oool4
0?l000h0oooo1@000?lB0?ooo`P0o`00903ooolI0000oa<0oooo003a0?oo
o`D0003o;P3oool90?l005T0oooo50000?mB0?ooo`H0003o503oool50?l0
00h0oooo1P000?lD0?ooo`P0o`00=@3oool;0000o`P0oooo003f0?ooo`H0
003o<@3oool70?l006H0oooo3@000?m;0?ooo`D0003o503oool50?l000l0
oooo1@000?lG0?ooo`H0o`00@P3oool00?`0oooo1P000?lb0?ooo`P0o`00
^`3oool50000oa@0oooo103o000@0?ooo`H0003o5`3ooolB0?l00300oooo
003o0?ooo`<0oooo1P000?ld0?ooo`T0o`00]`3oool50000oa<0oooo1@3o
000A0?ooo`H0003o8`3oool;0?l002D0oooo003o0?ooo`T0oooo1`000?lf
0?ooo`X0o`00/P3oool50000oa<0oooo1@3o000B0?ooo`D0003o:@3ooolM
0?l000P0oooo003o0?oooa00oooo1`000?li0?ooo`l0o`00Z03oool50000
oa<0oooo1@3o000B0?ooo`P0003oAP3oool00?l0oooo5`3oool60000od80
oooo5@3o002H0?ooo`@0003o503oool60?l001@0oooo2`000?lk0?ooo`00
o`3ooolM0?ooo`L0003oD03ooolE0?l008L0oooo1@000?lE0?ooo`D0o`00
6P3ooolG0000ob@0oooo003o0?ooob@0oooo2@000?mL0?oooa@0o`00N03o
ool50000oaD0oooo1P3o000[0?oooa00003o503oool00?l0oooo;@3oool:
0000ofH0oooo2`3o001b0?ooo`@0003o5`3oool90?l00380oooo30000?l8
0?ooo`00o`3ooolg0?ooo`/0003og03oool60000oaX0oooo303o000j0?oo
o`00o`3ooom20?ooo`/0003oe`3oool70000oal0oooo2`3o000_0?ooo`00
o`3ooom=0?ooo`/0003od`3oool80000ob80oooo703o000C0?ooo`00o`3o
oomH0?ooo`X0003od@3oool90000ocD0oooo2`3o00080?ooo`00o`3ooomR
0?oooa00003obP3oool;0000ocd0oooo003o0?ooog80oooo5P000?no0?oo
o``0003o<@3oool00?l0ooooR03ooolE0000okH0oooo30000?lU0?ooo`00
o`3ooonM0?ooo`/0003o]`3ooolA0000oa@0oooo003o0?ooool0ooooL@3o
ool<0000o`P0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{643, 178},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.92",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/fluidflowimage/\
FluidFlowImageFigures/mat1192.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  (a) Flow up an inclined step\n\t\t\t\t\t(b) Flow around a pointed \
object."
}], "Text"],

Cell[TextData[{
  "Solution.  Set  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 1\)}]]],
  ".  In the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  "-plane ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = \[ImaginaryI]\)}]]],
  ", and the exterior angles are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(\[Pi]\/4\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", \(-\(\[Pi]\/4\)\)}]}]]],
  ",  and the formula for the derivative ",
  Cell[BoxData[
      \(f' \((z)\)\)]],
  " is  \n\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \((z - 0)\)\^\(\(-\
\[Alpha]\_1\)/\[Pi]\)\ \((z - 1)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \((z)\)\^\(\(-\((\
\[Pi]\/4)\)\)/\[Pi]\)\ \((z - \
1)\)\^\(\(-\((\(-\(\[Pi]\/4\)\))\)\)/\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \((z)\)\^\(-\(1\/4\
\)\)\ \((z - 1)\)\^\(1\/4\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ \((z - 1)\)\^\(1\/4\
\)\/z\^\(1\/4\)\)\)\)}]]
}], "Text"],

Cell[TextData[{
  "Integrate and get  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(f \((z)\)\ \  = \ \ B\ \  + \ \ A\ \(\[Integral]\(\((z - \
1)\)\^\(1\/4\)\/z\^\(1\/4\)\) \[DifferentialD]z\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(B\  + \ 
          A \((\((z - 1)\)\^\(1\/4\)\ z\^\(3\/4\) - \(1\/2\) 
                  Arctan \((\((1 - 1\/z)\)\^\(1\/4\))\) + \(1\/4\) 
                  Log \( 1 - \((1 - 1\/z)\)\^\(1\/4\)\)\/\(1 + \((1 - 1\/z)\)\
\^\(1\/4\)\))\)\)\)\)}]],
  " \n\nSolve for the coefficients A and B and obtain \n\n\t\t\t",
  Cell[BoxData[
      \(f \((z)\)\ \  = \ \[ImaginaryI]\  + \ \(1\/\[Pi]\) \((4 \((z - 1)\)\^\
\(1\/4\)\ z\^\(3\/4\) - 2  Arctan \((\((1 - 1\/z)\)\^\(1\/4\))\) + 
                Log \( 1 - \((1 - 1\/z)\)\^\(1\/4\)\)\/\(1 + \((1 - 1\/z)\)\^\
\(1\/4\)\))\)\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 5.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(f[
          z_]\  = \ \[ImaginaryI]\  + \ \(1\/\[Pi]\) \((4 \((z - 1)\)\^\(1\/4\
\)\ z\^\(3\/4\) - 2  ArcTan[\((1 - 1\/z)\)\^\(1\/4\)] + 
                Log[\(1 - \((1 - 1\/z)\)\^\(1\/4\)\)\/\(1 + \((1 - \
1\/z)\)\^\(1\/4\)\)])\);\)\), "\[IndentingNewLine]", 
    \(\(Print["\< f[z] = \>", f[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", \(f'\)[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f'[z] = \>", 
        MapAll[FullSimplify, 
          Together[\ \(f'\)[z]]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[BoxData[
    \(\(\(\(Print["\<f[z] = \>", f[z]\ ];\)\ \[IndentingNewLine]
    \(Print["\<f[0] = \>", 
        Chop[f[0 + 
              0.000000000000001  \[ImaginaryI]]]\ ];\)\ \[IndentingNewLine]
    \(Print["\<f[1] = \>", 
        Chop[f[1 + 0.00000000001  \[ImaginaryI]]]\ ];\)\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\(f[
          z_]\  = \ \[ImaginaryI]\  + \ \(1\/\[Pi]\) \((4 \((z - 1)\)\^\(1\/4\
\)\ z\^\(3\/4\) - 2  ArcTan[\((1 - 1\/z)\)\^\(1\/4\)] + 
                Log[\(1 - \((1 - 1\/z)\)\^\(1\/4\)\)\/\(1 + \((1 - \
1\/z)\)\^\(1\/4\)\)])\);\)\[IndentingNewLine]
    \(Needs["\<Graphics`Colors`\>"];\)\ \[IndentingNewLine]
    \(Needs["\<Graphics`ComplexMap`\>"];\)\ \[IndentingNewLine]
    \(CartesianMap[f, {\(-4\), 8, 0.5}, {0.00001, 4.00001, 0.2}, 
        PlotStyle \[Rule] {Blue, Red}, 
        PlotRange \[Rule] {{\(-1.5\), 3.5}, {0, 
              4.3}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-2\), 4, 
              1], {\[Pi]\/2, \[Pi]}}];\)\ \ \[IndentingNewLine]
    \(Print["\<The image of the upper half plane Im[z] > 0 under the \
mapping\>"];\)\ \[IndentingNewLine]
    \(Print["\<w = f[z] = \>", f[z]];\)\)\(\ \)\)\)], "Input"],

Cell[BoxData[{
    \(\(f[
          z_]\  = \ \[ImaginaryI]\  + \ \(1\/\[Pi]\) \((4 \((z - 1)\)\^\(1\/4\
\)\ z\^\(3\/4\) - 2  ArcTan[\((1 - 1\/z)\)\^\(1\/4\)] + 
                Log[\(1 - \((1 - 1\/z)\)\^\(1\/4\)\)\/\(1 + \((1 - \
1\/z)\)\^\(1\/4\)\)])\);\)\), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.1  k]]}, {k, 1, 11, 2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {x, \(-6\), 6}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.1  k]]}, {k, 2, 11, 2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {x, \(-6\), 6}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Red, Line[{{\(-3\), 0}, {\(-1\), 0}}], 
            Line[{{\(-1\), 0}, {0, 1}}], 
            Line[{{0, 1}, {2, 1}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, boundary, 
        PlotRange \[Rule] {{\(-3\), 2}, {\(-0.1\), 2.3}}, 
        AspectRatio \[Rule] 2.4\/5, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0, 1, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow across the upper half plane Im[z] > 0,\
\>"];\)\ \), "\n", 
    \(\(Print["\<under w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f[
          z_]\  = \ \[ImaginaryI]\  + \ \(1\/\[Pi]\) \((4 \((z - 1)\)\^\(1\/4\
\)\ z\^\(3\/4\) - 2  ArcTan[\((1 - 1\/z)\)\^\(1\/4\)] + 
                Log[\(1 - \((1 - 1\/z)\)\^\(1\/4\)\)\/\(1 + \((1 - \
1\/z)\)\^\(1\/4\)\)])\);\)\), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.1  k]]}, {k, 1, 11, 2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {x, \(-6\), 6}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[f[x + \[ImaginaryI]\ 0.2  k]], 
            Im[f[x + \[ImaginaryI]\ 0.1  k]]}, {k, 2, 11, 2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {x, \(-6\), 6}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns3\  = \ 
        Table[{Re[
              f[x + \[ImaginaryI]\ 0.2  k]], \(-Im[
                f[x + \[ImaginaryI]\ 0.1  k]]\)}, {k, 1, 11, 
            2}];\)\ \), "\n", 
    \(\(graph3 = 
        ParametricPlot[Evaluate[eqns3], {x, \(-6\), 6}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns4\  = \ 
        Table[{Re[
              f[x + \[ImaginaryI]\ 0.2  k]], \(-Im[
                f[x + \[ImaginaryI]\ 0.1  k]]\)}, {k, 2, 11, 
            2}];\)\ \), "\n", 
    \(\(graph4 = 
        ParametricPlot[Evaluate[eqns4], {x, \(-6\), 6}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Red, Line[{{\(-3\), 0}, {\(-1\), 0}}], 
            Line[{{\(-1\), 0}, {0, 1}}], Line[{{0, 1}, {2, 1}}], 
            Line[{{\(-1\), 0}, {0, \(-1\)}}], 
            Line[{{0, \(-1\)}, {2, \(-1\)}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, graph4, boundary, 
        PlotRange \[Rule] {{\(-3\), 2}, {\(-2.3\), 2.3}}, 
        AspectRatio \[Rule] 4.6\/5, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], Range[0, 1, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow across the z-plane,\>"];\)\ \), "\n", 
    \(\(Print["\<under w = f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We could let ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " do the integral."
}], "Text"],

Cell[BoxData[
    \(\(Print[\*"\"\<B + A \[Integral]\!\(\((z - \
1)\)\^\(1\/4\)\/z\^\(1\/4\)\)\[DifferentialD]z = \>\"", 
        B\ \  + \ \ A\ \(\[Integral]\(\((z - 1)\)\^\(1\/4\)\/z\^\(1\/4\)\) \
\[DifferentialD]z\)];\)\)], "Input"],

Cell[BoxData[{
    \(\(f[
          z_]\  = \ \(-2.8483970453558163\)\  + \ \(4\/\[Pi]\) \
\(\[Integral]\_\(-1\)\%z\(\((\[Xi] - 1)\)\^\(1\/4\)\/\[Xi]\^\(1\/4\)\) \
\[DifferentialD]\[Xi]\);\)\), "\[IndentingNewLine]", 
    \(\(f[
          z_]\  = \ \(-2.8483970453558163\)\  + \ \(4\/\[Pi]\) \
\(\[Integral]\(\((z - 1)\)\^\(1\/4\)\/z\^\(1\/4\)\) \[DifferentialD]z\);\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[0] = \>", 
        Chop[f[0 + 0.0  \[ImaginaryI]]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[1] = \>", 
        Chop[f[1 + 0.00000000001  \[ImaginaryI]]]\ ];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(f[
          z_]\  = \(-1\) + \ \(4\/\[Pi]\) \(\[Integral]\(\((z - \
1)\)\^\(1\/4\)\/z\^\(1\/4\)\) \[DifferentialD]z\);\)\), \
"\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(CartesianMap[f, {\(-4\), 8, 0.5}, {0.00001, 4.00001, 0.2}, 
        PlotStyle \[Rule] {Blue, Red}, 
        PlotRange \[Rule] {{\(-1.5\), 3.5}, {0, 
              4.3}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-2\), 4, 
              1], {\[Pi]\/2, \[Pi]}}];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0 under the \
mapping\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<w = f[z] = \>", f[z]];\)\ \)}], "Input"],

Cell["Which is the same as our solution.", "Text"],

Cell[BoxData[
    \(\(\(\(f[
          z_]\  = \ \[ImaginaryI]\  + \ \(1\/\[Pi]\) \((4 \((z - 1)\)\^\(1\/4\
\)\ z\^\(3\/4\) - 2  ArcTan[\((1 - 1\/z)\)\^\(1\/4\)] + 
                Log[\(1 - \((1 - 1\/z)\)\^\(1\/4\)\)\/\(1 + \((1 - \
1\/z)\)\^\(1\/4\)\)])\);\)\[IndentingNewLine]
    \(Needs["\<Graphics`Colors`\>"];\)\ \[IndentingNewLine]
    \(Needs["\<Graphics`ComplexMap`\>"];\)\ \[IndentingNewLine]
    \(CartesianMap[f, {\(-4\), 8, 0.5}, {0.00001, 4.00001, 0.2}, 
        PlotStyle \[Rule] {Blue, Red}, 
        PlotRange \[Rule] {{\(-1.5\), 3.5}, {0, 
              4.3}}, \[IndentingNewLine]Ticks \[Rule] {Range[\(-2\), 4, 
              1], {\[Pi]\/2, \[Pi]}}];\)\ \ \[IndentingNewLine]
    \(Print["\<The image of the upper half plane Im[z] > 0 under the \
mapping\>"];\)\ \[IndentingNewLine]
    \(Print["\<w = f[z] = \>", f[z]];\)\)\(\ \)\)\)], "Input"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Ideal Fluid Flow",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/FluidFlowBib.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Joukowski Transformation and Airfoils",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/JoukowskiTransBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Schwarz-Christoffel Transformation",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/SchwarzChristoffelBib.html"]\
, None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1009, 646},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 409505, 7511}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 118, 2, 33, "Text"],
Cell[2223, 66, 5861, 151, 259, "Text",
  Evaluatable->False],
Cell[8087, 219, 1975, 58, 62, "Text",
  Evaluatable->False],
Cell[10065, 279, 43146, 710, 192, 43032, 706, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[53214, 991, 382, 11, 52, "Text"],
Cell[53599, 1004, 2599, 76, 245, "Text"],
Cell[56201, 1082, 659, 14, 235, "Text"],
Cell[56863, 1098, 3120, 81, 271, "Text"],

Cell[CellGroupData[{
Cell[60008, 1183, 113, 2, 33, "Text"],
Cell[60124, 1187, 252, 6, 55, "Text"],
Cell[60379, 1195, 695, 15, 267, "Input"],
Cell[61077, 1212, 200, 5, 33, "Text",
  Evaluatable->False],
Cell[61280, 1219, 654, 14, 213, "Input"],
Cell[61937, 1235, 106, 2, 33, "Text",
  Evaluatable->False],
Cell[62046, 1239, 867, 19, 254, "Input"],
Cell[62916, 1260, 167, 5, 33, "Text",
  Evaluatable->False],
Cell[63086, 1267, 224, 5, 83, "Input"],
Cell[63313, 1274, 147, 4, 33, "Text",
  Evaluatable->False],
Cell[63463, 1280, 478, 12, 180, "Input"],
Cell[63944, 1294, 132, 5, 33, "Text"],
Cell[64079, 1301, 1268, 24, 250, "Input"],
Cell[65350, 1327, 2061, 42, 325, "Input"],
Cell[67414, 1371, 561, 16, 55, "Text"],
Cell[67978, 1389, 294, 9, 71, "Text",
  Evaluatable->False],
Cell[68275, 1400, 1555, 33, 290, "Input"],
Cell[69833, 1435, 2350, 50, 370, "Input"],
Cell[72186, 1487, 574, 16, 65, "Text"]
}, Closed]],
Cell[72775, 1506, 530, 16, 30, "Text"],
Cell[73308, 1524, 34944, 576, 192, 34830, 572, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[108255, 2102, 695, 22, 33, "Text"],
Cell[108953, 2126, 4006, 107, 354, "Text"],
Cell[112962, 2235, 492, 11, 221, "Text"],

Cell[CellGroupData[{
Cell[113479, 2250, 115, 2, 33, "Text"],
Cell[113597, 2254, 214, 4, 58, "Input"],
Cell[113814, 2260, 412, 8, 138, "Input"],
Cell[114229, 2270, 2209, 46, 353, "Input"]
}, Closed]],
Cell[116453, 2319, 206, 6, 30, "Text"],
Cell[116662, 2327, 80787, 1327, 192, 80673, 1323, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[197452, 3656, 369, 11, 33, "Text"],
Cell[197824, 3669, 2680, 71, 298, "Text"],
Cell[200507, 3742, 906, 24, 253, "Text"],

Cell[CellGroupData[{
Cell[201438, 3770, 115, 2, 33, "Text"],
Cell[201556, 3774, 233, 4, 43, "Input"],
Cell[201792, 3780, 411, 8, 124, "Input"],
Cell[202206, 3790, 2268, 48, 359, "Input"]
}, Closed]],
Cell[204489, 3841, 164, 5, 30, "Text"],
Cell[204656, 3848, 86725, 1425, 192, 86611, 1421, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[291384, 5275, 460, 12, 52, "Text"],
Cell[291847, 5289, 3885, 104, 282, "Text"],
Cell[295735, 5395, 768, 15, 198, "Text"],

Cell[CellGroupData[{
Cell[296528, 5414, 115, 2, 33, "Text"],
Cell[296646, 5418, 375, 6, 42, "Input"],
Cell[297024, 5426, 753, 14, 191, "Input"],
Cell[297780, 5442, 1748, 38, 315, "Input"],
Cell[299531, 5482, 2615, 59, 395, "Input"]
}, Closed]],
Cell[302161, 5544, 170, 5, 30, "Text"],
Cell[302334, 5551, 55826, 918, 192, 55712, 914, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[358163, 6471, 335, 11, 33, "Text"],
Cell[358501, 6484, 2335, 66, 256, "Text"],
Cell[360839, 6552, 565, 12, 211, "Text"],

Cell[CellGroupData[{
Cell[361429, 6568, 115, 2, 33, "Text"],
Cell[361547, 6572, 251, 4, 43, "Input"],
Cell[361801, 6578, 374, 7, 124, "Input"],
Cell[362178, 6587, 1566, 34, 279, "Input"]
}, Closed]],
Cell[363759, 6624, 164, 5, 30, "Text"],
Cell[363926, 6631, 30316, 500, 192, 30202, 496, "GraphicsData", "Bitmap", \
"Text",
  Evaluatable->False],
Cell[394245, 7133, 393, 12, 52, "Text"],
Cell[394641, 7147, 2442, 67, 281, "Text"],
Cell[397086, 7216, 883, 17, 277, "Text"],

Cell[CellGroupData[{
Cell[397994, 7237, 115, 2, 33, "Text"],
Cell[398112, 7241, 579, 11, 156, "Input"],
Cell[398694, 7254, 309, 6, 70, "Input"],
Cell[399006, 7262, 865, 15, 209, "Input"],
Cell[399874, 7279, 1702, 35, 311, "Input"],
Cell[401579, 7316, 2523, 53, 411, "Input"],
Cell[404105, 7371, 224, 9, 71, "Text"],
Cell[404332, 7382, 235, 4, 59, "Input"],
Cell[404570, 7388, 673, 13, 180, "Input"],
Cell[405246, 7403, 794, 14, 195, "Input"],
Cell[406043, 7419, 50, 0, 33, "Text"],
Cell[406096, 7421, 865, 15, 209, "Input"]
}, Closed]],
Cell[406976, 7439, 290, 7, 30, "Text"],
Cell[407269, 7448, 278, 6, 33, "Text"],
Cell[407550, 7456, 309, 7, 33, "Text"],
Cell[407862, 7465, 307, 7, 33, "Text"],
Cell[408172, 7474, 257, 5, 33, "Text"],
Cell[408432, 7481, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

