(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    759135,      13679]*)
(*NotebookOutlinePosition[    760141,      13715]*)
(*  CellTagsIndexPosition[    760063,      13709]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["11.11  Sources and Sinks",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tIf the two-dimensional motion of an ideal fluid consists of an outward \
radial flow from a point and is symmetrical in all directions, then the point \
is called a simple source.  A source at the origin can be considered as a \
line perpendicular to the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane along which fluid is being emitted.  If the rate of emission of \
volume of fluid per unit length  ",
  Cell[BoxData[
      \(2  \[Pi]\ m\)]],
  ",  then the origin is said to be a source of strength  ",
  StyleBox["m",
    FontFamily->"Courier New"],
  ",  the complex potential for the flow is  \n\n\t\t\t",
  Cell[BoxData[
      \(F \((z)\)\ \  = \ \ m\ log \((z)\)\)]],
  ",  \n\nand the velocity  ",
  StyleBox["V",
    FontWeight->"Bold"],
  "  at the point ",
  Cell[BoxData[
      \(\((x, y)\)\)]],
  " is given by  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["V",
            FontWeight->"Bold"], \((x, y)\)}], "  ", "=", 
        "  ", \(\(F' \((z)\)\)\&_\ \  = \ \ m\/\(\(z\)\(\ \)\)\&_\)}]]],
  ".  \n\nFor fluid flows, a sink is a negative source and is a point of \
inward radial flow at which the fluid is considered to be absorbed or \
annihilated.  Sources and sinks for flows are illustrated in Figure 11.93."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.93",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/sourcesink/SourceSinkFigures/\
mat1193.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Sources and sinks for an ideal fluid. "
}], "Text"],

Cell[TextData[StyleBox["11.11.1  Source: A Charged Line",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tIn the case of electrostatics a source will correspond to a uniformly \
charged line perpendicular to the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-plane at the point ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  We will show that if the line ",
  StyleBox["L",
    FontFamily->"Courier New"],
  " is located at  ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  "  and carries a charge density of  ",
  Cell[BoxData[
      \(q\/2\)]],
  "  coulombs per unit length, then the magnitude of the electric field is  \
",
  Cell[BoxData[
      RowBox[{
        RowBox[{"|", 
          RowBox[{
            StyleBox["E",
              FontWeight->"Bold"], \((x, y)\)}], "|"}], 
        "=", \(q\/\@\(x\^2 + y\^2\)\)}]]],
  ".  Hence  ",
  StyleBox["E",
    FontWeight->"Bold"],
  "  is given by  \n\n",
  StyleBox["(11-41)",
    FontColor->RGBColor[0, 0, 1]],
  "\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["E",
            FontWeight->"Bold"], \((x, y)\)}], "  ", "=", 
        "  ", \(\(q\ z\)\/\(\(|\)\(z\^2\)\(|\)\)\ \  = \ \ q\/\(\(z\)\(\ \)\)\
\&_\)}]]],
  ",  \n\nand the complex potential is  \n\n\t\t\t",
  Cell[BoxData[
      \(F \((z)\)\ \  = \ \ \(-\ q\)\ log \((z)\)\)]],
  ",  and  \n\t\t\t\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["E",
            FontWeight->"Bold"], \((x, y)\)}], "  ", "=", 
        "  ", \(\(-\ \ \(F' \((z)\)\)\&_\)\(\ \)\)}]]],
  ".  \n\nA sink for electrostatics is a negatively charged line \
perpendicular to the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  "-plane.  The electrostatic field for electrostatic problems corresponds to \
the velocity field for fluid flow problems, except that their corresponding \
potentials differ by a sign change. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tTo establish Equation ",
  StyleBox["(11-41)",
    FontColor->RGBColor[0, 0, 1]],
  ", we start with Coulomb's law, which states that two particles with \
charges ",
  StyleBox["q",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["Q",
    FontFamily->"Courier New"],
  " exert a force on one another with magnitude   ",
  Cell[BoxData[
      \(\(C\ q\ Q\)\/r\^2\)]],
  ",  where ",
  StyleBox["r",
    FontFamily->"Courier New"],
  " is the distance between particles and ",
  StyleBox["C",
    FontFamily->"Courier New"],
  " is a constant that depends on the scientific units.  For simplicity, we \
assume that ",
  Cell[BoxData[
      \(C = 1\)]],
  " and the test particle at the point ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " has charge ",
  Cell[BoxData[
      \(Q = 1\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe contribution ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["E",
              FontWeight->"Bold"]}]], "1"]]],
  " induced by the element of charge  ",
  Cell[BoxData[
      \(\(q\ \[CapitalDelta]h\)\/2\)]],
  "  along the segment of length ",
  Cell[BoxData[
      \(\[CapitalDelta]h\)]],
  " situated at a height ",
  StyleBox["h",
    FontFamily->"Courier New"],
  " above the plane has magnitude  ",
  Cell[BoxData[
      RowBox[{"|", 
        SubscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["E",
                FontWeight->"Bold"]}]], "1"], "|"}]]],
  "  given by  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"|", 
          SubscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["E",
                  FontWeight->"Bold"]}]], "1"], "|"}], "  ", "=", 
        "  ", \(\(\((q/2)\)\ \[CapitalDelta]h\)\/\(r\^2 + h\^2\)\)}]]],
  ".  \n\n\tIt has the same magnitude as ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["E",
              FontWeight->"Bold"]}]], "2"]]],
  " induced by the element  ",
  Cell[BoxData[
      \(\(q\ \[CapitalDelta]h\)\/2\)]],
  "  located a distance ",
  StyleBox["-h",
    FontFamily->"Courier New"],
  "  below the plane.  From the vertical symmetry involved their sum,  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["E",
                FontWeight->"Bold"]}]], "1"], "+", 
        SubscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["E",
                FontWeight->"Bold"]}]], "2"]}]]],
  ",  lies parallel to the plane along the ray from the origin, as shown in \
Figure 11.94. "
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.94",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/sourcesink/SourceSinkFigures/\
mat1194.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Contributions to ",
  Cell[BoxData[
      StyleBox["E",
        FontWeight->"Bold"]]],
  " from the elements of charge ",
  Cell[BoxData[
      \(\(q\ \[CapitalDelta]h\)\/2\)]],
  " situated at ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{"0", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], "0", 
          StyleBox[",",
            FontFamily->"Times New Roman",
            FontSize->12,
            FontWeight->"Plain",
            FontSlant->"Plain",
            FontColor->GrayLevel[0],
            FontVariations->{"Underline"->False,
            "StrikeThrough"->False}], \(\[PlusMinus]h\)}], ")"}]]],
  ", above and below the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane."
}], "Text"],

Cell[TextData[{
  "\tBy the principal of superposition, we add all contributions from the \
elements of charge along ",
  StyleBox["L",
    FontFamily->"Courier New"],
  " to obtain  ",
  Cell[BoxData[
      RowBox[{
        StyleBox["E",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{"\[Sum]", " ", 
          SubscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["E",
                  FontWeight->"Bold"]}]], "k"]}]}]]],
  ".  By vertical symmetry,  ",
  Cell[BoxData[
      StyleBox["E",
        FontWeight->"Bold"]]],
  " lies parallel to the complex plane along the ray from the origin through \
the point ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ".  Hence the magnitude of  ",
  Cell[BoxData[
      StyleBox["E",
        FontWeight->"Bold"]]],
  " is the sum of all components  ",
  Cell[BoxData[
      RowBox[{"|", 
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["E",
              FontWeight->"Bold"]}]], "|", \(cos\ t\)}]]],
  "  that are parallel to the complex plane, where ",
  StyleBox["t",
    FontFamily->"Courier New"],
  " is the angle between  ",
  Cell[BoxData[
      StyleBox["E",
        FontWeight->"Bold"]]],
  " and the plane.  Letting  ",
  Cell[BoxData[
      \(\[CapitalDelta]h \[Rule] 0\)]],
  "  in this summation process produces the definite integral   \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"|", 
          RowBox[{
            StyleBox["E",
              FontWeight->"Bold"], \((x, y)\)}], "|"}], "  ", "=", "  ", 
        RowBox[{
          RowBox[{\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
            RowBox[{"|", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["E",
                    FontWeight->"Bold"]}]], 
              "|", \(cos\ t \[DifferentialD]h\)}]}], "  ", "=", 
          "  ", \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\(\((q/
                        2)\)\ \[CapitalDelta]h\)\/\(r\^2 + 
                    h\^2\)\) \[DifferentialD]h\)}]}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tNext, we use the change of variable  ",
  Cell[BoxData[
      RowBox[{"h", " ", "=", " ", 
        RowBox[{
          RowBox[{"r", " ", "tan", " ", "t", "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "   ", \(\[DifferentialD]h\)}], " ", 
          "=", " ", \(r\ sec\^2\ t\ \[DifferentialD]t\)}]}]]],
  "  and the trigonometric identity  ",
  Cell[BoxData[
      \(sec\^2\ t\  = \ \(r\^2 + h\^2\)\/r\^2\)]],
  "  to obtain the equivalent integral:  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{"|", 
          RowBox[{
            StyleBox["E",
              FontWeight->"Bold"], \((x, y)\)}], "|"}], "  ", "=", 
        "  ", \(\[Integral]\_\(\(-\[Pi]\)/2\)\%\(\[Pi]/2\)\(\(\((q/2)\) 
                    cos\ t\)\/\(r\^2 + h\^2\)\) \(\(r\^2 + 
                    h\^2\)\/r\) \[DifferentialD]t\ \  = \ \ \(\(q\/\(2  
                    r\)\) \(\[Integral]\_\(\(-\[Pi]\)/2\)\%\(\[Pi]/2\)\ 
                cos\ t \[DifferentialD]t\)\ \  = \ \ q\/r\)\)}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tMultiplying this magnitude  ",
  Cell[BoxData[
      \(q\/r\)]],
  "  by the unit vector  ",
  Cell[BoxData[
      \(z\/\(\(|\)\(z\)\(|\)\)\)]],
  "  establishes Formula ",
  StyleBox["(11-41)",
    FontColor->RGBColor[0, 0, 1]],
  ".  If ",
  Cell[BoxData[
      \(q > 0\)]],
  ", then the field is directed away from ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  " and, if ",
  Cell[BoxData[
      \(q < 0\)]],
  ", then it is directed toward ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  ".  An electrical field located at ",
  Cell[BoxData[
      \(z\_0 \[NotEqual] 0\)]],
  " is given by   \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["E",
            FontWeight->"Bold"], \((x, y)\)}], " ", "=", 
        " ", \(\(q\ \((z - z\_0)\)\)\/\(\(|\)\(\((z - z\_0)\)\^2\)\(|\)\)\  = \
\ q\/\(\(\(z\)\(\ \)\)\&_\  - \ \(z\_0\)\&_\)\)}]]],
  ",  \n\nand the corresponding complex potential is  \n\n\t\t\t",
  Cell[BoxData[
      \(F \((z)\)\  = \ \(-\ q\)\ \ log \((z - z\_0)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 11.30.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox["(Source and sink of equal strength)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let a source and sink of unit strength be located at the points ",
  Cell[BoxData[
      \(z\_1 = \(+1\)\)]],
  " and ",
  Cell[BoxData[
      \(z\_2 = \(-1\)\)]],
  ", respectively.  The complex potential for a fluid flowing from the source \
at  ",
  Cell[BoxData[
      \(z\_1 = \(+1\)\)]],
  "  to the sink at  ",
  Cell[BoxData[
      \(z\_2 = \(-1\)\)]],
  "  is  \n\n\t\t\t",
  Cell[BoxData[
      \(F \((z)\)\ \  = \ \ \(log \((z - 1)\)\  - \ 
            log \((z + 1)\)\ \  = \ \ log \((\(z - 1\)\/\(z + 1\))\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005B0000i2000`400?l0
0000o`00003oo`3ooomC0?ooo`00o`3ooomC0?ooo`00o`3ooomC0?ooo`00
o`3ooomC0?ooo`00o`3ooomC0?ooo`00R@3oool00`000?l0oooo0?ooo`2P
0?ooo`030000o`3oool0oooo02<0oooo00280?ooo`030000o`3oool0oooo
0:80oooo00<0003o0?ooo`3oool08P3oool008P0oooo00<0003o0?ooo`3o
ool0XP3oool00`000?l0oooo0?ooo`0R0?ooo`00Q`3oool00`000?l0oooo
0?ooo`2S0?ooo`030000o`3oool0oooo0280oooo00270?ooo`030000o`3o
ool0oooo04`0oooo2@3o001?0?ooo`030000o`3oool0oooo0240oooo0026
0?ooo`030000o`3oool0oooo04H0oooo1`3o00090?ooo`T0o`00AP3oool0
0`000?l0oooo0?ooo`0Q0?ooo`00QP3oool00`000?l0oooo0?ooo`120?oo
o`@0o`006@3oool30?l004<0oooo00<0003o0?ooo`3oool08@3oool008H0
oooo00<0003o0?ooo`3oool0?P3oool40?l00200oooo103o000o0?ooo`03
0000o`3oool0oooo0240oooo00260?ooo`030000o`3oool0oooo03`0oooo
0P3o000X0?ooo`<0o`00?@3oool00`000?l0oooo0?ooo`0P0?ooo`00Q@3o
ool00`000?l0oooo0?ooo`0k0?ooo`80o`00;@3oool20?l003/0oooo00<0
003o0?ooo`3oool0803oool008D0oooo00<0003o0?ooo`3oool0>03oool3
0?l00340oooo0P3o000j0?ooo`030000o`3oool0oooo01l0oooo00250?oo
o`030000o`3oool0oooo03H0oooo0P3o000f0?ooo`80o`00>03oool00`00
0?l0oooo0?ooo`0O0?ooo`00Q@3oool00`000?l0oooo0?ooo`0d0?ooo`80
o`00>P3oool20?l003H0oooo00<0003o0?ooo`3oool07`3oool008@0oooo
00<0003o0?ooo`3oool0<`3oool20?l003h0oooo0P3o000e0?ooo`030000
o`3oool0oooo01h0oooo00240?ooo`030000o`3oool0oooo0340oooo0P3o
00120?ooo`80o`00<`3oool00`000?l0oooo0?ooo`0N0?ooo`00Q03oool0
0`000?l0oooo0?ooo`0`0?ooo`030?l0003oool0oooo04@0oooo00<0o`00
0?ooo`3oool0<03oool00`000?l0oooo0?ooo`0N0?ooo`00Q03oool00`00
0?l0oooo0?ooo`0_0?ooo`030?l0003oool0oooo04H0oooo0P3o000`0?oo
o`030000o`3oool0oooo01h0oooo00230?ooo`030000o`3oool0oooo02h0
oooo0P3o001;0?ooo`030?l0003oool0oooo02h0oooo00<0003o0?ooo`3o
ool07@3oool008<0oooo00<0003o0?ooo`3oool0;@3oool00`3o0000oooo
0?ooo`1<0?ooo`030?l0003oool0oooo02d0oooo00<0003o0?ooo`3oool0
7@3oool008<0oooo00<0003o0?ooo`3oool0;03oool00`3o0000oooo0?oo
o`1>0?ooo`030?l0003oool0oooo02`0oooo00<0003o0?ooo`3oool07@3o
ool008<0oooo00<0003o0?ooo`3oool0:P3oool20?l00580oooo0P3o000/
0?ooo`030000o`3oool0oooo01d0oooo00220?ooo`030000o`3oool0oooo
02X0oooo00<0o`000?ooo`3oool0E03oool00`3o0000oooo0?ooo`0Y0?oo
o`030000o`3oool0oooo01d0oooo00220?ooo`030000o`3oool0oooo02T0
oooo00<0o`000?ooo`3oool0EP3oool00`3o0000oooo0?ooo`0X0?ooo`03
0000o`3oool0oooo01d0oooo00220?ooo`030000o`3oool0oooo02P0oooo
00<0o`000?ooo`3oool0E`3oool00`3o0000oooo0?ooo`0X0?ooo`030000
o`3oool0oooo01d0oooo00220?ooo`030000o`3oool0oooo02P0oooo00<0
o`000?ooo`3oool0F03oool00`3o0000oooo0?ooo`0X0?ooo`030000o`3o
ool0oooo01`0oooo00220?ooo`030000o`3oool0oooo02L0oooo00<0o`00
0?ooo`3oool0FP3oool00`3o0000oooo0?ooo`0W0?ooo`030000o`3oool0
oooo01`0oooo00220?ooo`030000o`3oool0oooo02H0oooo00<0o`000?oo
o`3oool0G03oool00`3o0000oooo0?ooo`0V0?ooo`030000o`3oool0oooo
01`0oooo00220?ooo`030000o`3oool0oooo02D0oooo00<0o`000?ooo`3o
ool0GP3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo01`0
oooo00220?ooo`030000o`3oool0oooo02D0oooo00<0o`000?ooo`3oool0
GP3oool00`3o0000oooo0?ooo`0U0?ooo`030000o`3oool0oooo01`0oooo
00220?ooo`030000o`3oool0oooo02@0oooo00<0o`000?ooo`3oool0H03o
ool00`3o0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo01`0oooo0022
0?ooo`030000o`3oool0oooo02<0oooo00<0o`000?ooo`3oool0HP3oool0
0`3o0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo01`0oooo00220?oo
o`030000o`3oool0oooo02<0oooo00<0o`000?ooo`3oool0H`3oool00`3o
0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo01`0oooo00220?ooo`03
0000o`3oool0oooo0280oooo00<0o`000?ooo`3oool0I03oool00`3o0000
oooo0?ooo`0R0?ooo`030000o`3oool0oooo01`0oooo00220?ooo`030000
o`3oool0oooo0240oooo00<0o`000?ooo`3oool0IP3oool00`3o0000oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo01`0oooo00220?ooo`030000o`3o
ool0oooo0240oooo00<0o`000?ooo`3oool0IP3oool00`3o0000oooo0?oo
o`0Q0?ooo`030000o`3oool0oooo01`0oooo00220?ooo`030000o`3oool0
oooo0200oooo00<0o`000?ooo`3oool0:@3ooolD0000ob/0oooo00<0o`00
0?ooo`3oool0803oool00`000?l0oooo0?ooo`0L0?ooo`00PP3oool00`00
0?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo02H0oooo0`000?lD0?oo
o`@0003o:03oool00`3o0000oooo0?ooo`0O0?ooo`030000o`3oool0oooo
01`0oooo00220?ooo`030000o`3oool0oooo01l0oooo00<0o`000?ooo`3o
ool08`3oool40000oa/0oooo0`000?lU0?ooo`030?l0003oool0oooo01l0
oooo00<0003o0?ooo`3oool0703oool00880oooo00<0003o0?ooo`3oool0
7P3oool00`3o0000oooo0?ooo`0Q0?ooo`<0003o8P3oool30000ob<0oooo
00<0o`000?ooo`3oool07P3oool00`000?l0oooo0?ooo`0L0?ooo`00PP3o
ool00`000?l0oooo0?ooo`0N0?ooo`030?l0003oool0oooo01l0oooo0P00
0?lX0?ooo`80003o8@3oool00`3o0000oooo0?ooo`0N0?ooo`030000o`3o
ool0oooo01`0oooo00220?ooo`030000o`3oool0oooo01d0oooo00<0o`00
0?ooo`3oool07P3oool20000ob`0oooo0P000?lP0?ooo`030?l0003oool0
oooo01d0oooo00<0003o0?ooo`3oool0703oool00880oooo00<0003o0?oo
o`3oool07@3oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo
02h0oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`0M0?oo
o`030000o`3oool0oooo01`0oooo00220?ooo`030000o`3oool0oooo01`0
oooo00<0o`000?ooo`3oool0703oool20000oc80oooo0P000?lN0?ooo`03
0?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool0703oool00880oooo
00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0K0?ooo`030000
o`3oool0oooo03@0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo
0?ooo`0L0?ooo`030000o`3oool0oooo01`0oooo00220?ooo`030000o`3o
ool0oooo01/0oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?oo
o`0f0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool06`3o
ool00`000?l0oooo0?ooo`0L0?ooo`00PP3oool00`000?l0oooo0?ooo`0K
0?ooo`030?l0003oool0oooo01T0oooo0P000?lj0?ooo`80003o6`3oool0
0`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo01`0oooo00220?oo
o`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3oool06@3oool00`00
0?l0oooo0?ooo`0l0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?oo
o`3oool06`3oool00`000?l0oooo0?ooo`0L0?ooo`00P`3oool00`000?l0
oooo0?ooo`0I0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3o
ool0?P3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0oooo01X0
oooo00<0003o0?ooo`3oool0703oool008<0oooo00<0003o0?ooo`3oool0
6@3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0400oooo
00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0I0?ooo`030000
o`3oool0oooo01d0oooo00230?ooo`030000o`3oool0oooo01P0oooo00<0
o`000?ooo`3oool05P3oool20000od@0oooo0P000?lG0?ooo`030?l0003o
ool0oooo01T0oooo00<0003o0?ooo`3oool07@3oool008<0oooo00<0003o
0?ooo`3oool0603oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0
oooo04H0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0I
0?ooo`030000o`3oool0oooo01d0oooo00230?ooo`030000o`3oool0oooo
01P0oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`180?oo
o`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool0603oool00`00
0?l0oooo0?ooo`0M0?ooo`00P`3oool00`000?l0oooo0?ooo`0G0?ooo`03
0?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0BP3oool00`000?l0
oooo0?ooo`0C0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3o
ool07@3oool008<0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo
0?ooo`0C0?ooo`030000o`3oool0oooo04`0oooo00<0003o0?ooo`3oool0
4P3oool00`3o0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo01h0oooo
00230?ooo`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`0L0?oooa40o`007`3oool00`000?l0oooo0?oo
o`0C0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool07P3o
ool008@0oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo01T0oooo103o000A0?ooo`@0o`00703oool0
0`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo01H0oooo00<0003o
0?ooo`3oool07P3oool008@0oooo00<0003o0?ooo`3oool05P3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo01P0oooo0P3o000I0?oo
o`<0o`006P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
01D0oooo00<0003o0?ooo`3oool07`3oool008@0oooo00<0003o0?ooo`3o
ool05P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo01H0
oooo0`3o000N0?ooo`<0o`00603oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool07`3oool008D0oooo
00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo01@0oooo0P3o000T0?ooo`<0o`005@3oool00`000?l0oooo
0?ooo`0A0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0
7`3oool008D0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo01<0oooo0P3o000Y0?ooo`80o`00503o
ool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01@0oooo00<0
003o0?ooo`3oool07`3oool008H0oooo00<0003o0?ooo`3oool04`3oool0
0`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0180oooo0P3o000]
0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo01l0oooo00260?oo
o`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo02h0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
01<0oooo00<0003o0?ooo`3oool0803oool008H0oooo00<0003o0?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0100
oooo0P3o000b0?ooo`80o`004P3oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0803oool008L0oooo
00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00h0oooo0P3o000f0?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0C0?ooo`030000
o`3oool0oooo0200oooo00270?ooo`030000o`3oool0oooo0180oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo03L0oooo0P3o000@0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0Q0?ooo`00Q`3oool0
0`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0j0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo0240oooo00270?ooo`030000o`3oool0oooo
0180oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo03`0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool08P3oool008P0oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool0603oool<0000oaX0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3o
ool08P3oool008P0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
4`3oool60000o``0oooo1P000?lE0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo02<0oooo00290?ooo`030000o`3oool0oooo0100oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo0140oooo0`000?lH0?ooo`<0003o4`3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0S0?ooo`00R@3oool00`000?l0oooo0?ooo`0@
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0?0?ooo`80003o7P3oool20000oa80oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool0903oool008X0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool03P3oool20000ob80oooo0P000?l@0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo02@0oooo002:0?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o
ool0903oool20000o`l0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o
ool09@3oool008/0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
3@3oool20000obT0oooo0P000?l>0?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo02D0oooo002;0?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00/0oooo0P000?l]0?ooo`80003o3@3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`0U0?ooo`00S03oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo02l0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0V
0?ooo`00K03oool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00T0oooo0P000?lc0?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool09P3oool006d0
oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`080?ooo`80003o603oool60?l001P0oooo0P000?l:0?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo01l0oooo00<0o`000?ooo`3o
ool01@3oool006h0oooo00<0o`000?ooo`3oool0703oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo0140oooo
203o00050?ooo`L0o`004`3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0
1P3oool006l0oooo00<0o`000?ooo`3oool0703oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00l0oooo0`3o
000D0?ooo`@0o`00403oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo01d0oooo0P3o00090?ooo`00L03oool0
0`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool03P3oool20?l001/0oooo0`3o000>
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0703oool00`3o0000oooo0?ooo`090?ooo`00L@3oool00`3o
0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool02`3oool30?l00200oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool02P3oool00780
oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00X0oooo0P3o000T0?ooo`80
o`003@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo01/0oooo0P3o000=0?ooo`00L`3oool00`3o0000oooo
0?ooo`0J0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool02@3oool20?l002P0oooo0P3o000<0?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
6P3oool00`3o0000oooo0?ooo`0=0?ooo`00M03oool20?l001/0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`080?ooo`80o`00;03oool20?l000X0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0I0?ooo`80o`00403o
ool007H0oooo0P3o000J0?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01`3oool20?l00300oooo0P3o0009
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool0603oool20?l00180oooo001h0?ooo`030?l0003oool0oooo
01L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`80o`004P3oool?0000oa<0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo01L0oooo00<0o`000?ooo`3oool04P3oool007T0
oooo0P3o000H0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`0=0?ooo`D0
003o3`3oool50000o`l0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo01H0
oooo0P3o000E0?ooo`00N`3oool00`3o0000oooo0?ooo`0F0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`0;0?ooo`<0003o6@3oool40000o``0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool0
5@3oool007`0oooo0P3o000G0?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`090?ooo`<0003o803oool30000o`X0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo01D0oooo0P3o000H0?ooo`00OP3oool20?l001D0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00P0oooo0P000?lV0?ooo`80003o2@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool04`3oool20?l001X0oooo00200?oo
o`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00L0oooo0P000?lZ0?ooo`80003o203oool20?l000H0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0C0?oo
o`030?l0003oool0oooo01X0oooo00210?ooo`80o`00503oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool01P3oool20000obh0oooo0P000?l80?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0B0?ooo`80o`007@3oool008<0oooo
0P3o000C0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo0100oooo3P3o000B0?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo0140oooo0P3o000O0?ooo`00Q@3o
ool20?l00180oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00D0oooo0P00
0?l<0?ooo`L0o`003P3oool70?l000`0oooo0P000?l70?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`0@0?ooo`80o`008@3oool008L0oooo00<0o`00
0?ooo`3oool0403oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00D0oooo00<0o`000?ooo`3oool00`3oool20000o`X0oooo103o
000L0?ooo`@0o`002P3oool20000o`D0oooo00<0o`000?ooo`3oool00`3o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo0100oooo
00<0o`000?ooo`3oool08@3oool008P0oooo0P3o000@0?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo
0?ooo`020?ooo`80003o2P3oool20?l002@0oooo0P3o000:0?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00l0oooo0P3o000T0?ooo`00
RP3oool20?l000l0oooo00<0003o0?ooo`3oool01P3oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00@0o`000?ooo`3oool0003o103oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo0P3o000X0?oo
o`80o`002@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo00@0003o0?ooo`3oool0o`00103oool01@000?l0oooo0?ooo`3o
ool0o`0000L0oooo00<0003o0?ooo`3oool03P3oool20?l002H0oooo002<
0?ooo`80o`003P3oool00`000?l0oooo0?ooo`050?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool0103o0000oooo0?ooo`000?l30?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool30?l002`0oooo
0`3o00070?ooo`030000o`3oool0oooo00<0oooo00D0o`000?ooo`3oool0
oooo0000o`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3o
ool0oooo0?l000060?ooo`030000o`3oool0oooo00d0oooo0P3o000X0?oo
o`00SP3oool20?l000d0oooo00<0003o0?ooo`3oool01@3oool01@3o0000
oooo0?ooo`3oool0003o00<0oooo00@0o`000?ooo`3oool0003o0`3oool0
1@3o0000oooo0?ooo`3oool0003o00L0oooo0P3o000b0?ooo`80o`001P3o
ool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0
0P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0<0?ooo`80o`00:P3oool00900oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`040?ooo`050?l0
003oool0oooo0?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l20?oo
o`050?l0003oool0oooo0?ooo`000?l01P3oool20?l000h0oooo6P000?l>
0?ooo`80o`001@3oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0
oooo0000o`80oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0Z0?ooo`00T@3oool20?l000`0oooo00<0003o0?ooo`3oool0103o
ool0103o0000oooo0?ooo`000?l30?ooo`030?l0003oool0003o00<0oooo
00@0o`000?ooo`3oool0003o1@3oool20?l000/0oooo1@000?lJ0?ooo`<0
003o3@3oool20?l000@0oooo0P000?l30?ooo`030?l0003oool0003o0080
oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool02`3oool20?l002d0oooo002C0?ooo`80
o`002`3oool20000o`@0oooo00D0o`000?ooo`3oool0oooo0000o`020?oo
o`030?l0003oool0003o0080oooo00@0o`000?ooo`3oool0003o103oool2
0?l000P0oooo1@000?lR0?ooo`L0003o203oool20?l000@0oooo00@0003o
0?ooo`3oool0o`000P3oool00`000?l0oooo0?l000020?ooo`040000o`3o
ool0oooo0?l000D0oooo00<0003o0?ooo`3oool02P3oool20?l002l0oooo
002E0?ooo`80o`002`3oool00`000?l0oooo0?ooo`020?ooo`040?l0003o
ool0oooo0000o`80oooo00D0o`000?ooo`000?l0oooo0?l000020?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool30000obh0
oooo0P000?l80?ooo`80o`000`3oool020000?l0oooo0?ooo`3o0000oooo
0000o`3oool0o`000P3oool010000?l0oooo0?ooo`3o00040?ooo`030000
o`3oool0oooo00T0oooo0P3o000a0?ooo`00U`3oool20?l000X0oooo00D0
003o0?ooo`3oool0oooo0?l000020?ooo`080000o`3oool0oooo0?l0003o
ool0003o0?ooo`3o00020?ooo`030000o`3oool0oooo0080o`001@3oool3
0000oc<0oooo10000?l60?ooo`80o`0000T0oooo0000o`3oool0oooo0?l0
003oool0003o0?ooo`3o00000P3oool00`000?l0oooo0?l000040?ooo`03
0000o`3oool0oooo00P0oooo0P3o000c0?ooo`00V@3oool30?l000P0oooo
0P000?l20?ooo`090?l0003oool0oooo0000o`3oool0o`000?ooo`000?l0
o`000080oooo00@0003o0?ooo`3oool0o`00103oool30000ocX0oooo0`00
0?l50?ooo`0=0?l0003oool0003o0?ooo`3o0000oooo0000o`3oool0o`00
0?ooo`000?l0oooo0?l000030?ooo`80003o203oool30?l003D0oooo002L
0?ooo`@0o`001P3oool03P000?l0oooo0?ooo`3o0000oooo0000o`3oool0
o`000000o`3oool0o`000?ooo`000?l0oooo0P3o00030?ooo`80003o3P3o
oolR0?l00100oooo0P000?l40?ooo`0<0?l0003oool0003o0?ooo`3o0000
003o0?ooo`3o0000oooo0000o`3oool0o`000P3oool00`000?l0oooo0?oo
o`040?ooo`@0o`00>03oool00:00oooo0P3o00050?ooo`80003o00/0oooo
0?l0003oool0003o0?l000000?l0o`000?ooo`000?l0oooo0?l000030?oo
o`80003o2P3oool60?l00280oooo1`3o000;0?ooo`80003o0`3oool02`3o
0000oooo0000o`3oool0o`000000o`3o0000003o0?ooo`3o0000oooo0080
003o1@3oool20?l003`0oooo002R0?ooo`80o`001@3oool02P000?l0oooo
0?l000000?l0o`000000o`3o0000003o0?ooo`3o00020?ooo`80003o103o
ool80?l002l0oooo2@3o00040?ooo`80003o0P3oool0103o0000oooo0000
o`3o00020000o`040?ooo`3o0000oooo0000o`D0oooo0P3o000n0?ooo`00
Y03oool30?l000<0oooo00<0003o0?ooo`3o00000P000?l00`3o0000003o
0?l000030000o`<0oooo0`3o00100?ooo`<0o`000`3oool30000o`030?l0
00000?l0o`000080003o00<0o`000?ooo`000?l00`3oool30?l00400oooo
002W0?ooo`@0o`001`000?l60?l004H0oooo1P3o00070000o`@0o`00@`3o
ool006`0oooo@@000?l20?oooeL0003o0P3ooom30000o`L0oooo002[0?oo
o`80o`000P3oool00`000?l0o`000?l0001B0?ooo`80o`000P3oool00`00
0?l0o`000?l000170?ooo`00Y`3oool40?l000L0003o1@3o00180?ooo`D0
o`001`000?l40?l004<0oooo002U0?ooo`80o`000`3oool00`000?l0oooo
0?l000020000o`030?l000000?l0o`000080003o0`3oool30?l00480oooo
0`3o00030?ooo`80003o00<0o`000000o`3o00000P000?l00`3o0000oooo
0000o`030?ooo`80o`00@@3oool00:<0oooo0P3o00040?ooo`0;0000o`3o
ool0o`000000o`3o0000003o0?l000000?l0oooo0?l0003oool00`000?l3
0?ooo`T0o`00;`3oool:0?l000<0oooo0`000?l01@3oool0o`000?ooo`00
0?l0o`000080003o00@0oooo0?l0003oool0003o103oool20?l003l0oooo
002P0?ooo`<0o`00103oool20000o`0;0?ooo`3o0000oooo0000o`3o0000
003o0?l0003oool0003o0?ooo`3o00000`3oool20000o`X0oooo1P3o000R
0?ooo`L0o`002`3oool20000o`<0oooo00/0o`000?ooo`000?l0oooo0?l0
00000?l0o`000000o`3oool0o`000?ooo`020000o`@0oooo0`3o000l0?oo
o`00W03oool40?l000H0oooo00l0003o0?ooo`3oool0o`000?ooo`000?l0
oooo0?l000000?l0oooo0?l0003oool0003o0?ooo`3o0000103oool20000
o`h0oooo8P3o000@0?ooo`80003o103oool0303o0000oooo0000o`3oool0
o`000000o`3oool0o`000?ooo`000?l0oooo0?l00080oooo00<0003o0?oo
o`3oool0103oool40?l003P0oooo002J0?ooo`80o`00203oool20000o`80
oooo00T0o`000?ooo`3oool0003o0?ooo`3o0000oooo0000o`3o00000P3o
ool010000?l0oooo0?l0003o00040?ooo`80003o>`3oool30000o`D0oooo
00d0o`000?ooo`000?l0oooo0?l0003oool0003o0?ooo`3o0000oooo0000
o`3oool0o`0000<0oooo0P000?l80?ooo`80o`00=P3oool009P0oooo0P3o
00090?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool020000?l0oooo
0?ooo`3o0000oooo0000o`3oool0o`000P3oool010000?l0oooo0?ooo`3o
00050?ooo`@0003o<`3oool40000o`L0oooo00<0o`000?ooo`000?l00P3o
ool01@3o0000oooo0000o`3oool0o`000080oooo00<0003o0?ooo`3o0000
103oool00`000?l0oooo0?ooo`070?ooo`80o`00=03oool009H0oooo0P3o
000:0?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0003o
0P3oool01@3o0000oooo0000o`3oool0o`000080oooo00@0003o0?ooo`3o
ool0oooo0P3o00070?ooo`<0003o;P3oool20000o`T0oooo0P3o00020?oo
o`080000o`3oool0oooo0?l0003oool0003o0?ooo`3o00020?ooo`040000
o`3oool0oooo0?l000@0oooo00<0003o0?ooo`3oool0203oool20?l00380
oooo002D0?ooo`80o`002P3oool20000o`@0oooo00D0o`000?ooo`3oool0
oooo0000o`020?ooo`030?l0003oool0003o0080oooo00@0o`000?ooo`3o
ool0003o103oool00`3o0000oooo0?ooo`070?ooo`@0003o903oool60000
o`T0oooo0P3o00030?ooo`040000o`3oool0oooo0?l00080oooo00<0003o
0?ooo`3o00000P3oool010000?l0oooo0?ooo`3o00050?ooo`030000o`3o
ool0oooo00T0oooo0P3o000`0?ooo`00TP3oool20?l000/0oooo00<0003o
0?ooo`3oool0103oool0103o0000oooo0?ooo`000?l30?ooo`030?l0003o
ool0003o00<0oooo00@0o`000?ooo`3oool0003o103oool20?l000/0oooo
1@000?lK0?ooo`@0003o3@3oool20?l000<0oooo0P000?l30?ooo`030?l0
003oool0003o0080oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool02P3oool20?l002h0
oooo002@0?ooo`80o`00303oool00`000?l0oooo0?ooo`040?ooo`050?l0
003oool0oooo0?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l20?oo
o`050?l0003oool0oooo0?ooo`000?l01@3oool30?l000d0oooo6`000?l>
0?ooo`<0o`00103oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0
oooo0000o`80oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool02`3oool20?l002`0oooo
002>0?ooo`80o`003@3oool00`000?l0oooo0?ooo`050?ooo`050?l0003o
ool0oooo0?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l30?ooo`05
0?l0003oool0oooo0?ooo`000?l01`3oool20?l00380oooo0P3o00060?oo
o`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`02
0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00`0oooo0P3o000Z0?ooo`00S03oool2
0?l000h0oooo00<0003o0?ooo`3oool01@3oool01@3o0000oooo0?ooo`3o
ool0003o00@0oooo00@0o`000?ooo`3oool0003o0`3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00H0oooo0`3o000]0?ooo`80o`00
1`3oool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`00
0?l00P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?oo
o`3o00001P3oool00`000?l0oooo0?ooo`0=0?ooo`80o`00:03oool008X0
oooo0P3o000?0?ooo`030000o`3oool0oooo00H0oooo00D0o`000?ooo`3o
ool0oooo0000o`040?ooo`040?l0003oool0oooo0000o`@0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`80o`00:@3oool2
0?l000P0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`040000o`3oool0oooo0?l000@0oooo00D0003o0?ooo`3oool0oooo
0?l000070?ooo`030000o`3oool0oooo00h0oooo0P3o000V0?ooo`00R@3o
ool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00T0oooo0P3o000T0?ooo`<0o`002@3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo02<0
oooo00270?ooo`80o`004@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo
0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool00P3oool20000o`/0
oooo0`3o000N0?ooo`<0o`002P3oool20000o`D0oooo00<0o`000?ooo`3o
ool00`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00l0oooo0P3o000S0?ooo`00Q@3oool20?l00180oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo00@0oooo0P000?l<0?ooo`L0o`003`3oool80?l000/0
oooo0P000?l70?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0@0?ooo`80
o`008@3oool008<0oooo0P3o000C0?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`050?ooo`80003o4@3oool?0?l00180oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool04@3oool20?l001l0oooo
00210?ooo`80o`00503oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01P3o
ool20000obh0oooo0P000?l80?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0B0?ooo`80o`007@3oool00800oooo00<0o`000?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0Z
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo01<0oooo00<0o`000?ooo`3oool06P3oool007h0oooo0P3o000E0?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`070?ooo`80003o:03oool20000
o`P0oooo0P3o00060?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool04`3oool20?l001X0oooo001l0?ooo`80
o`005`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0203oool30000ob40
oooo10000?l90?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0E0?ooo`80
o`00603oool007/0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool02P3oool40000oaX0oooo0`000?l<0?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo01D0oooo
001i0?ooo`80o`00603oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool03@3o
ool40000oa40oooo1@000?l>0?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0F0?ooo`80o`005@3oool007P0oooo00<0o`000?ooo`3oool05`3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo0P3o000A0?oooa40003o4P3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0B0?ooo`00MP3oool20?l0
01X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo02l0oooo0P3o00090?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool0603oool20?l00180oooo001d0?ooo`80o`006`3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo0P3o000]0?ooo`80o`002P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo01T0oooo0P3o000@0?ooo`00
L`3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool30?l002P0oooo
0P3o000<0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool06P3oool00`3o0000oooo0?ooo`0=0?ooo`00LP3o
ool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool02P3oool20?l002D0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool0303o
ool00740oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00/0oooo0P3o000Q
0?ooo`80o`003@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo01/0oooo0P3o000<0?ooo`00L03oool00`3o
0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool03@3oool30?l001/0oooo0`3o000>0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0703oool00`3o0000oooo0?ooo`090?ooo`00K`3oool00`3o0000
oooo0?ooo`0K0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool03`3oool30?l001@0oooo103o000@0?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool07@3oool00`3o0000oooo0?ooo`080?ooo`00KP3oool00`3o0000oooo
0?ooo`0L0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool04@3oool80?l000D0oooo1`3o000C0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
7@3oool20?l000P0oooo001]0?ooo`030?l0003oool0oooo01`0oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0203oool20000oaP0oooo1P3o
000H0?ooo`80003o2P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0O0?ooo`030?l0003oool0oooo00D0oooo001/0?ooo`030?l0003oool0
oooo01d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool2
0000oc<0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0V0?ooo`00R`3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo02l0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0V0?oo
o`00R`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0;0?ooo`80
003o;@3oool20000o`d0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o
ool09@3oool008X0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
3@3oool20000obT0oooo0P000?l>0?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo02D0oooo002:0?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool0903oool20000o`l0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool09@3oool008T0oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool03P3oool20000ob80oooo0P000?l@
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo02@0oooo00290?oo
o`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00l0oooo0P000?lN0?oo
o`80003o4P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0T0?oo
o`00R03oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0A0?ooo`<0
003o6@3oool20000oa<0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool08`3oool008P0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
4`3oool60000o`d0oooo1P000?lD0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo02<0oooo00280?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo01P0oooo3@000?lI0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo0280oooo00270?ooo`030000o`3oool0oooo0180oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo03`0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool08P3oool0
08L0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0>P3oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0Q0?ooo`00Q`3oool00`000?l0
oooo0?ooo`0B0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0g0?ooo`80o`00403oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o
ool08@3oool008L0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
=@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0P0?ooo`00QP3o
ool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool03`3oool20?l003<0oooo0P3o000B0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`0P0?ooo`00QP3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool0403oool20?l00300oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo01<0oooo00<0003o0?ooo`3oool0803oool008H0oooo00<0003o0?oo
o`3oool04`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
0180oooo0P3o000]0?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo
01l0oooo00250?ooo`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0C0?ooo`80o`00:@3oool20?l001@0
oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo01l0oooo00250?ooo`030000o`3oool0oooo01@0oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0D0?ooo`80o`00
9@3oool20?l001D0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0D0?ooo`030000o`3oool0oooo01l0oooo00240?ooo`030000o`3o
ool0oooo01H0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0F0?ooo`80o`007`3oool40?l001L0oooo00<0003o0?ooo`3oool04@3o
ool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo01l0oooo0024
0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0G0?ooo`80o`006`3oool20?l001X0oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0
oooo01l0oooo00240?ooo`030000o`3oool0oooo01H0oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0H0?ooo`@0o`004P3oool50?l0
01/0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0F0?oo
o`030000o`3oool0oooo01h0oooo00230?ooo`030000o`3oool0oooo01L0
oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0K0?oooa80
o`007`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo01H0
oooo00<0003o0?ooo`3oool07P3oool008<0oooo00<0003o0?ooo`3oool0
5`3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo04`0oooo
00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0G0?ooo`030000
o`3oool0oooo01h0oooo00230?ooo`030000o`3oool0oooo01L0oooo00<0
o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`1:0?ooo`030000o`3o
ool0oooo01<0oooo00<0o`000?ooo`3oool0603oool00`000?l0oooo0?oo
o`0M0?ooo`00P`3oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0
oooo01@0oooo00<0003o0?ooo`3oool0B03oool00`000?l0oooo0?ooo`0D
0?ooo`030?l0003oool0oooo01P0oooo00<0003o0?ooo`3oool07@3oool0
08<0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0E0?oo
o`030000o`3oool0oooo04H0oooo00<0003o0?ooo`3oool0503oool00`3o
0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01d0oooo00230?ooo`03
0000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool05P3oool20000od@0
oooo0P000?lG0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3o
ool07@3oool008<0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo
0?ooo`0G0?ooo`030000o`3oool0oooo0400oooo00<0003o0?ooo`3oool0
5`3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3oool0oooo01d0oooo
00230?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool0603o
ool00`000?l0oooo0?ooo`0n0?ooo`030000o`3oool0oooo01P0oooo00<0
o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`0L0?ooo`00PP3oool0
0`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo01T0oooo00<0003o
0?ooo`3oool0?03oool00`000?l0oooo0?ooo`0H0?ooo`030?l0003oool0
oooo01/0oooo00<0003o0?ooo`3oool0703oool00880oooo00<0003o0?oo
o`3oool06`3oool00`3o0000oooo0?ooo`0I0?ooo`80003o>P3oool20000
oa/0oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0L0?oo
o`00PP3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo01/0
oooo00<0003o0?ooo`3oool0=P3oool00`000?l0oooo0?ooo`0K0?ooo`03
0?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool0703oool00880oooo
00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0K0?ooo`030000
o`3oool0oooo03@0oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo
0?ooo`0L0?ooo`030000o`3oool0oooo01`0oooo00220?ooo`030000o`3o
ool0oooo01`0oooo00<0o`000?ooo`3oool0703oool20000oc80oooo0P00
0?lN0?ooo`030?l0003oool0oooo01`0oooo00<0003o0?ooo`3oool0703o
ool00880oooo00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`0M
0?ooo`030000o`3oool0oooo02h0oooo00<0003o0?ooo`3oool07@3oool0
0`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo01`0oooo00220?oo
o`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool07P3oool20000
ob`0oooo0P000?lP0?ooo`030?l0003oool0oooo01d0oooo00<0003o0?oo
o`3oool0703oool00880oooo00<0003o0?ooo`3oool07P3oool00`3o0000
oooo0?ooo`0O0?ooo`80003o:03oool20000ob40oooo00<0o`000?ooo`3o
ool07P3oool00`000?l0oooo0?ooo`0L0?ooo`00PP3oool00`000?l0oooo
0?ooo`0N0?ooo`030?l0003oool0oooo0240oooo0`000?lR0?ooo`<0003o
8`3oool00`3o0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo01`0oooo
00220?ooo`030000o`3oool0oooo01l0oooo00<0o`000?ooo`3oool08`3o
ool30000oa`0oooo0`000?lU0?ooo`030?l0003oool0oooo01l0oooo00<0
003o0?ooo`3oool0703oool00880oooo00<0003o0?ooo`3oool0803oool0
0`3o0000oooo0?ooo`0U0?ooo`<0003o5P3oool30000obP0oooo00<0o`00
0?ooo`3oool07`3oool00`000?l0oooo0?ooo`0L0?ooo`00PP3oool00`00
0?l0oooo0?ooo`0P0?ooo`030?l0003oool0oooo02P0oooo5P000?lZ0?oo
o`030?l0003oool0oooo0200oooo00<0003o0?ooo`3oool0703oool00880
oooo00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?ooo`1V0?ooo`03
0?l0003oool0oooo0240oooo00<0003o0?ooo`3oool0703oool00880oooo
00<0003o0?ooo`3oool08@3oool00`3o0000oooo0?ooo`1V0?ooo`030?l0
003oool0oooo0240oooo00<0003o0?ooo`3oool0703oool00880oooo00<0
003o0?ooo`3oool08P3oool00`3o0000oooo0?ooo`1T0?ooo`030?l0003o
ool0oooo0280oooo00<0003o0?ooo`3oool0703oool00880oooo00<0003o
0?ooo`3oool08`3oool00`3o0000oooo0?ooo`1S0?ooo`030?l0003oool0
oooo0280oooo00<0003o0?ooo`3oool0703oool00880oooo00<0003o0?oo
o`3oool08`3oool00`3o0000oooo0?ooo`1R0?ooo`030?l0003oool0oooo
02<0oooo00<0003o0?ooo`3oool0703oool00880oooo00<0003o0?ooo`3o
ool0903oool00`3o0000oooo0?ooo`1P0?ooo`030?l0003oool0oooo02@0
oooo00<0003o0?ooo`3oool0703oool00880oooo00<0003o0?ooo`3oool0
9@3oool00`3o0000oooo0?ooo`1N0?ooo`030?l0003oool0oooo02D0oooo
00<0003o0?ooo`3oool0703oool00880oooo00<0003o0?ooo`3oool09P3o
ool00`3o0000oooo0?ooo`1M0?ooo`030?l0003oool0oooo02D0oooo00<0
003o0?ooo`3oool0703oool00880oooo00<0003o0?ooo`3oool09`3oool0
0`3o0000oooo0?ooo`1K0?ooo`030?l0003oool0oooo02H0oooo00<0003o
0?ooo`3oool0703oool00880oooo00<0003o0?ooo`3oool09`3oool00`3o
0000oooo0?ooo`1J0?ooo`030?l0003oool0oooo02L0oooo00<0003o0?oo
o`3oool0703oool00880oooo00<0003o0?ooo`3oool0:03oool00`3o0000
oooo0?ooo`1H0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3o
ool0703oool00880oooo00<0003o0?ooo`3oool0:@3oool00`3o0000oooo
0?ooo`1F0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool0
7@3oool00880oooo00<0003o0?ooo`3oool0:P3oool00`3o0000oooo0?oo
o`1E0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool07@3o
ool00880oooo00<0003o0?ooo`3oool0:`3oool00`3o0000oooo0?ooo`1C
0?ooo`030?l0003oool0oooo02T0oooo00<0003o0?ooo`3oool07@3oool0
08<0oooo00<0003o0?ooo`3oool0:`3oool00`3o0000oooo0?ooo`1A0?oo
o`030?l0003oool0oooo02X0oooo00<0003o0?ooo`3oool07@3oool008<0
oooo00<0003o0?ooo`3oool0;03oool00`3o0000oooo0?ooo`1>0?ooo`80
o`00;@3oool00`000?l0oooo0?ooo`0M0?ooo`00P`3oool00`000?l0oooo
0?ooo`0]0?ooo`80o`00C@3oool00`3o0000oooo0?ooo`0]0?ooo`030000
o`3oool0oooo01d0oooo00230?ooo`030000o`3oool0oooo02l0oooo00<0
o`000?ooo`3oool0B@3oool00`3o0000oooo0?ooo`0^0?ooo`030000o`3o
ool0oooo01d0oooo00240?ooo`030000o`3oool0oooo02l0oooo00<0o`00
0?ooo`3oool0AP3oool20?l00300oooo00<0003o0?ooo`3oool07P3oool0
08@0oooo00<0003o0?ooo`3oool0<03oool00`3o0000oooo0?ooo`140?oo
o`030?l0003oool0oooo0300oooo00<0003o0?ooo`3oool07P3oool008@0
oooo00<0003o0?ooo`3oool0<@3oool20?l00480oooo0P3o000c0?ooo`03
0000o`3oool0oooo01h0oooo00240?ooo`030000o`3oool0oooo03<0oooo
0P3o000n0?ooo`80o`00=@3oool00`000?l0oooo0?ooo`0N0?ooo`00Q@3o
ool00`000?l0oooo0?ooo`0d0?ooo`80o`00>P3oool20?l003H0oooo00<0
003o0?ooo`3oool07`3oool008D0oooo00<0003o0?ooo`3oool0=P3oool2
0?l003H0oooo0P3o000h0?ooo`030000o`3oool0oooo01l0oooo00250?oo
o`030000o`3oool0oooo03P0oooo0P3o000b0?ooo`80o`00>P3oool00`00
0?l0oooo0?ooo`0O0?ooo`00Q@3oool00`000?l0oooo0?ooo`0j0?ooo`80
o`00;P3oool20?l003/0oooo00<0003o0?ooo`3oool0803oool008H0oooo
00<0003o0?ooo`3oool0>`3oool20?l002T0oooo0`3o000m0?ooo`030000
o`3oool0oooo0200oooo00260?ooo`030000o`3oool0oooo03d0oooo103o
000R0?ooo`<0o`00?`3oool00`000?l0oooo0?ooo`0Q0?ooo`00QP3oool0
0`000?l0oooo0?ooo`110?ooo`D0o`006@3oool40?l00480oooo00<0003o
0?ooo`3oool08@3oool008L0oooo00<0003o0?ooo`3oool0A@3oool70?l0
00X0oooo203o00160?ooo`030000o`3oool0oooo0240oooo00270?ooo`03
0000o`3oool0oooo04`0oooo2P3o001>0?ooo`030000o`3oool0oooo0240
oooo00280?ooo`030000o`3oool0oooo0:80oooo00<0003o0?ooo`3oool0
8P3oool008P0oooo00<0003o0?ooo`3oool0XP3oool00`000?l0oooo0?oo
o`0R0?ooo`00R@3oool00`000?l0oooo0?ooo`2P0?ooo`80003o903oool0
0001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{338, 228},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.95 (a)",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/sourcesink/SourceSinkFigures/\
mat1195.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Source and sink of unit strength."
}], "Text"],

Cell[TextData[{
  "The velocity potential and stream function are  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\ \  = \ \ ln | \(z - 1\)\/\(z + 1\) | \)]],
  ",   and  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Psi] \((x, y)\)\ \  = \ \ arg \((\(z - 1\)\/\(z + 1\))\)\)]],
  ",  \n\nrespectively.  Solving for the streamline  ",
  Cell[BoxData[
      \(\[Psi] \((x, y)\)\  = \ c\)]],
  ",  we start with   \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(c\ \  = \ \ \(arg \((\(z - 1\)\/\(z + 1\))\)\ \  = \ \ arg \
\((\(\((x + \[ImaginaryI]\ y - 1)\) \((x - \[ImaginaryI]\ y + 1)\)\)\/\(\((x \
+ \[ImaginaryI]\ y + 1)\) \((x - \[ImaginaryI]\ y + 1)\)\))\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \(\(\(=\)\(\ \ \)\(arg \((\(x\^2 + y\^2 - 1 + \ \
\[ImaginaryI]\ 2  y\)\/\(\(x\^2\)\(+\)\(2\ x\)\(+\)\(1\)\(+\)\(y\^2\)\(\ \
\)\))\)\ \  = \ \ arg \((\(x\^2 + y\^2 - 1 + \ \[ImaginaryI]\ 2  \
y\)\/\(\(\((x + 1)\)\^2\)\(+\)\(y\^2\)\(\ \)\))\)\)\)\(\ \)\(\
\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \(\(=\)\(\ \ \)\(arctan \((\(2  \
y\)\/\(\(x\^2\)\(+\)\(y\^2\)\(-\)\(1\)\(\ \)\))\)\)\)\)}]],
  "  \n\nand obtain the equation\n\n\t\t\t",
  Cell[BoxData[
      \(\((tan\ c)\) \((x\^2 + y\^2 - 1)\)\ \  = \ \ 2  y\)]],
  ". \n\nA straightforward calculation shows that points on the streamline \
must satisfy the equation  \n\n\t\t\t",
  Cell[BoxData[
      \(x\^2\  + \ \((y - cot\ c)\)\^2\ \  = \ \ 1\  + \ \(cot\^2\) c\)]],
  ",  \n\nwhich is the equation of a circle with center at  ",
  Cell[BoxData[
      \(\((0, cot\ c)\)\)]],
  "  that passes through the points  ",
  Cell[BoxData[
      \(\((\(\[PlusMinus]1\), 0)\)\)]],
  ".  Several streamlines are indicated in Figure 11.95(a)."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.30.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the formula for the complex potential F[z].", "Text"],

Cell[BoxData[{
    \(\(Clear[f, F, \[Phi], \[Psi], W, x, y, z, Z];\)\ \), "\n", 
    \(\(F[Z_]\  = \ 
        Log[\(Z\  - \ 1\)\/\(Z\  + \ 1\)];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi][x_, y_] = 
        ComplexExpand[Re[F[x + \[ImaginaryI]\ y]], 
          TargetFunctions \[Rule] {Re, Im}];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Psi][x_, y_] = 
        Simplify[
          ComplexExpand[Im[F[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Re, Im}]];\)\ \), "\n", 
    \(\(Print["\<W = F[Z] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The velocity potential is:\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = Re[F[x + \[ImaginaryI]y]]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        Re[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The stream function is:\>"];\)\ \), "\n", 
    \(\(Print["\<\[Psi][x,y] = Im[F[x + \[ImaginaryI]y]]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", 
        Im[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Psi][x_, y_] = 
        ArcTan[\(-1\) + x\^2 + y\^2, 2\ y];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a density plot of the velocity potential."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(DensityPlot[\[Phi][x, y], {x, \(-1.5\), 1.5}, {y, \(-1.5\), 1.5}, 
        PlotPoints \[Rule] 100, Mesh \[Rule] False, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential for the\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<source at \!\(z\_1\)=+1 and sink at \
\!\(z\_2\)=-1.\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", Re[F[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        Re[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the stream function."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ContourPlot[\[Psi][x, y], {x, \(-1.5\), 1.5}, {y, 0, 
            1.5}, \[IndentingNewLine]Contours \[Rule] 11, 
          PlotPoints \[Rule] 40, ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ContourPlot[\[Psi][x, y], {x, \(-1.5\), 
            1.5}, {y, \(-1.50001\), \(-0.00001\)}, \
\[IndentingNewLine]Contours \[Rule] 11, PlotPoints \[Rule] 40, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The stream function for the\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<source at \!\(z\_1\)=+1 and sink at \
\!\(z\_2\)=-1.\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", Im[F[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", 
        Im[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the velocity potential."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Phi][x, y], {x, \(-1.5\), 1.5}, {y, \(-1.5\), 1.5}, 
        Contours \[Rule] 11, PlotPoints \[Rule] 40, AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential for the\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<source at \!\(z\_1\)=+1 and sink at \
\!\(z\_2\)=-1.\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", Re[F[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        Re[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Find the inverse of the function F[Z].", "Text"],

Cell[BoxData[{
    \(\(solset\  = \ Solve[F[Z]\  \[Equal] \ W, Z];\)\ \), "\n", 
    \(\(f[x_, y_]\  = \ \ ReplaceAll[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), 
          W \[Rule] x\  + \ \[ImaginaryI]\ y];\)\ \), "\n", 
    \(\(Print["\<W = F[Z] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The inverse function is:\>"];\)\ \), "\n", 
    \(\(Print["\<f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph the stream functions using  f[x,y]."
}], "Text"],

Cell[BoxData[{
    \(\(n\  = \ 12;\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[k];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(eqns1\  = \ 
        N[Table[{Re[f[x, \(\(\ \)\(k\ \[Pi]\)\)\/n]], 
              Im[f[x, \(k\ \[Pi]\)\/n]]}, {k, 1, 2  n, 
              2}]];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ParametricPlot[Evaluate[eqns1], {x, \(-4\), 4}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        N[Table[{Re[f[x, \(\(\ \)\(k\ \[Pi]\)\)\/n]], 
              Im[f[x, \(k\ \[Pi]\)\/n]]}, {k, 0, 2  n, 
              2}]];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ParametricPlot[Evaluate[eqns2], {x, \(-4\), 4}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, PlotRange \[Rule] {{\(-2.5\), 2.5}, {\(-2.5\), 2.5}}, 
        AspectRatio \[Rule] 1, Axes \[Rule] None, Ticks \[Rule] None, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The streamlines for the\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<source at \!\(z\_1\)=+1 and sink at \
\!\(z\_2\)=-1.\>\""];\)\ \), "\n", 
    \(\(Print["\<w = f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The stream function for a fluid flowing from the source at  z = +1  to the \
sink at  z = -1.  \
\>", "Text"],

Cell[BoxData[{
    \(\(n\  = \ 12;\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[k];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\n", 
    \(\(eqns3\  = \ 
        N[Table[{Re[f[k, y]], Im[f[k, y]]}, {k, \(-3\), 3, 
              1}]];\)\ \), "\[IndentingNewLine]", 
    \(\(gr3 = 
        ParametricPlot[Evaluate[eqns3], {y, \(-4\), 4}, 
          PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns4\  = \ 
        N[Table[{Re[f[k, y]], Im[f[k, y]]}, {k, \(-4\) + 1\/2, 4 - 1\/2, 
              1}]];\)\ \), "\[IndentingNewLine]", 
    \(\(gr4 = 
        ParametricPlot[Evaluate[eqns4], {y, \(-4\), 4}, 
          PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[gr3, gr4, PlotRange \[Rule] {{\(-2.5\), 2.5}, {\(-2.5\), 2.5}}, 
        AspectRatio \[Rule] 1, Axes \[Rule] None, Ticks \[Rule] None, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential for the\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<source at \!\(z\_1\)=+1 and sink at \
\!\(z\_2\)=-1.\>\""];\)\ \), "\n", 
    \(\(Print["\<w = f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The velocity potential for a fluid flowing from the source at  z = +1  to the \
sink at  z = -1.  \
\>", "Text"],

Cell[BoxData[{
    \(\(Show[gr1, gr2, gr3, gr4, 
        PlotRange \[Rule] {{\(-2.5\), 2.5}, {\(-2.5\), 2.5}}, 
        AspectRatio \[Rule] 1, Axes \[Rule] None, Ticks \[Rule] None, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The streamlines and velocity potential for the\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<source at \!\(z\_1\)=+1 and sink at \
\!\(z\_2\)=-1.\>\""];\)\ \), "\n", 
    \(\(Print["\<w = f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The streamlines and velocity potential for a fluid flowing from the source at \
 z = +1  to the sink at  z = -1.  \
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.31.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  ",
  StyleBox["(Two sources of equal strength)",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let two sources of unit strength be located at the points  ",
  Cell[BoxData[
      \(z\_1 = \(1\ \ and\ \ z\_2 = \(-1\)\)\)]],
  ".  The resulting complex potential for a fluid flow is  \n\n\t\t\t",
  Cell[BoxData[
      \(F \((z)\)\ \  = \ \ \(log \((z - 1)\)\  - \ 
            log \((z + 1)\)\ \  = \ \ log \((z\^2 - 1)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005B0000i2000`400?l0
0000o`00003oo`3ooomC0?ooo`00o`3ooomC0?ooo`00o`3ooomC0?ooo`00
o`3ooomC0?ooo`00o`3ooomC0?ooo`00O03oool00`3o0000oooo0?ooo`0C
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00l0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0C
0?ooo`030?l0003oool0oooo01H0oooo001l0?ooo`030?l0003oool0oooo
01<0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0?0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool03`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
01<0oooo00<0o`000?ooo`3oool05P3oool007d0oooo00<0o`000?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`0G0?ooo`00O@3oool00`3o0000oooo
0?ooo`0C0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00l0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0C0?ooo`030?l0003oool0oooo01L0oooo001n0?ooo`030?l0003o
ool0oooo01<0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0?0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo01<0oooo00<0o`000?ooo`3oool0603oool007h0oooo00<0o`00
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo00l0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0H0?ooo`00O`3oool00`3o
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo01T0oooo00200?ooo`03
0?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0403oool00`3o0000
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo0180oooo00<0o`000?ooo`3oool06P3oool00840oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0
003oool0oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0K0?ooo`00P@3o
ool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo0100oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo01/0oooo0022
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0703oool0
06`0oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool01@3oool006`0
oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo0100oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00d0
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool01P3oool006d0oooo
00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0A0?ooo`030000
o`3oool0oooo00l0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo01@0oooo00<0003o0?ooo`3oool01`3oool006h0oooo00<0
003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0>0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo01@0oooo00<0003o0?ooo`3oool0203oool006l0oooo00<0003o
0?ooo`3oool0503oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo00l0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo01@0oooo00<0003o0?ooo`3oool02@3oool00700oooo00<0003o0?oo
o`3oool04`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo
00l0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool03`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo
01<0oooo00<0003o0?ooo`3oool02P3oool00740oooo00<0003o0?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01<0
oooo00<0003o0?ooo`3oool02`3oool00780oooo00<0003o0?ooo`3oool0
4`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo01<0oooo
00<0003o0?ooo`3oool0303oool007<0oooo00<0003o0?ooo`3oool04P3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0180oooo00<0
003o0?ooo`3oool03@3oool007<0oooo00<0003o0?ooo`3oool04`3oool0
0`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo01<0oooo00<0003o
0?ooo`3oool03@3oool007@0oooo00<0003o0?ooo`3oool04P3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool03P3oool007D0oooo00<0003o0?ooo`3oool04P3oool00`3o0000
oooo0?ooo`0?0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o
ool03`3oool007H0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0
403oool007L0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?oo
o`0?0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04@3o
ool007P0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0?
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04P3oool0
07T0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0>0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?oo
o`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04`3oool007X0
oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0503oool007/0oooo
00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool05@3oool007/0oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3oool05P3oool007`0oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool05P3oool007d0oooo00<0003o0?oo
o`3oool0403oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool05`3oool007h0oooo00<0003o0?ooo`3o
ool03`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool0603oool007l0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool06@3oool00800oooo00<0003o0?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00l0oooo00<0
003o0?ooo`3oool06P3oool00800oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool06`3oool006`0oooo00<0o`000?ooo`3oool04P3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool03`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo
00D0oooo001/0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`060?ooo`00
K@3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo01<0oooo00<0o`000?ooo`3oool01`3oool006h0oooo00<0
o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`0C0?ooo`030?l0003oool0oooo00P0oooo001_0?ooo`030?l0003oool0
oooo01<0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool04`3oool0
0`3o0000oooo0?ooo`090?ooo`00L03oool20?l001<0oooo00<0003o0?oo
o`3oool03P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool04@3oool20?l000`0oooo001b0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0<0?ooo`00L`3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool03@3oool007@0oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo00h0oooo001e0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0?
0?ooo`00MP3oool20?l00140oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool03`3oool20?l00180oooo001h0?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0B0?ooo`00N@3oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
4`3oool007X0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo01@0oooo001k
0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0E0?ooo`00O03oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00l0oooo00<0o`000?ooo`3oool05P3oool007d0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo01L0oooo001n0?ooo`030?l0003oool0oooo00h0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0H0?ooo`00O`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool06@3o
ool00800oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo01X0oooo001/0?oo
o`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
01<0oooo00<0003o0?ooo`3oool01@3oool006d0oooo00<0003o0?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool04P3oool20000o`P0
oooo001^0?ooo`80003o4`3oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
4@3oool20000o`X0oooo001`0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool02P3o
ool00740oooo0P000?lB0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0@
0?ooo`80003o3@3oool007<0oooo00<0003o0?ooo`3oool0403oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0=0?oo
o`00M03oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0@0?ooo`030000o`3oool0oooo00h0oooo001e0?ooo`80003o
4@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03`3oool20000oa40oooo
001g0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3oool04@3oool007P0oooo0P000?l@
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0>0?ooo`80003o503oool0
07X0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`0D0?ooo`00N`3oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo01D0oooo001l0?ooo`80003o3`3oool20?l000/0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool20?l000l0oooo
0P000?lH0?ooo`00OP3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01P0oooo001o
0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool06@3oool00800oooo0P000?l?0?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`0=0?ooo`80003o703oool00880
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0L0?ooo`00K03oool00`3o0000oooo
0?ooo`0D0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool0503oool20?l000L0oooo
001]0?ooo`80o`005@3oool20000o`h0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00`0oooo0P000?lE0?ooo`80o`002@3oool006l0oooo0P3o000E
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool04`3oool20?l000/0oooo001a0?oo
o`80o`00503oool20000o``0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00X0oooo0P000?lD0?ooo`80o`003@3oool007<0oooo0P3o000D0?ooo`80
003o2`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool20000oa@0
oooo0P3o000?0?ooo`00M@3oool20?l001@0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0B0?ooo`80o`004@3oool007L0oooo0P3o000C0?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool04@3oool20?l001<0oooo001i0?ooo`80o`004P3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo0100oooo0P3o000E0?ooo`00N`3oool20?l0
0140oooo0P000?l:0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?oo
o`80003o4@3oool20?l001L0oooo001m0?ooo`80o`004@3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00l0oooo0P3o000I0?ooo`00O`3oool20?l00100oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`0>0?ooo`80o`006`3oool00840oooo0P3o
000?0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool03@3oool20?l001d0oooo0023
0?ooo`80o`003P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00`0oooo0P3o000O
0?ooo`00Q@3oool20?l000d0oooo0P000?l80?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`060?ooo`80003o3@3oool20?l00240oooo001/0?ooo`80
003o6@3oool20?l000d0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`0;0?ooo`80
o`006P3oool20000o`L0oooo001^0?ooo`<0003o603oool20?l000`0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`0:0?ooo`80o`00603oool40000o`T0oooo
001a0?ooo`@0003o5P3oool20?l000/0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`090?ooo`80o`005P3oool40000o`d0oooo001e0?ooo`@0003o503oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0B0?ooo`@0003o4@3oool007T0oooo0`000?lB0?oo
o`80o`002P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00P0oooo0P3o000B0?oo
o`<0003o5@3oool007`0oooo0P000?lB0?ooo`80o`002@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?oo
o`000?l01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00L0oooo0P3o000B0?ooo`80003o603oool007h0oooo0`000?lA0?ooo`80
o`00203oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00H0oooo0P3o000A0?ooo`<0003o6P3oool00840oooo0`000?l@0?oo
o`80o`001`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
003o00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00D0oooo0P3o000@0?ooo`<0003o7@3oool008@0oooo0P000?l@
0?ooo`80o`001P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00D0003o0?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0oooo00@0
oooo0P3o000@0?ooo`80003o803oool008H0oooo0`000?l?0?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
0080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00d0oooo0`000?lR0?ooo`00R@3oool30000
o`d0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?oo
o`050?l0003oool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3o
ool0003o00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool02`3oool30000obD0oooo002<0?ooo`<0003o
2`3oool20?l000D0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`05
0000o`3oool0oooo0?ooo`3o00000P3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0
oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`030?ooo`80o`002`3o
ool30000obP0oooo001/0?ooo`030?l0003oool0oooo0200oooo0`000?l:
0?ooo`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l0
00020?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00@0003o0?ooo`3oool0o`000`3oool010000?l0
oooo0?ooo`3o00030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0203oool30000ob<0oooo00<0o`000?ooo`3oool01@3oool006d0
oooo1@3o000P0?ooo`80003o2@3oool20?l000<0oooo00D0003o0?ooo`3o
ool0oooo0?l000030?ooo`040000o`3oool0oooo0?l00080oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo0?oo
o`3oool0003o0080oooo00@0o`000?ooo`3oool0003o0P3oool00`3o0000
oooo0?ooo`020?ooo`040000o`3oool0oooo0?ooo`80o`002@3oool20000
ob00oooo1P3o00080?ooo`00LP3oool80?l001X0oooo0P000?l90?ooo`05
0?l0003oool0oooo0?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l2
0?ooo`040?l0003oool0oooo0000o`<0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`070?ooo`80o`005P3oool00`000?l0oooo0?oo
o`0C0?ooo`80o`002@3oool00`000?l0oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`000?l00P3oool0103o0000oooo0?ooo`000?l20?ooo`05
0?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`070?oo
o`80003o6P3oool80?l000h0oooo001j0?ooo`@0o`00603oool20000o`P0
oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`040?l0003oool0oooo
0000o`80oooo00<0o`000?ooo`000?l00`3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool05P3oool0
0`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l20?ooo`060?l0003o
ool0oooo0000o`3oool0o`000`3oool01@000?l0oooo0?ooo`3oool0o`00
00P0oooo0P000?lH0?ooo`@0o`005P3oool007h0oooo1P3o000D0?ooo`<0
003o1P3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00<0o`000?oo
o`000?l00P3oool00`3o0000oooo0000o`020?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool01P3oool20?l001T0oooo00<0003o0?oo
o`3oool05P3oool20?l000P0oooo00<0003o0?ooo`3oool00P3oool01P3o
0000oooo0?ooo`000?l0oooo0?l00080oooo00<0003o0?ooo`3o00000P3o
ool01@000?l0oooo0?ooo`3oool0o`0000H0oooo0`000?lD0?ooo`H0o`00
6P3oool008@0oooo1`3o000@0?ooo`<0003o103oool20?l00080oooo00D0
003o0?ooo`3o0000oooo0000o`020?ooo`050?l000000?l0oooo0?ooo`3o
0000103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo01T0
oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo0080oooo00T0o`000?ooo`000?l0oooo0?l0003oool0
003o0?ooo`3o00000P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
0`000?l@0?ooo`L0o`00803oool008/0oooo1P3o000=0?ooo`80003o103o
ool03@3o0000oooo0?ooo`000?l0oooo0?l0003oool0003o0?ooo`3o0000
003o0?ooo`3o00000`3oool20000o`L0oooo0P3o000L0?ooo`030000o`3o
ool0oooo01T0oooo0P3o00070?ooo`80003o0P3oool02`3o0000oooo0?oo
o`000?l0o`000?ooo`000?l0oooo0?l0003oool0003o00<0oooo00@0o`00
0?ooo`3oool0oooo0P000?l=0?ooo`H0o`009`3oool00940oooo1@3o000:
0?ooo`030000o`3oool0oooo0080oooo00`0o`000?ooo`3oool0003o0?l0
003oool0003o0?l0003oool0003o0?ooo`3o00020?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool0703oool00`000?l0oooo0?ooo`0K
0?ooo`030?l0003oool0oooo00H0oooo00`0003o0?ooo`3oool0o`000?oo
o`000?l0oooo0?l000000?l0o`000?ooo`000?l20?ooo`80o`000`3oool0
0`000?l0oooo0?ooo`080?ooo`D0o`00;@3oool009H0oooo103o00070?oo
o`80003o0`3oool02P3o0000oooo0?ooo`000?l0o`000000o`3o0000oooo
0000o`3o00020?ooo`030000o`3oool0oooo00D0oooo0P3o000O0?ooo`03
0000o`3oool0oooo01`0oooo0P3o00070?ooo`0:0000o`3oool0oooo0?l0
00000?l0oooo0?l000000?l0o`000000o`80oooo00@0o`000?ooo`3oool0
oooo0P000?l70?ooo`@0o`00<P3oool009X0oooo103o00050?ooo`@0003o
0P3o00001P000?l0o`000000o`3o0000003o0?l00080oooo00<0003o0?oo
o`3oool00`3oool30?l00240oooo00<0003o0?ooo`3oool07P3oool30?l0
00D0oooo00T0003o0?ooo`3oool0o`000000o`3o0000003o0?l000000?l0
0P3o00040000o`D0oooo103o000f0?ooo`00WP3oool40?l000D0oooo00@0
003o0?l0003o0000003o0P3o00001@000?l0o`000000o`000?l0oooo00D0
o`00903oool00`000?l0oooo0?ooo`0Q0?ooo`D0o`0000D0oooo0000o`00
0?l0o`000000o`020?l000040000o`3o0000o`000000o`D0oooo103o000j
0?ooo`00XP3oool50?l000030?ooo`000?l0o`0000@0o`0000@0003o0?l0
003o0000o`00:@3oool00`000?l0oooo0?ooo`0V0?ooo`<0o`0000<0003o
0?l0003o00000`3o00000`000?l0oooo0?l000040?l003h0oooo001/0?oo
oc/0003o0`3o00020?oooe`0003o0`3oool40?l003`0003o1`3oool00:L0
oooo0`3o00030?ooo`80o`00;03oool00`000?l0oooo0?ooo`0Y0?ooo`80
o`000P3oool40?l004<0oooo002S0?ooo`@0o`0000D0oooo0000o`3o0000
o`000?ooo`020?l000040000o`3o0000o`000?l002T0oooo00<0003o0?oo
o`3oool09P3oool30?l000040000o`3o0000o`000?ooo`80o`0000<0003o
0?ooo`3o00000`3o000o0?ooo`00WP3oool50?l000@0oooo00@0003o0?l0
003o0000003o0P3o00001@000?l0o`000000o`000?l0oooo00D0o`00903o
ool00`000?l0oooo0?ooo`0Q0?ooo`D0o`0000D0oooo0000o`000?l0o`00
0000o`020?l000040000o`3o0000o`000000o`@0oooo1@3o000j0?ooo`00
V`3oool30?l000H0oooo0`000?l0203oool0o`000000o`3o0000003o0?l0
00000?l0o`000P3oool00`000?l0oooo0?ooo`030?ooo`80o`008P3oool0
0`000?l0oooo0?ooo`0O0?ooo`80o`001@3oool02`000?l0oooo0?ooo`3o
0000003o0?l000000?l0o`000000o`3o0000oooo00<0003o1P3oool30?l0
03L0oooo002G0?ooo`@0o`001`3oool20000o`80oooo0P3o0000203oool0
003o0?l000000?l0o`000?ooo`000?l0o`000P3oool00`000?l0oooo0?oo
o`040?ooo`80o`00803oool00`000?l0oooo0?ooo`0M0?ooo`80o`001P3o
ool02`000?l0oooo0?ooo`3o0000003o0?ooo`3o0000003o0?l000000?l0
oooo0080o`000P3oool20000o`L0oooo103o000c0?ooo`00TP3oool50?l0
00T0oooo0P000?l30?ooo`0<0?l0003oool0oooo0000o`3o0000oooo0000
o`3o0000oooo0000o`3oool0o`000P3oool00`000?l0oooo0?ooo`050?oo
o`80o`007P3oool00`000?l0oooo0?ooo`0K0?ooo`80o`001`3oool03000
0?l0oooo0?ooo`3o0000oooo0000o`3oool0o`000000o`3o0000oooo0000
o`80oooo00@0o`000?ooo`3oool0oooo0P000?l90?ooo`D0o`00;P3oool0
08`0oooo1P3o000<0?ooo`80003o103oool03@3o0000oooo0?ooo`000?l0
oooo0?l0003oool0003o0?ooo`3o0000003o0?ooo`3o00000`3oool20000
o`L0oooo0P3o000L0?ooo`030000o`3oool0oooo01T0oooo0P3o00070?oo
o`80003o0P3oool02`3o0000oooo0?ooo`000?l0o`000?ooo`000?l0oooo
0?l0003oool0003o0080oooo0P3o00030?ooo`80003o303oool60?l002P0
oooo00250?ooo`L0o`00403oool20000o`@0oooo0P3o00020?ooo`050000
o`3oool0o`000?ooo`000?l00P3oool01@3o0000003o0?ooo`3oool0o`00
00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0I0?oo
o`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`020?ooo`090?l0003oool0003o0?ooo`3o0000oooo0000
o`3oool0o`000080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`80
003o403oool70?l00240oooo001n0?ooo`L0o`00503oool30000o`D0oooo
00D0o`000?ooo`3oool0oooo0000o`020?ooo`030?l0003oool0003o0080
oooo00<0o`000?ooo`000?l00P3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo00H0oooo0P3o000I0?ooo`030000o`3oool0oooo01H0
oooo0P3o00080?ooo`030000o`3oool0oooo0080oooo00H0o`000?ooo`3o
ool0003o0?ooo`3o00020?ooo`030000o`3oool0o`000080oooo00D0003o
0?ooo`3oool0oooo0?l000050?ooo`<0003o503oool70?l001X0oooo001j
0?ooo`@0o`006@3oool20000o`L0oooo00D0o`000?ooo`3oool0oooo0000
o`020?ooo`040?l0003oool0oooo0000o`80oooo00<0o`000?ooo`000?l0
0`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo
0?ooo`000?l20?ooo`060?l0003oool0oooo0000o`3oool0o`000`3oool0
1@000?l0oooo0?ooo`3oool0o`0000L0oooo0P000?lI0?ooo`@0o`005P3o
ool007<0oooo1`3o000J0?ooo`<0003o203oool01@3o0000oooo0?ooo`3o
ool0003o00<0oooo00@0o`000?ooo`3oool0003o0P3oool0103o0000oooo
0?ooo`000?l30?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool01`3oool20?l001H0oooo00<0003o0?ooo`3oool04`3oool20?l000T0
oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o
0080oooo00@0o`000?ooo`3oool0003o0P3oool01@3o0000oooo0?ooo`3o
ool0003o00<0oooo00<0o`000?ooo`3oool01P3oool30000oaX0oooo1`3o
000?0?ooo`00K03oool70?l001l0oooo0P000?l90?ooo`80o`000`3oool0
1@000?l0oooo0?ooo`3oool0o`0000<0oooo00@0003o0?ooo`3oool0o`00
0P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0180
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`030?ooo`05
0?l0003oool0oooo0?ooo`000?l00P3oool0103o0000oooo0?ooo`000?l2
0?ooo`030?l0003oool0oooo0080oooo00@0003o0?ooo`3oool0oooo0P3o
00090?ooo`80003o7`3oool80?l000L0oooo002?0?ooo`<0003o2P3oool0
0`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o00000P3o
ool01@000?l0oooo0?ooo`3oool0o`000080oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`040000o`3oool0oooo0?l000<0oooo00@0003o0?ooo`3o
ool0o`000`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00P0oooo0`000?l[0?ooo`00S03oool30000o``0oooo00<0o`000?ooo`3o
ool00`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?oo
o`3oool0oooo0?l000020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo
0?l000030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
2P3oool30000obP0oooo00290?ooo`<0003o3@3oool20?l000D0oooo00<0
003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo
00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3o
ool0oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
0`000?l0oooo0?ooo`030?ooo`80o`003@3oool30000obD0oooo00270?oo
o`80003o3`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000
0`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`0=0?ooo`80003o
8`3oool008@0oooo0`000?l?0?ooo`80o`001P3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000050?oo
o`030000o`3oool0oooo00@0oooo0P3o000?0?ooo`<0003o803oool00840
oooo0`000?l@0?ooo`80o`001`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000
oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00l0oooo00<0003o0?oo
o`3oool03P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00D0oooo0P3o000@0?ooo`<0003o7@3oool0
07l0oooo0P000?lB0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo0100oooo0P000?lK0?ooo`00O03oool30000oa80oooo0P3o0008
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01P3oool20?l00180oooo0`000?lH0?ooo`00N@3oool3
0000oa<0oooo0P3o00090?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01`3oool2
0?l001<0oooo0`000?lE0?ooo`00M@3oool40000oa@0oooo0P3o000:0?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0203oool20?l001@0oooo10000?lA0?oo
o`00L@3oool40000oaH0oooo0P3o000;0?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool02@3oool20?l001H0oooo10000?l=0?ooo`00KP3oool30000oaP0oooo
0P3o000<0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool02P3oool20?l001P0oooo
0`000?l:0?ooo`00K03oool20000oaT0oooo0P3o000<0?ooo`80003o1`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool20000o``0oooo0P3o
000I0?ooo`<0003o1`3oool008H0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0803oool0
08@0oooo0P3o000<0?ooo`80003o2@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool01`3oool20000o``0oooo0P3o000P0?ooo`00PP3oool20?l000d0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0;0?ooo`80o`007P3oool00800oooo
0P3o000>0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool0303oool20?l001`0oooo
001n0?ooo`80o`003`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00d0oooo0P3o
000J0?ooo`00O03oool20?l00100oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0>
0?ooo`80o`00603oool007X0oooo0P3o000A0?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool03`3oool20?l001H0oooo001h0?ooo`80o`004P3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo0100oooo0P3o000D0?ooo`00MP3oool20?l001<0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`0A0?ooo`80o`004P3oool007@0oooo0P3o
000C0?ooo`80003o2`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02@3o
ool20000oa<0oooo0`3o000?0?ooo`00LP3oool20?l001@0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`0C0?ooo`80o`003@3oool00700oooo0P3o000D0?oo
o`80003o303oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02P3oool20000
oaD0oooo0P3o000;0?ooo`00KP3oool20?l001@0oooo0P000?l>0?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0<0?ooo`80003o5@3oool20?l000T0
oooo001/0?ooo`80o`005@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01@0oooo
0P3o00070?ooo`00PP3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01`0oooo0020
0?ooo`80003o3`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool03@3oool2
0000oa`0oooo001o0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool06@3oool007h0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0H0?ooo`00O03oool20000o`l0oooo
0P3o000;0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
0P3o000?0?ooo`80003o603oool007/0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`0E0?ooo`00NP3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01@0oooo001h0?oo
o`80003o403oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03P3oool20000
oa@0oooo001g0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool04@3oool007H0oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0@0?ooo`00M03oool20000oa40oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00l0oooo0P000?l@0?ooo`00L`3oool0
0`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo00d0oooo001a0?ooo`80003o4P3oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool0403oool20000o`d0oooo001`0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo0140
oooo00<0003o0?ooo`3oool02P3oool006l0oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00h0oooo00<0o`000?ooo`3oool04@3oool20000o`X0oooo
001]0?ooo`80003o4`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool04P3o
ool20000o`P0oooo001/0?ooo`030000o`3oool0oooo0180oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool01@3oool0
0800oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo01X0oooo001o0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool03P3oool00`3o0000oooo0?ooo`0I0?ooo`00OP3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool0603oool007d0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo01L0oooo001l0?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0F
0?ooo`00N`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool05@3oool007X0
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo01@0oooo001i0?ooo`030?l0
003oool0oooo00l0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`0C0?ooo`00N03oool00`3o0000oooo0?oo
o`0?0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool04P3oool007L0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo0140oooo001e0?ooo`80o`004P3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0@0?ooo`80o`004@3oool007@0oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo00h0oooo001c0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0=0?ooo`00LP3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0303o
ool00740oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00/0oooo001_0?oo
o`80o`00503oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0B0?oo
o`80o`002`3oool006h0oooo00<0o`000?ooo`3oool04`3oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00P0
oooo001]0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo
00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`070?ooo`00K03o
ool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo01<0oooo0P3o00070?ooo`00P@3oool00`000?l0oooo0?ooo`0?
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`0K0?ooo`00P03oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool00`00
0?l0oooo0?ooo`0K0?ooo`00P03oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03`3oool00`000?l0
oooo0?ooo`0J0?ooo`00O`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`0I0?ooo`00OP3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0H0?ooo`00O@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0G
0?ooo`00O03oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0F0?oo
o`00N`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0F0?ooo`00
N`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0E0?ooo`00NP3o
ool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0D0?ooo`00N@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0C0?ooo`00N03oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool03P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0B0?ooo`00M`3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0A0?ooo`00MP3oool00`000?l0oooo
0?ooo`0B0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
4P3oool00`000?l0oooo0?ooo`0@0?ooo`00M@3oool00`000?l0oooo0?oo
o`0B0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`0?0?ooo`00M03oool00`000?l0oooo0?ooo`0B
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`0>0?ooo`00L`3oool00`000?l0oooo0?ooo`0C0?oo
o`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>0?oo
o`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool04`3oool00`00
0?l0oooo0?ooo`0=0?ooo`00L`3oool00`000?l0oooo0?ooo`0B0?ooo`03
0?l0003oool0oooo0100oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo0100oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0=0?ooo`00LP3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0
003oool0oooo00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo00l0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo
0?ooo`0<0?ooo`00L@3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo0100oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`0;0?ooo`00L03oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0:
0?ooo`00K`3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool03@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
0100oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`090?oo
o`00KP3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0100
oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`080?ooo`00
K@3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`070?ooo`00K03o
ool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo00<0
o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0140oooo00<0o`00
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`050?ooo`00PP3oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo0100oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo01`0oooo00210?ooo`03
0?l0003oool0oooo0180oooo00<0003o0?ooo`3oool0403oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0@0?ooo`03
0000o`3oool0oooo0180oooo00<0o`000?ooo`3oool06`3oool00840oooo
00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0
003oool0oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0100oooo
00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0K0?ooo`00P03o
ool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo0100oooo00<0
o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo01X0oooo001o
0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool04@3oool0
0`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0@
0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool06@3oool0
07h0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0@0?oo
o`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0H0?oo
o`00OP3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo0140
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0=0?ooo`03
0?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo01P0
oooo001m0?ooo`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00h0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0A0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0
5`3oool007`0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo0100oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?oo
o`0G0?ooo`00O03oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00l0oooo00<0o`00
0?ooo`3oool04@3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0
oooo01H0oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{338, 228},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.95 (b)",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/sourcesink/SourceSinkFigures/\
mat1195.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Two sources of unit strength"
}], "Text"],

Cell[TextData[{
  "The velocity potential and stream function are \n\n\n\t\t\t",
  Cell[BoxData[
      \(\[Phi] \((x, y)\)\ \  = \ \ ln | z\^2 - 1 | \)]],
  ",   and  \n\n\t\t\t",
  Cell[BoxData[
      \(\[Psi] \((x, y)\)\ \  = \ \ arg \((z\^2 - 1)\)\)]],
  ",  \n\nrespectively.  Solving for the streamline  ",
  Cell[BoxData[
      \(\[Psi] \((x, y)\)\  = \ c\)]],
  ",  we start with  \n\n\t\t\t",
  Cell[BoxData[{
      \(c\ \  = \ \ \(arg \((z\^2 - 1)\)\ \  = \ \ arg \((x\^2 - y\^2 - 
                1\  + \ \[ImaginaryI]\ 2  x\ y)\)\)\ \ \[IndentingNewLine]\), 
    "\[IndentingNewLine]", 
      \(\ \ \ \ \ \(\(=\)\(\ \ \)\(arctan \((\(2  xy\)\/\(x\^2 - y\^2 - \
1\))\)\)\)\)}]],
  "\n\nand obtain the equation  \n\n\t\t\t",
  Cell[BoxData[
      \(x\^2\ \  + \ \ 2  x\ y\ cot\ c\ \  - \ \ y\^2\ \ \  = \ \ \ 1\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\t If we express this equation in the form  ",
  Cell[BoxData[
      \(\((x\  - \ y\ tan  c\/2)\) \((x\  + \ 
              y\ cot  c\/2)\)\ \  = \ \ 1\)]],
  "  then we can get  \n\n\t\t\t",
  Cell[BoxData[
      \(\((x\ cos  c\/2\  - \ y\ sin  c\/2)\) \((x\ sin  c\/2\  + \ 
              y\ cos  c\/2)\)\ \  = \ \ sin  c\/2\ \ cos  c\/2\)]],
  ",   or  \n\t\t\t\n\t\t\t",
  Cell[BoxData[
      \(\((x\ cos  c\/2\  - \ y\ sin  c\/2)\) \((x\ sin  c\/2\  + \ 
              y\ cos  c\/2)\)\ \  = \ \ \(sin\ c\)\/2\)]],
  ".\n\nNow use the rotation of axes  \n\n\t\t\t",
  Cell[BoxData[{
      RowBox[{
        RowBox[{\(x\^*\), "  ", "=", "  ", 
          RowBox[{\(x\ cos \(-c\)\/2\), " ", "+", " ", 
            RowBox[{"y", " ", "sin", \(\(-c\)\/2\), 
              StyleBox[
                RowBox[{" ", 
                  StyleBox["  ",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}]}]], 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}]}]}]}], "\n"}], "\[IndentingNewLine]",
     
      RowBox[{\(\(y\^*\)\ \  = \ \ \(-\ x\)\ sin \(-c\)\/2\  + \ 
            y\ cos \(-c\)\/2\), 
        StyleBox[" ",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}]}]}]],
  "  \n\nthen the streamlines must satisfy the equation   \n\n\t\t\t",
  Cell[BoxData[
      \(\(x\^*\) \(y\^*\)\ \  = \ \ \(sin\ c\)\/2\)]],
  "  \n\nand are rectangular hyperbolas with centers at the origin that pass \
through the points  ",
  Cell[BoxData[
      \(z\  = \ \(\[PlusMinus]1\)\)]],
  ".  Several streamlines are indicated in Figure 11.95(b)."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.31.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the formula for the complex potential F[z].", "Text"],

Cell[BoxData[{
    \(\(Clear[f, f1, f2, F, \[Phi], \[Psi], W, x, y, z, Z];\)\ \), "\n", 
    \(\(F[Z_]\  = \ Log[Z\^2\  - \ 1];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi][x_, y_] = 
        ComplexExpand[Re[F[x + \[ImaginaryI]\ y]], 
          TargetFunctions \[Rule] {Re, Im}];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Psi][x_, y_] = 
        ComplexExpand[Im[F[x + \[ImaginaryI]\ y]], 
          TargetFunctions \[Rule] {Re, Im}];\)\ \), "\n", 
    \(\(Print["\<W = F[Z] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The velocity potential is:\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = Re[F[x + \[ImaginaryI]y]]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        Re[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The stream function is:\>"];\)\ \), "\n", 
    \(\(Print["\<\[Psi][x,y] = Im[F[x + \[ImaginaryI]y]]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", 
        Im[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a density plot of the velocity potential."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(DensityPlot[\[Phi][x, y], {x, \(-1.5\), 1.5}, {y, \(-1.5\), 
          1.5}, \[IndentingNewLine]PlotPoints \[Rule] 100, 
        Mesh \[Rule] False, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential for two sources\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<of unit strength at \!\(z\_1\)=+1 and \
\!\(z\_2\)=-1.\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", Re[F[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        Re[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the stream function."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ContourPlot[\[Psi][x, y], {x, 0.00001, 1.5}, {y, 0.00001, 
            1.5}, \[IndentingNewLine]Contours \[Rule] 11, 
          PlotPoints \[Rule] 40, ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ContourPlot[\[Psi][x, y], {x, \(-1.5\), \(-0.00001\)}, {y, 0.00001, 
            1.5}, \[IndentingNewLine]Contours \[Rule] 11, 
          PlotPoints \[Rule] 40, ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr3 = 
        ContourPlot[\[Psi][x, y], {x, 0.00001, 
            1.5}, {y, \(-1.5\), \(-0.00001\)}, \[IndentingNewLine]Contours \
\[Rule] 11, PlotPoints \[Rule] 40, ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr4 = 
        ContourPlot[\[Psi][x, 
            y], {x, \(-1.5\), \(-0.00001\)}, {y, \(-1.5\), \(-0.00001\)}, \
\[IndentingNewLine]Contours \[Rule] 11, PlotPoints \[Rule] 40, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, gr3, gr4, AspectRatio \[Rule] 1, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The stream function for two sources\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<of unit strength at \!\(z\_1\)=+1 and \
\!\(z\_2\)=-1.\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", Im[F[z]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", 
        Im[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the velocity potential."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ContourPlot[\[Phi][x, y], {x, \(-1.5\), 1.5}, {y, \(-1.5\), 
          1.5}, \[IndentingNewLine]Contours \[Rule] 11, 
        PlotPoints \[Rule] 40, \[IndentingNewLine]AspectRatio \[Rule] 1, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential for two sources\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<of unit strength at \!\(z\_1\)=+1 and \
\!\(z\_2\)=-1.\>\""];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", Re[F[z]]];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        Re[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Find the inverse of the function F[Z].", "Text"],

Cell[BoxData[{
    \(\(solset\  = \ Solve[F[Z]\  \[Equal] \ W, Z];\)\ \), "\n", 
    \(\(f[x_, y_]\  = \ \ ReplaceAll[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), 
          W \[Rule] x\  + \ \[ImaginaryI]\ y];\)\ \), "\n", 
    \(\(Print["\<W = F[Z] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The inverse function is:\>"];\)\ \), "\n", 
    \(\(Print["\<f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph the stream functions using  f[x,y]."
}], "Text"],

Cell[BoxData[{
    \(\(n\  = \ 12;\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[k];\)\ \), "\n", 
    \(\(eqns1\  = \ 
        N[Table[{Re[f[x, \(k\ \[Pi]\)\/n]], Im[f[x, \(k\ \[Pi]\)\/n]]}, {k, 
              0, n - 1, 2}]];\)\ \), "\n", 
    \(\(eqns2\  = \ 
        N[Table[{Re[f[x, \(k\ \[Pi]\)\/n]], Im[f[x, \(k\ \[Pi]\)\/n]]}, {k, 
              12 + 2, 12 + n - 1, 2}]];\)\ \), "\n", 
    \(\(eqns3\  = \ 
        N[Table[{Re[\(-f[x, \(k\ \[Pi]\)\/n]\)], 
              Im[\(-f[x, \(k\ \[Pi]\)\/n]\)]}, {k, 0, n - 1, 
              2}]];\)\ \), "\n", 
    \(\(eqns4\  = \ 
        N[Table[{Re[\(-f[x, \(k\ \[Pi]\)\/n]\)], 
              Im[\(-f[x, \(k\ \[Pi]\)\/n]\)]}, {k, 12 + 2, 12 + n - 1, 
              2}]];\)\ \), "\n", 
    \(\(eqns\ \  = \ Union[eqns1, eqns2, eqns3, eqns4];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns], {x, \(-3\), 3}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        N[Table[{Re[f[x, \(k\ \[Pi]\)\/n]], Im[f[x, \(k\ \[Pi]\)\/n]]}, {k, 
              1, n - 1, 2}]];\)\ \), "\n", 
    \(\(eqns2\  = \ 
        N[Table[{Re[f[x, \(k\ \[Pi]\)\/n]], Im[f[x, \(k\ \[Pi]\)\/n]]}, {k, 
              12 + 1, 12 + n - 1, 2}]];\)\ \), "\n", 
    \(\(eqns3\  = \ 
        N[Table[{Re[\(-f[x, \(k\ \[Pi]\)\/n]\)], 
              Im[\(-f[x, \(k\ \[Pi]\)\/n]\)]}, {k, 1, n - 1, 
              2}]];\)\ \), "\n", 
    \(\(eqns4\  = \ 
        N[Table[{Re[\(-f[x, \(k\ \[Pi]\)\/n]\)], 
              Im[\(-f[x, \(k\ \[Pi]\)\/n]\)]}, {k, 12 + 1, 12 + n - 1, 
              2}]];\)\ \), "\n", 
    \(\(eqns\ \  = \ Union[eqns1, eqns2, eqns3, eqns4];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns], {x, \(-3\), 3}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Blue, Line[{{0, 3}, {0, \(-3\)}}], 
            Line[{{\(-0.98\), 0}, {0.98, 0}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, boundary, AspectRatio \[Rule] 1, 
        Ticks \[Rule] None, 
        PlotRange \[Rule] {{\(-2.35\), 2.35}, {\(-2.35\), 2.35}}, 
        AspectRatio \[Rule] 1, Axes \[Rule] None, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The streamlines for two sources\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<of unit strength at \!\(z\_1\)=+1 and \
\!\(z\_2\)=-1.\>\""];\)\ \), "\n", 
    \(\(Print["\<w = f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The stream function for a fluid with two sources of unit strength be located \
at the points  z = 1  and  z = -1. \
\>", "Text"],

Cell[BoxData[{
    \(\(n\  = \ 12;\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[k];\)\ \), "\n", 
    \(\(eqns1\  = \ 
        N[Table[{Re[f[k\ , y]], Im[f[k\ , y]]}, {k, \(-2\), 2, 
              1}]];\)\ \), "\n", 
    \(\(eqns3\  = \ 
        N[Table[{Re[\(-f[k\ , y]\)], Im[\(-f[k\ , y]\)]}, {k, \(-2\), 2, 
              1}]];\)\ \), "\n", 
    \(\(eqns\ \  = \ Union[eqns1, eqns3];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(graph3 = 
        ParametricPlot[Evaluate[eqns], {y, \(-\[Pi]\), \[Pi]}, 
          PlotStyle \[Rule] Green, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        N[Table[{Re[f[k\ , y]], Im[f[k\ , y]]}, {k, \(-\(5\/2\)\), 3\/2, 
              1}]];\)\ \), "\n", 
    \(\(eqns4\  = \ 
        N[Table[{Re[\(-f[k\ , y]\)], Im[\(-f[k\ , y]\)]}, {k, \(-\(5\/2\)\), 
              3\/2, 1}]];\)\ \), "\n", 
    \(\(eqns\ \  = \ Union[eqns2, eqns4];\)\ \), "\n", 
    \(\(graph4 = 
        ParametricPlot[Evaluate[eqns], {y, \(-\[Pi]\), \[Pi]}, 
          PlotStyle \[Rule] Magenta, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Show[graph3, graph4, AspectRatio \[Rule] 1, Ticks \[Rule] None, 
        PlotRange \[Rule] {{\(-2.35\), 2.35}, {\(-2.35\), 2.35}}, 
        AspectRatio \[Rule] 1, Axes \[Rule] None, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential for two sources\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<of unit strength at \!\(z\_1\)=+1 and \
\!\(z\_2\)=-1.\>\""];\)\ \), "\n", 
    \(\(Print["\<w = f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\
The velocity potential for a fluid with two sources of unit strength be \
located at the points  z = 1  and  z = -1. \
\>", "Text"],

Cell[BoxData[{
    \(\(Show[graph1, graph2, graph3, graph4, boundary, AspectRatio \[Rule] 1, 
        Ticks \[Rule] None, 
        PlotRange \[Rule] {{\(-2.35\), 2.35}, {\(-2.35\), 2.35}}, 
        AspectRatio \[Rule] 1, Axes \[Rule] None, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The streamlines and the velocity potential for two \
sources\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<of unit strength at \!\(z\_1\)=+1 and \
\!\(z\_2\)=-1.\>\""];\)\ \), "\n", 
    \(\(Print["\<w = f[x,y] = \>", f[x, y]];\)\ \)}], "Input"],

Cell["\<\
The streamlines and velocity potential for a fluid with two sources of unit \
strength be located at the points  z = 1  and  z = -1. \
\>", "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Ideal Fluid Flow",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\tLet an ideal fluid flow in a domain in the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane be effected by a source located at the point ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  Then the flow at points ",
  StyleBox["z",
    FontFamily->"Courier New"],
  ", which lie in a small neighborhood of the point ",
  Cell[BoxData[
      \(z\_0\)]],
  ", is approximated by that of a source with the complex potential  \n\n\t\t\
\t",
  Cell[BoxData[
      \(F \((z)\)\ \  = \ \ log \((z - z\_0)\)\  + \ constant\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "If  ",
  Cell[BoxData[
      \(w\  = \ S \((z)\)\)]],
  "  is a conformal mapping and  ",
  Cell[BoxData[
      \(w\_0\  = \ S \((z\_0)\)\)]],
  ",  then ",
  StyleBox["S(z)",
    FontFamily->"Courier New"],
  " has a nonzero derivative at ",
  Cell[BoxData[
      \(z\_0\)]],
  " and   \n\n\t\t\t",
  Cell[BoxData[
      \(w - 
          w\_0\ \  = \ \ \((z - 
              z\_0)\) \((S' \((z\_0)\)\  + \ \[Eta] \((z)\))\)\)]],
  "\n\nwhere  ",
  Cell[BoxData[
      \(\[Eta] \((z)\) \[Rule] 0\)]],
  "  as  ",
  Cell[BoxData[
      \(z \[Rule] z\_0\)]],
  ".  Taking logarithms yields \n\n\t\t\t",
  Cell[BoxData[
      \(log \((w - 
              w\_0)\)\ \  = \ \ log \((z - 
                z\_0)\)\ \  + \ \ Log \((S' \((z\_0)\)\  + \ \[Eta] \
\((z)\))\)\)]],
  ".\n\nBecause  ",
  Cell[BoxData[
      \(S' \((z\_0)\) \[NotEqual] 0\)]],
  ",  the term  ",
  Cell[BoxData[
      \(Log \((S' \((z\_0)\)\  + \ \[Eta] \((z)\))\)\)]],
  "  approaches the constant value  ",
  Cell[BoxData[
      \(Log \((S' \((z\_0)\))\)\)]],
  "  as  ",
  Cell[BoxData[
      \(z \[Rule] z\_0\)]],
  ".  As  ",
  Cell[BoxData[
      \(log \((z - z\_0)\)\)]],
  "  is the complex potential for a source located at the point ",
  Cell[BoxData[
      \(z\_0\)]],
  ", the image of a source under a conformal mapping is a source."
}], "Text"],

Cell[TextData[{
  "\tWe can use the technique of conformal mapping to determine the fluid \
flow in a domain ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " in the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane that is produced by sources and sinks.  If we can construct a \
conformal mapping  ",
  Cell[BoxData[
      \(w\  = \ S \((z)\)\)]],
  "  so that the image of sources, sinks, and boundary curves for the flow in \
",
  StyleBox["D",
    FontFamily->"Courier New"],
  " are mapped onto sources, sinks, and boundary curves in a domain ",
  StyleBox["G",
    FontFamily->"Courier New"],
  " where the complex potential is known to be ",
  Cell[BoxData[
      \(\(F\_1\) \((w)\)\)]],
  ", then the complex potential in ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " is given by ",
  Cell[BoxData[
      \(\(F\_2\) \((z)\) = \(F\_1\) \((S \((z)\))\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 11.32.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Suppose that the lines  ",
  Cell[BoxData[
      \(x\  = \ \(\[PlusMinus]\(\[Pi]\/2\)\)\)]],
  "  are considered as walls of a containing vessel for a fluid flow produced \
by a single source of unit strength located at the origin.  The conformal \
mapping  ",
  Cell[BoxData[
      \(w\  = \ \(S \((z)\)\  = \ sin\ z\)\)]],
  "   maps the infinite strip bounded by the lines  ",
  Cell[BoxData[
      \(x\  = \ \(\[PlusMinus]\(\[Pi]\/2\)\)\)]],
  "  onto the ",
  StyleBox["w",
    FontFamily->"Courier New"],
  " plane slit along the boundary rays  ",
  Cell[BoxData[
      \(u \[LessEqual] \(-1\), v = 0\)]],
  "  and  ",
  Cell[BoxData[
      \(u \[GreaterEqual] 1, v = 0\)]],
  ",  and the image of the source at  ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  "  is a source located at  ",
  Cell[BoxData[
      \(w\_0 = 0\)]],
  ".  The complex potential  \n\n\t\t\t",
  Cell[BoxData[
      \(\(F\_1\) \((w)\)\  = \ log\ w\)]],
  "  \n\ndetermines a fluid flow in the w plane past the boundary curves  ",
  Cell[BoxData[
      \(u \[LessEqual] \(-1\), v = 0\)]],
  "  and  ",
  Cell[BoxData[
      \(u \[GreaterEqual] 1, v = 0\)]],
  ", which lie along streamlines of the flow.  Therefore the complex \
potential for the fluid flow in the infinite strip in the z plane is  \n\n\t\t\
\t",
  Cell[BoxData[
      \(\(F\_2\) \((z)\)\ \  = \ \ \(\(F\_1\) \((S \((z)\))\)\ \  = \ \ log\ \
\((sin\ z)\)\)\)]],
  ".  \n\nSeveral streamlines for the flow are illustrated in Figure 11.96. "
}], "Text"],

Cell[TextData[Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000400000i2000`400?l0
0000o`00003oo`3oool10?ooo`00o`3oool10?ooo`00o`3oool10?ooo`00
o`3oool10?ooo`00o`3oool10?ooo`00o`3oool10?ooo`00K03oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`06
0?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`06
0?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`06
0?ooo`00K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`00K03o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`06
0?ooo`00K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`00K03o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`06
0?ooo`00K03oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`00K03o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0?
0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03`3oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0403oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0@0?ooo`030?l0
003oool0oooo00h0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`06
0?ooo`00K03oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`060?ooo`00K03o
ool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`00
0?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool05P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0
oooo0?ooo`0F0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3o
ool05P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`0G0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool05`3oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0H0?ooo`80o`00
3`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00<0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool03@3oool20?l001X0oooo00<0003o0?oo
o`3oool01P3oool006`0oooo00<0003o0?ooo`3oool06P3oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool0103oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo01X0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o0?oo
o`3oool06`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0
o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo01/0oooo00<0003o0?ooo`3oool01P3o
ool006`0oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool00`3oool0
10000?l0oooo0?ooo`3o00030?ooo`050000o`3oool0oooo0?ooo`3o0000
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0L0?ooo`030000
o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo01d0oooo00<0
o`000?ooo`3oool03@3oool20000o`H0oooo00<0o`000?ooo`3oool00`3o
ool01@000?l0oooo0?ooo`3oool0o`000080oooo00D0003o0?ooo`3oool0
oooo0?l000030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool01@3oool20000o`l0oooo00<0o`000?ooo`3oool07@3oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0N0?ooo`80o`00
3`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00@0003o0?ooo`3oool0o`000P3oool01@000?l0oooo0?ooo`3oool0o`00
0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00d0oooo0P3o000P0?ooo`030000o`3oool0oooo
00H0oooo001/0?ooo`030000o`3oool0oooo0200oooo0P3o000>0?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool010000?l0
oooo0?ooo`3o00020?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0303oool20?l00280oooo00<0003o0?ooo`3oool01P3oool0
06`0oooo00<0003o0?ooo`3oool08P3oool20?l000d0oooo00<0003o0?oo
o`3oool0103oool20?l000<0oooo00H0003o0?ooo`3oool0o`000?ooo`00
0?l20?ooo`040?l0003oool0oooo0000o`<0oooo0P3o00060?ooo`030000
o`3oool0oooo00/0oooo0P3o000T0?ooo`030000o`3oool0oooo00H0oooo
001/0?ooo`030000o`3oool0oooo02@0oooo0P3o000<0?ooo`80003o1P3o
ool0103o0000oooo0?ooo`000?l20?ooo`030?l0003oool0003o0080oooo
00@0o`000?ooo`3oool0003o0P3oool00`3o0000oooo0?ooo`040?ooo`80
003o303oool20?l002H0oooo00<0003o0?ooo`3oool01P3oool006`0oooo
00<0003o0?ooo`3oool09P3oool30?l000/0oooo00<0003o0?ooo`3oool0
103oool02P3o0000oooo0?ooo`000?l0oooo0?l0003oool0003o0?ooo`3o
00020?ooo`040000o`3oool0oooo0?l000H0oooo00<0003o0?ooo`3oool0
2@3oool30?l002P0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0
003o0?ooo`3oool0:@3oool40?l000P0oooo0P000?l50?ooo`0;0?l0003o
ool0003o0?ooo`3o0000oooo0000o`3oool0o`000?ooo`000?l00P3oool0
0`3o0000oooo0?ooo`030?ooo`80003o203oool40?l002/0oooo00<0003o
0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool0;@3oool20?l0
00P0oooo0P000?l30?ooo`0=0?l0003oool0oooo0000o`3o0000oooo0000
o`3oool0o`000?ooo`000?l0oooo0?l000040?ooo`80003o203oool20?l0
02l0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3o
ool0;`3oool20?l000P0oooo0P000?l20?ooo`090?l0003oool0003o0?oo
o`3o0000003o0?ooo`3o0000003o0080oooo00<0o`000?ooo`3oool00P00
0?l80?ooo`80o`00<@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`0a0?ooo`<0o`001`3oool03@000?l0oooo0?ooo`3o
0000oooo0000o`3o0000003o0?ooo`3o0000003o0?ooo`3o00000P3oool0
0`000?l0oooo0?ooo`050?ooo`<0o`00<`3oool00`000?l0oooo0?ooo`06
0?ooo`00K03oool00`000?l0oooo0?ooo`0d0?ooo`@0o`00103oool20000
o`0:0?ooo`3o0000oooo0?l000000?l0o`000000o`3oool0o`000?ooo`80
003o103oool40?l003H0oooo00<0003o0?ooo`3oool01P3oool006`0oooo
00<0003o0?ooo`3oool0>03oool40?l00080oooo00<0003o0?ooo`3o0000
10000?l00`3o0000oooo0000o`020?ooo`@0o`00>P3oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0l0?ooo`<0o`0000H0
003o0?l0003o0000003o0?ooo`3o00020000o`<0o`00?P3oool00`000?l0
oooo0?ooo`060?ooo`00K03ooom40000o`<0ooooA@000?l80?ooo`00K03o
ool00`000?l0oooo0?ooo`0o0?ooo`80o`00103oool20?l00440oooo00<0
003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool0?@3oool2
0?l000030000o`3o0000oooo0080003o00<0o`000000o`000?l00P3o000o
0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo
03P0oooo1@3o0000103oool0003o0?ooo`3o00020000o`060?l000000?l0
o`000?ooo`000?l0oooo1@3o000j0?ooo`030000o`3oool0oooo00H0oooo
001/0?ooo`030000o`3oool0oooo03D0oooo0`3o00040?ooo`80003o00X0
oooo0?l0003oool0o`000000o`3o0000003o0?ooo`3o0000oooo0P000?l4
0?ooo`<0o`00=`3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`00
0?l0oooo0?ooo`0b0?ooo`<0o`001P3oool03@000?l0oooo0?ooo`3o0000
oooo0000o`3o0000003o0?ooo`3o0000003o0?ooo`3o00000P3oool00`00
0?l0oooo0?ooo`040?ooo`<0o`00=03oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`0`0?ooo`80o`001`3oool20000o`80
oooo00T0o`000?ooo`000?l0oooo0?l000000?l0oooo0?l000000?l00P3o
ool00`3o0000oooo0?ooo`020000o`L0oooo0P3o000b0?ooo`030000o`3o
ool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo02d0oooo0`3o0007
0?ooo`80003o0`3oool03@3o0000oooo0?ooo`000?l0o`000?ooo`000?l0
oooo0?l0003oool0003o0?ooo`3o0000103oool20000o`L0oooo0`3o000_
0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo
02T0oooo103o00080?ooo`80003o1@3oool02`3o0000oooo0000o`3oool0
o`000?ooo`000?l0oooo0?l0003oool0003o0080oooo00<0o`000?ooo`3o
ool00`3oool20000o`P0oooo103o000[0?ooo`030000o`3oool0oooo00H0
oooo001/0?ooo`030000o`3oool0oooo02L0oooo0P3o000;0?ooo`030000
o`3oool0oooo00@0oooo00X0o`000?ooo`3oool0003o0?ooo`3o0000oooo
0000o`3oool0o`000P3oool010000?l0oooo0?ooo`3o00060?ooo`030000
o`3oool0oooo00T0oooo0P3o000Y0?ooo`030000o`3oool0oooo00H0oooo
001/0?ooo`030000o`3oool0oooo02D0oooo0P3o000<0?ooo`030000o`3o
ool0oooo00@0oooo00@0o`000?ooo`3oool0003o0P3oool00`3o0000oooo
0000o`020?ooo`040?l0003oool0oooo0000o`80oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0:0?ooo`80o`009`3oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0R0?ooo`<0o`00
303oool20000o`D0oooo0P3o00030?ooo`060000o`3oool0oooo0?l0003o
ool0003o0P3oool0103o0000oooo0?ooo`000?l30?ooo`80o`001@3oool2
0000o``0oooo0`3o000T0?ooo`030000o`3oool0oooo00H0oooo001/0?oo
o`030000o`3oool0oooo0200oooo0P3o000>0?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00P3oool010000?l0oooo0?ooo`3o0002
0?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0303o
ool20?l00280oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o
0?ooo`3oool07P3oool20?l000l0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`040000o`3oool0oooo0?l00080oooo00D0
003o0?ooo`3oool0oooo0?l000020?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`0=0?ooo`80o`00
803oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`0M0?ooo`030?l0003oool0oooo00d0oooo0P000?l60?ooo`030?l0003o
ool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`050000
o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo00D0oooo0P000?l?0?ooo`030?l0003oool0oooo01d0
oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool0
703oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool00`3oool010000?l0oooo0?ooo`3o00030?ooo`05
0000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`03
0000o`3oool0oooo01/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3o
ool0oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0
oooo00H0oooo001/0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?oo
o`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00@0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`0J0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0
oooo01P0oooo0P3o000?0?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0=0?ooo`80o`00
6P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`0G0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00l0oooo00<0o`000?ooo`3oool05`3oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0
oooo00d0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`06
0?ooo`00K03oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo00d0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`060?ooo`00K03o
ool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`00
0?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`0@0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`0@0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0?
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0403oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03`3oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`06
0?ooo`00K03oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00`0
oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`00K03o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`00
0?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`06
0?ooo`00K03oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`00K03o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`06
0?ooo`00K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`00K03o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`06
0?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`06
0?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`06
0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{256, 228},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.96",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/sourcesink/SourceSinkFigures/\
mat1196.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  A source in the center of a strip. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.32.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the formula for the complex potential F[z].", "Text"],

Cell[BoxData[{
    \(\(Clear[f, F, \[Phi], \[Psi], W, x, y, z, Z];\)\ \), "\n", 
    \(\(F[Z_]\  = \ Log[Sin[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi][x_, y_] = 
        ComplexExpand[Re[F[x + \[ImaginaryI]\ y]], 
          TargetFunctions \[Rule] {Re, Im}];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Psi][x_, y_] = 
        ComplexExpand[Im[F[x + \[ImaginaryI]\ y]], 
          TargetFunctions \[Rule] {Re, Im}];\)\ \), "\n", 
    \(\(Print["\<W = F[Z] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The velocity potential is:\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = Re[F[x + \[ImaginaryI]y]]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        Re[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The stream function is:\>"];\)\ \), "\n", 
    \(\(Print["\<\[Psi][x,y] = Im[F[x + \[ImaginaryI]y]]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", 
        Im[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a density plot of the velocity potential."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(DensityPlot[\[Phi][x, y], {x, \(-\[Pi]\)\/2, \[Pi]\/2}, {y, \(-2.5\), 
          2.5}, \[IndentingNewLine]PlotPoints \[Rule] 100, 
        Mesh \[Rule] False, \[IndentingNewLine]AspectRatio \[Rule] 5\/\[Pi], 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential is:\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        Re[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a density plot of the stream function."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ContourPlot[\[Psi][x, y], {x, \(-\[Pi]\)\/2, \[Pi]\/2}, {y, 0.00001, 
            2.5}, \[IndentingNewLine]Contours \[Rule] 11, 
          PlotPoints \[Rule] 40, ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ContourPlot[\[Psi][x, 
            y], {x, \(-\[Pi]\)\/2, \[Pi]\/2}, {y, \(-2.50001\), \
\(-0.00001\)}, \[IndentingNewLine]Contours \[Rule] 11, PlotPoints \[Rule] 40, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, AspectRatio \[Rule] 5\/\[Pi], 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The stream function\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", 
        Im[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the velocity potential."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ContourPlot[\[Phi][x, y], {x, \(-\[Pi]\)\/2, \[Pi]\/2}, {y, 0, 
            2.5}, \[IndentingNewLine]Contours \[Rule] 11, 
          PlotPoints \[Rule] 40, ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ContourPlot[\[Phi][x, 
            y], {x, \(-\[Pi]\)\/2, \[Pi]\/2}, {y, \(-2.50001\), \
\(-0.00001\)}, \[IndentingNewLine]Contours \[Rule] 11, PlotPoints \[Rule] 40, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, AspectRatio \[Rule] 5\/\[Pi], 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential is:\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        Re[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Find the inverse of the function F[Z].", "Text"],

Cell[BoxData[{
    \(\(solset\  = \ Solve[F[Z]\  \[Equal] \ W, Z];\)\ \), "\n", 
    \(\(f[x_, y_]\  = \ \ ReplaceAll[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), 
          W \[Rule] x\  + \ \[ImaginaryI]\ y];\)\ \), "\n", 
    \(\(Print["\<W = F[Z] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The inverse function is:\>"];\)\ \), "\n", 
    \(\(Print["\<f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph the stream functions using  f[x,y]."
}], "Text"],

Cell[BoxData[{
    \(\(n\  = \ 12;\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[k];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        Table[{Re[f[x, \(k\ \[Pi]\)\/n]], Im[f[x, \(k\ \[Pi]\)\/n]]}, {k, 2, 
            n - 2, 2}];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ParametricPlot[Evaluate[eqns1], {x, \(-3\), 3}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\n", 
    \(\(eqns2\  = \ 
        Table[{Re[f[x, \(k\ \[Pi]\)\/n]], Im[f[x, \(k\ \[Pi]\)\/n]]}, {k, 
            n + 2, 2  n - 2, 2}];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ParametricPlot[Evaluate[eqns2], {x, \(-3\), 3}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns3\  = \ 
        Table[{Re[f[x, \(k\ \[Pi]\)\/n]], Im[f[x, \(k\ \[Pi]\)\/n]]}, {k, 1, 
            2  n, 2}];\)\ \), "\[IndentingNewLine]", 
    \(\(gr3 = 
        ParametricPlot[Evaluate[eqns3], {x, \(-3\), 3}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Blue, Line[{{\(-\[Pi]\)\/2, \(-3\)}, {\(-\[Pi]\)\/2, 3}}], 
            Line[{{\[Pi]\/2, \(-3\)}, {\[Pi]\/2, 3}}], 
            Line[{{0, \(-0.045\)}, {0, \(-3\)}}], Line[{{0, 0.045}, {0, 3}}], 
            Line[{{\(-\[Pi]\)\/2, 0}, {\(-0.045\), 0}}], 
            Line[{{0.045, 0}, {\[Pi]\/2, 0}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, gr3, boundary, 
        PlotRange \[Rule] {{\(-1.58\), 1.58}, {\(-2.5\), 2.5}}, 
        AspectRatio \[Rule] 5\/3.16, Ticks \[Rule] None, Axes \[Rule] None, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<    w = f[x,y] = \>", 
        f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The stream function for a fluid flow in the infinite strip  ",
  Cell[BoxData[
      \(\(-\[Pi]\)\/2 < Re[z] < \[Pi]\/2\)]],
  "  with a single source at the origin."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 11.33.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Suppose that the lines  ",
  Cell[BoxData[
      \(x\  = \ \(\[PlusMinus]\(\[Pi]\/2\)\)\)]],
  "  are considered as walls of a containing vessel for the fluid flow \
produced by a single source of unit strength located at the point  ",
  Cell[BoxData[
      \(z\_1\  = \ \[Pi]\/2\)]],
  "  and a sink of unit strength located at the point  ",
  Cell[BoxData[
      \(z\_2\  = \ \(-\(\[Pi]\/2\)\)\)]],
  ".  The conformal mapping  ",
  Cell[BoxData[
      \(w\  = \ \(S \((z)\)\  = \ sin\ z\)\)]],
  "  maps the infinite strip bounded by the lines  ",
  Cell[BoxData[
      \(x\  = \ \(\[PlusMinus]\(\[Pi]\/2\)\)\)]],
  "  onto the w plane slit along the boundary rays  ",
  Cell[BoxData[
      \(\(K\_1\) : u \[LessEqual] \(-1\), v = 0\)]],
  "  and  ",
  Cell[BoxData[
      \(\(K\_2\) : u \[GreaterEqual] 1, v = 0\)]],
  ".  The image of the source at ",
  Cell[BoxData[
      \(z\_1 = \[Pi]\/2\)]],
  " is a source at ",
  Cell[BoxData[
      \(w\_1 = 1\)]],
  ", and the image of the sink at ",
  Cell[BoxData[
      \(z\_2 = \(-\[Pi]\)\/2\)]],
  " is a sink at ",
  Cell[BoxData[
      \(w\_2 = \(-1\)\)]],
  ".  The potential  \n\n\t\t\t",
  Cell[BoxData[
      \(\(F\_1\) \((w)\)\  = \ log\ \(w - 1\)\/\(w + 1\)\)]],
  "  \n\ndetermines a fluid flow in the w plane past the boundary curves ",
  Cell[BoxData[
      RowBox[{\(K\_1\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(K\_2\)}]]],
  ", which lie along streamlines of the flow.  Therefore the complex \
potential for the fluid flow in the infinite strip in the ",
  StyleBox["z",
    FontFamily->"Courier New"],
  " plane is \n\n\t\t\t",
  Cell[BoxData[
      \(\(F\_2\) \((z)\)\ \  = \ \ \(\(F\_1\) \((S \((z)\))\)\ \  = 
          log \((\(sin\ z\ \  - \ \ 1\)\/\(sin\ z\ \  + \ \ 1\))\)\)\)]],
  ".  \n\nSeveral streamlines for the flow are illustrated in Figure 11.97."
}], "Text"],

Cell[TextData[Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004V0000i2000`400?l0
0000o`00003oo`3ooolW0?ooo`00o`3ooolW0?ooo`00o`3ooolW0?ooo`00
o`3ooolW0?ooo`00o`3ooolW0?ooo`00o`3ooolW0?ooo`00K03oool00`00
0?l0oooo0?ooo`2^0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`03
0000o`3oool0oooo0:h0oooo00<0003o0?ooo`3oool01P3oool006`0oooo
00<0003o0?ooo`3oool0[P3oool00`000?l0oooo0?ooo`060?ooo`00K03o
ool00`000?l0oooo0?ooo`2^0?ooo`030000o`3oool0oooo00H0oooo001/
0?ooo`030000o`3oool0oooo0:h0oooo00<0003o0?ooo`3oool01P3oool0
06`0oooo00<0003o0?ooo`3oool0[P3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`2^0?ooo`030000o`3oool0oooo00H0
oooo001/0?ooo`030000o`3oool0oooo0:h0oooo00<0003o0?ooo`3oool0
1P3oool006`0oooo00<0003o0?ooo`3oool0C03ooolC0?l004l0oooo00<0
003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool0A`3oool5
0?l001<0oooo1P3o00190?ooo`030000o`3oool0oooo00H0oooo001/0?oo
o`030000o`3oool0oooo04<0oooo103o000N0?ooo`@0o`00A@3oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0o0?ooo`@0
o`009P3oool40?l00440oooo00<0003o0?ooo`3oool01P3oool006`0oooo
00<0003o0?ooo`3oool0?@3oool20?l002h0oooo0`3o000n0?ooo`030000
o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo03X0oooo0`3o
000c0?ooo`80o`00?03oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`0g0?ooo`<0o`00>03oool20?l003X0oooo00<0003o
0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool0=@3oool20?l0
03d0oooo0P3o000h0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`03
0000o`3oool0oooo03<0oooo0P3o00110?ooo`80o`00=P3oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0a0?ooo`80o`00
A@3oool20?l003@0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0
003o0?ooo`3oool0;`3oool20?l004T0oooo0P3o000b0?ooo`030000o`3o
ool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo02h0oooo00<0o`00
0?ooo`3oool0B`3oool20?l00300oooo00<0003o0?ooo`3oool01P3oool0
06`0oooo00<0003o0?ooo`3oool0;03oool20?l00500oooo00<0o`000?oo
o`3oool0;@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0
oooo0?ooo`0[0?ooo`030?l0003oool0oooo0540oooo00<0o`000?ooo`3o
ool0;03oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`0Z0?ooo`030?l0003oool0oooo05<0oooo0P3o000/0?ooo`030000
o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo02T0oooo00<0
o`000?ooo`3oool0EP3oool00`3o0000oooo0?ooo`0Y0?ooo`030000o`3o
ool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo02L0oooo0P3o001J
0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool01P3oool0
06`0oooo00<0003o0?ooo`3oool09P3oool00`3o0000oooo0?ooo`1K0?oo
o`030?l0003oool0oooo02L0oooo00<0003o0?ooo`3oool01P3oool006`0
oooo00<0003o0?ooo`3oool09@3oool00`3o0000oooo0?ooo`1M0?ooo`80
o`009`3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`0T0?ooo`030?l0003oool0oooo0600oooo00<0o`000?ooo`3oool0
903oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`0S0?ooo`030?l0003oool0oooo0680oooo00<0o`000?ooo`3oool08`3o
ool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0R
0?ooo`030?l0003oool0oooo06@0oooo00<0o`000?ooo`3oool08P3oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0Q0?oo
o`030?l0003oool0oooo06H0oooo00<0o`000?ooo`3oool08@3oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0P0?ooo`03
0?l0003oool0oooo06P0oooo00<0o`000?ooo`3oool0803oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0O0?ooo`030?l0
003oool0oooo06X0oooo00<0o`000?ooo`3oool07`3oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0N0?ooo`030?l0003o
ool0oooo06`0oooo00<0o`000?ooo`3oool07P3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0
oooo06h0oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`06
0?ooo`00K03oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo
06l0oooo00<0o`000?ooo`3oool07@3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`0L0?ooo`030?l0003oool0oooo0700
oooo00<0o`000?ooo`3oool0703oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003oool0oooo0780oooo
00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`060?ooo`00K03o
ool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo07@0oooo00<0
o`000?ooo`3oool06P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`0I0?ooo`030?l0003oool0oooo0300oooo50000?la
0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool01P3oool0
06`0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0Y0?oo
o`L0003o503oool50000obd0oooo00<0o`000?ooo`3oool06@3oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0H0?ooo`03
0?l0003oool0oooo02P0oooo0P000?lP0?ooo`D0003o:@3oool00`3o0000
oooo0?ooo`0H0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000
o`3oool0oooo01L0oooo00<0o`000?ooo`3oool09@3oool40000obL0oooo
0P000?lX0?ooo`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool0
1P3oool006`0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?oo
o`0Q0?ooo`@0003o;@3oool30000obD0oooo00<0o`000?ooo`3oool05`3o
ool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0F
0?ooo`030?l0003oool0oooo0200oooo0P000?ld0?ooo`@0003o8P3oool0
0`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo00H0oooo001/0?oo
o`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool07`3oool20000
ocX0oooo0P000?lQ0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?oo
o`3oool01P3oool006`0oooo00<0003o0?ooo`3oool0503oool00`3o0000
oooo0?ooo`0N0?ooo`80003o?P3oool20000ob00oooo00<0o`000?ooo`3o
ool0503oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`0D0?ooo`030?l0003oool0oooo01`0oooo0P000?m20?ooo`80003o
7P3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo00H0oooo
001/0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool06`3o
ool20000odH0oooo00<0003o0?ooo`3oool0703oool00`3o0000oooo0?oo
o`0C0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0
oooo0180oooo00<0o`000?ooo`3oool06`3oool00`000?l0oooo0?ooo`17
0?ooo`80003o703oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0
oooo00H0oooo001/0?ooo`030000o`3oool0oooo0180oooo00<0o`000?oo
o`3oool06@3oool20000od`0oooo0P000?lK0?ooo`030?l0003oool0oooo
0180oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0H0?ooo`80003oD03oool00`000?l0
oooo0?ooo`0H0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o
ool01P3oool006`0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0G0?ooo`030000o`3oool0oooo0540oooo0P000?lI0?ooo`030?l0
003oool0oooo0140oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0F0?ooo`80003oEP3o
ool20000oaL0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo01H0oooo00<0003o0?ooo`3oool0F03oool20000oaH0oooo00<0o`00
0?ooo`3oool0403oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo01@0oooo0P000?mM0?oo
o`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0>0?ooo`03
0?l0003oool0oooo01<0oooo0P000?mP0?ooo`030000o`3oool0oooo01<0
oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0180oooo
00<0003o0?ooo`3oool0H@3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0
003oool0oooo00l0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3o
ool0oooo02@0oooo6@3o000V0?ooo`030000o`3oool0oooo0180oooo00<0
o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool07P3oool70?l001T0oooo1P3o000Q0?ooo`80003o4P3oool0
0`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00H0oooo001/0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0K0?ooo`@0o`009P3oool30?l00200oooo00<0003o0?oo
o`3oool0403oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00H0oooo001/0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool03`3oool20000oa/0oooo0`3o000]0?ooo`@0o`007@3oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3o
ool01P3oool006`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo01P0oooo0`3o000d0?ooo`<0o`00
6`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01L0oooo0P3o
000j0?ooo`<0o`006@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o
0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo01H0oooo0P3o000o0?ooo`80o`00603oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool01P3oool0
06`0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo01D0oooo0P3o00130?ooo`<0o`005P3oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool01P3oool006`0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo01@0oooo0P3o00180?ooo`80
o`005@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01<0oooo
0P3o001<0?ooo`80o`00503oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo0140oooo0P3o001@0?ooo`80o`004`3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool01P3o
ool006`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo0100oooo0P3o001D0?ooo`80o`004P3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00l0oooo0P3o001H0?oo
o`80o`004@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00h0
oooo0P3o000Y0?ooo`T0003o:P3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0N0?ooo``0003o203oool:0000ob40oooo0P3o000@0?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?oo
o`0K0?ooo`@0003o7P3oool60000oad0oooo00<0o`000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00`0oooo0P3o000I
0?ooo`D0003o:03oool40000oaX0oooo00<0o`000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool05P3oool30000oc40oooo10000?lG0?ooo`80o`003P3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool01P3oool006`0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3o
ool04`3oool40000ocP0oooo10000?lE0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`0;0?ooo`80o`00
4`3oool30000od00oooo0`000?lC0?ooo`80o`00303oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1P3oool006`0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool04@3o
ool20000odH0oooo0`000?lB0?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00l0oooo0`000?m;0?ooo`80003o4@3oool20?l000/0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo001/0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`090?ooo`80o`003`3oool30000
oe00oooo0P000?lA0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo001/0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00d0
oooo0P000?mE0?ooo`80003o403oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`0<0?ooo`80003oF@3oool20000o`l0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool02`3oool20000ob40oooo7@3o000O0?ooo`80003o3P3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0:0?ooo`80003o6`3oool8
0?l001d0oooo1@3o000L0?ooo`80003o3@3oool20?l000P0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00H0oooo001/0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`80o`002`3oool20000
oaP0oooo1@3o000Z0?ooo`@0o`006P3oool20000o`d0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool02@3oool20000oaH0oooo103o000c0?ooo`D0
o`005`3oool20000o``0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01P3oool006`0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
203oool20000oa@0oooo103o000l0?ooo`@0o`005@3oool20000o`/0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`0@0?ooo`@0o`00A03oool40?l001<0oooo0P000?l:0?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00L0oooo0P000?l@0?ooo`<0o`00C03oool4
0?l00140oooo0P000?l90?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00H0oooo001/0?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool03@3oool30?l005<0oooo0`3o000@0?oo
o`80003o203oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`80
003o3@3oool30?l005T0oooo0`3o000?0?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool006`0oooo
00D0003o0?ooo`3oool0oooo0?l000050?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`0:0?ooo`<0
o`00G`3oool30?l000d0oooo0P000?l70?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo00H0oooo001/0?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00D0
oooo0P000?l:0?ooo`<0o`007@3ooolZ0000oah0oooo0P3o000=0?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool01P3oool006`0oooo00@0003o0?ooo`3oool0o`00103oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo0P000?l:0?ooo`80
o`006P3oool60000obX0oooo20000?lH0?ooo`<0o`002`3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool01@3o0000oooo0?ooo`3oool0003o00P0oooo001/0?ooo`04
0000o`3oool0oooo0?l000@0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`80003o2@3oool30?l001P0oooo10000?lh0?oo
o`H0003o5@3oool20?l000X0oooo0P000?l60?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00P0oooo001/
0?ooo`040000o`3oool0oooo0?l000<0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo0P3o
000F0?ooo`D0003o@P3oool40000oa<0oooo0`3o00090?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?oo
o`3oool0o`0000<0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0
003o0?ooo`3o00000`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool01P3oool20?l00180oooo1P00
0?m;0?ooo`@0003o4P3oool20?l000P0oooo00<0003o0?ooo`3oool00`3o
ool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0
oooo0000o`080?ooo`00K03oool00`000?l0oooo0?l000030?ooo`030000
o`3oool0oooo0080oooo00@0o`000?ooo`3oool0oooo0P000?l70?ooo`80
o`003`3oool50000oeD0oooo1@000?l?0?ooo`<0o`001P3oool20000o`@0
oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`040?l0003oool0oooo
0000o`P0oooo001/0?ooo`030000o`3oool0o`000080oooo00<0003o0?oo
o`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00L0oooo0P3o000=
0?ooo`@0003oG`3oool30000o`l0oooo0P3o00060?ooo`030000o`3oool0
oooo0080oooo00@0o`000?ooo`3oool0003o0`3oool0103o0000oooo0?oo
o`000?l80?ooo`00K03oool00`000?l0oooo0?l000020?ooo`050000o`3o
ool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`040?ooo`80o`00
2`3oool40000ofH0oooo10000?l=0?ooo`80o`001@3oool00`000?l0oooo
0?ooo`020?ooo`040?l0003oool0oooo0000o`80oooo00@0o`000?ooo`3o
ool0003o203oool006`0oooo00<0003o0?ooo`3o00000P3oool010000?l0
oooo0?ooo`3o00020?ooo`80003o1@3oool20?l000X0oooo0`000?m^0?oo
o`@0003o2`3oool20?l000@0oooo0P000?l30?ooo`040?l0003oool0oooo
0000o`80oooo00<0o`000?ooo`000?l0203oool006`0oooo00D0003o0?oo
o`3o0000oooo0000o`020?ooo`040?l0003oool0oooo0000o`D0oooo0P3o
00080?ooo`@0003o9P3oool`0?l001l0oooo10000?l90?ooo`80o`00103o
ool01`000?l0oooo0?ooo`3oool0o`000?ooo`000?l00P3oool00`3o0000
oooo0000o`080?ooo`00K03oool020000?l0o`000?ooo`3oool0003o0?oo
o`3o0000oooo0P000?l40?ooo`80o`001P3oool40000oaP0oooo4P3o000`
0?ooo`L0o`00703oool40000o`L0oooo0P3o00030?ooo`80003o0P3oool0
1`3o0000oooo0000o`3oool0o`000?ooo`000?l0203oool006`0oooo00P0
003o0?l0003oool0003o0?ooo`3o0000oooo0000o`@0oooo0P3o00060?oo
o`80003o4`3oool90?l004T0oooo3@3o000C0?ooo`<0003o1P3oool20?l0
00<0oooo00T0003o0?ooo`3o0000oooo0000o`3oool0o`000?ooo`000?l0
203oool006`0oooo00L0003o0?l0003oool0003o0?l0003oool0003o00<0
oooo0P3o00040?ooo`@0003o403oool50?l005l0oooo1@3o000A0?ooo`<0
003o1@3oool20?l00080oooo00P0003o0?ooo`3o0000oooo0000o`3o0000
oooo0000o`P0oooo001/0?ooo`060000o`3o0000003o0?l0003oool0003o
0P3oool20?l00080oooo10000?l=0?ooo`L0o`00J@3oool60?l000h0oooo
10000?l30?ooo`0:0?l0003oool0oooo0000o`3oool0o`000?ooo`000?l0
o`000000o`P0oooo001/0?ooo`80003o00@0oooo0?l000000?l0oooo0P3o
0000103oool0003o0000o`000?l:0?ooo`L0o`00MP3oool80?l000X0oooo
0`000?l02P3oool0o`000?l0003oool0003o0?l0003oool0003o0?l00000
0?l80?ooo`00K03oool01`000?l0o`000?l000000?l0oooo0?l0003oool0
0P000?l40?ooo`T0o`00Q@3oool:0?l000<0oooo0P000?l0103oool0o`00
0?l0003oool30?l000030000o`3oool0oooo00H0oooo001/0?ooo`030000
o`3oool0o`000080o`000P000?l60?l009P0oooo1@3o00030000o`80o`00
0P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?oo
o`040?l00:<0003o1@3o00020?ooo`030000o`3oool0oooo00H0oooo001/
0?ooo`030000o`3oool0oooo00<0o`00Y@3oool40?l00080oooo00<0003o
0?ooo`3oool01P3oool006`0oooo00@0003o0?ooo`3o0000o`000P000?l6
0?l009T0oooo1P3o00020000o`80o`000P3oool00`000?l0oooo0?ooo`06
0?ooo`00K03oool010000?l0o`000?l000000?l20?l000<0003o0`3oool:
0?l008D0oooo2P3o00040?ooo`80003o00<0oooo0?l0003oool00`3o0000
0`000?l0oooo0?ooo`060?ooo`00K03oool20000o`040?ooo`3o0000003o
0?ooo`80o`0000@0oooo0000o`000?l0003o2P3oool70?l007L0oooo1`3o
000;0?ooo`<0003o00T0oooo0?l0003o0000oooo0?l0003oool0003o0?l0
00000?l0203oool006`0oooo00H0003o0?l000000?l0o`000?ooo`000?l2
0?ooo`80o`000P3oool40000o`d0oooo1`3o001Y0?ooo`L0o`003P3oool4
0000o`80oooo0P3o0000203oool0003o0000o`3o0000oooo0000o`3o0000
003o203oool006`0oooo00L0003o0?l0003oool0003o0?l0003oool0003o
00<0oooo0P3o00040?ooo`@0003o403oool50?l005l0oooo1@3o000A0?oo
o`@0003o103oool20?l00080oooo00P0003o0?ooo`3o0000oooo0000o`3o
0000oooo0000o`P0oooo001/0?ooo`080000o`3o0000oooo0000o`3oool0
o`000?ooo`000?l40?ooo`030?l0003oool0oooo00D0oooo0P000?lC0?oo
o`T0o`00BP3oool<0?l001<0oooo0`000?l70?ooo`0=0?l0003oool0oooo
0?ooo`000?l0oooo0?l0003oool0003o0?ooo`3o0000oooo0000o`080?oo
o`00K03oool020000?l0o`000?ooo`3oool0003o0?ooo`3o0000oooo0P00
0?l30?ooo`80o`001`3oool30000oaT0oooo4@3o000a0?ooo`P0o`006`3o
ool40000o`P0oooo0P3o00020?ooo`80003o0P3oool01`3o0000oooo0000
o`3oool0o`000?ooo`000?l0203oool006`0oooo00D0003o0?ooo`3o0000
oooo0000o`020?ooo`040?l0003oool0oooo0000o`@0oooo0`3o00070?oo
o`@0003o9P3ooola0?l001l0oooo10000?l:0?ooo`80o`000`3oool01`00
0?l0oooo0?ooo`3oool0o`000?ooo`000?l00P3oool00`3o0000oooo0000
o`080?ooo`00K03oool00`000?l0oooo0?l000020?ooo`040000o`3oool0
oooo0?l00080oooo0P000?l50?ooo`80o`002@3oool40000ofh0oooo1000
0?l<0?ooo`80o`000`3oool20000o`<0oooo00@0o`000?ooo`3oool0003o
0P3oool00`3o0000oooo0000o`080?ooo`00K03oool00`000?l0oooo0?l0
00020?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo
0?ooo`040?ooo`80o`002`3oool40000ofL0oooo0`000?l>0?ooo`80o`00
103oool00`000?l0oooo0?ooo`020?ooo`040?l0003oool0oooo0000o`80
oooo00@0o`000?ooo`3oool0003o203oool006`0oooo00<0003o0?ooo`3o
00000P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?oo
o`000?l01`3oool20?l000d0oooo10000?mO0?ooo`@0003o3P3oool30?l0
00D0oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`000?l3
0?ooo`040?l0003oool0oooo0000o`P0oooo001/0?ooo`030000o`3oool0
o`0000<0oooo00<0003o0?ooo`3oool00P3oool0103o0000oooo0?ooo`3o
ool20000o`L0oooo0P3o000?0?ooo`@0003oE`3oool40000oa00oooo0P3o
00060?ooo`80003o103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo
00@0o`000?ooo`3oool0003o203oool006`0oooo00<0003o0?ooo`3o0000
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool01P3oool20?l00140oooo1P000?m<0?ooo`D0003o
4@3oool30?l000L0oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo
0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000o`080?oo
o`00K03oool010000?l0oooo0?ooo`3o00030?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?oo
o`80o`005@3oool50000od<0oooo10000?lC0?ooo`<0o`002@3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00D0003o0?oo
o`3oool0oooo0?l000030?ooo`030000o`3oool0oooo00H0oooo001/0?oo
o`040000o`3oool0oooo0?l000@0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`030?ooo`80003o2@3oool30?l001L0oooo10000?lj
0?ooo`D0003o5@3oool20?l000X0oooo0P000?l60?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00P0oooo
001/0?ooo`040000o`3oool0oooo0?l000@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`80003o2P3oool20?l001T0oooo
1P000?l/0?ooo`P0003o5`3oool30?l000/0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
00D0o`000?ooo`3oool0oooo0000o`080?ooo`00K03oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`050?ooo`80003o2P3oool30?l001`0oooo;0000?lM0?ooo`80
o`003@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo00H0oooo001/0?ooo`050000o`3oool0oooo0?ooo`3o
00001@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool02P3oool30?l005l0oooo0`3o000=0?ooo`80
003o1`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`00
K03oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`060?ooo`80003o
3@3oool30?l005T0oooo0`3o000?0?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0=0?ooo`<0o`00D`3oool30?l00100oooo0P000?l80?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00L0oooo0P000?l@0?ooo`<0o`00C03oool4
0?l00140oooo0P000?l90?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00H0oooo001/0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0403oool30?l004D0oooo103o000C0?oo
o`80003o2P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`80
003o4`3oool40?l003d0oooo103o000E0?ooo`80003o2`3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`090?ooo`80003o5@3oool50?l003@0oooo
103o000H0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool02P3oool20000oaP0oooo1@3o000[0?ooo`@0o`006P3o
ool20000o``0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01P3o
ool006`0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00H0oooo0P3o000<0?ooo`80003o6`3oool8
0?l001d0oooo1P3o000L0?ooo`80003o3@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`0;0?ooo`80003o8@3ooolM0?l00200oooo0P000?l=0?oo
o`80o`00203oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0303oool20000oeX0oooo0P000?l>0?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00d0oooo0P000?mF0?ooo`80003o
3`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`00K03o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0>0?ooo`<0003oD@3o
ool20000oa00oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool006`0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00T0oooo0P3o000A0?ooo`80003oC03oool3
0000oa00oooo0P3o000;0?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`0@0?ooo`<0003oAP3oool30000
oa80oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool006`0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool04P3oool30000od00
oooo0`000?lC0?ooo`80o`00303oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool006`0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00/0oooo0P3o000E0?ooo`<0003o>@3oool40000oaD0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool05@3oool40000oc40oooo1000
0?lG0?ooo`80o`003P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool0603oool40000obT0oooo10000?lJ
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo001/0?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`0=0?ooo`80o`00703oool50000oal0oooo1@000?lM0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0>0?ooo`030?l0003oool0oooo01h0oooo30000?l80?ooo`/0
003o803oool20?l00100oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0>0?ooo`80o`00:@3oool90000obX0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00l0oooo0P3o
001H0?ooo`80o`004@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo0100oooo0P3o001D0?ooo`80o`004P3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01P3oool0
06`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo0140oooo0P3o001@0?ooo`80o`004`3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool01P3oool006`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo01<0oooo0P3o001<0?ooo`80
o`00503oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo01@0oooo
0P3o00180?ooo`80o`005@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo01D0oooo0P3o00130?ooo`<0o`005P3oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool01P3o
ool006`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo01H0oooo0P3o000o0?ooo`80o`00603oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo01L0oooo0P3o000j0?oo
o`<0o`006@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo01P0
oooo0`3o000d0?ooo`<0o`006`3oool00`000?l0oooo0?ooo`0?0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool01P3oool006`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo01X0oooo0`3o000^0?ooo`<0o`007@3oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
1P3oool006`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0@0?ooo`80003o7@3oool30?l002L0oooo103o000O0?ooo`030000o`3o
ool0oooo0100oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool07@3oool80?l001T0oooo1P3o000Q
0?ooo`80003o4P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo00H0oooo001/0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0T0?oooaT0o`009P3oool00`00
0?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool01P3oool006`0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0B0?ooo`030000o`3oool0oooo0640oooo00<0003o0?ooo`3o
ool04P3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00H0
oooo001/0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
4`3oool20000of00oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?ooo`3oool0503oool20000oed0oooo00<0
003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo00l0oooo00<0o`00
0?ooo`3oool05P3oool00`000?l0oooo0?ooo`1H0?ooo`80003o5P3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00H0oooo001/0?oo
o`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool05P3oool20000
oeH0oooo0P000?lG0?ooo`030?l0003oool0oooo0140oooo00<0003o0?oo
o`3oool01P3oool006`0oooo00<0003o0?ooo`3oool04@3oool00`3o0000
oooo0?ooo`0G0?ooo`030000o`3oool0oooo0580oooo00<0003o0?ooo`3o
ool05`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0
oooo001/0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0
603oool20000oe00oooo0P000?lI0?ooo`030?l0003oool0oooo0180oooo
00<0003o0?ooo`3oool01P3oool006`0oooo00<0003o0?ooo`3oool04P3o
ool00`3o0000oooo0?ooo`0I0?ooo`80003oC03oool20000oa/0oooo00<0
o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`060?ooo`00K03oool0
0`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo01/0oooo00<0003o
0?ooo`3oool0A`3oool20000oa`0oooo00<0o`000?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0C0?oo
o`030?l0003oool0oooo01/0oooo0P000?m60?ooo`030000o`3oool0oooo
01`0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`060?oo
o`00K03oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo01`0
oooo0P000?m20?ooo`80003o7P3oool00`3o0000oooo0?ooo`0D0?ooo`03
0000o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo01@0oooo
00<0o`000?ooo`3oool07P3oool20000och0oooo0P000?lP0?ooo`030?l0
003oool0oooo01@0oooo00<0003o0?ooo`3oool01P3oool006`0oooo00<0
003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0O0?ooo`80003o>P3o
ool20000ob40oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?oo
o`060?ooo`00K03oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0
oooo0200oooo0P000?le0?ooo`<0003o8P3oool00`3o0000oooo0?ooo`0F
0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo
01L0oooo00<0o`000?ooo`3oool08@3oool40000obd0oooo10000?lT0?oo
o`030?l0003oool0oooo01L0oooo00<0003o0?ooo`3oool01P3oool006`0
oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?ooo`0U0?ooo`@0
003o9`3oool20000obP0oooo00<0o`000?ooo`3oool05`3oool00`000?l0
oooo0?ooo`060?ooo`00K03oool00`000?l0oooo0?ooo`0H0?ooo`030?l0
003oool0oooo02P0oooo0P000?lP0?ooo`D0003o:@3oool00`3o0000oooo
0?ooo`0H0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000o`3o
ool0oooo01T0oooo00<0o`000?ooo`3oool0:@3oool70000oa@0oooo1@00
0?l]0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool01P3o
ool006`0oooo00<0003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0`
0?oooa@0003o<@3oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0
oooo00H0oooo001/0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?oo
o`3oool0M03oool00`3o0000oooo0?ooo`0J0?ooo`030000o`3oool0oooo
00H0oooo001/0?ooo`030000o`3oool0oooo01/0oooo00<0o`000?ooo`3o
ool0LP3oool00`3o0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00H0
oooo001/0?ooo`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool0
L03oool00`3o0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00H0oooo
001/0?ooo`030000o`3oool0oooo01`0oooo00<0o`000?ooo`3oool0K`3o
ool00`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00H0oooo001/
0?ooo`030000o`3oool0oooo01d0oooo00<0o`000?ooo`3oool0KP3oool0
0`3o0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00H0oooo001/0?oo
o`030000o`3oool0oooo01h0oooo00<0o`000?ooo`3oool0K03oool00`3o
0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`03
0000o`3oool0oooo01l0oooo00<0o`000?ooo`3oool0JP3oool00`3o0000
oooo0?ooo`0O0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000
o`3oool0oooo0200oooo00<0o`000?ooo`3oool0J03oool00`3o0000oooo
0?ooo`0P0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000o`3o
ool0oooo0240oooo00<0o`000?ooo`3oool0IP3oool00`3o0000oooo0?oo
o`0Q0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0
oooo0280oooo00<0o`000?ooo`3oool0I03oool00`3o0000oooo0?ooo`0R
0?ooo`030000o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo
02<0oooo00<0o`000?ooo`3oool0HP3oool00`3o0000oooo0?ooo`0S0?oo
o`030000o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo02@0
oooo00<0o`000?ooo`3oool0H03oool00`3o0000oooo0?ooo`0T0?ooo`03
0000o`3oool0oooo00H0oooo001/0?ooo`030000o`3oool0oooo02D0oooo
00<0o`000?ooo`3oool0G@3oool20?l002L0oooo00<0003o0?ooo`3oool0
1P3oool006`0oooo00<0003o0?ooo`3oool09P3oool00`3o0000oooo0?oo
o`1K0?ooo`030?l0003oool0oooo02L0oooo00<0003o0?ooo`3oool01P3o
ool006`0oooo00<0003o0?ooo`3oool09`3oool00`3o0000oooo0?ooo`1I
0?ooo`030?l0003oool0oooo02P0oooo00<0003o0?ooo`3oool01P3oool0
06`0oooo00<0003o0?ooo`3oool0:03oool20?l005P0oooo00<0o`000?oo
o`3oool0:@3oool00`000?l0oooo0?ooo`060?ooo`00K03oool00`000?l0
oooo0?ooo`0Z0?ooo`030?l0003oool0oooo05<0oooo0P3o000/0?ooo`03
0000o`3oool0oooo00H0oooo002J0?ooo`030?l0003oool0oooo0540oooo
00<0o`000?ooo`3oool0=@3oool009/0oooo0P3o001@0?ooo`030?l0003o
ool0oooo03H0oooo002M0?ooo`030?l0003oool0oooo04/0oooo0P3o000i
0?ooo`00WP3oool20?l004T0oooo0P3o000k0?ooo`00X03oool20?l004D0
oooo0P3o000m0?ooo`00XP3oool20?l00480oooo00<0o`000?ooo`3oool0
?@3oool00:@0oooo0P3o000n0?ooo`80o`00@03oool00:H0oooo0`3o000i
0?ooo`80o`00@P3oool00:T0oooo0P3o000e0?ooo`80o`00A03oool00:/0
oooo0`3o000_0?ooo`<0o`00AP3oool00:h0oooo103o000W0?ooo`@0o`00
B@3oool00;80oooo0`3o000O0?ooo`D0o`00C@3oool00;D0oooo1P3o000D
0?ooo`D0o`00DP3oool00;/0oooo503o001G0?ooo`00o`3ooolW0?ooo`00
o`3ooolW0?ooo`00o`3ooolW0?ooo`00o`3ooolW0?ooo`00o`3ooolW0?oo
o`00o`3ooolW0?ooo`00o`3ooolW0?ooo`00o`3ooolW0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{294, 228},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.97",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/sourcesink/SourceSinkFigures/\
mat1197.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  A source and a sink on the edges of a strip. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.33.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter the formula for the complex potential F[z].", "Text"],

Cell[BoxData[{
    \(\(Clear[f, F, \[Phi], \[Psi], W, x, y, z, Z];\)\ \), "\n", 
    \(\(F[Z_]\  = \ 
        Log[\(Sin[Z] - 1\)\/\(Sin[Z] + 1\)];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Phi][x_, y_] = 
        ComplexExpand[Re[F[x + \[ImaginaryI]\ y]], 
          TargetFunctions \[Rule] {Re, Im}];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Psi][x_, y_] = 
        MapAll[Together, 
          ComplexExpand[Im[F[x + \[ImaginaryI]\ y]], 
            TargetFunctions \[Rule] {Re, Im}]];\)\ \), "\n", 
    \(\(Print["\<W = F[Z] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The velocity potential is:\>"];\)\ \), "\n", 
    \(\(Print["\<\[Phi][x,y] = Re[F[x + \[ImaginaryI]y]]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        Re[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The stream function is:\>"];\)\ \), "\n", 
    \(\(Print["\<\[Psi][x,y] = Im[F[x + \[ImaginaryI]y]]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", 
        Im[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\(\[Psi][x_, y_] = 
        ArcTan[\(-1\) + Cosh[y]\^2\ Sin[x]\^2 + Cos[x]\^2\ Sinh[y]\^2, 
          2\ Cos[x]\ Sinh[y]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a density plot of the velocity potential."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(DensityPlot[\[Phi][x, y], {x, \(-\[Pi]\)\/2, \[Pi]\/2}, {y, \(-2.5\), 
          2.5}, PlotPoints \[Rule] 100, Mesh \[Rule] False, 
        AspectRatio \[Rule] 5\/\[Pi], 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        Re[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a density plot of the stream function."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ContourPlot[\[Psi][x, y], {x, \(-\[Pi]\)\/2, \[Pi]\/2}, {y, 0.00001, 
            2.5}, Contours \[Rule] 11, PlotPoints \[Rule] 40, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ContourPlot[\[Psi][x, 
            y], {x, \(-\[Pi]\)\/2, \[Pi]\/2}, {y, \(-2.50001\), \
\(-0.00001\)}, Contours \[Rule] 11, PlotPoints \[Rule] 40, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, AspectRatio \[Rule] 5\/\[Pi], 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The stream function\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", 
        Im[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Psi][x,y] = \>", \[Psi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to make a contour plot of the velocity potential."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(gr1 = 
        ContourPlot[\[Phi][x, y], {x, \(-\[Pi]\)\/2, \[Pi]\/2}, {y, 0.00001, 
            2.5}, Contours \[Rule] 11, PlotPoints \[Rule] 40, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(gr2 = 
        ContourPlot[\[Phi][x, 
            y], {x, \(-\[Pi]\)\/2, \[Pi]\/2}, {y, \(-2.50001\), \
\(-0.00001\)}, Contours \[Rule] 11, PlotPoints \[Rule] 40, 
          ColorFunction \[Rule] Hue, 
          DisplayFunction \[Rule] Identity];\)\ \), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, AspectRatio \[Rule] 5\/\[Pi], 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<The velocity potential is:\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", 
        Re[F[x\  + \ \[ImaginaryI]y]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\[Phi][x,y] = \>", \[Phi][x, 
          y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["Find the inverse of the function F[Z].", "Text"],

Cell[BoxData[{
    \(\(solset\  = \ 
        Solve[F[Z]\  \[Equal] \ W, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(f[x_, y_]\  = \ \ ReplaceAll[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), 
          W \[Rule] x\  + \ \[ImaginaryI]\ y];\)\ \), "\n", 
    \(\(Print["\<W = F[Z] = \>", F[Z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The inverse function is:\>"];\)\ \), "\n", 
    \(\(Print["\<f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph the stream functions using  f[x,y]."
}], "Text"],

Cell[BoxData[{
    \(\(n\  = \ 8;\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[k];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ 
        Table[{Re[f[x, \(k\ \[Pi]\)\/n]], Im[f[x, \(k\ \[Pi]\)\/n]]}, \ {k, 
            2, 2  n, 2}];\)\ \), "\n", 
    \(\(gr1 = 
        ParametricPlot[Evaluate[eqns1], {x, \(-7\), 7}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[f[x, \(k\ \[Pi]\)\/n]], Im[f[x, \(k\ \[Pi]\)\/n]]}, \ {k, 
            1, 2  n, 2}];\)\ \), "\n", 
    \(\(gr2 = 
        ParametricPlot[Evaluate[eqns2], {x, \(-7\), 7}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Blue, Line[{{\(-\[Pi]\)\/2, 2}, {\(-\[Pi]\)\/2, \(-2\)}}], 
            Line[{{\[Pi]\/2, 
                  2}, {\[Pi]\/2, \(-2\)}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[gr1, gr2, boundary, AspectRatio \[Rule] 2\/1.6, 
        Ticks \[Rule] None, Axes \[Rule] None, 
        PlotRange \[Rule] {{\(-\[Pi]\)\/2, \[Pi]\/2}, {\(-2.5\), 2.5}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<     f[x,y] = \>", f[x, y]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The stream function for a fluid flow in the infinite strip  ",
  Cell[BoxData[
      \(\(-\[Pi]\)\/2 < Re[z] < \[Pi]\/2\)]],
  "  with a two sources at  ",
  Cell[BoxData[
      \(z\_1 = \(\(-\[Pi]\)\/2\ \ and\ \ z\_2 = \[Pi]\/2\)\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\tWe can use the technique of transformation of a source to determine the \
effluence from a channel extending from infinity.  In this case, we construct \
a conformal mapping  ",
  Cell[BoxData[
      \(w\  = \ S \((z)\)\)]],
  "  from the upper half-plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  " so that the single source located at ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  " is mapped to the point ",
  Cell[BoxData[
      \(w\_0 = \(-\[ImaginaryI]\)\ \[Infinity]\)]],
  " at infinity that lies along the channel.  The streamlines emanating from \
",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  " in the upper half-plane are mapped onto streamlines issuing from the \
channel."
}], "Text"],

Cell[TextData[{
  StyleBox["Example 11.34.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Consider the conformal mapping   \n\n\t\t\t",
  Cell[BoxData[
      \(w\ \  = \ \ \(S \((z)\)\  = \ \ \(2\/\[Pi]\) \@\((z\^2 - 1)\)\  + \ \
\(2\/\[Pi]\) Arcsin \((1\/z)\)\)\)]],
  ",  \n\nwhich maps the upper half-plane ",
  Cell[BoxData[
      \(Im \((z)\) > 0\)]],
  " onto the domain consisting of the upper half-plane ",
  Cell[BoxData[
      \(Im \((w)\) > 0\)]],
  " joined to the channel  ",
  Cell[BoxData[
      \(\(-1\) \[LessEqual] u \[LessEqual] 1, v \[LessEqual] 0\)]],
  ".  The point ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  " is mapped onto the point ",
  Cell[BoxData[
      \(w\_0 = \ \(S \((z\_0)\) = \(S \((0)\) = \(-\[ImaginaryI]\)\ \
\[Infinity]\)\)\)]],
  " and ",
  Cell[BoxData[
      \(z\_1 = 1\)]],
  " is mapped onto ",
  Cell[BoxData[
      \(w\_1 = \ \(S \((z\_1)\) = \(S \((1)\) = 1\)\)\)]],
  " along the channel.  Images of the rays  ",
  Cell[BoxData[
      \(r > 0, \ \[Theta] = \[Alpha]\)]],
  ", where ",
  Cell[BoxData[
      \(\[Alpha]\)]],
  " is a constant, are streamlines issuing from the channel as indicated in \
Figure 11.98."
}], "Text"],

Cell[TextData[Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005B0000i2000`400?l0
0000o`00003oo`3ooomC0?ooo`00o`3ooomC0?ooo`00o`3ooomC0?ooo`00
o`3ooomC0?ooo`00o`3ooomC0?ooo`00K03ooolh0?3ol0030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3`oo00l?o`03L0l?o`1`3o
ool006`0oooo>03`oo000`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo
00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?oo
o`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`000?l0l?o`0?3ol00g0?3ol0L0oooo001/0?ooocP0l?o`00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?3ol03`oo00=`3`
oo070?ooo`00K03ooolh0?3ol0030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3o
ool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`030000o`3`oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo00
0`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o
0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo
0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0l?o`0?3o
l00g0?3ol0L0oooo001/0?ooocP0l?o`00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?3ol03`oo00=`3`oo070?ooo`00K03ooolh
0?3ol0030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3`
oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo000`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?oo
o`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`00
00@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool00`000?l0l?o`0?3ol00g0?3ol0L0oooo001/
0?ooocP0l?o`00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0
003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o
00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo
0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?3ol03`oo00=`3`oo070?ooo`00K03ooolh0?3ol0030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3`oo00l?o`03L0l?o`1`3o
ool006`0oooo>03`oo000`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo
00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?oo
o`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`000?l0l?o`0?3ol00g0?3ol0L0oooo001/0?ooocP0l?o`00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?3ol03`oo00=`3`
oo070?ooo`00K03ooolh0?3ol0030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3o
ool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`030000o`3`oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo00
0`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o
0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo
0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0l?o`0?3o
l00g0?3ol0L0oooo001/0?ooocP0l?o`00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?3ol03`oo00=`3`oo070?ooo`00K03ooolh
0?3ol0030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3`
oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo000`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?oo
o`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`00
00@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool00`000?l0l?o`0?3ol00g0?3ol0L0oooo001/
0?ooocP0l?o`00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0
003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o
00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo
0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?3ol03`oo00=`3`oo070?ooo`00K03ooolh0?3ol0030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3`oo00l?o`03L0l?o`1`3o
ool006`0oooo>03`oo000`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo
00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?oo
o`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`000?l0l?o`0?3ol00g0?3ol0L0oooo001/0?ooocP0l?o`00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?3ol03`oo00=`3`
oo070?ooo`00K03ooolh0?3ol0030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3o
ool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`030000o`3`oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo00
0`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o
0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo
0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0l?o`0?3o
l00g0?3ol0L0oooo001/0?ooocP0l?o`00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?3ol03`oo00=`3`oo070?ooo`00K03ooolh
0?3ol0030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3`
oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo000`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?oo
o`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`00
00@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool00`000?l0l?o`0?3ol00g0?3ol0L0oooo001/
0?ooocP0l?o`00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0
003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o
00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo
0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?3ol03`oo00=`3`oo070?ooo`00K03ooolh0?3ol0030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3`oo00l?o`03L0l?o`1`3o
ool006`0oooo>03`oo000`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo
00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?oo
o`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`000?l0l?o`0?3ol00g0?3ol0L0oooo001/0?ooocP0l?o`00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?3ol03`oo00=`3`
oo070?ooo`00K03ooolh0?3ol0030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3o
ool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`030000o`3`oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo00
0`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o
0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo
0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0l?o`0?3o
l00g0?3ol0L0oooo001/0?ooocP0l?o`00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?3ol03`oo00=`3`oo070?ooo`00K03ooolh
0?3ol0030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3`
oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo000`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?oo
o`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`00
00@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool00`000?l0l?o`0?3ol00g0?3ol0L0oooo001/
0?ooocP0l?o`00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0
003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o
00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo
0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?3ol03`oo00=`3`oo070?ooo`00K03ooolh0?3ol0030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3`oo00l?o`03L0l?o`1`3o
ool006`0oooo>03`oo000`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo
00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?oo
o`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`000?l0l?o`0?3ol00g0?3ol0L0oooo001/0?ooocP0l?o`00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?3ol03`oo00=`3`
oo070?ooo`00K03ooolh0?3ol0030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3o
ool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`030000o`3`oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo00
0`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o
0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo
0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0l?o`0?3o
l00g0?3ol0L0oooo001/0?ooocP0l?o`00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?3ol03`oo00=`3`oo070?ooo`00K03ooolh
0?3ol0030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3`
oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo000`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?oo
o`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`00
00@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool00`000?l0l?o`0?3ol00g0?3ol0L0oooo001/
0?ooocP0l?o`00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0
003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o
00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo
0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?3ol03`oo00=`3`oo070?ooo`00K03ooolh0?3ol0030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3`oo00l?o`03L0l?o`1`3o
ool006`0oooo>03`oo000`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo
00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?oo
o`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`000?l0l?o`0?3ol00g0?3ol0L0oooo001/0?ooocP0l?o`00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?3ol03`oo00=`3`
oo070?ooo`00K03ooolh0?3ol0030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3o
ool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`030000o`3`oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo00
0`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o
0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo
0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0l?o`0?3o
l00g0?3ol0L0oooo001/0?ooocP0l?o`00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?3ol03`oo00=`3`oo070?ooo`00K03ooolh
0?3ol0030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3`
oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo000`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000
oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0l?o`0?3ol00g0?3ol0L0oooo001/0?ooocP0l?o`00<0003o0?ooo`3o
ool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0
o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo
00<0003o0?3ol03`oo00=`3`oo070?ooo`00K03ooolh0?3ol0030000o`3o
ool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0
003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?oo
o`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3`oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo000`00
0?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3o
ool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0l?o`0?3ol00g0?3ol0L0oooo001/0?ooocP0l?o`
00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0
oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`00
00@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003o
ool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?3ol03`oo00=`3`oo070?ooo`00K03ooolh
0?3ol0030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
o`030?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0
oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o
0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3`oo00l?o`03L0l?o`1`3oool006`0
oooo>03`oo000`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?oo
o`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo
0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo
00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0l?o`0?3ol00g0?3ol0L0oooo
001/0?ooocP0l?o`00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?oo
o`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`03
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?3ol03`oo00=`3`oo07
0?ooo`00K03ooolh0?3ol0030000o`3oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`00
0?l00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3`oo00l?o`03L0
l?o`1`3oool006`0oooo>03`oo000`000?l0oooo0?ooo`020?ooo`050?l0
003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3o
ool0003o00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0l?o`0?3o
l00g0?3ol0L0oooo001/0?ooocP0l?o`00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3o
ool0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?3o
l03`oo00=`3`oo070?ooo`00K03ooolh0?3ol0030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo
0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003o
ool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3`oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo000`000?l0oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo
0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o
0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0l?o`0?3ol00g0?3ol0L0oooo001/0?ooocP0l?o`00<0003o0?oo
o`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo
00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo0080
oooo00<0003o0?3ol03`oo00=`3`oo070?ooo`00K03ooolh0?3ol0030000
o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000
oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@00
0?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`030000o`3`oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo00
0`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l00`3o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0
o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool00`000?l0l?o`0?3ol00g0?3ol0L0oooo001/0?ooocP0
l?o`00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o
00<0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`03
0000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00<0003o0?3ol03`oo00=`3`oo070?ooo`00K03o
oolh0?3ol0030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo
0000o`030?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`030000o`3`oo00l?o`03L0l?o`1`3oool0
06`0oooo>03`oo000`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo
0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`00
00@0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool00`000?l0l?o`0?3ol00g0?3ol0L0
oooo001/0?ooocP0l?o`00<0003o0?ooo`3oool00P3oool01@3o0000oooo
0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0?l000040?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?3ol03`oo00=`3`
oo070?ooo`00K03ooolh0?3ol0030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3o
ool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo
0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000<0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3`oo00l?o`
03L0l?o`1`3oool006`0oooo>03`oo001@000?l0oooo0?ooo`3oool0o`00
00@0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003o
ool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0l?o`
0?3ol00g0?3ol0L0oooo001/0?ooocP0l?o`00D0003o0?ooo`3oool0oooo
0?l000040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0
oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0>@3`oo070?ooo`00
K03ooolh0?3ol0050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0
oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0
oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`00
00<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
003o03T0l?o`1`3oool006`0oooo>03`oo001@000?l0oooo0?ooo`3oool0
o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l00`3o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`0i0?3ol0L0oooo001/0?ooocP0l?o`00D0003o0?ooo`3oool0
oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0
003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o
00<0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0
oooo0?ooo`000?l0>@3`oo070?ooo`00K03ooolh0?3ol0050000o`3oool0
oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo
0000o`030?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000
oooo0?ooo`3oool0003o03T0l?o`1`3oool006`0oooo>03`oo001@000?l0
oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0
o`000?ooo`3oool0oooo0000o`0i0?3ol0L0oooo001/0?ooocP0l?o`00D0
003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`030?oo
o`050?l0003oool0oooo0?ooo`000?l0>@3`oo070?ooo`00K03ooolh0?3o
l0050000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o
00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0
oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0003o03T0l?o`
1`3oool006`0oooo>03`oo001@000?l0oooo0?ooo`3oool0o`0000<0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?oo
o`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0
003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo
00D0o`000?ooo`3oool0oooo0000o`0i0?3ol0L0oooo001/0?ooocP0l?o`
00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0oooo0?oo
o`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`3o00001@3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@00
0?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?3ol03`oo00=`3`oo07
0?ooo`00K03ooolh0?3ol0050000o`3oool0oooo0?ooo`3o00000`3oool0
1@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool0
0P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3o
ool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000
o`3`oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo001@000?l0oooo0?oo
o`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`03
0000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0
o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0oooo0?oo
o`3o00000`3oool00`000?l0l?o`0?3ol00g0?3ol0L0oooo001/0?ooocP0
l?o`00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0oooo
0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0
1@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?3ol03`oo00=`3`
oo070?ooo`00K03ooolh0?3ol0050000o`3oool0oooo0?ooo`3o00000`3o
ool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3o
ool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?oo
o`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`03
0000o`3`oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo001@000?l0oooo
0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000030?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0oooo
0?ooo`3o00000`3oool00`000?l0l?o`0?3ol00g0?3ol0L0oooo001/0?oo
ocP0l?o`00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0
oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool01@000?l0oooo0?ooo`3oool0o`0000D0oooo00D0003o0?oo
o`3oool0oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o00000`3o
ool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?3ol03`oo00
=`3`oo070?ooo`00K03ooolh0?3ol0050000o`3oool0oooo0?ooo`3o0000
0P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3o
ool0oooo0?l000030?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00000`3o
ool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0
oooo0?l000030?ooo`030000o`3`oo00l?o`03L0l?o`1`3oool006`0oooo
>03`oo001@000?l0oooo0?ooo`3oool0o`000080oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0
003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o0080oooo
00D0o`000?ooo`3oool0oooo0000o`0i0?3ol0L0oooo001/0?ooocP0l?o`
00D0003o0?ooo`3oool0oooo0?l000020?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3o
ool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`050?l0
003oool0oooo0?ooo`000?l0>@3`oo070?ooo`00K03ooolh0?3ol0050000
o`3oool0oooo0?ooo`3o00000P3oool01@000?l0oooo0?ooo`3oool0o`00
00<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?oo
o`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`03
0000o`3`oo00l?o`03L0l?o`1`3oool006`0oooo>03`oo0010000?l0oooo
0?ooo`3o00030?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00D0
o`000?ooo`3oool0oooo0000o`030?ooo`040?l0003oool0oooo0000ocT0
l?o`1`3oool006`0oooo>03`oo0010000?l0oooo0?ooo`3o00020?ooo`03
0000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`030?oo
o`050?l0003oool0oooo0?ooo`000?l01@3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo
0?ooo`3oool0o`000080oooo00<0003o0?3ol03`oo00=`3`oo070?ooo`00
K03ooolh0?3ol0040000o`3oool0oooo0?l00080oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`040000o`3oool0oooo0?l00080
oooo00<0003o0?3ol03`oo00=`3`oo070?ooo`00K03ooolh0?3ol0040000
o`3oool0oooo0?l00080oooo00D0003o0?ooo`3oool0oooo0?l000030?oo
o`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0003o0080oooo00@0o`000?ooo`3oool0
003o>@3`oo070?ooo`00K03ooolh0?3ol0040000o`3oool0oooo0?l00080
oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`040000
o`3oool0oooo0?l00080oooo00<0003o0?3ol03`oo00=`3`oo070?ooo`00
K03ooolh0?3ol0040000o`3oool0oooo0?l00080oooo00D0003o0?ooo`3o
ool0oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0003o0080oooo
00@0o`000?ooo`3oool0003o>@3`oo070?ooo`00K03oooli0000o`050?oo
o`3o0000oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0003o
00@0oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?ooo`3o
ool0o`0000<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?oo
o`3oool0003o0080oooo00<0o`000?ooo`000?l0>@000?l70?ooo`00Y@3o
ool20?l00080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000
o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`050?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l00003
0?ooo`030000o`3oool0oooo0080o`00@@3oool00:@0oooo0P3o00020?oo
o`030000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0003o1@3oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00@0003o0?ooo`3o
ool0oooo0P3o00100?ooo`00X`3oool00`3o0000oooo0?ooo`020?ooo`05
0000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?oo
o`3oool0oooo0?l000050?ooo`050000o`3oool0oooo0?ooo`3o00000`3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo03d0oooo002Q
0?ooo`80o`00103oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool0
0P3oool20?l003d0oooo002N0?ooo`<0o`001@3oool00`000?l0oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool01@3o0000oooo
0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00`3oool3
0?l003X0oooo002J0?ooo`@0o`001`3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool01@3o
0000oooo0?ooo`3oool0003o00D0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o00001@3o
ool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0
203oool40?l003H0oooo002E0?ooo`D0o`002`3oool01@000?l0oooo0?oo
o`3oool0o`0000D0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`050?l0
003oool0oooo0?ooo`000?l02`3oool50?l00340oooo002A0?ooo`@0o`00
3`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool03@3oool40?l002d0oooo002<0?ooo`D0o`004@3o
ool20000o`@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool20000oa40oooo1@3o
000X0?ooo`00Q`3oool50?l001D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo01<0oooo1@3o000S
0?ooo`00PP3oool50?l001P0oooo0P000?l60?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00@0oooo0P000?lH0?ooo`D0o`007P3oool007`0oooo1P3o000K0?ooo`80
003o1`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`80003o6`3oool60?l001P0
oooo001g0?ooo`D0o`00803oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool07P3oool50?l001<0oooo
001b0?ooo`D0o`008`3oool20000o`T0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01`3o
ool20000ob<0oooo1@3o000>0?ooo`00KP3oool40?l002H0oooo0P000?l:
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00P0oooo0P000?lV0?ooo`D0o`002@3oool0
06`0oooo0P3o000X0?ooo`80003o2`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`090?oo
o`80003o:@3oool20?l000L0oooo002C0?ooo`<0003o303oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`0:0?ooo`<0003o;`3oool00940oooo0P000?l>0?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00`0oooo0P000?l]0?ooo`00SP3oool30000o`l0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool03@3oool30000obX0oooo002<0?ooo`80003o403oool2
0?l000L0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`80o`00403oool2
0000obP0oooo00290?ooo`<0003o403oool20?l000P0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`80o`00403oool30000obD0oooo00270?ooo`80
003o4P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`0@0?ooo`80003o8`3oool008@0oooo
0`000?lC0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo0140oooo0`000?lP0?ooo`00PP3o
ool20000oa@0oooo0P3o00090?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3o
ool20?l001@0oooo0P000?lN0?ooo`00O`3oool30000oaD0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool04`3oool30000oa/0oooo001m0?ooo`80003o5P3oool20?l0
00X0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`80o`005P3oool20000
oaT0oooo001j0?ooo`<0003o5P3oool20?l000`0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0:0?ooo`80o`005P3oool30000oaH0oooo001h0?ooo`80003o
603oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0F0?ooo`80003o503oool007D0oooo0`00
0?lI0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0;0?ooo`030?l0003oool0oooo01L0oooo0`000?lA0?ooo`00L`3oool2
0000oaX0oooo0P3o000=0?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool02`3oool2
0?l001X0oooo0P000?l?0?ooo`00L03oool30000oa/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool06@3oool30000o``0oooo001^0?ooo`80003o703oool20?l000h0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0<0?ooo`80o`00703oool20000o`X0
oooo001/0?ooo`80003o703oool20?l000l0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`0=0?ooo`80o`00703oool30000o`L0oooo00290?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo02<0oooo00270?ooo`80o`00403oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00h0oooo0P3o000S0?ooo`00Q@3oool20?l00140oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`0?0?ooo`80o`008@3oool008@0oooo00<0o`000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`090?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3o
ool07P3oool00880oooo0P3o000B0?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
403oool20?l001h0oooo00200?ooo`80o`004`3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo0140oooo0P3o000L0?ooo`00O`3oool00`3o0000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0I
0?ooo`00O@3oool20?l001@0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0B0?oo
o`80o`006@3oool007/0oooo0P3o000E0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool04`3oool20?l001L0oooo001j0?ooo`030?l0003oool0oooo01<0oooo
0P000?l=0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`0;0?ooo`80003o
5@3oool00`3o0000oooo0?ooo`0D0?ooo`00N03oool20?l001D0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0C0?ooo`80o`00503oool007H0oooo0P3o000F
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0503oool20?l00180oooo001e0?oo
o`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0E0?oo
o`030?l0003oool0oooo00l0oooo001c0?ooo`80o`005`3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo01D0oooo0P3o000?0?ooo`00L@3oool20?l001P0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`0F0?ooo`80o`003@3oool00700oooo00<0
o`000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo01L0oooo0P3o
000;0?ooo`00KP3oool20?l001T0oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0H
0?ooo`80o`002@3oool006`0oooo0P3o000I0?ooo`80003o3`3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool03@3oool20000oaX0oooo0P3o00070?oo
o`00QP3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0>0?ooo`030000o`3oool0oooo0200oooo00250?ooo`030000
o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool07`3oool008<0oooo0P000?lA0?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0?0?ooo`80003o7`3oool00840oooo0P000?lB
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0@0?ooo`80003o7@3oool0
0800oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool04@3oool00`000?l0oooo0?ooo`0J0?ooo`00O`3oool00`000?l0
oooo0?ooo`0@0?ooo`80o`00303oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`0;0?ooo`80o`004P3oool00`000?l0oooo0?ooo`0I0?ooo`00
OP3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo01P0oooo001m0?ooo`030000o`3o
ool0oooo0100oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo0100oooo00<0
003o0?ooo`3oool05`3oool007`0oooo00<0003o0?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0F
0?ooo`00N`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo01D0oooo001i0?ooo`80
003o4`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool04@3oool20000oaD0
oooo001h0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo0180oooo00<0003o0?ooo`3oool04P3oool007L0oooo00<0
003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool04P3o
ool00`000?l0oooo0?ooo`0A0?ooo`00M@3oool20000oa@0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0=
0?ooo`030?l0003oool0oooo0180oooo0P000?lA0?ooo`00L`3oool20000
oaD0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo01<0oooo0P000?l?0?oo
o`00LP3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0E0?ooo`030000o`3oool0oooo00`0oooo001a0?ooo`030000
o`3oool0oooo01D0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo01D0oooo
00<0003o0?ooo`3oool02`3oool006l0oooo0P000?lG0?ooo`030?l0003o
ool0oooo00d0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool03@3o
ool00`3o0000oooo0?ooo`0E0?ooo`80003o2`3oool006h0oooo00<0003o
0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool05P3oool0
0`000?l0oooo0?ooo`080?ooo`00K@3oool00`000?l0oooo0?ooo`0E0?oo
o`80o`00403oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0>0?oo
o`80o`005`3oool00`000?l0oooo0?ooo`070?ooo`00K03oool00`000?l0
oooo0?ooo`0E0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0E0?ooo`80
003o1`3oool008<0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01d0oooo
00220?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0L0?ooo`00P@3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool06`3oool00840oooo00<0o`000?oo
o`3oool0403oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0@0?oo
o`030?l0003oool0oooo01/0oooo00200?ooo`030?l0003oool0oooo0100
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0403oool00`3o0000
oooo0?ooo`0J0?ooo`00O`3oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0
6@3oool007h0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo01P0oooo001m
0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool04@3oool00`3o0000oooo0?ooo`0G0?ooo`00O03oool00`3o
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
0140oooo00<0o`000?ooo`3oool05P3oool007/0oooo00<0o`000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo01D0oooo001j0?ooo`030?l0003oool0oooo0180oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool04P3oool00`3o0000oooo
0?ooo`0D0?ooo`00N@3oool00`3o0000oooo0?ooo`0B0?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool04`3o
ool007P0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo0180oooo001g0?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool04P3oool00`3o0000oooo0?ooo`0A0?ooo`00MP3oool00`3o0000
oooo0?ooo`0B0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo0180
oooo00<0o`000?ooo`3oool0403oool007D0oooo00<0o`000?ooo`3oool0
4`3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0
003oool0oooo00l0oooo001d0?ooo`030?l0003oool0oooo01<0oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?oo
o`0>0?ooo`00L`3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0
oooo00h0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool03@3oool0
0780oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03`3oool00`00
0?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo00`0oooo001a0?ooo`03
0?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3o
ool04`3oool00`3o0000oooo0?ooo`0;0?ooo`00L03oool00`3o0000oooo
0?ooo`0D0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo01@0oooo
00<0o`000?ooo`3oool02P3oool006l0oooo00<0o`000?ooo`3oool0503o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003o
ool0oooo00T0oooo001^0?ooo`030?l0003oool0oooo01@0oooo00<0003o
0?ooo`3oool0403oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo0100oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`08
0?ooo`00K@3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo
0100oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo01@0oooo00<0o`000?ooo`3oool01`3oool006d0
oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?ooo`0@0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0403oool00`000?l0
oooo0?ooo`0E0?ooo`030?l0003oool0oooo00H0oooo001/0?ooo`030?l0
003oool0oooo01@0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo
0?ooo`0>0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool0
5@3oool00`3o0000oooo0?ooo`050?ooo`00PP3oool00`000?l0oooo0?oo
o`0A0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool04@3o
ool00`000?l0oooo0?ooo`0L0?ooo`00PP3oool00`000?l0oooo0?ooo`0@
0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool04@3oool0
0`000?l0oooo0?ooo`0L0?ooo`00P@3oool00`000?l0oooo0?ooo`0A0?oo
o`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0K0?ooo`00P03oool00`000?l0oooo0?ooo`0A0?ooo`03
0?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool04@3oool00`000?l0
oooo0?ooo`0J0?ooo`00O`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00d0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo
0?ooo`0I0?ooo`00O`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?oo
o`0I0?ooo`00OP3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo00h0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00l0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0H
0?ooo`00O@3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo
00h0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00h0oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0G0?oo
o`00O03oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00h0
oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0F0?ooo`00
O03oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00l0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0F0?ooo`00N`3o
ool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00h0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00l0oooo00<0
o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0E0?ooo`00N`3oool0
0`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo00l0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`0E0?ooo`00NP3oool00`00
0?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool03P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0D0?ooo`00N@3oool00`000?l0
oooo0?ooo`0B0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000
oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`0C0?ooo`00N03oool00`000?l0oooo
0?ooo`0C0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
4`3oool00`000?l0oooo0?ooo`0B0?ooo`00M`3oool00`000?l0oooo0?oo
o`0C0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0>0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`0A0?ooo`00MP3oool00`000?l0oooo0?ooo`0D
0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool03`3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0503oool0
0`000?l0oooo0?ooo`0@0?ooo`00S03oool00`3o0000oooo0?ooo`0?0?oo
o`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo02H0oooo002<0?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0
oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool09P3oool008/0oooo00<0o`000?ooo`3oool0
3`3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
3`3oool00`3o0000oooo0?ooo`0U0?ooo`00RP3oool00`3o0000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`0@0?ooo`030?l0003oool0oooo02@0oooo00290?ooo`030?l0003oool0
oooo0140oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0
oooo0100oooo00<0o`000?ooo`3oool0903oool008T0oooo00<0o`000?oo
o`3oool0403oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?oo
o`3oool0403oool00`3o0000oooo0?ooo`0S0?ooo`00R03oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0280oooo0000\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{338, 228},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.98",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/sourcesink/SourceSinkFigures/\
mat1198.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Effluence from a channel into a half-plane. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 11.34.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "When ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is used we must use a different branch of the square root."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[S, z];\)\ \), "\n", 
    \(\(S[
          z_]\  = \ \(\(2  \[ImaginaryI]\)\/\[Pi]\) \@\((1 - z\^2)\) + \(2\/\
\[Pi]\) ArcSin[1\/z];\)\ \), "\n", 
    \(\(Print["\< S[z] = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[-1] = \>", S[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< S[0] = \>", S[0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< S[1] = \>", S[1]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph conformal mapping  w = S(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[S, {0.001, 3.001, 0.25}, {0.0001, 3.14149, 3.14139\/24}, 
        PlotRange \[Rule] {{\(-2.05\), 2.05}, {\(-1.5\), 1.85}}, 
        PlotStyle \[Rule] {Blue, Red}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image of the upper half plane Im[z] > 0,\>"];\)\ \), "\n\
", 
    \(\(Print["\<under w = S[z] = \>", S[z]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ \ Table[{Re[
              S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            0, 23, 2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {r, 0.01, 4}, PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            1, 23, 2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {r, 0.01, 4}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Blue, Line[{{\(-2\), 0}, {\(-1\), 0}, {\(-1\), \(-2\)}}], 
            Line[{{2, 0}, {1, 
                  0}, {1, \(-2\)}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, boundary, 
        PlotRange \[Rule] {{\(-2.05\), 2.05}, {\(-1.5\), 1.85}}, 
        AspectRatio \[Rule] 1\/1, 
        Ticks \[Rule] {Range[\(-2\), 2, 2], Range[1, 2, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow in the upper half plane Im[z] > \
0,\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<where a source is located at \!\(z\_0\) = 0, under the\>\
\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<conformal mapping w = S[z] = \>", 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use a Schwarz-Christoffel transformation to show that the conformal \
mapping  \n\n\t\t\t",
  Cell[BoxData[
      \(w\ \  = \ \ \(S \((z)\)\ \  = \ \ \[ImaginaryI]\ \[Pi]\ \  + \ 
            2 \((z + 1)\)\^\(1\/2\)\  + \ 
            Log \((\(1 - \((z + 1)\)\^\(1\/2\)\)\/\(1 + \((z + 1)\)\^\(1\/2\)\
\))\)\)\)]],
  "  \n\nwill map the flow in the upper half-plane from a source at  ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  "  onto the flow from a channel with  ",
  Cell[BoxData[
      \(w\_0 = \(S \((z\_0)\)\  = \ \(-\[Infinity]\)\)\)]],
  "  into the first quadrant, as shown in Figure 11.105. \nHint: Set  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 0\)}]]],
  " and ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \[ImaginaryI]\ \[Pi]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(w\_2\), "=", 
          RowBox[{
            RowBox[{\(-d\), "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["let",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "d"}], "\[Rule]", 
            "\[Infinity]"}]}]}]]],
  ".  "
}], "Text"],

Cell[TextData[Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008<0000i2000`400?l0
0000o`00003oo`3ooooo0?ooo`h0oooo003o0?ooool0oooo3P3oool00?l0
ooooo`3oool>0?ooo`00o`3ooooo0?ooo`h0oooo003o0?ooool0oooo3P3o
ool006`0ooooo`000?nI0000o`P0oooo003o0?ooool0oooo3P3oool00?l0
ooooo`3oool>0?ooo`00o`3ooooo0?ooo`h0oooo003o0?ooool0oooo3P3o
ool006`0ooooJ@3o003o0?ooocP0oooo003E0?oooeD0o`00hP3oool00?l0
oooo:`3oool/0?l00;H0oooo003o0?oooeL0oooo6`3o002K0?ooo`00o`3o
oomb0?ooo``0o`00S`3oool006`0ooooJ@000?nX0?oooa40o`00OP3oool0
0=D0oooo=P000?n30?ooob@0o`00FP3oool00?l0oooo303ooolO0000ohP0
oooo3`3o001;0?ooo`00o`3oool[0?oooa00003oQ`3oool>0?l003d0oooo
003o0?oooc/0oooo4@000?n40?ooo`d0o`00<03oool006`0ooooJ@3o001f
0?oooa@0003oO@3ooolG0?l001T0oooo003E0?ooocH0o`00E03oool?0000
ohD0oooo2`3o000>0?ooo`00o`3oool<0?ooo`l0o`00E03oool80000ohP0
oooo1P3o00080?ooo`00o`3ooolK0?ooo`l0o`00C@3oool80000ohh0oooo
003o0?ooobX0oooo4@3o00140?ooo`X0003oQ03oool006`0ooooJ@000?mU
0?ooo``0o`00@P3oool:0000ogX0oooo003E0?ooobL0003oBP3oool:0?l0
0480oooo3P000?m/0?ooo`00o03ooolN0000ocH0oooo2P3o00160?ooo`d0
003oG`3oool00?l0oooo6`3oool;0000ocD0oooo2P3o00190?ooo`P0003o
E`3oool00?l0oooo9P3oool90000ocH0oooo2@3o00180?ooo`P0003oC`3o
ool006`0ooooJ03o001J0?ooo`/0003o=03oool80?l004P0oooo1`000?m8
0?ooo`00e03ooolX0?l003d0oooo2`000?la0?ooo`P0o`00A`3oool:0000
och0oooo003l0?ooo`h0o`00>P3oool60000oc<0oooo1`3o001:0?ooo`X0
003o=03oool00?l0oooo2`3oool?0?l00340oooo1`000?lc0?ooo`D0o`00
C`3oool60000obh0oooo003o0?oooaX0oooo2`3o000]0?ooo`L0003o<@3o
ool60?l004l0oooo2@000?lU0?ooo`00K03ooomX0000oe00oooo2@3o000[
0?ooo`H0003o<@3oool50?l005<0oooo2`000?lJ0?ooo`00e03ooolW0000
oc80oooo203o000Y0?ooo`L0003o;`3oool70?l005L0oooo20000?lB0?oo
o`00n`3oool?0000ob/0oooo1`3o000Y0?ooo`H0003o<03oool80?l005L0
oooo1P000?l<0?ooo`00o`3oool;0?ooo`l0003o8`3oool60?l002T0oooo
1P000?lb0?ooo`L0o`00EP3oool40000o`P0oooo003o0?oooaX0oooo2@00
0?lP0?ooo`H0o`00:@3oool60000oc<0oooo1P3o001L0?ooo`00K03ooomf
0?l00400oooo1P000?lP0?ooo`D0o`00:P3oool60000oc<0oooo1P3o001F
0?ooo`00hP3ooolI0?l002d0oooo1P000?lO0?ooo`H0o`00:P3oool60000
oc<0oooo1P3o001@0?ooo`00n`3oool:0?l002T0oooo1P000?lO0?ooo`H0
o`00:P3oool50000oc@0oooo1`3o00190?ooo`00o`3oool60?ooo`T0o`00
9P3oool70000oah0oooo1@3o000Z0?ooo`D0003o=P3oool60?l004<0oooo
001/0?ooob@0003oOP3oool:0?l002<0oooo1P000?lM0?ooo`H0o`00:@3o
ool50000ocL0oooo1P3o000m0?ooo`00T03ooomB0000ocH0oooo2`3o000N
0?ooo`D0003o7P3oool50?l002T0oooo1@000?lh0?ooo`H0o`00=`3oool0
0>80oooo6@000?lX0?ooo`P0o`006`3oool40000oal0oooo1@3o000Y0?oo
o`@0003o>P3oool40?l003<0oooo003k0?ooo`X0003o9P3oool70?l001P0
oooo1@000?lO0?ooo`@0o`00:@3oool40000ocX0oooo103o000_0?ooo`00
o`3oool60?ooo`T0003o903oool40?l001T0oooo1@000?lN0?ooo`D0o`00
:03oool40000ocX0oooo1@3o000Z0?ooo`00K03ooolT0?l007h0oooo2P00
0?lN0?ooo`D0o`006@3oool50000oah0oooo1@3o000W0?ooo`D0003o>P3o
ool60?l002@0oooo002@0?oooe80o`00=P3oool80000oa/0oooo103o000J
0?ooo`@0003o7`3oool40?l002P0oooo1@000?lk0?ooo`D0o`007`3oool0
0>80oooo603o000V0?ooo`H0003o6@3oool40?l001X0oooo1@000?lN0?oo
o`@0o`00:@3oool60000ocX0oooo1P3o000I0?ooo`00nP3oool:0?l00280
oooo1P000?lG0?ooo`@0o`006`3oool40000oah0oooo103o000[0?ooo`@0
003o?03oool80?l00140oooo003o0?ooo`D0oooo2@3o000O0?ooo`D0003o
5P3oool30?l001`0oooo10000?lN0?ooo`@0o`00:`3oool40000od00oooo
1`3o000:0?ooo`00K03ooomD0000odd0oooo1`3o000M0?ooo`@0003o5@3o
ool40?l001`0oooo0`000?lO0?ooo`@0o`00:`3oool30000od@0oooo0P3o
00080?ooo`00`03ooolQ0000oc<0oooo1P3o000K0?ooo`D0003o503oool4
0?l001/0oooo0`000?lP0?ooo`@0o`00:P3oool40000odX0oooo003Q0?oo
oaT0003o803oool50?l001/0oooo10000?lD0?ooo`@0o`006P3oool40000
ob00oooo103o000Z0?ooo`D0003oA@3oool00?X0oooo2P000?lK0?ooo`H0
o`006@3oool30000oaD0oooo0`3o000K0?ooo`<0003o8@3oool30?l002`0
oooo1P000?lo0?ooo`00o`3oool50?ooo`P0003o6@3oool60?l001H0oooo
10000?lD0?ooo`@0o`006P3oool40000ob00oooo0`3o000_0?ooo`D0003o
>P3oool006`0ooooE03o001<0?ooo`L0003o603oool50?l001D0oooo0`00
0?lE0?ooo`@0o`006P3oool30000ob00oooo103o000`0?ooo`@0003o=P3o
ool00<00oooo8@3o000b0?ooo`H0003o5`3oool40?l001@0oooo0`000?lF
0?ooo`<0o`006P3oool30000ob40oooo0`3o000a0?ooo`@0003o<P3oool0
0>40oooo6@3o000O0?ooo`H0003o5@3oool40?l001<0oooo0`000?lF0?oo
o`<0o`006P3oool30000ob40oooo103o000a0?ooo`@0003o;P3oool00?X0
oooo2P3o000K0?ooo`D0003o503oool40?l00180oooo10000?lE0?ooo`@0
o`006@3oool40000ob40oooo103o000a0?ooo`@0003o:P3oool00?l0oooo
1@3oool80?l001P0oooo1P000?lB0?ooo`<0o`004`3oool30000oaH0oooo
0`3o000J0?ooo`<0003o8P3oool40?l00340oooo10000?lV0?ooo`00K03o
oomD0000od`0oooo1`3o000G0?ooo`@0003o4@3oool30?l001<0oooo0`00
0?lF0?ooo`<0o`006P3oool30000ob<0oooo0`3o000b0?ooo`<0003o8`3o
ool00<00oooo;@000?lV0?ooo`H0o`005@3oool30000oa40oooo0`3o000C
0?ooo`@0003o5@3oool40?l001T0oooo0`000?lS0?ooo`@0o`00<@3oool4
0000oal0oooo003]0?ooo``0003o803oool50?l001<0oooo10000?l@0?oo
o`<0o`00503oool30000oaH0oooo0`3o000I0?ooo`@0003o8`3oool30?l0
0380oooo10000?lK0?ooo`00n@3oool:0000oa/0oooo1@3o000B0?ooo`<0
003o403oool30?l001@0oooo0`000?lF0?ooo`<0o`006P3oool30000ob<0
oooo103o000b0?ooo`@0003o5`3oool00?l0oooo103oool80000oaP0oooo
1P3o000?0?ooo`<0003o403oool20?l001D0oooo0`000?lF0?ooo`<0o`00
6P3oool30000ob@0oooo0`3o000c0?ooo`D0003o4P3oool006`0ooooI`3o
000h0?ooo`L0003o5`3oool40?l000h0oooo0`000?l?0?ooo`<0o`005@3o
ool20000oaL0oooo0P3o000K0?ooo`@0003o8`3oool40?l003@0oooo1000
0?l>0?ooo`00d`3ooolJ0?l002D0oooo1P000?lE0?ooo`<0o`003P3oool3
0000o`l0oooo0`3o000D0?ooo`<0003o5P3oool30?l001`0oooo0`000?lT
0?ooo`@0o`00=03oool40000o`X0oooo003]0?ooo``0o`007`3oool50000
oa<0oooo0`3o000>0?ooo`80003o403oool30?l001@0oooo0`000?lF0?oo
o`<0o`00703oool30000obD0oooo103o000d0?ooo`80003o203oool00?T0
oooo2P3o000J0?ooo`D0003o4@3oool30?l000d0oooo0`000?l@0?ooo`<0
o`00503oool30000oaH0oooo0P3o000M0?ooo`<0003o9P3oool30?l003/0
oooo003o0?ooo`@0oooo203o000G0?ooo`D0003o3`3oool30?l000d0oooo
0`000?l@0?ooo`<0o`00503oool20000oaH0oooo0`3o000M0?ooo`<0003o
9P3oool30?l003P0oooo001/0?ooofL0003o>03oool60?l001H0oooo1000
0?l>0?ooo`<0o`003@3oool30000oa00oooo0`3o000C0?ooo`<0003o5P3o
ool30?l001d0oooo0`000?lV0?ooo`<0o`00=@3oool00=<0oooo6@000?lU
0?ooo`H0o`00503oool30000o`h0oooo0P3o000>0?ooo`<0003o403oool2
0?l001@0oooo0`000?lF0?ooo`80o`007P3oool30000obH0oooo0`3o000b
0?ooo`00k03oool<0000oal0oooo1@3o000B0?ooo`<0003o3@3oool30?l0
00h0oooo0`000?l?0?ooo`80o`005@3oool20000oaH0oooo0`3o000N0?oo
o`80003o9`3oool40?l002h0oooo003h0?ooo`X0003o6P3oool50?l00100
oooo0`000?l=0?ooo`<0o`003P3oool20000o`l0oooo0`3o000D0?ooo`80
003o5`3oool30?l001d0oooo0`000?lX0?ooo`@0o`00:P3oool006`0oooo
903o001b0?ooo`P0003o5`3oool50?l000h0oooo0`000?l=0?ooo`80o`00
3P3oool30000o`l0oooo0P3o000D0?ooo`<0003o5`3oool20?l001h0oooo
0`000?lY0?ooo`<0o`009`3oool00900ooooD03o000Z0?ooo`H0003o5P3o
ool40?l000d0oooo0P000?l=0?ooo`<0o`003P3oool30000o`h0oooo0P3o
000E0?ooo`80003o5`3oool30?l001h0oooo0P000?lZ0?ooo`@0o`008`3o
ool00>00oooo303o000T0?ooo`H0003o503oool30?l000`0oooo0P000?l>
0?ooo`80o`003`3oool20000o`h0oooo0`3o000D0?ooo`<0003o5`3oool3
0?l001d0oooo0`000?l[0?ooo`@0o`007`3oool00>`0oooo5@3o000E0?oo
o`H0003o4@3oool20?l000`0oooo0`000?l=0?ooo`80o`003`3oool20000
o`l0oooo0P3o000E0?ooo`80003o603oool20?l001h0oooo0`000?l/0?oo
o`<0o`00703oool00?l0oooo0P3oool80?l001<0oooo1P000?l=0?ooo`<0
o`00303oool20000o`d0oooo0P3o000?0?ooo`80003o3`3oool20?l001D0
oooo0P000?lH0?ooo`<0o`007P3oool30000ob`0oooo0P3o000J0?ooo`00
K03ooomD0000odT0oooo1`3o000B0?ooo`<0003o3@3oool30?l000/0oooo
0`000?l<0?ooo`80o`003`3oool20000o`l0oooo0`3o000D0?ooo`<0003o
603oool20?l001l0oooo0`000?l[0?ooo`<0o`005`3oool00<00oooo8000
0?l`0?ooo`D0o`00403oool30000o`d0oooo0P3o000<0?ooo`80003o303o
ool20?l000l0oooo0P000?l@0?ooo`80o`005@3oool20000oaP0oooo0`3o
000O0?ooo`<0003o:`3oool20?l001D0oooo003P0?oooaL0003o7P3oool4
0?l000l0oooo0`000?l<0?ooo`80o`00303oool20000o``0oooo0P3o000?
0?ooo`80003o403oool20?l001D0oooo0P000?lI0?ooo`80o`00803oool3
0000obX0oooo103o000A0?ooo`00m`3oool:0000oaP0oooo103o000>0?oo
o`<0003o2`3oool20?l000`0oooo0P000?l<0?ooo`80o`003`3oool20000
oa00oooo0P3o000E0?ooo`80003o6@3oool30?l00200oooo0`000?l[0?oo
o`@0o`003@3oool00?l0oooo0P3oool80000oa@0oooo103o000=0?ooo`<0
003o2P3oool30?l000/0oooo0P000?l<0?ooo`80o`003`3oool20000oa00
oooo0`3o000D0?ooo`80003o6P3oool20?l00240oooo0`000?l/0?ooo`<0
o`002P3oool006`0ooooE03o00190?ooo`H0003o4P3oool30?l000d0oooo
0P000?l;0?ooo`80o`002`3oool20000o``0oooo0P3o000?0?ooo`80003o
4@3oool20?l001@0oooo0P000?lJ0?ooo`<0o`008@3oool30000ob`0oooo
0P3o00080?ooo`00`03oool/0?l002<0oooo1@000?l@0?ooo`<0o`00303o
ool20000o`/0oooo0P3o000;0?ooo`030000o`3oool0oooo00/0oooo0P3o
000?0?ooo`80003o4@3oool20?l001@0oooo0P000?lK0?ooo`<0o`008@3o
ool20000oc@0oooo003/0?ooo`h0o`006P3oool60000o`d0oooo0`3o000;
0?ooo`80003o2`3oool20?l000X0oooo0P000?l=0?ooo`80o`003`3oool2
0000oa40oooo0P3o000D0?ooo`<0003o6`3oool20?l00240oooo0`000?la
0?ooo`00nP3oool:0?l001H0oooo1P000?l:0?ooo`80o`002`3oool20000
o`/0oooo0P3o000:0?ooo`80003o3@3oool00`3o0000oooo0?ooo`0>0?oo
o`80003o4@3oool20?l001D0oooo0P000?lK0?ooo`<0o`008@3oool20000
obl0oooo003o0?ooo`D0oooo2P3o000B0?ooo`80003o2P3oool30?l000X0
oooo0P000?l;0?ooo`80o`002P3oool20000o``0oooo0P3o000@0?ooo`80
003o4@3oool20?l001D0oooo0P000?lL0?ooo`80o`008@3oool30000ob`0
oooo001/0?ooofL0003o>`3oool50?l000l0oooo0`000?l:0?ooo`80o`00
2P3oool20000o`/0oooo0P3o000:0?ooo`030000o`3oool0oooo00/0oooo
0P3o000@0?ooo`030000o`3oool0oooo0100oooo0P3o000E0?ooo`<0003o
6`3oool20?l00280oooo0`000?lY0?ooo`00d`3ooolL0000ob@0oooo103o
000>0?ooo`<0003o2@3oool20?l000X0oooo0P000?l;0?ooo`030?l0003o
ool0oooo00P0oooo0P000?l=0?ooo`030?l0003oool0oooo00h0oooo0P00
0?lB0?ooo`80o`005P3oool20000oa/0oooo0P3o000S0?ooo`80003o9`3o
ool00>l0oooo4@000?lG0?ooo`@0o`003@3oool20000o`T0oooo0P3o000:
0?ooo`80003o2P3oool20?l000X0oooo0P000?l<0?ooo`80o`00403oool2
0000oa80oooo0P3o000F0?ooo`80003o6`3oool20?l002<0oooo0`000?lT
0?ooo`00o`3oool10?ooo`L0003o503oool40?l000/0oooo0`000?l80?oo
o`80o`002P3oool00`000?l0oooo0?ooo`090?ooo`80o`002P3oool20000
o``0oooo0P3o000@0?ooo`80003o4P3oool20?l001H0oooo0`000?lJ0?oo
o`<0o`008`3oool30000ob40oooo003o0?ooo`P0oooo20000?l@0?ooo`<0
o`002`3oool20000o`P0oooo0P3o00090?ooo`80003o2`3oool20?l000X0
oooo00<0003o0?ooo`3oool02`3oool20?l00100oooo00<0003o0?ooo`3o
ool04@3oool20?l001L0oooo0P000?lK0?ooo`80o`00903oool20000oal0
oooo001/0?ooog<0o`00<03oool70000o``0oooo0`3o000:0?ooo`80003o
203oool20?l000T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`080?ooo`80003o3@3oool00`3o0000oooo0?ooo`0>0?ooo`80003o
4`3oool20?l001L0oooo0P000?lK0?ooo`80o`00903oool30000oa`0oooo
003O0?oooaL0o`00803oool40000o`/0oooo0`3o00090?ooo`80003o203o
ool00`3o0000oooo0?ooo`070?ooo`80003o2`3oool00`3o0000oooo0?oo
o`090?ooo`80003o303oool20?l00100oooo0P000?lC0?ooo`030?l0003o
ool0oooo01H0oooo0P000?lK0?ooo`<0o`00903oool20000oaX0oooo003f
0?oooa40o`004`3oool40000o`X0oooo0`3o00080?ooo`80003o1`3oool2
0?l000T0oooo00<0003o0?ooo`3oool02@3oool20?l000/0oooo00<0003o
0?ooo`3oool02`3oool20?l00100oooo00<0003o0?ooo`3oool04@3oool2
0?l001P0oooo0P000?lL0?ooo`80o`00903oool30000oaL0oooo003o0?oo
o`P0oooo1P3o000A0?ooo`<0003o2P3oool20?l000P0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`80003o2`3oool00`3o
0000oooo0?ooo`090?ooo`80003o3@3oool00`3o0000oooo0?ooo`0>0?oo
o`80003o4`3oool20?l001P0oooo0P000?lL0?ooo`80o`009@3oool30000
oa@0oooo001/0?ooob@0003oO@3oool80?l000`0oooo0`000?l90?ooo`80
o`001`3oool20000o`L0oooo0P3o00090?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02P3oool20000o``0oooo0P3o000@0?ooo`80
003o4`3oool20?l001P0oooo0P000?lL0?ooo`80o`009P3oool30000oa40
oooo002@0?oooeP0003o;@3oool40?l000/0oooo0P000?l90?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`070?ooo`80003o2P3oool20?l000`0oooo0P000?l<0?ooo`80o`00
403oool20000oa<0oooo00<0o`000?ooo`3oool05`3oool20000oa`0oooo
0P3o000W0?ooo`<0003o3P3oool00>P0oooo5`000?lJ0?ooo`D0o`00203o
ool30000o`L0oooo00<0o`000?ooo`3oool01P3oool20000o`L0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool20?l00100oooo00<0
003o0?ooo`3oool04@3oool20?l001T0oooo0P000?lL0?ooo`80o`00:03o
ool20000o``0oooo003o0?ooo`d0003o4P3oool40?l000L0oooo0P000?l6
0?ooo`80o`00203oool00`000?l0oooo0?ooo`050?ooo`80o`002@3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0>0?ooo`80003o4`3oool2
0?l001T0oooo0P000?lL0?ooo`80o`00:03oool20000o`X0oooo003o0?oo
o`d0oooo2@000?l=0?ooo`80o`001`3oool20000o`H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo0P000?l:0?ooo`80o`00303oool20000o`d0oooo0P3o000@0?oo
o`80003o4`3oool20?l001T0oooo0P000?lL0?ooo`<0o`009`3oool20000
o`P0oooo001/0?oooe@0o`00E@3oool40000o`/0oooo0P3o00070?ooo`03
0000o`3oool0oooo00@0oooo0P3o00070?ooo`80003o1`3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0<0?ooo`80o`00403oool20000oa<0
oooo00<0o`000?ooo`3oool0603oool20000oad0oooo0P3o000_0?ooo`00
`03ooolf0?l002<0oooo10000?l90?ooo`80o`001P3oool20000o`H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`80o`00
2@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo0140oooo0P3o000J0?ooo`80003o7@3oool30?l002`0oooo
003f0?oooaH0o`004@3oool40000o`L0oooo00<0o`000?ooo`3oool01@3o
ool20000o`D0oooo0P3o00070?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool20000o`X0oooo0P3o000<0?ooo`80003o3P3o
ool20?l00100oooo0P000?lC0?ooo`80o`006P3oool20000oah0oooo0P3o
000Z0?ooo`00o`3oool=0?ooo`P0o`003@3oool30000o`D0oooo0P3o0007
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00d0oooo00<0o`000?ooo`3oool03`3oool20000oa<0oooo0P3o000J
0?ooo`80003o7P3oool30?l002L0oooo003o0?oooaD0oooo203o00080?oo
o`80003o1@3oool20?l000H0oooo0P000?l50?ooo`030?l0003oool0oooo
00D0oooo0P000?l70?ooo`80o`002@3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool03@3oool20?l0
0140oooo00<0003o0?ooo`3oool04P3oool20?l001X0oooo0P000?lO0?oo
o`80o`009@3oool006`0ooooL`000?lm0?ooo`@0o`001P3oool20000o`D0
oooo0P3o00060?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo0P000?l:0?ooo`030?l0003oool0oooo00/0oooo0P000?l?0?ooo`03
0?l0003oool0oooo00l0oooo0P000?lD0?ooo`80o`006P3oool20000oal0
oooo0`3o000R0?ooo`00g`3ooolV0000oa/0oooo0`3o00050?ooo`80003o
1@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool20?l000d0oooo
00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo01<0oooo0P3o000J0?ooo`80003o803oool20?l00200oooo
003o0?ooo`H0oooo3`000?l?0?ooo`80o`001@3oool20000o`@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`80o`001`3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo00d0oooo0P3o000A0?ooo`80003o5@3oool20?l001X0oooo0P00
0?lP0?ooo`<0o`007@3oool00?l0oooo5@3oool:0000o`L0oooo0P3o0005
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`80003o2P3oool0
0`3o0000oooo0?ooo`0;0?ooo`80003o3`3oool00`3o0000oooo0?ooo`0@
0?ooo`80003o5@3oool20?l001X0oooo0P000?lQ0?ooo`80o`006`3oool0
0?l0oooo7`3oool50000o`@0oooo0P3o00040?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool20?l0
00X0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00d0oooo0P3o000B0?ooo`030000o`3oool0oooo
01@0oooo0P3o000J0?ooo`030000o`3oool0oooo0200oooo0P3o000I0?oo
o`00K03ooonC0?l002@0oooo0P000?l40?ooo`050?l0003oool0oooo0?oo
o`000?l01@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool20?l0
00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0@0?oo
o`80003o5P3oool20?l001T0oooo0P000?lR0?ooo`80o`005`3oool00?l0
oooo703o000:0?ooo`80003o0`3oool01@3o0000oooo0?ooo`3oool0003o
00D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02`3oool20000o`l0oooo0P3o000B0?ooo`030000o`3oool0oooo
01D0oooo0P3o000I0?ooo`80003o8P3oool20?l001D0oooo003o0?oooa`0
oooo203o00040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0@0?ooo`80003o5`3oool00`3o0000oooo0?ooo`0H0?oo
o`030000o`3oool0oooo0240oooo0P3o000C0?ooo`00o`3ooolT0?ooo`<0
o`000P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?oo
o`80o`002@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool03P3oool20?l00180oooo00<0003o0?oo
o`3oool05@3oool20?l001T0oooo0P000?lS0?ooo`80o`004@3oool00?l0
oooo9P3oool20?l00080oooo00@0003o0?ooo`3oool0o`00103oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`090?oo
o`80o`003@3oool20000oa00oooo00<0o`000?ooo`3oool0403oool20000
oaL0oooo0P3o000I0?ooo`80003o8`3oool20?l000l0oooo001/0?oookX0
003o00@0oooo0?l0003oool0003o0`3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0>0?oo
o`80o`004P3oool00`000?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo
01P0oooo0P000?lS0?ooo`<0o`00303oool006`0oooo^@3`oo000`000?l0
oooo0?l000020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool01`3oool20000o`/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo
0100oooo0P000?lG0?ooo`80o`006P3oool20000ob@0oooo0P3o000:0?oo
o`00K03oooni0?3ol0040000o`3oool0oooo0?l00080oooo00@0003o0?oo
o`3oool0o`00103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00`0oooo0P000?l@
0?ooo`80o`004P3oool00`000?l0oooo0?ooo`0F0?ooo`80o`006P3oool3
0000ob<0oooo0P3o00080?ooo`00K03oooni0?3ol0040000o`3oool0oooo
0?l00080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo0100oooo0P000?lH0?ooo`030?l0003oool0oooo01X0oooo0P00
0?l[0?ooo`00K03oooni0?3ol0040000o`3oool0oooo0?l000<0oooo00@0
003o0?ooo`3oool0o`00103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`090?ooo`80o`003P3oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0003oool0oooo0140oooo0P000?lG0?ooo`80o`00
703oool20000obT0oooo001/0?oookT0l?o`00@0003o0?ooo`3oool0o`00
0`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0<0?ooo`80003o403oool20?l001<0oooo00<0003o0?ooo`3o
ool05P3oool20?l001`0oooo0P000?lW0?ooo`00K03oooni0?3ol0040000
o`3oool0oooo0?l000<0oooo00D0003o0?ooo`3oool0oooo0?l000050?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo0140oooo0P000?lH0?ooo`030?l0003oool0oooo
01/0oooo0P000?lU0?ooo`00K03oooni0?3ol0040000o`3oool0oooo0?l0
00@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0
oooo0180oooo0P000?lG0?ooo`80o`007@3oool20000ob<0oooo001/0?oo
okT0l?o`00@0003o0?ooo`3oool0o`00103oool01@000?l0oooo0?ooo`3o
ool0o`0000D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`0F0?ooo`80o`007@3oool00`000?l0oooo0?ooo`0P0?ooo`00K03oooni
0?3ol0050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool20?l000h0oooo00<0
003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0C0?ooo`80003o603o
ool00`3o0000oooo0?ooo`0K0?ooo`80003o803oool006`0oooo^@3`oo00
1@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool20000oa00oooo0P3o000E0?ooo`030000o`3oool0oooo01H0oooo0P3o
000M0?ooo`80003o7P3oool006`0oooo^@3`oo001@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000050?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0
003oool0oooo01<0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo
0?ooo`0L0?ooo`80003o703oool006`0oooo^@3`oo001@000?l0oooo0?oo
o`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo
0?ooo`0?0?ooo`030?l0003oool0oooo01<0oooo0P000?lH0?ooo`80o`00
7P3oool20000oaX0oooo001/0?oookT0l?o`00D0003o0?ooo`3oool0oooo
0?l000040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0
3`3oool20?l001D0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo
0?ooo`0M0?ooo`80003o603oool006`0oooo^@3`oo000`000?l0oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`000?l01@3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03@3oool20000oa40oooo
00<0o`000?ooo`3oool04`3oool20000oaP0oooo0P3o000O0?ooo`80003o
5P3oool006`0oooo^@3`oo000`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00/0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool05`3o
ool00`3o0000oooo0?ooo`0N0?ooo`80003o503oool006`0oooo^@3`oo00
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo0P3o000?
0?ooo`030000o`3oool0oooo00l0oooo0P3o000E0?ooo`80003o603oool2
0?l00200oooo0P000?lB0?ooo`00K03oooni0?3ol0030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?oo
o`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0503oool00`00
0?l0oooo0?ooo`0G0?ooo`80o`00803oool00`000?l0oooo0?ooo`0?0?oo
o`00K03oooni0?3ol0030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo0100
oooo0P3o000E0?ooo`80003o6@3oool20?l001l0oooo0P000?l?0?ooo`00
K03oooni0?3ol0030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0
303oool00`3o0000oooo0?ooo`0=0?ooo`80003o4P3oool00`3o0000oooo
0?ooo`0D0?ooo`030000o`3oool0oooo01P0oooo0P3o000O0?ooo`80003o
3@3oool006`0oooo^@3`oo000`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`0@0?ooo`80o`005@3oool20000oaX0oooo00<0o`000?ooo`3oool07P3o
ool00`000?l0oooo0?ooo`0:0?ooo`00K03oooni0?3ol0030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool0503oool0
0`000?l0oooo0?ooo`0H0?ooo`80o`007`3oool20000o`X0oooo001/0?oo
okT0l?o`00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool04@3oool00`3o
0000oooo0?ooo`0D0?ooo`80003o6P3oool00`3o0000oooo0?ooo`0N0?oo
o`80003o203oool006`0oooo^@3`oo000`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03P3oool00`000?l0
oooo0?ooo`0A0?ooo`80o`005P3oool00`000?l0oooo0?ooo`0H0?ooo`80
o`00:03oool006`0oooo^@3`oo000`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo
0?ooo`0B0?ooo`030?l0003oool0oooo01@0oooo0P000?lJ0?ooo`80o`00
9P3oool006`0oooo^@3`oo000`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00`0oooo00<0o`000?ooo`3oool03P3oool20000oa<0oooo0P3o
000F0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?ooo`3oool08`3o
ool006`0oooo^@3`oo000`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0B
0?ooo`030?l0003oool0oooo01@0oooo0P000?lJ0?ooo`80o`008`3oool0
06`0oooo^@3`oo000`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0B0?oo
o`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool06@3oool20?l0
0240oooo001/0?oookT0l?o`00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`080?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0<0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3o
ool04P3oool20?l001H0oooo0P000?lK0?ooo`80o`007`3oool006`0oooo
^@3`oo000`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0
003oool0oooo01D0oooo00<0003o0?ooo`3oool06P3oool20?l001d0oooo
001/0?oookT0l?o`00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool04`3o
ool00`3o0000oooo0?ooo`0E0?ooo`80003o703oool00`3o0000oooo0?oo
o`0J0?ooo`00K03oooni0?3ol0030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0
oooo01<0oooo0P3o000G0?ooo`030000o`3oool0oooo01X0oooo0P3o000J
0?ooo`00K03oooni0?3ol0030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo
01@0oooo00<0o`000?ooo`3oool05@3oool20000oa`0oooo00<0o`000?oo
o`3oool05`3oool006`0oooo^@3`oo000`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03`3oool20000oaD0
oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo0?ooo`0J0?ooo`03
0?l0003oool0oooo01H0oooo001/0?oookT0l?o`00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0=0?ooo`80o`004@3oool00`000?l0oooo
0?ooo`0C0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3oool0
6P3oool20?l001H0oooo001/0?oookT0l?o`00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0
003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3o
ool0oooo01/0oooo00<0o`000?ooo`3oool04`3oool006`0oooo^@3`oo00
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0
oooo01H0oooo0P000?lL0?ooo`80o`004`3oool006`0oooo^@3`oo000`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool03`3oool00`000?l0oooo0?ooo`0C0?ooo`80o`00603oool00`00
0?l0oooo0?ooo`0K0?ooo`80o`004@3oool006`0oooo^@3`oo000`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo01H0
oooo00<0003o0?ooo`3oool0703oool20?l000l0oooo001/0?oookT0l?o`
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00l0oooo0P000?lE0?ooo`030?l0003oool0oooo01H0oooo
00<0003o0?ooo`3oool07@3oool00`3o0000oooo0?ooo`0<0?ooo`00K03o
ooni0?3ol0030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo01<0oooo00<0
o`000?ooo`3oool05P3oool20000oah0oooo0P3o000<0?ooo`00K03oooni
0?3ol0030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool0
0`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo01<0oooo00<0o`00
0?ooo`3oool05`3oool00`000?l0oooo0?ooo`0M0?ooo`030?l0003oool0
oooo00T0oooo001/0?oookT0l?o`00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0100oooo0P000?lD0?oo
o`80o`00603oool20000oah0oooo0P3o00090?ooo`00K03oooni0?3ol003
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0B0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3o
ool05`3oool20000oah0oooo00<0o`000?ooo`3oool01P3oool006`0oooo
^@3`oo000`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00h0oooo
00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0
003oool0oooo01P0oooo00<0003o0?ooo`3oool0903oool006`0oooo^@3`
oo000`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02`3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00h0oooo00<0
o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0C0?ooo`80o`006@3o
ool20000ob@0oooo001/0?oookT0l?o`00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0180oooo00<0003o
0?ooo`3oool0503oool00`3o0000oooo0?ooo`0H0?ooo`030000o`3oool0
oooo0240oooo001/0?oookT0l?o`00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool0503oool00`3o0000oooo0?ooo`0H0?ooo`80003o8@3oool006`0
oooo^@3`oo000`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0
oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0D0?ooo`03
0?l0003oool0oooo01T0oooo0P000?lO0?ooo`00K03oooni0?3ol0030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0B0?ooo`030000o`3oool0oooo01@0oooo0P3o000K0?ooo`030000
o`3oool0oooo01`0oooo001/0?oookT0l?o`00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo0180oooo00<0
003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0I0?ooo`030000o`3o
ool0oooo01/0oooo001/0?oookT0l?o`00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0>0?ooo`80o`004`3oool00`000?l0oooo0?ooo`0E
0?ooo`030?l0003oool0oooo01T0oooo00<0003o0?ooo`3oool06P3oool0
06`0oooo^@3`oo000`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
0100oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0E0?oo
o`030?l0003oool0oooo01T0oooo0P000?lJ0?ooo`00K03oooni0?3ol003
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool0403oool00`3o0000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo01D0oooo0P3o000K0?ooo`03
0000o`3oool0oooo01L0oooo001/0?oookT0l?o`00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
3P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0140oooo
00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0I0?ooo`030000
o`3oool0oooo01H0oooo001/0?oookT0l?o`00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0140oooo0P00
0?lG0?ooo`030?l0003oool0oooo01T0oooo0P000?lF0?ooo`00K03oooni
0?3ol0030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;
0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo01D0oooo0P3o000K
0?ooo`030000o`3oool0oooo01<0oooo001/0?oookT0l?o`00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool03P3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo
0180oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0I0?oo
o`030000o`3oool0oooo0180oooo001/0?oookT0l?o`00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0180
oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo0?ooo`0I0?ooo`80
003o4P3oool006`0oooo^@3`oo000`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0?0?ooo`030000
o`3oool0oooo0100oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo
0?ooo`0F0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?ooo`3oool0
3`3oool006`0oooo^@3`oo000`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?oo
o`0F0?ooo`80o`006`3oool20000o`l0oooo001/0?oookT0l?o`00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool03P3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo0180oooo0P000?lH0?ooo`030?l0003oool0oooo01X0oooo00<0003o
0?ooo`3oool0303oool006`0oooo^@3`oo000`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0?0?oo
o`030000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04`3oool00`00
0?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo01X0oooo00<0003o0?oo
o`3oool02`3oool006`0oooo^@3`oo000`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo0140oooo00<0o`000?ooo`3oool04`3oool00`000?l0
oooo0?ooo`0F0?ooo`030?l0003oool0oooo01X0oooo0P000?l;0?ooo`00
K03oooni0?3ol0030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?ooo`3oool0
4@3oool00`3o0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01H0oooo
0P3o000L0?ooo`030000o`3oool0oooo00P0oooo001/0?oookT0l?o`00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo01@0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo0?oo
o`0J0?ooo`80003o203oool006`0oooo^@3`oo000`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0503oool0
0`000?l0oooo0?ooo`0G0?ooo`030?l0003oool0oooo02<0oooo001/0?oo
okT0l?o`00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0@0?oo
o`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool05`3oool20?l0
02<0oooo001/0?oookT0l?o`00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03`3oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3o
ool0603oool00`3o0000oooo0?ooo`0P0?ooo`00K03oooni0?3ol0030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00/0oooo
00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00l0oooo00<0003o0?ooo`3oool04@3oool00`3o0000oooo
0?ooo`0D0?ooo`030000o`3oool0oooo01P0oooo00<0o`000?ooo`3oool0
7`3oool006`0oooo^@3`oo000`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool0503oool00`000?l0oooo0?oo
o`0H0?ooo`030?l0003oool0oooo01h0oooo001/0?oookT0l?o`00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0
oooo01@0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0M
0?ooo`00K03oooni0?3ol0030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?oo
o`3oool04@3oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo
01P0oooo00<0o`000?ooo`3oool0703oool006`0oooo^@3`oo000`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0?0?ooo`030000o`3oool0oooo0140oooo00<0o`000?ooo`3o
ool0503oool20000oaT0oooo00<0o`000?ooo`3oool06`3oool006`0oooo
^@3`oo000`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
3@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0140oooo
00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0G0?ooo`030?l0
003oool0oooo01X0oooo001/0?oookT0l?o`00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo01D0oooo00<0
003o0?ooo`3oool05`3oool20?l001X0oooo001/0?oookT0l?o`00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`09
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0
oooo01D0oooo00<0003o0?ooo`3oool0603oool00`3o0000oooo0?ooo`0G
0?ooo`00K03oooni0?3ol0030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0oooo00<0003o0?oo
o`3oool04P3oool00`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo
01P0oooo00<0o`000?ooo`3oool05P3oool006`0oooo^@3`oo000`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`3o0000
oooo0?ooo`0@0?ooo`030000o`3oool0oooo0180oooo00<0o`000?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`0H0?ooo`80o`005P3oool006`0oooo
^@3`oo000`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0
3P3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo0180oooo
00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0I0?ooo`030?l0
003oool0oooo01<0oooo001/0?oookT0l?o`00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo01D0oooo00<0
003o0?ooo`3oool06@3oool00`3o0000oooo0?ooo`0B0?ooo`00K03oooni
0?3ol0030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0
oooo00`0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>
0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool04P3oool0
0`3o0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01T0oooo00<0o`00
0?ooo`3oool04@3oool006`0oooo^@3`oo000`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo
00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo0180oooo00<0o`000?ooo`3oool05@3oool00`00
0?l0oooo0?ooo`0I0?ooo`80o`004@3oool006`0oooo^@3`oo000`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3oool00`3o0000
oooo0?ooo`0@0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo00h0
oooo001/0?oookT0l?o`00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00h0oooo00<0o`000?ooo`3oool04@3oool00`000?l0oooo
0?ooo`0C0?ooo`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool0
6P3oool00`3o0000oooo0?ooo`0=0?ooo`00K03oooni0?3ol0030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?oo
o`0E0?ooo`030000o`3oool0oooo01X0oooo00<0o`000?ooo`3oool0303o
ool006`0oooo^@3`oo000`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00d0oooo00<0003o
0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0
oooo01<0oooo00<0o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0J
0?ooo`030?l0003oool0oooo00/0oooo001/0?oookT0l?o`00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0C0?ooo`030?l0003oool0oooo
01D0oooo00<0003o0?ooo`3oool06P3oool20?l000/0oooo001/0?oookT0
l?o`00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00l0
oooo00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0C0?ooo`03
0?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool06`3oool00`3o0000
oooo0?ooo`080?ooo`00K03oooni0?3ol0030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool0
3@3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0180oooo
00<0003o0?ooo`3oool04`3oool00`3o0000oooo0?ooo`0E0?ooo`030000
o`3oool0oooo01/0oooo00<0o`000?ooo`3oool01`3oool006`0oooo^@3`
oo000`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?oo
o`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo01@0oooo00<0
o`000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0K0?ooo`030?l0003o
ool0oooo00H0oooo001/0?oookT0l?o`00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`0D0?ooo`030?l0003oool0oooo01D0oooo0P000?lT
0?ooo`00K03oooni0?3ol0030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0180oooo00<0003o0?oo
o`3oool0503oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3oool0oooo
0240oooo001/0?oookT0l?o`00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00/0
oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0>0?ooo`03
0000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool04P3oool00`000?l0
oooo0?ooo`0D0?ooo`030?l0003oool0oooo01H0oooo00<0003o0?ooo`3o
ool0803oool006`0oooo^@3`oo000`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00h0oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0C0?ooo`030000
o`3oool0oooo01@0oooo00<0o`000?ooo`3oool05P3oool00`000?l0oooo
0?ooo`0O0?ooo`00K03oooni0?3ol0030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03P3o
ool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0180oooo00<0
003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0F0?ooo`030000o`3o
ool0oooo01h0oooo001/0?oookT0l?o`00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0>
0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo01H0oooo00<0003o
0?ooo`3oool07@3oool006`0oooo^@3`oo000`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool0303oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo
00l0oooo00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0B0?oo
o`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool05P3oool00`00
0?l0oooo0?ooo`0L0?ooo`00K03oooni0?3ol0030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool03P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo01<0
oooo00<0003o0?ooo`3oool0503oool00`3o0000oooo0?ooo`0G0?ooo`03
0000o`3oool0oooo01/0oooo001/0?oookT0l?o`00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool0
4P3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo01L0oooo
00<0003o0?ooo`3oool06P3oool006`0oooo^@3`oo000`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00h0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0B0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool05`3o
ool00`000?l0oooo0?ooo`0I0?ooo`00K03oooni0?3ol0030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool0303oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0
oooo0180oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0G
0?ooo`030000o`3oool0oooo01P0oooo001/0?oookT0l?o`00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool04`3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo
01L0oooo0P000?lH0?ooo`00K03oooni0?3ol0030000o`3oool0oooo00X0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool03`3oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo01<0
oooo00<0003o0?ooo`3oool05@3oool00`3o0000oooo0?ooo`0H0?ooo`03
0000o`3oool0oooo01D0oooo001/0?oookT0l?o`00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0?0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool0
4`3oool00`000?l0oooo0?ooo`0E0?ooo`030?l0003oool0oooo01P0oooo
00<0003o0?ooo`3oool0503oool006`0oooo^@3`oo000`000?l0oooo0?oo
o`0:0?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00/0oooo00<0
o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?oo
o`0C0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool0603o
ool00`000?l0oooo0?ooo`0C0?ooo`00\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{524, 228},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.105",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/sourcesink/SourceSinkFigures/\
mat11105.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Flow from a channel into a quadrant. "
}], "Text"],

Cell[TextData[{
  "Solution.  Using the Schwarz-Christoffel transformation method, the \
exterior angles are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(-\(\[Pi]\/2\)\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", "\[Pi]"}]}]]],
  ",  and the formula for the derivative ",
  Cell[BoxData[
      \(S' \((z)\)\)]],
  " is  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(S' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z - \
\((\(-1\))\))\)\^\(\(-\((\(-\(\[Pi]\/2\)\))\)\)/\[Pi]\)\) \((z - \
0)\)\^\(\(-\((\[Pi])\)\)/\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ \(\((z + 
                  1)\)\^\(1\/2\)\) \((z)\)\^\(-1\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \((z + \
1)\)\^\(1\/2\)\/z\)\)\)}]],
  "   \nintegrate \n\n\t\t\t",
  Cell[BoxData[
      \(S \((z)\)\ \  = \ 
        B\  + \ A\ \(\[Integral]\(\((z + 1)\)\^\(1\/2\)\/z\) \
\[DifferentialD]z\)\)],
    AspectRatioFixed->True],
  "\n\t\t\t\n\t\t\t",
  Cell[BoxData[
      \(S \((z)\)\ \  = \ 
        B\  + \ A\ \((2 \((z + 1)\)\^\(1\/2\)\ \  - \ \ Log \((\(1 + \((z + \
1)\)\^\(1\/2\)\)\/\(1 - \((z + 1)\)\^\(1\/2\)\))\))\)\)],
    AspectRatioFixed->True],
  "\n\t\t\t\n\t\t\t",
  Cell[BoxData[
      \(S \((z)\)\ \  = \ 
        B\  + \ A\ \((2 \((z + 1)\)\^\(1\/2\)\ \  + \ \ Log \((\(1 - \((z + \
1)\)\^\(1\/2\)\)\/\(1 + \((z + 1)\)\^\(1\/2\)\))\))\)\)],
    AspectRatioFixed->True],
  "\n\n\t\nuse the conditions  ",
  Cell[BoxData[
      \(S \((0)\)\  = \ 0\)]],
  ",  ",
  Cell[BoxData[
      \(S \((1)\) = \[ImaginaryI]\ \[Pi]\)]],
  "  and solve the resulting system for ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["B",
    FontFamily->"Courier New"],
  ".  The desired result is\n\n\t\t\t",
  Cell[BoxData[
      \(S \((z)\)\ \  = \ \ \[ImaginaryI]\ \[Pi]\ \  + \ \ 2 \((z + 1)\)\^\(1\
\/2\)\ \  + \ \ Log \((\(1 - \((z + 1)\)\^\(1\/2\)\)\/\(1 + \((z + \
1)\)\^\(1\/2\)\))\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[f, z];\)\ \), "\n", 
    \(\(S[
          z_]\  = \ \[ImaginaryI]\ \[Pi]\ \  + \ \ 2 \((z + 1)\)\^\(1\/2\)\ \ \
 + \ \ Log[\(1 - \((z + 1)\)\^\(1\/2\)\)\/\(1 + \((z + 1)\)\^\(1\/2\)\)];\)\ \
\), "\n", 
    \(\(Print["\< S[z] = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[-1] = \>", S[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< S[0] = \>", S[0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph conformal mapping  w = S(z)."
}], "Text"],

Cell[BoxData[
    \(\(\(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \[IndentingNewLine]
    \(Needs["\<Graphics`Colors`\>"];\)\ \[IndentingNewLine]
    \(boundary = 
        Graphics[{Blue, Line[{{\(-5\), \[Pi]}, {0, \[Pi]}, {0, 6}}], 
            Line[{{\(-5\), 0}, {6, 0}}]}];\)\[IndentingNewLine]
    \(gr1 = 
        PolarMap[S, {0.00001, 7.00001, 0.5}, {0.00001, 3.14149, 3.14139\/24}, 
          PlotRange \[Rule] {{\(-5\), 6}, {0, 6}}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \[IndentingNewLine]
    \(Show[gr1, boundary, PlotRange \[Rule] {{\(-5\), 6}, {0, 6}}, 
        AspectRatio \[Rule] 6\/11, 
        Ticks \[Rule] {Range[\(-4\), 6, 2], Range[4, 6, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \[IndentingNewLine]
    \(Print["\<The image of the flow in the upper half plane Im[z] > \
0,\>"];\)\ \n
    \(Print[\*"\"\<where a source is located at \!\(z\_0\) = 0, under \
the\>\""];\)\ \[IndentingNewLine]
    \(Print["\<conformal mapping w = S[z] = \>", 
        S[z]];\)\)\(\ \)\)\)], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ \ Table[{Re[
              S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            0, 23, 2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {r, 0.001, 20}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            1, 23, 2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {r, 0.001, 20}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Blue, Line[{{\(-5\), \[Pi]}, {0, \[Pi]}, {0, 6}}], 
            Line[{{\(-5\), 0}, {6, 0}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, boundary, 
        PlotRange \[Rule] {{\(-5\), 6}, {0, 6}}, AspectRatio \[Rule] 6\/11, 
        Ticks \[Rule] {Range[\(-4\), 6, 2], Range[4, 6, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow in the upper half plane Im[z] > \
0,\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<where a source is located at \!\(z\_0\) = 0, under the\>\
\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<conformal mapping w = S[z] = \>", 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can extend the flow into the fourth quadrant using symmetry."
}], "Text"],

Cell[BoxData[
    \(\(\(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \[IndentingNewLine]
    \(Needs["\<Graphics`Colors`\>"];\)\ \[IndentingNewLine]
    \(boundary = 
        Graphics[{Blue, Line[{{\(-5\), \[Pi]}, {0, \[Pi]}, {0, 6}}], 
            Line[{{\(-5\), 0}, {6, 0}}]}];\)\[IndentingNewLine]
    \(gr1 = 
        PolarMap[S, {0.00001, 7.00001, 0.5}, {0.00001, 3.14149, 3.14139\/24}, 
          PlotRange \[Rule] {{\(-5\), 6}, {0, 6}}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \[IndentingNewLine]
    \(g[z_] = Conjugate[S[z]];\)\[IndentingNewLine]
    \(gr2 = 
        PolarMap[g, {0.00001, 7.00001, 0.5}, {0.00001, 3.14149, 3.14139\/24}, 
          PlotRange \[Rule] {{\(-5\), 6}, {0, 6}}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \[IndentingNewLine]
    \(Show[gr1, gr2, boundary, PlotRange \[Rule] {{\(-5\), 6}, {\(-6\), 6}}, 
        AspectRatio \[Rule] 12\/11, 
        Ticks \[Rule] {Range[6, 6, 2], {\(-6\), \(-5\), \(-4\), 4, 5, 6}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ \ Table[{Re[
              S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            0, 23, 2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {r, 0.001, 20}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            1, 23, 2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {r, 0.001, 20}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Blue, Line[{{\(-5\), \[Pi]}, {0, \[Pi]}, {0, 6}}], 
            Line[{{\(-5\), 0}, {6, 0}}]}];\)\), "\[IndentingNewLine]", 
    \(\(eqns3\  = \ \ Table[{Re[
              g[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[g[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            0, 23, 2}];\)\ \), "\n", 
    \(\(graph3 = 
        ParametricPlot[Evaluate[eqns3], {r, 0.001, 20}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns4\  = \ 
        Table[{Re[g[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[g[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            1, 23, 2}];\)\ \), "\n", 
    \(\(graph4 = 
        ParametricPlot[Evaluate[eqns4], {r, 0.001, 20}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Blue, Line[{{\(-5\), \[Pi]}, {0, \[Pi]}, {0, 6}}], 
            Line[{{\(-5\), 0}, {6, 0}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, graph4, boundary, 
        PlotRange \[Rule] {{\(-5\), 6}, {\(-6\), 6}}, 
        AspectRatio \[Rule] 12\/11, 
        Ticks \[Rule] {None, {\(-6\), \(-5\), \(-4\), 4, 5, 6}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow in the z-plane,\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<where a source is located at \!\(z\_0\) = 0, under the\>\
\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<conformal mapping w = S[z] = \>", 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use a Schwarz-Christoffel transformation to show that the conformal \
mapping  \n\n\t\t\t",
  Cell[BoxData[
      \(w\ \  = \ \ \(S \((z)\)\ \  = \ \ 4 \((1 + z)\)\^\(1/4\)\  + \ 
            Log \(\((z + 1)\)\^\(1/4\) - 1\)\/\(\((z + 1)\)\^\(1/4\) + 1\)\  \
+ \ \[ImaginaryI]\ Log \( \[ImaginaryI] - \((z + 1)\)\^\(1/4\)\)\/\(\
\[ImaginaryI] + \((z + 1)\)\^\(1/4\)\)\)\)]],
  " \n\t\t\t\n\nwill map the flow in the upper half-plane from a source at  \
",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  "  onto the flow from a channel with  ",
  Cell[BoxData[
      \(w\_0 = \(S \((z\_0)\)\  = \ \(-\[Infinity]\)\)\)]],
  "  into a sector, as shown in Figure 11.106.\nHint: Set  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 0\)}]]],
  " and ",
  Cell[BoxData[
      RowBox[{\(w\_1 = \[ImaginaryI]\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{\(w\_2\), "=", 
          RowBox[{
            RowBox[{\(-d\), "  ", 
              StyleBox["and",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox[" ",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], 
              StyleBox["let",
                FontFamily->"Times New Roman",
                FontSize->12,
                FontWeight->"Plain",
                FontSlant->"Plain",
                FontColor->GrayLevel[0],
                FontVariations->{"Underline"->False,
                "StrikeThrough"->False}], "  ", "d"}], "\[Rule]", 
            "\[Infinity]"}]}]}]]],
  ".  Use the change of variable  ",
  Cell[BoxData[
      \(z + 1 = s\^4\)]],
  "  in the resulting integral."
}], "Text"],

Cell[TextData[Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007W0000i2000`400?l0
0000o`00003oo`3ooooX0?ooo`00o`3ooooX0?ooo`00o`3ooooX0?ooo`00
o`3ooooX0?ooo`00o`3ooooX0?ooo`00K03ooooo0000og@0003o203oool0
0?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03oool00?l0ooooj03o
ool006`0ooooCP3o003o0?ooobh0oooo002j0?ooog00o`00_@3oool00?l0
oooo:`3ooolT0?l009T0oooo003o0?ooodl0oooo803o001i0?ooo`00o`3o
oom_0?ooobD0o`00E03oool006`0ooooCP000?oI0?ooobD0o`00;`3oool0
0;X0ooooD0000?n^0?ooob80o`003@3oool00?l0oooo2`3ooolP0000ok00
oooo1@3o00080?ooo`00o`3oool[0?oooaX0003oX`3oool00?l0ooooA@3o
oolD0000ohl0oooo001/0?ooodh0o`00WP3oool?0000oh00oooo002j0?oo
ocX0o`00L`3oool<0000og@0oooo003d0?oooaD0o`00JP3oool?0000ofD0
oooo003o0?ooo`X0oooo603o001Q0?oooa40003oE03oool00?l0oooo8P3o
oolA0?l00640oooo6P000?lj0?ooo`00K03ooomQ0000ofD0oooo3`3o001/
0?ooo`X0003o<03oool00<d0oooo6P000?mJ0?ooo`d0o`00J@3ooolC0000
oad0oooo003W0?oooaX0003oC@3oool=0?l006l0oooo40000?l=0?ooo`00
o`3oool20?oooa00003oBP3oool<0?l007<0oooo1@000?l80?ooo`00o`3o
oolB0?oooa00003oAP3oool<0?l007@0oooo001/0?ooof40o`00E03oool@
0000od80oooo3`3o001U0?ooo`00c@3ooolJ0?l004X0oooo3@000?m40?oo
o`d0o`00F03oool00>L0oooo6P3o000m0?ooo`X0003oA`3oool70?l00540
oooo003o0?ooo`80oooo403o000g0?ooo`X0003oA03oool:0?l004L0oooo
003o0?oooa80oooo303o000e0?ooo`X0003oA03oool<0?l003/0oooo001/
0?ooof40003oD03oool:0?l003D0oooo20000?m80?ooo`X0o`00<@3oool0
0<d0oooo6@000?m10?ooo`P0o`00=@3oool80000odX0oooo2P3o000W0?oo
o`00iP3oool=0000oc`0oooo1`3o000f0?ooo`P0003oC03oool90?l001h0
oooo003c0?ooo`h0003o=@3oool70?l003L0oooo2@000?m<0?oooa00o`00
3P3oool00?l0oooo0P3oool?0000obd0oooo203o000h0?ooo`T0003oD`3o
ool60?l000P0oooo001/0?ooof40o`00@`3oool<0000obT0oooo1`3o000j
0?ooo`P0003oF@3oool00<d0oooo6@3o000f0?ooo`X0003o9P3oool80?l0
03X0oooo1`000?mB0?ooo`00iP3oool=0?l003<0oooo20000?lV0?ooo`P0
o`00>@3oool:0000odP0oooo003c0?ooo`X0o`00<@3oool70000obL0oooo
1`3o000l0?ooo`T0003o?`3oool006`0oooo8P000?m_0?ooo`X0o`00;P3o
ool70000obL0oooo203o000m0?ooo`H0003o>@3oool008h0oooo?`000?lj
0?ooo`X0o`00:`3oool60000obT0oooo203o000k0?ooo`L0003o<P3oool0
0<d0oooo6@000?l[0?ooo`X0o`009`3oool60000ob/0oooo203o000j0?oo
o`X0003o:03oool00>H0oooo3@000?lX0?ooo`X0o`008`3oool70000ob`0
oooo203o000l0?ooo`T0003o7`3oool00?<0oooo2P000?lX0?ooo`T0o`00
8@3oool60000obh0oooo1`3o000n0?ooo`P0003o5`3oool006`0oooo8P3o
001_0?ooo`T0003o:03oool60?l00240oooo1P000?l_0?ooo`D0o`00@@3o
ool80000o`l0oooo002>0?oooch0o`00>P3oool:0000ob@0oooo1P3o000Q
0?ooo`H0003o;P3oool60?l004<0oooo1@000?l:0?ooo`00c03ooolJ0?l0
02X0oooo2@000?lQ0?ooo`H0o`008@3oool60000obh0oooo1@3o00130?oo
o`80003o203oool00>H0oooo303o000W0?ooo`D0003o8P3oool50?l00280
oooo1P000?l]0?ooo`H0o`00A`3oool00?80oooo2P3o000R0?ooo`H0003o
8@3oool50?l002<0oooo1P000?l]0?ooo`T0o`00?P3oool006`0oooo8P00
0?m^0?ooo`T0o`007`3oool50000ob40oooo1P3o000S0?ooo`D0003o<@3o
ool90?l003D0oooo002>0?oooch0003o>@3oool70?l001d0oooo1@000?lR
0?ooo`D0o`008`3oool60000oc@0oooo1@3o000`0?ooo`00c03ooolI0000
obL0oooo1P3o000L0?ooo`H0003o8@3oool60?l002<0oooo1P000?lc0?oo
o`H0o`00:P3oool00>D0oooo3@000?lP0?ooo`H0o`00703oool50000ob80
oooo1@3o000T0?ooo`D0003o=03oool70?l002<0oooo003b0?ooo`P0003o
7P3oool50?l001`0oooo1@000?lR0?ooo`@0o`009@3oool50000ocH0oooo
103o000O0?ooo`00K03ooom=0?l00440oooo1P000?lM0?ooo`D0o`00703o
ool60000ob00oooo103o000V0?ooo`D0003o=@3oool60?l001T0oooo002i
0?oooa<0o`00=03oool60000oa`0oooo1P3o000L0?ooo`D0003o7`3oool5
0?l002H0oooo1@000?lf0?ooo`P0o`004@3oool00<`0oooo6@3o000Q0?oo
o`P0003o6P3oool50?l001`0oooo1@000?lO0?ooo`@0o`009`3oool60000
ocP0oooo1P3o000;0?ooo`00i@3oool<0?l001d0oooo2@000?lF0?ooo`D0
o`00703oool60000oad0oooo1@3o000X0?ooo`H0003o>03oool30?l000P0
oooo003a0?ooo`P0o`007P3oool40000oaL0oooo1@3o000M0?ooo`D0003o
7@3oool60?l002P0oooo1P000?lm0?ooo`00K03ooom=0000od00oooo1P3o
000L0?ooo`D0003o5`3oool40?l001h0oooo10000?lO0?ooo`H0o`00:03o
ool60000ocL0oooo002i0?oooa<0003o<`3oool60?l001/0oooo10000?lG
0?ooo`@0o`007P3oool40000ob40oooo103o000Z0?ooo`D0003o<P3oool0
0<`0oooo6@000?lP0?ooo`H0o`006@3oool40000oaL0oooo103o000N0?oo
o`@0003o8@3oool40?l002/0oooo1@000?l]0?ooo`00i@3oool<0000oaX0
oooo1P3o000G0?ooo`D0003o5P3oool40?l001h0oooo10000?lQ0?ooo`@0
o`00;03oool40000obT0oooo003a0?ooo`P0003o603oool50?l001L0oooo
10000?lF0?ooo`@0o`007P3oool40000ob40oooo103o000/0?ooo`H0003o
8`3oool006`0ooooC@3o00100?ooo`H0003o5`3oool40?l001L0oooo1000
0?lF0?ooo`@0o`007P3oool40000ob40oooo1@3o000]0?ooo`H0003o7@3o
ool00;T0oooo7`3o000W0?ooo`H0003o5@3oool50?l001H0oooo10000?lF
0?ooo`@0o`007P3oool30000ob<0oooo1P3o000]0?ooo`@0003o6@3oool0
0=P0oooo303o000Q0?ooo`D0003o5@3oool40?l001H0oooo0`000?lG0?oo
o`@0o`007@3oool40000obD0oooo1@3o000/0?ooo`H0003o4`3oool00>@0
oooo303o000J0?ooo`H0003o4`3oool40?l001D0oooo10000?lG0?ooo`D0
o`00703oool40000obH0oooo103o000^0?ooo`L0003o303oool006`0oooo
8@000?mS0?ooo`P0o`00603oool40000oa<0oooo1@3o000D0?ooo`@0003o
603oool40?l001`0oooo10000?lV0?ooo`@0o`00<@3oool40000o`P0oooo
002=0?ooob`0003o?`3oool60?l001H0oooo10000?lD0?ooo`@0o`00503o
ool30000oaT0oooo1@3o000K0?ooo`D0003o9@3oool40?l003T0oooo002i
0?oooal0003o9P3oool60?l001@0oooo10000?lD0?ooo`@0o`004`3oool4
0000oaX0oooo1@3o000K0?ooo`D0003o903oool50?l003@0oooo003H0?oo
o``0003o803oool50?l001<0oooo10000?lD0?ooo`@0o`004`3oool30000
oa`0oooo103o000L0?ooo`D0003o903oool50?l002l0oooo003T0?ooo`/0
003o6P3oool60?l00140oooo0`000?lE0?ooo`<0o`004`3oool40000oa`0
oooo103o000M0?ooo`@0003o9@3oool40?l002/0oooo001/0?ooob40o`00
HP3oool80000oaP0oooo103o000@0?ooo`@0003o503oool40?l001<0oooo
10000?lL0?ooo`<0o`007P3oool40000obD0oooo103o000W0?ooo`00S@3o
ooln0?l002`0oooo1P000?lF0?ooo`<0o`004@3oool40000oa@0oooo0`3o
000D0?ooo`<0003o703oool30?l001l0oooo10000?lU0?ooo`@0o`008`3o
ool00</0oooo3@3o000U0?ooo`H0003o4`3oool40?l00140oooo10000?lC
0?ooo`@0o`004`3oool40000oa/0oooo103o000O0?ooo`@0003o9@3oool6
0?l001d0oooo003H0?ooo``0o`007`3oool50000oa80oooo0`3o000B0?oo
o`<0003o503oool30?l001@0oooo10000?lK0?ooo`<0o`00803oool40000
obL0oooo1P3o000G0?ooo`00i03oool;0?l001T0oooo1P000?l?0?ooo`<0
o`004P3oool30000oa@0oooo103o000D0?ooo`<0003o6`3oool30?l00240
oooo10000?lY0?ooo`@0o`004`3oool006`0oooo8@000?mR0?ooo`T0o`00
5P3oool40000o`h0oooo0`3o000B0?ooo`<0003o5@3oool30?l001@0oooo
10000?lJ0?ooo`@0o`008@3oool40000obT0oooo0`3o000@0?ooo`00S@3o
ooln0000obd0oooo1P3o000D0?ooo`<0003o3P3oool30?l00180oooo1000
0?lD0?ooo`@0o`00503oool40000oaX0oooo103o000Q0?ooo`<0003o:@3o
ool40?l000`0oooo003;0?oooaD0003o7P3oool40?l001<0oooo0`000?l>
0?ooo`@0o`004P3oool30000oaD0oooo0`3o000E0?ooo`<0003o6`3oool4
0?l00200oooo10000?lY0?ooo`@0o`00203oool00>00oooo30000?lF0?oo
o`D0o`004@3oool30000o`l0oooo0`3o000B0?ooo`<0003o5@3oool30?l0
01D0oooo10000?lK0?ooo`<0o`008@3oool30000oc80oooo003/0?ooo`D0
003o5P3oool50?l000l0oooo0`000?l?0?ooo`<0o`004P3oool30000oaD0
oooo0P3o000G0?ooo`<0003o6`3oool40?l00200oooo10000?l^0?ooo`00
K03ooom=0?l003P0oooo1P000?lE0?ooo`@0o`003P3oool40000o`h0oooo
0`3o000B0?ooo`<0003o503oool30?l001L0oooo0`000?lL0?ooo`@0o`00
803oool50000obT0oooo002i0?oooah0o`00803oool80000oa40oooo0`3o
000?0?ooo`<0003o3P3oool30?l00180oooo10000?lC0?ooo`<0o`005`3o
ool40000oa`0oooo103o000Q0?ooo`@0003o9@3oool00=L0oooo2@3o000O
0?ooo`D0003o3`3oool20?l00100oooo0`000?l>0?ooo`<0o`004`3oool3
0000oa<0oooo0`3o000H0?ooo`<0003o7@3oool30?l00280oooo10000?lQ
0?ooo`00h03oool>0?l001H0oooo10000?l=0?ooo`<0o`00403oool30000
o`h0oooo0`3o000C0?ooo`<0003o4`3oool20?l001T0oooo0`000?lM0?oo
o`80o`00903oool40000oad0oooo003^0?ooo`P0o`004P3oool40000o``0
oooo0`3o000@0?ooo`<0003o3P3oool30?l001<0oooo0`000?lB0?ooo`<0
o`006@3oool20000oad0oooo0`3o000U0?ooo`<0003o6P3oool006`0oooo
C@000?lm0?ooo`H0o`00403oool30000o``0oooo0`3o000@0?ooo`80003o
3`3oool20?l001@0oooo0P000?lC0?ooo`<0o`00603oool30000oad0oooo
0`3o000U0?ooo`@0003o5P3oool00;T0oooo7P000?lU0?ooo`@0o`003`3o
ool30000o``0oooo0`3o000?0?ooo`<0003o3P3oool30?l001<0oooo0`00
0?lC0?ooo`<0o`00603oool30000oad0oooo0`3o000V0?ooo`<0003o4`3o
ool00=L0oooo3`000?lJ0?ooo`<0o`003`3oool30000o``0oooo0P3o000@
0?ooo`80003o3`3oool30?l001<0oooo0`000?lC0?ooo`<0o`00603oool3
0000oad0oooo103o000U0?ooo`@0003o3`3oool00>H0oooo1`000?lF0?oo
o`@0o`003P3oool40000o`X0oooo0`3o000?0?ooo`80003o403oool30?l0
01<0oooo0P000?lD0?ooo`@0o`005`3oool40000oad0oooo0`3o000V0?oo
o`@0003o2`3oool00>d0oooo2@000?lA0?ooo`@0o`003P3oool30000o`X0
oooo0`3o000>0?ooo`<0003o403oool30?l00180oooo0`000?lE0?ooo`<0
o`00603oool40000oa`0oooo103o000V0?ooo`<0003o203oool006`0oooo
G`3o000[0?ooo`L0003o3P3oool30?l000h0oooo0`000?l:0?ooo`<0o`00
3P3oool20000oa40oooo0`3o000B0?ooo`<0003o5@3oool30?l001T0oooo
10000?lL0?ooo`D0o`00;03oool00</0oooo503o000N0?ooo`D0003o303o
ool30?l000h0oooo0P000?l;0?ooo`80o`003P3oool30000oa40oooo0`3o
000B0?ooo`80003o5P3oool30?l001X0oooo0`000?lN0?ooo`@0o`00:03o
ool00=l0oooo3P3o000E0?ooo`<0003o303oool30?l000d0oooo0P000?l;
0?ooo`80o`003`3oool20000oa80oooo0P3o000B0?ooo`<0003o5P3oool2
0?l001/0oooo0P000?lP0?ooo`@0o`00903oool00>d0oooo1P3o000B0?oo
o`@0003o2`3oool30?l000`0oooo0P000?l;0?ooo`<0o`003P3oool30000
oa40oooo0`3o000B0?ooo`80003o5P3oool30?l001X0oooo0`000?lQ0?oo
o`80o`008P3oool006`0oooo8@000?mV0?ooo`T0o`003@3oool30000o`/0
oooo0`3o000;0?ooo`80003o303oool20?l000l0oooo0P000?lB0?ooo`<0
o`004@3oool30000oaH0oooo0`3o000J0?ooo`<0003o803oool20?l00200
oooo002=0?ooodT0003o9P3oool50?l000/0oooo0P000?l<0?ooo`<0o`00
2P3oool30000o`/0oooo0P3o000?0?ooo`80003o4`3oool20?l00180oooo
0`000?lF0?ooo`<0o`006P3oool30000oal0oooo0`3o000M0?ooo`00eP3o
oolF0000oaD0oooo0P3o000;0?ooo`<0003o303oool20?l000/0oooo0P00
0?l;0?ooo`<0o`003P3oool30000oa80oooo0`3o000B0?ooo`80003o5`3o
ool30?l001X0oooo10000?lN0?ooo`@0o`006@3oool00>`0oooo1`000?l@
0?ooo`@0o`002P3oool20000o``0oooo0P3o000;0?ooo`80003o303oool2
0?l000l0oooo0P000?lC0?ooo`<0o`004@3oool30000oaL0oooo0`3o000K
0?ooo`<0003o7`3oool40?l001D0oooo003c0?ooo`L0003o3@3oool30?l0
00T0oooo0`000?l;0?ooo`80o`002`3oool20000o``0oooo0`3o000>0?oo
o`<0003o4`3oool20?l00180oooo0`000?lG0?ooo`<0o`006`3oool20000
ob40oooo0`3o000B0?ooo`00K03ooom=0?l00440oooo0`000?l=0?ooo`80
o`002P3oool20000o`/0oooo0P3o000;0?ooo`80003o3@3oool20?l000l0
oooo0P000?lC0?ooo`<0o`004P3oool20000oaP0oooo0`3o000J0?ooo`<0
003o8@3oool40?l000h0oooo002i0?ooobH0o`007P3oool40000o`/0oooo
0P3o000:0?ooo`80003o2`3oool20?l000/0oooo0P000?l=0?ooo`80o`00
3`3oool20000oa@0oooo0P3o000B0?ooo`80003o6@3oool30?l001X0oooo
0`000?lR0?ooo`@0o`002P3oool00=l0oooo3@3o000E0?ooo`@0003o2@3o
ool20?l000X0oooo0P000?l;0?ooo`80o`002`3oool20000o`d0oooo0`3o
000>0?ooo`80003o503oool20?l00180oooo0`000?lI0?ooo`80o`006`3o
ool30000ob<0oooo0P3o00080?ooo`00k03oool=0?l000`0oooo0`000?l8
0?ooo`80o`002P3oool20000o`/0oooo0P3o000;0?ooo`80003o3P3oool2
0?l000h0oooo0P000?lD0?ooo`80o`004`3oool20000oaT0oooo0`3o000K
0?ooo`<0003o:P3oool00?T0oooo1P3o00090?ooo`80003o203oool20?l0
00X0oooo0P000?l;0?ooo`80o`002`3oool30000o`d0oooo0P3o000>0?oo
o`<0003o4`3oool20?l001<0oooo0P000?lJ0?ooo`<0o`006`3oool30000
obL0oooo001/0?oooeh0003o=@3oool20?l000T0oooo0P000?l80?ooo`80
o`002P3oool20000o`/0oooo0P3o000<0?ooo`80003o3@3oool30?l000h0
oooo0P000?lC0?ooo`80o`004`3oool30000oaX0oooo0P3o000L0?ooo`@0
003o8`3oool00<X0oooo90000?lC0?ooo`<0o`00203oool20000o`P0oooo
0P3o000:0?ooo`80003o2`3oool20?l000`0oooo0P000?l>0?ooo`80o`00
3P3oool20000oa<0oooo0P3o000D0?ooo`<0003o6@3oool30?l001d0oooo
0`000?lP0?ooo`00kP3oool;0000o`/0oooo0`3o00070?ooo`80003o203o
ool20?l000X0oooo0P000?l;0?ooo`80o`00303oool20000o`h0oooo0P3o
000>0?ooo`80003o4`3oool30?l001@0oooo0`000?lI0?ooo`80o`007P3o
ool40000oa`0oooo003i0?ooo`@0003o2P3oool20?l000L0oooo0P000?l8
0?ooo`80o`002P3oool20000o`/0oooo0P3o000<0?ooo`80003o3P3oool2
0?l000h0oooo0`000?lC0?ooo`80o`005@3oool30000oaP0oooo0`3o000O
0?ooo`<0003o6@3oool00?d0oooo1@000?l70?ooo`80o`001`3oool20000
o`P0oooo0P3o000:0?ooo`80003o2`3oool20?l000`0oooo0P000?l>0?oo
o`80o`003`3oool20000oa<0oooo0P3o000F0?ooo`<0003o603oool20?l0
0200oooo0P000?lG0?ooo`00K03ooomm0?l001T0oooo0P000?l70?ooo`80
o`001`3oool00`000?l0oooo0?ooo`070?ooo`80o`002P3oool00`000?l0
oooo0?ooo`0:0?ooo`80o`00303oool20000o`h0oooo0P3o000?0?ooo`80
003o4`3oool30?l001H0oooo0`000?lG0?ooo`<0o`007`3oool20000oaD0
oooo003Y0?oooa@0o`001`3oool20000o`L0oooo0P3o00060?ooo`80003o
2@3oool00`3o0000oooo0?ooo`080?ooo`80003o303oool20?l000`0oooo
0P000?l>0?ooo`80o`003`3oool20000oa@0oooo0P3o000G0?ooo`80003o
603oool30?l001h0oooo0`000?lB0?ooo`00o@3oool40?l000D0oooo0P00
0?l70?ooo`030?l0003oool0oooo00D0oooo0P000?l80?ooo`80o`002P3o
ool20000o``0oooo0P3o000<0?ooo`80003o3P3oool20?l000l0oooo0`00
0?lC0?ooo`80o`005`3oool30000oaP0oooo0P3o000O0?ooo`<0003o3`3o
ool00?l0oooo0P3oool30?l000@0oooo0P000?l60?ooo`80o`001`3oool2
0000o`P0oooo0P3o000:0?ooo`80003o303oool20?l000`0oooo0P000?l>
0?ooo`80o`00403oool20000oa<0oooo0`3o000G0?ooo`<0003o5`3oool3
0?l001l0oooo10000?l;0?ooo`00o`3oool10?ooo`05003o003oool0oooo
0?ooo`3o00001@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo0P000?l80?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool02`3oool20?l000`0oooo0P000?l>0?ooo`<0o`003`3oool2
0000oa@0oooo0P3o000H0?ooo`80003o603oool30?l00200oooo0`000?l8
0?ooo`00K03ooonE0000o`@0oooo0P3o00040?ooo`030000o`3oool0oooo
00D0oooo0P3o00080?ooo`80003o1`3oool20?l000X0oooo0P000?l=0?oo
o`80o`00303oool20000o`l0oooo0P3o000?0?ooo`<0003o4`3oool20?l0
01P0oooo0P000?lI0?ooo`@0o`009`3oool006`0ooooU03`oo000`00o`00
003o0?ooo`040?ooo`030?l0003oool0oooo0080oooo0P000?l70?ooo`03
0?l0003oool0oooo00L0oooo0P000?l70?ooo`80o`002P3oool20000o`d0
oooo0P3o000<0?ooo`80003o3`3oool20?l00100oooo0P000?lC0?ooo`80
o`00603oool20000oa/0oooo0`3o000T0?ooo`00K03ooonD0?3ol003003o
003`oo00003o00D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`050?ooo`80o`002@3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00T0oooo0P000?l=0?ooo`030?l0003oool0oooo00/0oooo
0P000?l?0?ooo`80o`00403oool20000oa<0oooo0P3o000H0?ooo`<0003o
6`3oool20?l00280oooo001/0?oooi@0l?o`00@00?l00?3ol03`oo00003o
1@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`80o`00
2`3oool20000o``0oooo0P3o000=0?ooo`80003o3`3oool20?l00100oooo
0P000?lC0?ooo`<0o`00603oool20000oa/0oooo0`3o000O0?ooo`00K03o
oonD0?3ol005003o003`oo00l?o`0?3ol0000?l01@3oool20?l000@0oooo
0P000?l70?ooo`80o`00203oool20000o`P0oooo0P3o000;0?ooo`030000
o`3oool0oooo00/0oooo0P3o000=0?ooo`80003o3`3oool20?l00100oooo
0P000?lD0?ooo`<0o`005`3oool30000oa/0oooo0`3o000L0?ooo`00K03o
oonD0?3ol003003o003`oo00l?o`0080l?o`00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00T0oooo0P000?l=0?ooo`80o`003@3oool20000o`l0oooo0P3o
000@0?ooo`80003o5@3oool20?l001P0oooo0P000?lL0?ooo`<0o`006@3o
ool006`0ooooU03`oo000`00o`00l?o`0?3ol0030?3ol0030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool20000o`L0oooo0P3o0008
0?ooo`80003o203oool20?l000/0oooo0P000?l=0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool03P3oool20?l00100oooo0`000?lD
0?ooo`<0o`005`3oool20000oad0oooo0`3o000F0?ooo`00K03ooonD0?3o
l003003o003`oo00l?o`00@0l?o`00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`80o`002`3oool20000
o``0oooo0P3o000=0?ooo`80003o403oool20?l00140oooo0P000?lE0?oo
o`<0o`005P3oool20000oah0oooo0`3o000C0?ooo`00K03ooonD0?3ol003
003o003`oo00l?o`00D0l?o`00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`80003o1`3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0;0?ooo`80o`003@3oool20000oa00oooo0P3o000A0?ooo`80
003o5P3oool20?l001H0oooo0P000?lO0?ooo`80o`004@3oool006`0oooo
U03`oo000`00o`00l?o`0?3ol0060?3ol0030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`80o`00
203oool20000o`T0oooo0P3o000;0?ooo`80003o3@3oool00`3o0000oooo
0?ooo`0<0?ooo`80003o403oool20?l00140oooo0`000?lE0?ooo`80o`00
5P3oool30000oah0oooo0P3o000?0?ooo`00K03ooonD0?3ol003003o003`
oo00l?o`00L0l?o`00<0003o0?ooo`3oool0103oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`080?ooo`80o`002`3oool00`000?l0oooo0?oo
o`0;0?ooo`80o`003P3oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003o
ool0oooo0140oooo0P000?lE0?ooo`80o`005`3oool40000oa`0oooo0P3o
000=0?ooo`00K03ooonD0?3ol003003o003`oo00l?o`00P0l?o`00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01`3oool20000o`X0oooo00<0o`00
0?ooo`3oool02@3oool20000o`d0oooo0P3o000=0?ooo`80003o403oool2
0?l001<0oooo0P000?lE0?ooo`80o`006@3oool30000oa/0oooo0`3o000:
0?ooo`00K03ooonD0?3ol003003o003`oo00l?o`00T0l?o`00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`80003o1`3oool20?l0
00T0oooo00<0003o0?ooo`3oool0203oool20?l000/0oooo0P000?l=0?oo
o`80o`003@3oool20000oa00oooo0P3o000C0?ooo`80003o5@3oool20?l0
01X0oooo0P000?lL0?ooo`80o`00203oool006`0ooooU03`oo000`00o`00
l?o`0?3ol00:0?3ol0030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool02@3oool20?l000/0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`80003o403oool20?l001<0
oooo0P000?lE0?ooo`80o`006P3oool30000ob<0oooo001/0?oooi@0l?o`
00<00?l00?3ol03`oo002`3`oo000`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`070?ooo`80003o2`3oool00`3o0000oooo0?ooo`090?ooo`80003o
3@3oool20?l000h0oooo0P000?l@0?ooo`030?l0003oool0oooo0180oooo
0P000?lE0?ooo`80o`006`3oool20000ob40oooo001/0?oooi@0l?o`00<0
0?l00?3ol03`oo00303`oo000`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool20?l000T0oooo00<0
003o0?ooo`3oool02@3oool20?l000/0oooo00<0003o0?ooo`3oool0303o
ool20?l000h0oooo00<0003o0?ooo`3oool03P3oool20?l001@0oooo0P00
0?lE0?ooo`<0o`006P3oool20000oal0oooo001/0?oooi@0l?o`00<00?l0
0?3ol03`oo003@3`oo000`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`07
0?ooo`80003o2`3oool00`3o0000oooo0?ooo`090?ooo`80003o3P3oool0
0`3o0000oooo0?ooo`0<0?ooo`80003o403oool20?l001@0oooo0`000?lE
0?ooo`80o`006P3oool20000oad0oooo001/0?oooi@0l?o`00<00?l00?3o
l03`oo003P3`oo000`000?l0oooo0?ooo`040?ooo`80o`001`3oool20000
o`P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?oo
o`80o`002`3oool20000o`d0oooo0P3o000>0?ooo`80003o403oool20?l0
01D0oooo0P000?lE0?ooo`<0o`006@3oool30000oaX0oooo001/0?oooi@0
l?o`00<00?l00?3ol03`oo003`3`oo000`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool20?l000T0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00`0oooo0P3o000>0?ooo`80003o403oool20?l001D0
oooo0P000?lF0?ooo`<0o`006@3oool30000oaL0oooo001/0?oooi@0l?o`
00<00?l00?3ol03`oo00403`oo000`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`80003o2`3oool20?l000/0oooo0P000?l>0?ooo`030?l0
003oool0oooo00d0oooo0P000?l@0?ooo`80o`005@3oool20000oaL0oooo
0P3o000J0?ooo`80003o5@3oool006`0ooooU03`oo000`00o`00l?o`0?3o
l00A0?3ol0030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00`0oooo0P3o000?0?ooo`80003o403oool20?l001D0oooo0P00
0?lG0?ooo`80o`006P3oool20000oa<0oooo001/0?oooi@0l?o`00<00?l0
0?3ol03`oo004P3`oo000`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01`3oool20?l000T0oooo00<0003o
0?ooo`3oool02P3oool20?l000/0oooo0P000?l>0?ooo`80o`003`3oool2
0000oa00oooo0P3o000E0?ooo`80003o5`3oool30?l001T0oooo0P000?lA
0?ooo`00K03ooonD0?3ol003003o003`oo00l?o`01<0l?o`00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`80003o2@3oool00`3o
0000oooo0?ooo`070?ooo`80003o303oool00`3o0000oooo0?ooo`0:0?oo
o`80003o3P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo
00l0oooo0P3o000E0?ooo`80003o603oool20?l001T0oooo0`000?l>0?oo
o`00K03ooonD0?3ol003003o003`oo00l?o`01@0l?o`00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0:0?ooo`80
o`00303oool00`000?l0oooo0?ooo`0<0?ooo`80o`003`3oool20000oa40
oooo0P3o000E0?ooo`80003o603oool20?l001X0oooo0P000?l<0?ooo`00
K03ooonD0?3ol003003o003`oo00l?o`01D0l?o`00<0003o0?ooo`3oool0
1@3oool20?l000P0oooo00<0003o0?ooo`3oool01`3oool20?l000T0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0:0?ooo`80003o
3P3oool20?l000l0oooo0P000?lA0?ooo`80o`005@3oool20000oaP0oooo
0`3o000I0?ooo`@0003o203oool006`0ooooU03`oo000`00o`00l?o`0?3o
l00F0?3ol0030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo0P00
0?l<0?ooo`80o`00303oool20000o`h0oooo00<0o`000?ooo`3oool03P3o
ool20000oa40oooo0P3o000E0?ooo`80003o6@3oool20?l002<0oooo001/
0?oooi@0l?o`00<00?l00?3ol03`oo005`3`oo000`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`80o`00403oool2
0000oa40oooo0P3o000E0?ooo`80003o6@3oool20?l00240oooo001/0?oo
oi@0l?o`00<00?l00?3ol03`oo00603`oo000`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo0P000?l90?ooo`80o`002@3oool00`00
0?l0oooo0?ooo`0;0?ooo`80o`00303oool20000o`h0oooo00<0o`000?oo
o`3oool03`3oool20000oa40oooo0P3o000E0?ooo`80003o6@3oool20?l0
01l0oooo001/0?oooi@0l?o`00<00?l00?3ol03`oo006@3`oo000`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`070?ooo`80003o3@3oool00`3o0000
oooo0?ooo`0;0?ooo`80003o3@3oool20?l00140oooo00<0003o0?ooo`3o
ool0403oool20?l001D0oooo0`000?lH0?ooo`80o`007@3oool006`0oooo
U03`oo000`00o`00l?o`0?3ol00J0?3ol0030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo0P3o000@0?ooo`80003o
4P3oool30?l001D0oooo0P000?lH0?ooo`80o`006`3oool006`0ooooU03`
oo000`00o`00l?o`0?3ol00K0?3ol0030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02`3oool20?l000d0oooo0P00
0?l>0?ooo`030?l0003oool0oooo00l0oooo0P000?lC0?ooo`80o`005@3o
ool20000oaP0oooo0P3o000I0?ooo`00K03ooonD0?3ol003003o003`oo00
l?o`01`0l?o`00<0003o0?ooo`3oool01P3oool20?l000P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`80003o3@3oool0
0`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo0P3o000A
0?ooo`80003o4`3oool20?l001D0oooo0P000?lH0?ooo`<0o`005P3oool0
06`0ooooU03`oo000`00o`00l?o`0?3ol00M0?3ol0030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?oo
o`80o`002P3oool00`000?l0oooo0?ooo`0;0?ooo`80o`003@3oool20000
o`h0oooo0P3o000A0?ooo`80003o4`3oool20?l001D0oooo0P000?lI0?oo
o`80o`00503oool006`0ooooU03`oo000`00o`00l?o`0?3ol00N0?3ol003
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0
oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0B0?ooo`80
o`005@3oool20000oaT0oooo0P3o000B0?ooo`00K03ooonD0?3ol003003o
003`oo00l?o`01l0l?o`00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`80003o2P3oool00`3o0000oooo0?ooo`080?ooo`80003o
3@3oool00`3o0000oooo0?ooo`0<0?ooo`80003o3P3oool20?l00140oooo
0P000?lD0?ooo`80o`005@3oool20000oaT0oooo0P3o000@0?ooo`00K03o
oonD0?3ol003003o003`oo00l?o`0200l?o`00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`0;0?ooo`80o`003P3o
ool00`000?l0oooo0?ooo`0=0?ooo`80o`004@3oool20000oa@0oooo0P3o
000E0?ooo`030000o`3oool0oooo01P0oooo0P3o000>0?ooo`00K03ooonD
0?3ol003003o003`oo00l?o`0240l?o`00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool02@3oool20000o`d0oooo00<0o`000?ooo`3oool0303oool2
0000o`l0oooo00<0o`000?ooo`3oool0403oool20000oa@0oooo0P3o000D
0?ooo`80003o6P3oool20?l000`0oooo001/0?oooi@0l?o`00<00?l00?3o
l03`oo008P3`oo000`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool0203oool20?l000/0oooo00<0003o0?oo
o`3oool02`3oool20?l000h0oooo00<0003o0?ooo`3oool03@3oool20?l0
0180oooo0P000?lD0?ooo`030?l0003oool0oooo01<0oooo0P000?lJ0?oo
o`80o`002P3oool006`0ooooU03`oo000`00o`00l?o`0?3ol00S0?3ol003
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo0P000?l=0?ooo`03
0?l0003oool0oooo00`0oooo0P000?l?0?ooo`80o`004P3oool00`000?l0
oooo0?ooo`0B0?ooo`80o`005@3oool30000oaT0oooo0P3o00080?ooo`00
K03ooonD0?3ol003003o003`oo00l?o`02@0l?o`00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02P3oool20000o``0oooo0P3o000>0?ooo`030000
o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0403oool20000oa@0oooo
0P3o000F0?ooo`80003o8@3oool006`0ooooU03`oo000`00o`00l?o`0?3o
l00U0?3ol0030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00h0oooo0P3o000B0?ooo`030000o`3oool0oooo01<0oooo0P3o
000F0?ooo`80003o7`3oool006`0ooooU03`oo000`00o`00l?o`0?3ol00V
0?3ol0030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool2
0000o`X0oooo0P3o000<0?ooo`80003o303oool20?l000d0oooo0P000?l@
0?ooo`80o`004@3oool20000oaD0oooo0P3o000F0?ooo`80003o7@3oool0
06`0ooooU03`oo000`00o`00l?o`0?3ol00W0?3ol0030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool0403oool20000oaD0oooo0P3o000F0?ooo`80003o6`3oool006`0
ooooU03`oo000`00o`00l?o`0?3ol00X0?3ol0030000o`3oool0oooo00L0
oooo0P3o00090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0;0?ooo`80o`003@3oool20000oa00
oooo0P3o000B0?ooo`030000o`3oool0oooo01@0oooo0P3o000F0?ooo`<0
003o603oool006`0ooooU03`oo000`00o`00l?o`0?3ol00Y0?3ol0030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`090?ooo`80o`00303oool20000o`d0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0100oooo
0P000?lF0?ooo`80o`005`3oool20000oaH0oooo001/0?oooi@0l?o`00<0
0?l00?3ol03`oo00:P3`oo000`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00/0oooo0P3o000=0?ooo`80003o403o
ool20?l00180oooo0P000?lF0?ooo`80o`005`3oool20000oa@0oooo001/
0?oooi@0l?o`00<00?l00?3ol03`oo00:`3`oo000`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo00<0o`00
0?ooo`3oool0303oool20000oa00oooo0P3o000B0?ooo`80003o5P3oool0
0`3o0000oooo0?ooo`0F0?ooo`80003o4P3oool006`0ooooU03`oo000`00
o`00l?o`0?3ol00/0?3ol0030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool01`3oool20000o`/0oooo0P3o000<0?ooo`80003o3@3oool00`3o
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00l0oooo00<0o`000?oo
o`3oool04@3oool20000oaD0oooo0P3o000H0?ooo`80003o403oool006`0
ooooU03`oo000`00o`00l?o`0?3ol00]0?3ol0030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool20?l000h0
oooo0P000?l@0?ooo`80o`004`3oool20000oaD0oooo00<0o`000?ooo`3o
ool05`3oool20000o`h0oooo001/0?oooi@0l?o`00<00?l00?3ol03`oo00
;P3`oo000`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool03@3oool20000oa00oooo
00<0o`000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0C0?ooo`80o`00
6@3oool20000o``0oooo001/0?oooi@0l?o`00<00?l00?3ol03`oo00;`3`
oo000`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo0P00
0?l;0?ooo`030?l0003oool0oooo00/0oooo0P000?l=0?ooo`80o`003`3o
ool00`000?l0oooo0?ooo`0>0?ooo`80o`004`3oool20000oaD0oooo0P3o
000I0?ooo`80003o2P3oool006`0ooooU03`oo000`00o`00l?o`0?3ol00`
0?3ol0030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00`0oooo00<0003o
0?ooo`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`80003o403oool2
0?l001<0oooo0P000?lE0?ooo`80o`006@3oool20000o`P0oooo001/0?oo
oi@0l?o`00<00?l00?3ol03`oo00<@3`oo000`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool20?l0
00d0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0>0?oo
o`030000o`3oool0oooo00l0oooo00<0o`000?ooo`3oool04P3oool20000
oaD0oooo0`3o000P0?ooo`00K03ooonD0?3ol003003o003`oo00l?o`0380
l?o`0P000?l90?ooo`030?l0003oool0oooo00T0oooo0P000?l;0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool20?l000l0
oooo0P000?l@0?ooo`80o`00503oool20000oaH0oooo0P3o000N0?ooo`00
K03ooonD0?3ol003003o003`oo00l?o`03<0l?o`00<0oooo0000o`3oool0
203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0
003oool0oooo00h0oooo0P000?l@0?ooo`80o`00503oool20000oaH0oooo
0P3o000L0?ooo`00K03ooonD0?3ol003003o003`oo00l?o`03@0l?o`00<0
oooo0000o`3oool0203oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02`3oool20000o`h0oooo00<0
o`000?ooo`3oool03`3oool00`000?l0oooo0?ooo`0?0?ooo`80o`00503o
ool20000oaH0oooo0P3o000J0?ooo`00K03ooonD0?3ol003003o003`oo00
l?o`03D0l?o`00<0oooo0000o`3oool0203oool20?l000/0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00`0oooo0P3o000@0?ooo`80003o4@3oool00`3o0000oooo0?ooo`0C
0?ooo`030000o`3oool0oooo01D0oooo00<0o`000?ooo`3oool05`3oool0
06`0ooooU03`oo000`00o`00l?o`0?3ol00f0?3ol0030?ooo`000?l0oooo
00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?oo
o`80o`003@3oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo
00l0oooo00<0003o0?ooo`3oool03`3oool20?l001@0oooo0P000?lF0?oo
o`80o`005`3oool006`0ooooU03`oo000`00o`00l?o`0?3ol00g0?3ol003
0?ooo`000?l0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool03@3oool00`3o0000oooo0?ooo`0?0?ooo`80003o4@3oool20?l001@0
oooo00<0003o0?ooo`3oool05@3oool20?l001D0oooo001/0?oooi@0l?o`
00<00?l00?3ol03`oo00>03`oo000`3oool0003o0?ooo`090?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0
403oool20000oa40oooo0P3o000C0?ooo`80003o5`3oool00`3o0000oooo
0?ooo`0B0?ooo`00K03ooonD0?3ol003003o003`oo00l?o`03T0l?o`00<0
oooo0000o`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`80003o2`3o
ool00`3o0000oooo0?ooo`0;0?ooo`80003o3P3oool20?l00180oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0B0?ooo`80003o5P3o
ool20?l00180oooo001/0?oooi@0l?o`00<00?l00?3ol03`oo00>P3`oo00
0`3oool0003o0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02@3oool20?l000d0oooo00<0003o0?ooo`3oool03@3oool0
0`3o0000oooo0?ooo`0@0?ooo`80003o4@3oool20?l001@0oooo00<0003o
0?ooo`3oool05@3oool20?l00100oooo001/0?oooi@0l?o`00<00?l00?3o
l03`oo00>`3`oo000`3oool0003o0?ooo`090?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool04@3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0180oooo0P000?lG0?oo
o`80o`003P3oool006`0ooooU03`oo000`00o`00l?o`0?3ol00l0?3ol003
0?ooo`000?l0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0
oooo0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo0P000?l>0?ooo`80
o`004P3oool00`000?l0oooo0?ooo`0@0?ooo`80o`00503oool20000oaL0
oooo0P3o000<0?ooo`00K03ooonD0?3ol003003o003`oo00l?o`03d0l?o`
00<0oooo0000o`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo
0?ooo`0=0?ooo`030?l0003oool0oooo0100oooo0P000?lB0?ooo`030?l0
003oool0oooo01<0oooo00<0003o0?ooo`3oool05P3oool20?l000X0oooo
001/0?oooi@0l?o`00<00?l00?3ol03`oo00?P3`oo000`3oool0003o0?oo
o`090?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02P3o
ool20?l000d0oooo0P000?l>0?ooo`80o`004P3oool00`000?l0oooo0?oo
o`0@0?ooo`80o`00503oool20000oaP0oooo0P3o00080?ooo`00K03ooonD
0?3ol003003o003`oo00l?o`03l0l?o`00<0oooo0000o`3oool02@3oool0
0`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo00<0o`00
0?ooo`3oool0303oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0
oooo0100oooo0P000?lB0?ooo`80o`00503oool20000ob00oooo001/0?oo
oi@0l?o`00<00?l00?3ol03`oo00@03`oo000`3oool0003o0?ooo`090?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00d0oooo0P3o000B0?oo
o`030000o`3oool0oooo0140oooo0P3o000D0?ooo`80003o7P3oool006`0
ooooU03`oo000`00o`00l?o`0?3ol0110?3ol0030?ooo`000?l0oooo00T0
oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00`0oooo0P000?l?0?ooo`80o`004@3oool20000oa<0
oooo00<0o`000?ooo`3oool04`3oool20000oa`0oooo001/0?oooi@0l?o`
00<00?l00?3ol03`oo00@P3`oo000`3oool0003o0?ooo`090?ooo`030?l0
003oool0oooo00X0oooo0P000?l<0?ooo`80o`003P3oool00`000?l0oooo
0?ooo`0>0?ooo`030?l0003oool0oooo0100oooo00<0003o0?ooo`3oool0
4@3oool20?l001D0oooo0P000?lJ0?ooo`00K03ooonD0?3ol003003o003`
oo00l?o`04<0l?o`00<0oooo0000o`3oool02@3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0303o
ool00`000?l0oooo0?ooo`0>0?ooo`80o`004@3oool20000oa<0oooo00<0
o`000?ooo`3oool0503oool20000oaP0oooo001/0?oooi@0l?o`00<00?l0
0?3ol03`oo00A03`oo000`3oool0003o0?ooo`090?ooo`030?l0003oool0
oooo00/0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`80003o403oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0
oooo0140oooo00<0o`000?ooo`3oool05@3oool20000oaH0oooo001/0?oo
oi@0l?o`00<00?l00?3ol03`oo00A@3`oo000`3oool0003o0?ooo`090?oo
o`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02`3oool20?l0
00h0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0@0?oo
o`80003o4P3oool20?l001L0oooo00<0003o0?ooo`3oool04`3oool006`0
ooooU03`oo000`00o`00l?o`0?3ol0160?3ol0030?ooo`000?l0oooo00T0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00`0oooo0P000?l?0?ooo`80o`004P3oool00`000?l0
oooo0?ooo`0A0?ooo`80o`005P3oool20000oa<0oooo001/0?oooi@0l?o`
00<00?l00?3ol03`oo00A`3`oo000`3oool0003o0?ooo`090?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool0303oool00`3o0000oooo
0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo00<0o`000?ooo`3oool0
403oool20000oa<0oooo00<0o`000?ooo`3oool05@3oool20000oa40oooo
001/0?oooi@0l?o`00<00?l00?3ol03`oo00B03`oo000`3oool0003o0?oo
o`090?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00h0oooo0P3o
000B0?ooo`030000o`3oool0oooo0140oooo0P3o000G0?ooo`030000o`3o
ool0oooo00h0oooo001/0?oooi@0l?o`00<00?l00?3ol03`oo00B@3`oo00
0`3oool0003o0?ooo`090?ooo`80o`00303oool00`000?l0oooo0?ooo`0<
0?ooo`030?l0003oool0oooo00d0oooo0P000?l@0?ooo`030?l0003oool0
oooo0100oooo0P000?lC0?ooo`80o`005P3oool20000o`h0oooo001/0?oo
oi@0l?o`00<00?l00?3ol03`oo00BP3`oo000`3oool0003o0?ooo`0:0?oo
o`030?l0003oool0oooo00X0oooo0P000?l=0?ooo`80o`003`3oool00`00
0?l0oooo0?ooo`0>0?ooo`80o`004P3oool00`000?l0oooo0?ooo`0B0?oo
o`030?l0003oool0oooo01D0oooo00<0003o0?ooo`3oool02`3oool006`0
ooooU03`oo000`00o`00l?o`0?3ol01;0?3ol0030?ooo`000?l0oooo00X0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03`3oool00`3o0000
oooo0?ooo`0@0?ooo`80003o4`3oool20?l001H0oooo0P000?l;0?ooo`00
K03ooonD0?3ol003003o003`oo00l?o`04`0l?o`00<0oooo0000o`3oool0
2P3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0?0?ooo`80o`00
4P3oool20000oa<0oooo0P3o000F0?ooo`<0003o203oool006`0ooooU03`
oo000`00o`00l?o`0?3ol01=0?3ol0030?ooo`000?l0oooo00X0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003o
ool0oooo00d0oooo0P000?lA0?ooo`030?l0003oool0oooo0140oooo00<0
003o0?ooo`3oool04P3oool00`3o0000oooo0?ooo`0N0?ooo`00K03ooonD
0?3ol003003o003`oo00l?o`04h0l?o`00<0oooo0000o`3oool02P3oool0
0`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00`0oooo0P3o000?
0?ooo`030000o`3oool0oooo00l0oooo0P3o000B0?ooo`030000o`3oool0
oooo0180oooo0P3o000N0?ooo`00K03ooonD0?3ol003003o003`oo00l?o`
04l0l?o`00<0oooo0000o`3oool02P3oool00`3o0000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool03@3oool00`00
0?l0oooo0?ooo`0@0?ooo`030?l0003oool0oooo0100oooo0P000?lD0?oo
o`80o`00703oool006`0ooooU03`oo000`00o`00l?o`0?3ol01@0?3ol003
0?ooo`000?l0oooo00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0
oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo0P000?lA0?ooo`03
0?l0003oool0oooo0140oooo00<0003o0?ooo`3oool04`3oool00`3o0000
oooo0?ooo`0I0?ooo`00K03ooonD0?3ol003003o003`oo00l?o`0540l?o`
00<0oooo0000o`3oool02P3oool20?l000`0oooo0P000?l>0?ooo`80o`00
3`3oool00`000?l0oooo0?ooo`0?0?ooo`80o`004P3oool00`000?l0oooo
0?ooo`0C0?ooo`80o`006@3oool006`0ooooU03`oo000`00o`00l?o`0?3o
l01B0?3ol0030?ooo`000?l0oooo00/0oooo00<0o`000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00d0oooo00<0
003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0@0?ooo`80003o5@3o
ool20?l001L0oooo001/0?oooi@0l?o`00<00?l00?3ol03`oo00D`3`oo00
0`3oool0003o0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`80003o4@3oool0
0`3o0000oooo0?ooo`0A0?ooo`80003o5@3oool00`3o0000oooo0?ooo`0D
0?ooo`00K03ooonD0?3ol003003o003`oo00l?o`05@0l?o`00<0oooo0000
o`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo0180oooo00<0003o0?ooo`3oool04`3oool20?l0
01@0oooo001/0?oooi@0l?o`00<00?l00?3ol03`oo00E@3`oo000`3oool0
003o0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3o
ool03@3oool20?l000l0oooo00<0003o0?ooo`3oool03`3oool20?l001<0
oooo0P000?lE0?ooo`030?l0003oool0oooo0140oooo001/0?oooi@0l?o`
00<00?l00?3ol03`oo00EP3`oo000`3oool0003o0?ooo`0;0?ooo`030?l0
003oool0oooo00/0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo
0?ooo`0=0?ooo`80003o4@3oool00`3o0000oooo0?ooo`0B0?ooo`80003o
503oool20?l00140oooo001/0?oooi@0l?o`00<00?l00?3ol03`oo00E`3`
oo000`3oool0003o0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0
003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0>0?ooo`030000o`3o
ool0oooo00l0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`0C0?ooo`80o`003`3oool006`0ooooU03`oo000`00o`00l?o`0?3ol01H
0?3ol0030?ooo`000?l0oooo00/0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00h0oooo00<0003o
0?ooo`3oool03`3oool20?l001@0oooo00<0003o0?ooo`3oool0503oool2
0?l000d0oooo001/0?oooi@0l?o`00<00?l00?3ol03`oo00F@3`oo000`3o
ool0003o0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool03P3oool00`3o0000oooo0?ooo`0>0?ooo`80003o4@3oool20?l0
01<0oooo0P000?lF0?ooo`80o`002`3oool006`0ooooU03`oo000`00o`00
l?o`0?3ol01J0?3ol0030?ooo`000?l0oooo00/0oooo00<0o`000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0>0?ooo`80o`00403oool00`000?l0
oooo0?ooo`0@0?ooo`030?l0003oool0oooo0180oooo00<0003o0?ooo`3o
ool05@3oool20?l000T0oooo001/0?oooi@0l?o`00<00?l00?3ol03`oo00
F`3`oo000`3oool0003o0?ooo`0;0?ooo`030?l0003oool0oooo00/0oooo
0P000?l@0?ooo`030?l0003oool0oooo00h0oooo0P000?lA0?ooo`030?l0
003oool0oooo0180oooo00<0003o0?ooo`3oool05P3oool00`3o0000oooo
0?ooo`060?ooo`00K03ooonD0?3ol003003o003`oo00l?o`05`0l?o`00<0
oooo0000o`3oool02`3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3o
ool0oooo00h0oooo00<0o`000?ooo`3oool03`3oool00`000?l0oooo0?oo
o`0?0?ooo`80o`004`3oool20000oal0oooo001/0?oooi@0l?o`00<00?l0
0?3ol03`oo00G@3`oo000`3oool0003o0?ooo`0;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0?
0?ooo`030000o`3oool0oooo0100oooo00<0o`000?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`0L0?ooo`00K03ooonD0?3ol003003o003`oo00l?o`
05h0l?o`00<0oooo0000o`3oool02`3oool20?l000d0oooo0P000?l?0?oo
o`030?l0003oool0oooo00l0oooo0P000?lA0?ooo`030?l0003oool0oooo
0180oooo0P000?lL0?ooo`00K03ooonD0?3ol003003o003`oo00l?o`05l0
l?o`00<0oooo0000o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00d0oooo00<0o`000?ooo`3oool0403oool00`000?l0
oooo0?ooo`0?0?ooo`80o`00503oool20000oaX0oooo001/0?oooi@0l?o`
00<00?l00?3ol03`oo00H03`oo000`3oool0003o0?ooo`0<0?ooo`030?l0
003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0@0?ooo`030000o`3oool0oooo0100oooo0P3o000D0?ooo`030000
o`3oool0oooo01L0oooo001/0?oooi@0l?o`00<00?l00?3ol03`oo00H@3`
oo000`3oool0003o0?ooo`0<0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0140oooo00<0o`000?ooo`3oool04P3oool20000oaL0oooo001/
0?oooi@0l?o`00<00?l00?3ol03`oo00HP3`oo000`3oool0003o0?ooo`0<
0?ooo`030?l0003oool0oooo00`0oooo0P000?l>0?ooo`80o`004@3oool2
0000oa80oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0D
0?ooo`00K03ooonD0?3ol003003o003`oo00l?o`06<0l?o`00<0oooo0000
o`3oool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00d0oooo00<0o`000?ooo`3oool0403oool00`000?l0oooo0?ooo`0@0?oo
o`80o`00503oool20000oa@0oooo001/0?oooi@0l?o`00<00?l00?3ol03`
oo00I03`oo000`3oool0003o0?ooo`0<0?ooo`030?l0003oool0oooo00d0
oooo00<0003o0?ooo`3oool03@3oool20?l00140oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0C0?ooo`80003o4P3oool006`0oooo
U03`oo000`00o`00l?o`0?3ol01U0?3ol0030?ooo`000?l0oooo00`0oooo
00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`0>0?ooo`030?l0
003oool0oooo00l0oooo0P000?lB0?ooo`80o`005@3oool20000oa00oooo
001/0?oooi@0l?o`00<00?l00?3ol03`oo00IP3`oo000`3oool0003o0?oo
o`0<0?ooo`030?l0003oool0oooo00d0oooo00<0003o0?ooo`3oool03P3o
ool20?l00140oooo00<0003o0?ooo`3oool04@3oool20?l001D0oooo00<0
003o0?ooo`3oool03@3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{487, 228},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.106",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/sourcesink/SourceSinkFigures/\
mat11106.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Flow from a channel into a sector in the first quadrant. "
}], "Text"],

Cell[TextData[{
  "Solution.  Using the Schwarz-Christoffel transformation method, the \
exterior angles are  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "1"], "=", \(-\(\[Pi]\/4\)\)}], 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], 
        RowBox[{
          SubscriptBox[
            StyleBox["\[Alpha]",
              FontSize->14], "2"], "=", "\[Pi]"}]}]]],
  ",  and the formula for the derivative ",
  Cell[BoxData[
      \(S' \((z)\)\)]],
  " is  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(S' \((z)\)\ \  = \ \ A \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A \(\((z - \
\((\(-1\))\))\)\^\(\(-\((\(-\(\[Pi]\/4\)\))\)\)/\[Pi]\)\) \((z - \
0)\)\^\(\(-\((\[Pi])\)\)/\[Pi]\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ \(\((z + 
                  1)\)\^\(1\/4\)\) \((z)\)\^\(-1\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \((z + \
1)\)\^\(1\/4\)\/z\)\)\)}]],
  "   \nintegrate \n\n\t\t\t",
  Cell[BoxData[
      \(S \((z)\)\ \  = \ 
        B\  + \ A\ \(\[Integral]\(\((z + 1)\)\^\(1\/4\)\/z\) \
\[DifferentialD]z\)\)],
    AspectRatioFixed->True],
  "\n\t\t\t\nuse the substitutions \n\n\t\t\t",
  Cell[BoxData[{
      \(z + 1\ \  = \ \ s\^4\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ z\ \  = \ \ s\^4 - 1\), "\[IndentingNewLine]", 
      \(\ \ \ \[DifferentialD]z\ \  = \ \ 4\ \(s\^3\) \[DifferentialD]s\)}]],
  "  \nand get\n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(\[Integral]\(\((z + 1)\)\^\(1\/4\)\/z\) \[DifferentialD]z\ \  = \ \
\ \[Integral]\(\((s\^4)\)\^\(1/4\)\/\(s\^4 - 1\)\) 
            4\ \(s\^3\) \[DifferentialD]s\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \
\ \ \)\(\[Integral]\(\(4\ s\^4\)\/\(s\^4 - 
                  1\)\) \[DifferentialD]s\)\)\(\ \)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \
\)\(4\ s\  - \ 2\ Arctan\ s\  + \ Log \((s - 1)\)\  - \ 
          Log \((s + 1)\)\)\)\)}],
    AspectRatioFixed->True],
  "  \n\nUse the identity  ",
  Cell[BoxData[
      \(\(-\ 2\) 
          ArcTan\ s\  = \ \(\(-2\) \(\[ImaginaryI]\/2\) 
            Log \((\(\[ImaginaryI] + s\)\/\(\[ImaginaryI] - s\))\)\  = \ \
\[ImaginaryI]\ Log \((\(\[ImaginaryI] - s\)\/\(\[ImaginaryI] + s\))\)\)\)]],
  "  and write the integral as\n\n\t\t\t",
  Cell[BoxData[
      \(\[Integral]\(\((z + 1)\)\^\(1\/4\)\/z\) \[DifferentialD]z\ \  = \ \ 4\
\ s\ \  + \ \ Log \((\(s - 1\)\/\(s + 1\))\)\ \  + \ \ \[ImaginaryI]\ Log \((\
\(\[ImaginaryI] - s\)\/\(\[ImaginaryI] + s\))\)\)],
    AspectRatioFixed->True],
  " \n\nNow use the substitution ",
  Cell[BoxData[
      \(s \[Rule] \ \((z + 1)\)\^\(1\/4\)\)]],
  " and get \n\n\t\t\t",
  Cell[BoxData[{
      \(S \((z)\)\ \  = \ \ B\  + \ \(\(A\) \(\[Integral]\(\((z + \
1)\)\^\(1\/4\)\/z\) \[DifferentialD]z\)\(\ \ \)\)\), "\[IndentingNewLine]", 
      \(\(\(=\)\(\ \ \)\(B\  + \ 
          A \((4 \((z + 1)\)\^\(1/4\)\  + \ 
                Log \(\((z + 1)\)\^\(1/4\) - 1\)\/\(\((z + 1)\)\^\(1/4\) + \
1\)\  + \ \[ImaginaryI]\ Log \( \[ImaginaryI] - \((z + 1)\)\^\(1/4\)\)\/\(\
\[ImaginaryI] + \((z + 1)\)\^\(1/4\)\))\)\)\)\)}],
    AspectRatioFixed->True],
  "\n\t\t\t\nuse the conditions  ",
  Cell[BoxData[
      \(S \((0)\)\  = \ 0\)]],
  ",  ",
  Cell[BoxData[
      \(S \((1)\) = \[ImaginaryI]\ \[Pi]\)]],
  "  and solve the resulting system for ",
  StyleBox["A",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["B",
    FontFamily->"Courier New"],
  ".  The desired result is\n\n\t\t\t",
  Cell[BoxData[
      \(S \((z)\)\ \  = \ \ 4 \((1 + z)\)\^\(1/4\) + 
          Log \(\((z + 1)\)\^\(1/4\) - 1\)\/\(\((z + 1)\)\^\(1/4\) + 1\) + \
\[ImaginaryI]\ Log \( \[ImaginaryI] - \((z + 1)\)\^\(1/4\)\)\/\(\[ImaginaryI] \
+ \((z + 1)\)\^\(1/4\)\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[f, z];\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        4 \((z + 1)\)\^\(1/4\)\  + \ 
          Log[\(\((z + 1)\)\^\(1/4\) - 1\)\/\(\((z + 1)\)\^\(1/4\) + 1\)]\  + \
\ \[ImaginaryI]\ Log[\(\[ImaginaryI] - \((z + \
1)\)\^\(1/4\)\)\/\(\[ImaginaryI] + \((z + 1)\)\^\(1/4\)\)];\)\ \), "\n", 
    \(\(Print["\< S[z] = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[-1] = \>", S[\(-1\)]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< S[0] = \>", S[0]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph conformal mapping  w = S(z)."
}], "Text"],

Cell[BoxData[
    \(\(\(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \[IndentingNewLine]
    \(Needs["\<Graphics`Colors`\>"];\)\ \[IndentingNewLine]
    \(boundary = 
        Graphics[{Blue, Line[{{\(-4\), 0}, {6, 0}}]}];\)\[IndentingNewLine]
    \(gr1 = 
        PolarMap[
          S, {0.000001, 16.000001, 1}, {0.00001, 3.14149, 3.14139\/24}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \[IndentingNewLine]
    \(Show[gr1, boundary, PlotRange \[Rule] {{\(-4\), 6}, {0, 6}}, 
        AspectRatio \[Rule] 6\/10, 
        Ticks \[Rule] {Range[\(-4\), 6, 2], Range[4, 6, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \[IndentingNewLine]
    \(Print["\<The image of the flow in the upper half plane Im[z] > \
0,\>"];\)\ \n
    \(Print[\*"\"\<where a source is located at \!\(z\_0\) = 0, under \
the\>\""];\)\ \[IndentingNewLine]
    \(Print["\<conformal mapping w = S[z] = \>", 
        S[z]];\)\)\(\ \)\)\)], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ \ Table[{Re[
              S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            0, 23, 2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {r, 0.01, 55}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            1, 23, 2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {r, 0.01, 55}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Blue, 
            Line[{{\(-4\), \[Pi]}, {0, \[Pi]}, {\[Pi], 2  \[Pi]}}], 
            Line[{{\(-4\), 0}, {5, 0}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, boundary, 
        PlotRange \[Rule] {{\(-4\), 6}, {0, 6}}, AspectRatio \[Rule] 6\/10, 
        Ticks \[Rule] {Range[\(-4\), 6, 2], Range[4, 6, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow in the upper half plane Im[z] > \
0,\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<where a source is located at \!\(z\_0\) = 0, under the\>\
\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<conformal mapping w = S[z] = \>", 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "We are done.\n\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  "  We can extend the flow into the fourth quadrant using symmetry."
}], "Text"],

Cell[BoxData[
    \(\(\(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \[IndentingNewLine]
    \(Needs["\<Graphics`Colors`\>"];\)\ \[IndentingNewLine]
    \(boundary = 
        Graphics[{Blue, Line[{{\(-4\), 0}, {6, 0}}]}];\)\[IndentingNewLine]
    \(gr1 = 
        PolarMap[
          S, {0.000001, 16.000001, 1}, {0.00001, 3.14149, 3.14139\/24}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \[IndentingNewLine]
    \(g[z_] = Conjugate[S[z]];\)\[IndentingNewLine]
    \(gr2 = 
        PolarMap[
          g, {0.000001, 16.000001, 1}, {0.00001, 3.14149, 3.14139\/24}, 
          PlotStyle \[Rule] {Blue, Red}, 
          DisplayFunction \[Rule] Identity];\)\ \ \[IndentingNewLine]
    \(Show[gr1, gr2, boundary, PlotRange \[Rule] {{\(-4\), 6}, {\(-6\), 6}}, 
        AspectRatio \[Rule] 12\/10, 
        Ticks \[Rule] {Range[6, 6, 2], {\(-6\), \(-5\), \(-4\), 4, 5, 6}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)\(\ \ \)\)\)], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ \ Table[{Re[
              S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            0, 23, 2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {r, 0.01, 55}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            1, 23, 2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {r, 0.01, 55}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns3\  = \ \ Table[{Re[
              g[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[g[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            0, 23, 2}];\)\ \), "\n", 
    \(\(graph3 = 
        ParametricPlot[Evaluate[eqns3], {r, 0.01, 55}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns4\  = \ 
        Table[{Re[g[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[g[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            1, 23, 2}];\)\ \), "\n", 
    \(\(graph4 = 
        ParametricPlot[Evaluate[eqns4], {r, 0.01, 55}, PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Blue, 
            Line[{{\(-4\), \[Pi]}, {0, \[Pi]}, {\[Pi], 2  \[Pi]}}], 
            Line[{{\(-4\), \(-\[Pi]\)}, {0, \(-\[Pi]\)}, {\[Pi], \(-2\) \
\[Pi]}}], Line[{{\(-4\), 0}, {5, 0}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, graph3, graph4, boundary, 
        PlotRange \[Rule] {{\(-4\), 6}, {\(-6\), 6}}, 
        AspectRatio \[Rule] 12\/10, 
        Ticks \[Rule] {None, {\(-6\), \(-5\), \(-4\), 4, 5, 6}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow in the z-plane,\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<where a source is located at \!\(z\_0\) = 0, under the\>\
\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<conformal mapping w = S[z] = \>", 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 3.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use a Schwarz-Christoffel transformation to show that the conformal \
mapping  \n\n\t\t\t",
  Cell[BoxData[
      \(w\ \  = \ \ \(S \((z)\)\ \  = \ \ \(1\/\[Pi]\) 
              Arcsin\ z\  + \ \(\[ImaginaryI]\/\[Pi]\) Arcsin 
               1\/z\  + \ \(1\  + \ \[ImaginaryI]\)\/2\)\)]],
  "  \n\nwill map the flow in the upper half-plane from a source at  ",
  Cell[BoxData[
      \(z\_0 = 0\)]],
  "  onto the flow in a right-angled channel with  ",
  Cell[BoxData[
      \(w\_0 = \(S \((z\_0)\)\  = \ \(-\[Infinity]\)\)\)]],
  ", as shown in Figure 11.107."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005B0000i2000`400?l0
0000o`00003oo`3ooomC0?ooo`00o`3ooomC0?ooo`00o`3ooomC0?ooo`00
o`3ooomC0?ooo`00o`3ooomC0?ooo`00K03ooooO0000o`L0oooo001/0?oo
o`030000o`3oool0oooo0><0oooo001/0?ooo`030000o`3oool0oooo0><0
oooo001/0?ooo`030000o`3oool0oooo0><0oooo001/0?ooo`030000o`3o
ool0oooo0><0oooo001/0?ooo`030000o`3oool0oooo09d0oooo?`3o0007
0?ooo`00K03oool00`000?l0oooo0?ooo`1h0?ooobD0o`00AP3oool006`0
oooo00<0003o0?ooo`3oool0F`3ooolM0?l006/0oooo001/0?ooo`030000
o`3oool0oooo05<0oooo203o00280?ooo`00K03oool00`000?l0oooo0?oo
o`130?oooa00o`00T03oool006`0oooo00<0003o0?ooo`3oool0?P3oool5
0?l005H0oooo@`000?l70?ooo`00K03oool00`000?l0oooo0?ooo`0j0?oo
o`@0o`00A`3ooolD0000odX0oooo001/0?ooo`030000o`3oool0oooo03D0
oooo1@3o000l0?ooo`l0003oGP3oool006`0oooo00<0003o0?ooo`3oool0
<@3oool40?l003H0oooo2`000?m]0?ooo`00K03oool00`000?l0oooo0?oo
o`0]0?ooo`@0o`00:`3oool?0000ogP0oooo001/0?ooo`030000o`3oool0
oooo02T0oooo103o000Z0?ooo`D0003o@@3ooolo0?l000L0oooo001/0?oo
o`030000o`3oool0oooo02L0oooo0P3o000X0?ooo`H0003o<@3ooolE0?l0
04H0oooo001/0?ooo`030000o`3oool0oooo02@0oooo0`3o000T0?ooo`H0
003o:`3oool<0?l005/0oooo001/0?ooo`030000o`3oool0oooo0280oooo
0P3o000R0?ooo`D0003o:`3oool60?l006L0oooo001/0?ooo`030000o`3o
ool0oooo0200oooo0P3o000P0?ooo`@0003o:03oool80?l006d0oooo001/
0?ooo`030000o`3oool0oooo01h0oooo0P3o000O0?ooo`<0003o8`3oool9
0?l00340oooo?@000?l70?ooo`00K03oool00`000?l0oooo0?ooo`0L0?oo
o`80o`007@3oool40000oal0oooo1`3o000_0?ooo`/0003oA03oool006`0
oooo00<0003o0?ooo`3oool06`3oool00`3o0000oooo0?ooo`0J0?ooo`<0
003o7P3oool50?l002P0oooo3P000?m?0?ooo`00K03oool00`000?l0oooo
0?ooo`0J0?ooo`030?l0003oool0oooo01T0oooo0P000?lL0?ooo`D0o`00
8P3oool;0000oed0oooo001/0?ooo`030000o`3oool0oooo01T0oooo00<0
o`000?ooo`3oool05`3oool30000oaX0oooo103o000Q0?ooo`H0003oJ03o
ool006`0oooo00<0003o0?ooo`3oool05`3oool20?l001P0oooo0P000?lI
0?ooo`@0o`007@3oool80000obl0oooo>03o00070?ooo`00K03oool00`00
0?l0oooo0?ooo`0F0?ooo`030?l0003oool0oooo01H0oooo0P000?lH0?oo
o`<0o`006`3oool60000ob/0oooo303o000o0?ooo`00K03oool00`000?l0
oooo0?ooo`0E0?ooo`030?l0003oool0oooo01D0oooo0P000?lG0?ooo`<0
o`006P3oool40000ob80oooo3`3o001;0?ooo`00K03oool00`000?l0oooo
0?ooo`0D0?ooo`030?l0003oool0oooo01@0oooo0P000?lF0?ooo`<0o`00
6@3oool40000oaX0oooo303o001J0?ooo`00K03oool00`000?l0oooo0?oo
o`0C0?ooo`030?l0003oool0oooo01@0oooo00<0003o0?ooo`3oool0503o
ool20?l001P0oooo10000?lH0?ooo`H0o`00A03ooolK0000o`L0oooo001/
0?ooo`030000o`3oool0oooo01<0oooo00<0o`000?ooo`3oool04`3oool0
0`000?l0oooo0?ooo`0C0?ooo`80o`005`3oool30000oaH0oooo1P3o000Y
0?ooob40003o8P3oool006`0oooo00<0003o0?ooo`3oool04P3oool00`3o
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0180oooo0P3o000E0?oo
o`@0003o5@3oool40?l002@0oooo2`000?m30?ooo`00K03oool00`000?l0
oooo0?ooo`0A0?ooo`030?l0003oool0oooo0180oooo0P000?lC0?ooo`80
o`00503oool30000oaD0oooo103o000N0?ooo`X0003oCP3oool006`0oooo
00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0B0?ooo`030000
o`3oool0oooo0140oooo0P3o000B0?ooo`@0003o503oool40?l001X0oooo
20000?mH0?ooo`00K03oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo0140oooo00<0003o0?ooo`3oool0403oool20?l00140oooo0`00
0?lE0?ooo`<0o`005`3oool70000od00oooo6@3o00070?ooo`00K03oool0
0`000?l0oooo0?ooo`0?0?ooo`030?l0003oool0oooo0140oooo00<0003o
0?ooo`3oool03`3oool20?l00140oooo0P000?lD0?ooo`@0o`00503oool6
0000obT0oooo7P3o000P0?ooo`00K03oool00`000?l0oooo0?ooo`0?0?oo
o`030?l0003oool0oooo00l0oooo0P000?lA0?ooo`030?l0003oool0oooo
00l0oooo0P000?lC0?ooo`<0o`00503oool40000ob<0oooo303o000n0?oo
o`00K03oool00`000?l0oooo0?ooo`0>0?ooo`030?l0003oool0oooo00l0
oooo00<0003o0?ooo`3oool0403oool00`3o0000oooo0?ooo`0>0?ooo`80
003o4@3oool40?l001<0oooo10000?lL0?ooo`/0o`00BP3oool006`0oooo
00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00l0oooo0P3o000?0?ooo`80003o403oool30?l001<0oooo
10000?lH0?ooo`P0o`00@03oool>0000o`L0oooo001/0?ooo`030000o`3o
ool0oooo00d0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`0?0?ooo`030?l0003oool0oooo00d0oooo0P000?l@0?ooo`80o`004P3o
ool40000oaD0oooo1`3o000]0?oooa/0003o5@3oool006`0oooo00<0003o
0?ooo`3oool03@3oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0
oooo00h0oooo0P3o000>0?ooo`80003o403oool20?l00100oooo10000?lC
0?ooo`H0o`008@3ooolC0000oc00oooo001/0?ooo`030000o`3oool0oooo
00`0oooo00<0o`000?ooo`3oool03P3oool00`000?l0oooo0?ooo`0=0?oo
o`030?l0003oool0oooo00`0oooo0P000?l@0?ooo`80o`003P3oool40000
oa80oooo1@3o000M0?ooo`X0003o@`3oool006`0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00d0
oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0>0?ooo`80
o`003@3oool30000oa80oooo103o000I0?ooo`T0003oC@3oool006`0oooo
00<0003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000
o`3oool0oooo00`0oooo0P3o000>0?ooo`030000o`3oool0oooo00d0oooo
0P3o000=0?ooo`80003o4@3oool40?l001D0oooo20000?mF0?ooo`00K03o
ool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00`0oooo00<0
003o0?ooo`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`80003o3P3o
ool20?l000d0oooo0P000?l?0?ooo`@0o`004`3oool60000ob00oooo=`3o
00070?ooo`00K03oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00`0oooo0P3o000=0?ooo`80003o3P3oool3
0?l001<0oooo10000?lJ0?ooo``0o`00?P3oool006`0oooo00<0003o0?oo
o`3oool02`3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00/0oooo00<0o`000?ooo`3oool0303oool00`000?l0oooo0?ooo`0<0?oo
o`030?l0003oool0oooo00/0oooo0P000?l>0?ooo`80o`004P3oool40000
oaH0oooo203o001:0?ooo`00K03oool00`000?l0oooo0?ooo`0;0?ooo`03
0?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`0;0?ooo`80003o3@3oool20?l000`0oooo0P000?l>0?ooo`80
o`004@3oool30000oaD0oooo1@3o001B0?ooo`00K03oool00`000?l0oooo
0?ooo`0:0?ooo`030?l0003oool0oooo00/0oooo00<0003o0?ooo`3oool0
2`3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo
0P3o000<0?ooo`80003o3@3oool30?l000l0oooo10000?lB0?ooo`H0o`00
=@3ooolK0000o`L0oooo001/0?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?oo
o`0:0?ooo`80003o3@3oool20?l000l0oooo0`000?lA0?ooo`D0o`007@3o
oolN0000ob80oooo001/0?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`09
0?ooo`80003o3@3oool20?l000d0oooo10000?l>0?ooo`H0o`006`3oool7
0000od00oooo001/0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool02P3oool20?l000/0oooo00<0003o0?oo
o`3oool02`3oool20?l000`0oooo0`000?l>0?ooo`@0o`006P3oool70000
odL0oooo001/0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`80
003o303oool20?l000`0oooo0P000?l>0?ooo`<0o`005`3oool70000odh0
oooo001/0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00X0oooo0P3o000<0?ooo`80003o3P3oool20?l00180oooo
20000?lf0?oooaP0o`001`3oool006`0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`80o`002P3o
ool20000o`/0oooo0P3o000<0?ooo`80003o3@3oool30?l000h0oooo1P00
0?lP0?oooah0o`007`3oool006`0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:
0?ooo`80003o303oool30?l000`0oooo1@000?lJ0?ooo``0o`00?@3oool0
06`0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool02@3oool20?l000/0oooo0P000?l;0?ooo`<0o`002`3oool40000
oaH0oooo2@3o00190?ooo`00K03oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`080?ooo`80o`002`3oool20000o`X0
oooo0`3o000<0?ooo`80003o4P3oool80?l003h0oooo3@000?l70?ooo`00
K03oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool20000o`T0oooo
0P3o000;0?ooo`80003o2P3oool20?l000`0oooo0`000?l>0?ooo`H0o`00
;03ooolJ0000oa@0oooo001/0?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00L0oooo0P3o000;0?ooo`80003o2@3o
ool30?l000/0oooo0`000?l>0?ooo`<0o`007`3ooolC0000obh0oooo001/
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool02@3oool20000o`T0oooo0P3o000<
0?ooo`80003o3@3oool40?l001P0oooo2P000?m10?ooo`00K03oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00P0oooo0P000?l90?ooo`80o`002`3oool30000
o``0oooo0`3o000C0?ooo`T0003oB`3oool006`0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`80003o2@3oool20?l000/0oooo0P000?l<0?ooo`<0
o`003`3oool70000ocD0oooo603o00070?ooo`00K03oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`80o`00
2@3oool00`000?l0oooo0?ooo`070?ooo`80o`002P3oool30000o`X0oooo
103o000=0?ooo`D0003o7P3ooolN0?l001l0oooo001/0?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`060?ooo`80003o203oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00H0oooo0P3o000:0?ooo`80003o2P3o
ool30?l000h0oooo0`000?lH0?ooo`/0o`00?@3oool006`0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`80003o203oool00`3o0000oooo0?ooo`08
0?ooo`80003o2@3oool30?l000d0oooo10000?lC0?ooo`P0o`00B03oool0
06`0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00H0oooo0P3o00090?ooo`80003o2@3oool20?l000d0oooo0`000?lB0?oo
o`D0o`00?03oool=0000o`L0oooo001/0?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool01`3oool20?l000`0oooo0`000?l@0?ooo`D0
o`009`3ooolJ0000oa@0oooo001/0?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
0P000?l80?ooo`80o`002`3oool30000o`h0oooo1@3o000J0?oooa80003o
;P3oool006`0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo0P3o00080?ooo`80003o203oool20?l000X0oooo0`00
0?l=0?ooo`@0o`005@3oool:0000od00oooo001/0?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01P3oool20?l000T0oooo0`000?l<
0?ooo`@0o`00403oool90000odX0oooo001/0?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01@3oool20000o`L0oooo00<0o`000?ooo`3oool01P3oool20000
o`P0oooo00<0o`000?ooo`3oool01`3oool20000o``0oooo0`3o000>0?oo
o`H0003o=03ooolH0?l000L0oooo001/0?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool20?l000P0oooo0P000?l;0?ooo`<0
o`002`3oool60000oad0oooo7@3o000O0?ooo`00K03oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo0P3o00080?ooo`80003o
2P3oool30?l000X0oooo10000?lH0?ooo`/0o`00?03oool006`0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01@3oool20000o`L0oooo00<0o`000?ooo`3oool01P3o
ool20000o`T0oooo0`3o00090?ooo`@0003o4`3oool90?l004L0oooo001/
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`050?ooo`80003o2@3oool20?l000T0oooo0`000?l@
0?ooo`L0o`00?03oool=0000o`L0oooo001/0?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`040?oo
o`80003o2@3oool20?l000T0oooo0P000?l=0?ooo`H0o`00:@3ooolJ0000
oa@0oooo001/0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool20?l000D0oooo0P000?l90?ooo`80o`00203oool30000o`/0
oooo103o000N0?oooa40003o;P3oool006`0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01`3oool20?l000L0oooo0`000?l:0?ooo`@0o`00
603oool:0000ocl0oooo001/0?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00H0oooo0P3o00070?ooo`80003o2P3oool30?l001@0oooo2000
0?m90?ooo`00K03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`80o`001`3oool20000o`X0oooo0P3o000@0?ooo`L0003o<`3ooolG
0?l000L0oooo001/0?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`80003o1P3oool20?l0
00L0oooo0P000?l90?ooo`<0o`002`3oool70000oad0oooo7@3o000N0?oo
o`00K03oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo0P000?l80?ooo`<0o`00203oool60000oaT0
oooo2`3o000k0?ooo`00K03oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo0P3o00050?ooo`030000o`3oool0oooo00@0oooo
0P3o00060?ooo`80003o203oool20?l000P0oooo0`000?lC0?ooo``0o`00
AP3oool006`0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`80003o1`3oool30?l000P0oooo0P00
0?l=0?ooo`T0o`00?P3oool=0000o`L0oooo001/0?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo0P3o00050?ooo`80003o1`3oool2
0?l000P0oooo0`000?l;0?ooo`@0o`00;P3ooolI0000oa@0oooo001/0?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`030?ooo`80003o1@3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00D0oooo0P3o00070?ooo`<0003o2P3oool40?l0
01`0oooo5P000?l]0?ooo`00K03oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo0P000?l60?ooo`80
o`001`3oool20000o`T0oooo103o000C0?ooo`d0003o@`3oool006`0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00@0oooo0P3o00070?ooo`80003o
1`3oool40?l00140oooo1P000?m@0?ooo`00K03oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`80o`001@3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00D0oooo0P000?l60?ooo`<0o`003P3o
ool70000ocP0oooo5`3o00070?ooo`00K03oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool20?l000H0oooo0P000?l50?ooo`<0o`002`3oool6
0000oad0oooo8P3o000N0?ooo`00K03oool00`000?l0oooo0?ooo`040?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00P3oool20?l000H0oooo0P000?l50?ooo`80o`002`3oool30000
oa80oooo4@3o00100?ooo`00K03oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo0P000?l40?ooo`03
0?l0003oool0oooo00@0oooo0P000?l60?ooo`030?l0003oool0oooo00L0
oooo10000?l<0?ooo`T0o`00D@3oool006`0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`80o`001`3oool30000o``0oooo103o001J0?ooo`00K03o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`80003o1@3oool20?l000D0oooo10000?l:0?ooo`D0o`006`3o
ooll0000o`L0oooo001/0?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool2
0?l000D0oooo0P000?l90?ooo`D0o`004@3oool?0000od<0oooo001/0?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool20?l000D0oooo0P000?l70?oo
o`@0o`00303oool:0000oe80oooo001/0?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00@0003o0?ooo`3o
ool0oooo0P3o00050?ooo`80003o1@3oool40?l000T0oooo1`000?mL0?oo
o`00K03oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`80003o0`3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo0P3o00080?ooo`D0003oA@3ooolG0?l000L0
oooo001/0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`030?ooo`80003o103oool20?l000L0oooo0`000?lH0?oooc80o`00
7P3oool006`0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
0P000?l40?ooo`80o`001@3oool40000oa00oooo2`3o001@0?ooo`00K03o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?oo
o`3oool0003o00@0oooo00@0o`000?ooo`3oool0oooo0P000?l40?ooo`80
o`001@3oool20000o`d0oooo1`3o001K0?ooo`00K03oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00D0
oooo00@0o`000?ooo`3oool0003o103oool20?l000D0oooo0P000?l70?oo
o`P0o`00HP3oool006`0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`04
0?l0003oool0oooo0000o`<0oooo0P3o00040?ooo`<0003o1@3oool40?l0
01P0ooooB`000?l70?ooo`00K03oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo0000o`020?ooo`040?l0003oool0oooo0?ooo`<0003o103o
ool40?l00180oooo2P000?mB0?ooo`00K03oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00D0
o`000?ooo`3oool0oooo0000o`020?ooo`050?l0003oool0oooo0?ooo`00
0?l01@3oool20?l000H0oooo40000?mL0?ooo`00K03oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`050?l0003oool0oooo
0?ooo`000?l00`3oool30?l000@0oooo10000?m/0?ooo`00K03oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0
oooo0?ooo`3o00000`3oool010000?l0oooo0?ooo`3o00030?ooo`030000
o`3oool0oooo0080o`000`3oool40000ob00ooooB@3o00070?ooo`00K03o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?oo
o`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?l000030?ooo`040000o`3oool0oooo0?l00080oooo0`000?l90?oooa/0
o`00D03oool006`0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0
oooo0?l000050?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@00
0?l0oooo0?ooo`3oool0o`0000<0oooo00@0003o0?ooo`3oool0o`000P3o
ool01@000?l0oooo0?ooo`3o0000oooo0080003o103oool80?l006/0oooo
001/0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`00
0?l00`3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00@0o`000?oo
o`3oool0003o0`3oool0103o0000oooo0000o`3oool40?l007<0oooo001/
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00001@3o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0
oooo0?l000030?ooo`030000o`3oool0o`000080oooo00T0003o0?ooo`3o
ool0oooo0?l0003oool0003o0?ooo`3o0000L0000?l70?ooo`00K03oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo
00D0o`000?ooo`3oool0oooo0000o`020?ooo`040?l0003oool0oooo0000
o`80oooo00L0o`000?ooo`000?l0003o0?l0003oool0003o06h0l?o`203o
ool006`0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo
0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3o00000`3oool02P000?l0
oooo0?ooo`3o0000oooo0000o`3oool0o`000?ooo`000?m^0?3ol0P0oooo
001/0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`00
0?l00`3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00@0o`000?oo
o`3oool0003o0`3oool01`3o0000oooo0000o`3oool0o`000?ooo`000?l0
KP3`oo080?ooo`00K03oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`05
0000o`3oool0oooo0?ooo`3o00000`3oool010000?l0oooo0?ooo`3o0002
0?ooo`080000o`3oool0oooo0?l0003oool0003o0?ooo`3o00020?ooo`03
0000o`3`oo00l?o`06`0l?o`203oool006`0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0oooo
0?ooo`000?l00P3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00D0
o`000?ooo`000?l0oooo0?l000020?ooo`030000o`3`oo00l?o`06`0l?o`
203oool006`0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool01`3o
0000oooo0?ooo`3oool0003o0?ooo`3o00000P3oool00`000?l0oooo0?l0
00020?ooo`030000o`3`oo00l?o`06`0l?o`203oool006`0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool010000?l0oooo0?ooo`3o00030?ooo`05
0000o`3oool0oooo0?ooo`3o00000P3oool010000?l0oooo0?ooo`3o0002
0?ooo`030000o`3oool0o`000080oooo00<0003o0?3ol03`oo00K03`oo08
0?ooo`00K03oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l00003
0?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?oo
o`3oool0o`000080oooo00<0003o0?ooo`3o00000`3oool00`000?l0oooo
0?l000020?ooo`030000o`3`oo00l?o`06`0l?o`203oool006`0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?oo
o`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`04
0?l0003oool0oooo0000o`<0oooo00L0o`000?ooo`3oool0oooo0000o`3o
ool0o`000080oooo00@0003o0?ooo`3oool0o`000P3oool00`000?l0l?o`
0?3ol01/0?3ol0P0oooo001/0?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool00`3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`040?l0
003oool0oooo0000o`<0oooo00D0o`000?ooo`3oool0oooo0000o`030?oo
o`040?l0003oool0oooo0000o`80oooo00@0o`000?ooo`3oool0003o0P3o
ool0103o0000oooo0?ooo`000?m^0?3ol0P0oooo001/0?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0
oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool01000
0?l0oooo0?ooo`3o00020?ooo`040000o`3oool0oooo0?l00080oooo00<0
003o0?3ol03`oo00K03`oo080?ooo`00K03oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool0103o0000oooo0?ooo`000?l40?ooo`040?l0003oool0oooo0000o`<0
oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`040?l0003oool0oooo
0000o`80oooo00@0o`000?ooo`3oool0003oKP3`oo080?ooo`00K03oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00D0o`00
0?ooo`3oool0oooo0000o`050?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool0103o0000oooo0?ooo`000?l40?ooo`040?l0003oool0oooo0000
o`<0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`040?l0003oool0
oooo0000o`80oooo00@0o`000?ooo`3oool0003oKP3`oo080?ooo`00K03o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000
o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`00
0080oooo00@0003o0?ooo`3oool0o`000P3oool01@000?l0oooo0?ooo`3o
ool0o`000080oooo00<0003o0?3ol03`oo00K03`oo080?ooo`00K03oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo
00D0o`000?ooo`3oool0oooo0000o`020?ooo`050?l0003oool0oooo0?oo
o`000?l00P3oool0103o0000oooo0?ooo`000?l20?ooo`050?l0003oool0
oooo0?ooo`000?l0KP3`oo080?ooo`00K03oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l00`3o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`020?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool0103o
0000oooo0?ooo`000?l20?ooo`050?l0003oool0oooo0?ooo`000?l0KP3`
oo080?ooo`00K03oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0003o
0`3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00@0o`000?ooo`3o
ool0003o0P3oool01@3o0000oooo0?ooo`3oool0003o06h0l?o`203oool0
06`0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o
0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000
o`030?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool01@3o0000oooo
0?ooo`3oool0003o0080oooo00@0o`000?ooo`3oool0003o0P3oool01@3o
0000oooo0?ooo`3oool0003o06h0l?o`203oool006`0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`050?l0003o
ool0oooo0?ooo`000?l00P3oool01@3o0000oooo0?ooo`3oool0003o00<0
oooo00@0o`000?ooo`3oool0003o0P3oool01@3o0000oooo0?ooo`3oool0
003o06h0l?o`203oool006`0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool01@000?l0oooo0?ooo`3oool0o`000080oooo00D0003o0?ooo`3oool0
oooo0?l000030?ooo`040000o`3oool0oooo0?l000<0oooo00@0003o0?oo
o`3oool0o`000`3oool00`000?l0l?o`0?3ol01/0?3ol0P0oooo001/0?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0
0`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool0103o0000oooo0?ooo`000?l30?ooo`050?l0003oool0oooo0?ooo`00
0?l00P3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00D0o`000?oo
o`3oool0oooo0000o`1^0?3ol0P0oooo001/0?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?oo
o`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`05
0?l0003oool0oooo0?ooo`000?l00P3oool01@3o0000oooo0?ooo`3oool0
003o06h0l?o`203oool006`0oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`000?l0
0`3oool01@3o0000oooo0?ooo`3oool0003o0080oooo00D0o`000?ooo`3o
ool0oooo0000o`020?ooo`050?l0003oool0oooo0?ooo`000?l0KP3`oo08
0?ooo`00K03oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`040?l0
003oool0oooo0000o`<0oooo00D0o`000?ooo`3oool0oooo0000o`020?oo
o`050?l0003oool0oooo0?ooo`000?l0KP3`oo080?ooo`00K03oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`3o00000P3oool00`000?l0oooo0?ooo`020?ooo`040?l0003o
ool0oooo0000o`<0oooo00D0o`000?ooo`3oool0oooo0000o`020?ooo`05
0?l0003oool0oooo0?ooo`000?l0KP3`oo080?ooo`00K03oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?oo
o`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00@0o`00
0?ooo`3oool0003o0`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo
00D0o`000?ooo`3oool0oooo0000o`020?ooo`050?l0003oool0oooo0?oo
o`000?l0KP3`oo080?ooo`00K03oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o
0000oooo0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000
o`030?ooo`050?l0003oool0oooo0?ooo`000?l00P3oool01@3o0000oooo
0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000o`1^0?3o
l0P0oooo001/0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo
0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00@0
o`000?ooo`3oool0003o0`3oool01@3o0000oooo0?ooo`3oool0003o00<0
oooo00D0o`000?ooo`3oool0oooo0000o`1^0?3ol0P0oooo001/0?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool01@000?l0oooo
0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000030?oo
o`030000o`3`oo00l?o`06`0l?o`203oool006`0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0
o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000020?ooo`050000o`3o
ool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`0000<0
oooo00<0003o0?3ol03`oo00K03`oo080?ooo`00K03oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0
oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o
0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0
1@000?l0oooo0?ooo`3oool0o`000080oooo00D0003o0?ooo`3oool0oooo
0?l000030?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0
l?o`0?3ol01/0?3ol0P0oooo001/0?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo
0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`3o00000P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo
00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3`oo00l?o`06`0
l?o`203oool006`0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool01@3o0000
oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo
0?ooo`3oool0o`0000<0oooo00<0003o0?3ol03`oo00K03`oo080?ooo`00
K03oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0
003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`05
0000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0
o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3o
ool0oooo0?ooo`3o00000`3oool00`000?l0l?o`0?3ol01/0?3ol0P0oooo
001/0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0
o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo
00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0oooo0?oo
o`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o
0?ooo`3oool0oooo0?l000030?ooo`030000o`3`oo00l?o`06`0l?o`203o
ool006`0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo
0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000030?oo
o`050000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3o
ool0o`0000<0oooo00<0003o0?3ol03`oo00K03`oo080?ooo`00K03oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0
0`3oool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`3o
00000`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?oo
o`3oool0oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o00000`3o
ool00`000?l0l?o`0?3ol01/0?3ol0P0oooo001/0?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3o
ool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0
003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`05
0000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0
o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3`
oo00l?o`06`0l?o`203oool006`0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool0
0P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool0
1@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?3ol03`oo00K03`
oo080?ooo`00K03oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`00
00<0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`1^0?3ol0P0oooo001/
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo
0000o`030?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0
oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@00
0?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o06h0l?o`203oool006`0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000<0
oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0oooo
0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l0KP3`oo080?ooo`00K03oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0?l000040?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0
oooo0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l00003
0?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
o`1^0?3ol0P0oooo001/0?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00@0003o0?ooo`3oool0o`00103oool01@000?l0oooo0?ooo`3oool0o`00
00<0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`1^0?3ol0P0oooo001/
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo
0000o`030?ooo`030?l0003oool0oooo00<0oooo00@0003o0?ooo`3oool0
o`00103oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?oo
o`3oool0oooo0?l000030?ooo`030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`1^0?3ol0P0oooo001/0?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo
0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0
003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o06h0l?o`
203oool006`0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0
003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0
o`0000<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0
003oool0oooo0?ooo`000?l0KP3`oo080?ooo`00K03oool00`000?l0oooo
0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool01@3o0000oooo
0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0
l?o`0?3ol01/0?3ol0P0oooo001/0?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o
0?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo0080oooo00D0
o`000?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`00
0?l00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3`oo00l?o`06`0
l?o`203oool006`0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo
0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo
00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0
oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo
0080oooo00<0003o0?3ol03`oo00K03`oo080?ooo`00K03oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`050000o`3oool0oooo0?ooo`3o00001@3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000
o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`05
0?l0003oool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3oool0
003o00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0l?o`0?3ol01/
0?3ol0P0oooo001/0?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0
oooo0?l000030?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3o
ool0oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3`oo00l?o`06`0l?o`203oool0
06`0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo
00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000<0
oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o
00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0
oooo0080oooo00<0003o0?3ol03`oo00K03`oo080?ooo`00K03oool00`00
0?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`050?l0003oool0oooo0?ooo`000?l00`3oool01@3o0000oooo0?ooo`3o
ool0003o00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0l?o`0?3o
l01/0?3ol0P0oooo001/0?ooo`030000o`3oool0oooo0080oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0?l000040?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00@0o`000?oo
o`3oool0003o103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0l?o`0?3ol01/0?3ol0P0oooo001/
0?ooo`050000o`3oool0oooo0?ooo`3o00001@3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo
0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3`oo00l?o`06`0l?o`203oool006`0oooo00D0003o0?ooo`3oool0oooo
0?l000040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`00
00@0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003o
ool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000
o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?3ol03`oo00K03`oo080?ooo`00
K03oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`00
0?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
1@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3o
ool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0l?o`0?3ol01/0?3ol0P0oooo001/0?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0
oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?ooo`050?l0
003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3`oo00l?o`06`0l?o`203oool006`0oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
o`030?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0?l000030?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0
oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?3ol03`
oo00K03`oo080?ooo`00K03oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3o
ool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0l?o`0?3ol01/0?3ol0P0oooo001/0?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00D0003o0?ooo`3oool0oooo0?l000030?ooo`030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo
0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3`oo00
l?o`06`0l?o`203oool006`0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`00
00<0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?3ol03`oo00K03`oo080?ooo`00K03oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`050000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?oo
o`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0l?o`
0?3ol01/0?3ol0P0oooo001/0?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l0
00030?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000
oooo0?ooo`020?ooo`030000o`3`oo00l?o`06`0l?o`203oool006`0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3o
ool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00<0003o0?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3o
ool0oooo0000o`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?3o
l03`oo00K03`oo080?ooo`00K03oool01@000?l0oooo0?ooo`3oool0o`00
00@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3o
ool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
1@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0l?o`0?3ol01/0?3ol0P0oooo001/0?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3o
ool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo
0000o`030?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`030000o`3`oo00l?o`06`0l?o`203oool006`0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000
oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?3ol03`oo00K03`oo08
0?ooo`00K03oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0l?o`
0?3ol01/0?3ol0P0oooo001/0?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`03
0?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?oo
o`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`03
0?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`030000o`3`oo00l?o`06`0l?o`203oool006`0oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?oo
o`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0
003o00<0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?3ol03`oo00K03`oo080?ooo`00K03oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003o
ool0oooo0?ooo`000?l00`3oool00`3o0000oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool00`000?l0l?o`0?3ol01/0?3ol0P0
oooo001/0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`030?l0003oool0oooo
0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3`oo00
l?o`06`0l?o`203oool006`0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0
o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00<0003o0?3ol03`oo00K03`oo080?ooo`00K03oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
0`000?l0l?o`0?3ol01/0?3ol0P0oooo001/0?ooo`050000o`3oool0oooo
0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo
0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`03
0000o`3`oo00l?o`06`0l?o`203oool006`0oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?oo
o`000?l0103oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo
0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?3ol03`oo00K03`oo080?ooo`00K03oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3o
ool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`00
0?l0l?o`0?3ol01/0?3ol0P0oooo001/0?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3o
ool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000
o`3`oo00l?o`06`0l?o`203oool006`0oooo00D0003o0?ooo`3oool0oooo
0?l000040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo
0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o
0?3ol03`oo00K03`oo080?ooo`00K03oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0?l000040?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo
0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0
l?o`0?3ol01/0?3ol0P0oooo001/0?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3o
ool0003o00@0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0
o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3`
oo00l?o`06`0l?o`203oool006`0oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?oo
o`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo
0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o
0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?3o
l03`oo00K03`oo080?ooo`00K03oool01@000?l0oooo0?ooo`3oool0o`00
00@0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0
oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l0
00040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0l?o`
0?3ol01/0?3ol0P0oooo001/0?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`00
00@0oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003o
ool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`00
00@0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3`oo00
l?o`06`0l?o`203oool006`0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000
103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?3ol03`
oo00K03`oo080?ooo`00K03oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000
o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo
0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l00004
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0l?o`0?3o
l01/0?3ol0P0oooo001/0?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o
00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3`oo00l?o`
06`0l?o`203oool006`0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3o
ool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?3ol03`oo00
K03`oo080?ooo`00K03oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0l?o`0?3ol01/
0?3ol0P0oooo001/0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
0`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3`oo00l?o`06`0
l?o`203oool006`0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`03
0000o`3oool0oooo0080oooo00<0o`000?ooo`3oool00P3oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool01@3o
0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3o
ool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?3ol03`oo00K03`
oo080?ooo`00K03oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`050?l0
003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?oo
o`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3o
ool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0
003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool00`000?l0l?o`0?3ol01/0?3o
l0P0oooo001/0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`00
0?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo
00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?oo
o`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0
003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3`oo00l?o`06`0l?o`
203oool006`0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000
o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000
oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?3ol03`oo00K03`oo08
0?ooo`00K03oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o
0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo00<0o`000?ooo`3oool00P3oool00`000?l0l?o`0?3ol01/0?3ol0P0
oooo001/0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0
oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?oo
o`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool00`3o0000oooo0?ooo`020?ooo`030000o`3`oo00l?o`06`0l?o`203o
ool006`0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3o
ool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool01@3o
0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000
o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo
0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`030?l0003oool0oooo0080oooo00<0003o0?3ol03`oo00K03`oo080?oo
o`00K03oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?oo
o`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`020?ooo`050000o`3o
ool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0
oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o
00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0
oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo
00<0o`000?ooo`3oool00P3oool00`000?l0l?o`0?3ol01/0?3ol0P0oooo
001/0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0o`000?ooo`3o
ool0oooo0000o`040?ooo`030?l0003oool0oooo0080oooo00D0003o0?oo
o`3oool0oooo0?l000040?ooo`050000o`3oool0oooo0?ooo`3o0000103o
ool00`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0
103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3o
ool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3`oo00l?o`06`0l?o`203oool0
06`0oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?oo
o`3oool0003o00@0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`030000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`04
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?oo
o`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?3ol03`oo00K03`oo080?ooo`00
K03oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3o
ool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o
0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0
oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo
00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo
0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0l?o`0?3ol01/0?3ol0P0oooo001/
0?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo
0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0
oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o
0000oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool0
0`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0
oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o
0000oooo0?ooo`020?ooo`030000o`3`oo00l?o`06`0l?o`203oool006`0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3o
ool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0
003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`03
0000o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?oo
o`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3o
ool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0
003oool0oooo0080oooo00<0003o0?3ol03`oo00K03`oo080?ooo`00K03o
ool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool0
0P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3o
ool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?oo
o`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo
00D0o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?oo
o`000?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`00
0?ooo`3oool00P3oool00`000?l0l?o`0?3ol01/0?3ol0P0oooo001/0?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?oo
o`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo
0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000
oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`00
0?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000
oooo0?ooo`020?ooo`030000o`3`oo00l?o`06`0l?o`203oool006`0oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003oool0oooo
0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0
oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003o
ool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000
o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`05
0?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?ooo`3oool0
003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0003o
ool0oooo0080oooo00<0003o0?3ol03`oo00K03`oo080?ooo`00K03oool0
1@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3o
ool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?ooo`3oool0
0P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3o
ool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?oo
o`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00D0
o`000?ooo`3oool0oooo0000o`040?ooo`050?l0003oool0oooo0?ooo`00
0?l0103oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00<0o`000?oo
o`3oool00P3oool00`000?l0l?o`0?3ol01/0?3ol0P0oooo001/0?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`020?oo
o`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo0?ooo`02
0?ooo`040000o`3oool0oooo0?ooo`80o`000`3oool00`000?l0oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo
0?ooo`020?ooo`050000o`3oool0oooo0?ooo`3o0000103oool01@000?l0
oooo0?ooo`3oool0o`0000@0oooo00<0003o0?ooo`3oool00P3oool01@3o
0000oooo0?ooo`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000
o`040?ooo`050?l0003oool0oooo0?ooo`000?l0103oool00`3o0000oooo
0?ooo`020?ooo`030000o`3`oo00l?o`06`0l?o`203oool006`0oooo00<0
003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000
o`3oool0oooo0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`03
0?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000040?oo
o`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0oooo0?ooo`02
0?ooo`050?l0003oool0oooo0?ooo`000?l0103oool01@3o0000oooo0?oo
o`3oool0003o00@0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?3ol03`oo00K03`oo080?ooo`00
\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{338, 228},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.107",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/sourcesink/SourceSinkFigures/\
mat11107.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Flow in a right-angled channel. "
}], "Text"],

Cell[TextData[{
  "Solution.  Using the Schwarz-Christoffel transformation method, if we \
choose  ",
  Cell[BoxData[
      RowBox[{\(x\_1 = \(-1\)\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_2 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(x\_3 = 1\)}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{\(w\_1 = 0\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_2 = d\), 
        StyleBox[",",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], \(w\_3 = 1 + \[ImaginaryI]\)}]]],
  ",  then the formula  \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(g' \((z)\)\ \  = \ \ \(A\_1\) \(\((z - 
                  x\_1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - x\_2)\)\^\(\(-\
\[Alpha]\_2\)/\[Pi]\)\ \((z - x\_3)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(A\_1\) \(\((z - \
\((\(-1\))\))\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \((z - \
0)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\ \((z - 1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\)\
\(\n\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(\(A\_1\) \(\((z + 
                  1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \
\((z)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\ \((z - \
1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\)\)}]],
  "\n\nwill determine a mapping ",
  Cell[BoxData[
      \(w\  = \ g \((z)\)\)]],
  " of the upper half-plane onto the domain indicated in Figure 11.74(a).  \
With  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["\[Alpha]",
            FontSize->14], "1"], "=", \(\[Pi]\/2\)}]]],
  ",  we let ",
  Cell[BoxData[
      \(d \[Rule] \[Infinity]\)]],
  ",  then  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["\[Alpha]",
            FontSize->14], "2"], "\[Rule]", "\[Pi]"}]]],
  "  and  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["\[Alpha]",
            FontSize->14], "3"], "\[Rule]", \(-\(\[Pi]\/2\)\)}]]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe limiting formula for the derivative ",
  Cell[BoxData[
      \(g' \((z)\)\)]],
  " becomes   \n\n\t\t\t",
  Cell[BoxData[{
      \(\(\(S' \((z)\)\ \  = \ \ \(A\_1\) \(\((z + 
                  1)\)\^\(\(-\[Alpha]\_1\)/\[Pi]\)\) \
\((z)\)\^\(\(-\[Alpha]\_2\)/\[Pi]\)\ \((z - \
1)\)\^\(\(-\[Alpha]\_3\)/\[Pi]\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(A\_1\) \(\((z + 
                  1)\)\^\(\(-\(\[Pi]\/2\)\)/\[Pi]\)\) \((z)\)\^\(\(-\[Pi]\)/\
\[Pi]\)\ \((z - 1)\)\^\(\(-\((\(-\(\[Pi]\/2\)\))\)\)/\[Pi]\)\)\)\(\
\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(\(A\_1\) \(\((z + 
                  1)\)\^\(-\(1\/2\)\)\) \((z)\)\^\(-1\)\ \((z - \
1)\)\^\(1\/2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\n", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\_1\ \(1\/z\) \((z \
- 1)\)\^\(1\/2\)\/\((z + 1)\)\^\(1\/2\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\_1\ \(\(\((z - \
1)\)\^\(1\/2\)\) \((z - 1)\)\^\(1\/2\)\)\/\(z \(\((z + 1)\)\^\(1\/2\)\) \((z \
- 1)\)\^\(1\/2\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\_1\ \(z - 1\)\/\(z \
\((z\^2 - 1)\)\^\(1\/2\)\)\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A\ \(z - 1\)\/\(z \((1 \
- z\^2)\)\^\(1\/2\)\)\)\)\)}]],
  "\n\nwhere  ",
  Cell[BoxData[
      \(A\  = \ \(-\[ImaginaryI]\)\ A\_1\)]],
  ", which will determine a mapping ",
  Cell[BoxData[
      \(w\  = \ S \((z)\)\)]],
  " from the upper half plane onto the channel as indicated in Figure \
11.74(b) and Figure 11.107."
}], "Text"],

Cell[TextData[{
  "\tUsing integrals in Table 11.2, we obtain \n\n\t\t",
  Cell[BoxData[{
      \(\(\(S \((z)\)\ \  = \ \ A\ \(\[Integral]\(\(z - 
                      1\)\/\(z \((1 - z\^2)\)\^\(1\/2\)\)\) \[DifferentialD]z\
\)\ \  + \ \ B\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ \(\[Integral]\(z\/\(z \
\((1 - z\^2)\)\^\(1\/2\)\)\) \[DifferentialD]z\)\ \  - \ \ \ A\ \(\[Integral]\
\(1\/\(z \((1 - z\^2)\)\^\(1\/2\)\)\) \[DifferentialD]z\)\ \  + \ 
          B\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(\(=\)\(\ \ \)\(A\ \
\(\[Integral]\(1\/\((1 - z\^2)\)\^\(1\/2\)\) \[DifferentialD]z\)\ \  - \ \ \ \
A\ \[ImaginaryI] \(\[Integral]\(1\/\(z \((z\^2 - 1)\)\^\(1\/2\)\)\) \
\[DifferentialD]z\)\ \  + \ B\)\)\(\[IndentingNewLine]\)
      \)\), "\[IndentingNewLine]", 
      \(\ \ \ \ \ \ \ \ \ \ \ \ \ \(\(=\)\(\ \ \)\(A \((Arcsin\ z\  + \ \
\[ImaginaryI]\ Arcsin \((1\/z)\))\)\ \  + \ \ B\)\)\)}],
    AspectRatioFixed->True],
  "   "
}], "Text"],

Cell[TextData[{
  "\tIf we use the principal branch of the inverse sine function, then the \
boundary values  ",
  Cell[BoxData[
      \(S \((\(-1\))\) = \(0\ \ and\ \ S \((1)\) = 1 + \[ImaginaryI]\)\)]],
  "  lead to the system  \n\n\t\t\t",
  Cell[BoxData[
      \(A \((\(-\(\[Pi]\/2\)\) - \(\[ImaginaryI]\ \[Pi]\)\/2)\) + B = 0\)]],
  "   and   ",
  Cell[BoxData[
      \(A \((\[Pi]\/2 + \(\[ImaginaryI]\ \[Pi]\)\/2)\) + B = 
        1 + \[ImaginaryI]\)]],
  ",  \n\nwhich we can solve to obtain ",
  Cell[BoxData[
      \(A = \(1\/\[Pi]\ \ and\ \ B = \(1 + \[ImaginaryI]\)\/2\)\)]],
  ".  Hence the required solution is \n \n\t\t\t",
  Cell[BoxData[
      \(w\  = \ \(S \((z)\)\  = \ \(\(\(1\/\[Pi]\) 
              Arcsin\ z\)\(\ \)\(+\)\(\ \)\(\(\[ImaginaryI]\/\[Pi]\) Arcsin 
               1\/z\)\(\ \)\(+\)\(\ \)\(\(1\  + \ \[ImaginaryI]\)\/2\)\(\ \
\)\)\)\)]],
  "  "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 3.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[f, z];\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        1\/\[Pi]\ ArcSin[z]\  + \ \[ImaginaryI]\/\[Pi]\ ArcSin[
              1\/z]\  + \ \(1\  + \ \[ImaginaryI]\)\/2;\)\ \), "\n", 
    \(\(Print["\<S[z] = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[0] = \>", 
        Limit[S[z], z \[Rule] 0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[1] = \>", S[1]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph conformal mapping  w = S(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[S, {0.00001, 15.00001, 1}, {0.0001, 3.14149, 3.14139\/24}, 
        PlotRange \[Rule] {{0, 2}, {0, 2}}, PlotStyle \[Rule] {Blue, Red}, 
        Ticks \[Rule] {Range[\(-2\), 2, 1], 
            Range[\(-2\), 2, 1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow in the upper half plane Im[z] > \
0,\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<where a source is located at \!\(z\_0\) = 0, under the\>\
\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<conformal mapping w = S[z] = \>", S[z]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ \ Table[{Re[
              S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            2, 23, 2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {r, 0.01, 55}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            1, 23, 2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {r, 0.001, 55}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Blue, Line[{{0, 2}, {0, 0}, {2, 0}}], 
            Line[{{1, 2}, {1, 1}, {2, 1}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, boundary, PlotRange \[Rule] {{0, 2}, {0, 2}}, 
        AspectRatio \[Rule] 1\/1, 
        Ticks \[Rule] {Range[\(-2\), 2, 2], Range[1, 2, 1]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow in the upper half plane Im[z] > \
0,\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<where a source is located at \!\(z\_0\) = 0, under the\>\
\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<conformal mapping w = S[z] = \>", 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Use a Schwarz-Christoffel transformation to show that the conformal \
mapping  \n\n\t\t\t",
  Cell[BoxData[
      \(w\ \  = \ \ \(S \((z)\)\ \  = \ \ 2 \((z + 1)\)\^\(1/2\)\ \ \  - \ \ \
Log \((\(1 - \((z + 1)\)\^\(1/2\)\)\/\(1 + \((z + 1)\)\^\(1/2\)\))\)\)\)]],
  "  \n\nwill map the flow in the upper half-plane onto the flow from a \
channel back into a quadrant, as shown in Figure 11.108, \nwhere  ",
  Cell[BoxData[
      \(z\_1\  = \ 0, z\_2\  = \ 1\)]],
  "  and  ",
  Cell[BoxData[
      \(w\_1\  = \ \[Infinity], 
      w\_1\  = \ \(S \((1)\)\  = \ 
          2\ \@2 - \[ImaginaryI]\ \[Pi] - 2  Log \((\@2 - 1)\)\)\)]],
  ". "
}], "Text"],

Cell[TextData[Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005j0000i2000`400?l0
0000o`00003oo`3ooomk0?ooo`00o`3ooomk0?ooo`00o`3ooomk0?ooo`00
o`3ooomk0?ooo`00o`3ooomk0?ooo`00K03ooooo0000o`L0003o203oool0
06`0oooo00<0003o0?ooo`3oool0o`3oool<0?ooo`00K03oool00`000?l0
oooo0?ooo`3o0?ooo``0oooo001/0?ooo`030000o`3oool0oooo0?l0oooo
303oool006`0oooo00<0003o0?ooo`3oool0S03ooomg0?l000P0oooo001/
0?ooo`030000o`3oool0oooo06`0oooo803o001o0?ooo`00K03oool00`00
0?l0oooo0?ooo`1R0?ooo`X0o`00W`3oool006`0oooo00<0003o0?ooo`3o
ool0E@3oool=0?l005`0ooooA@000?l80?ooo`00K03oool00`000?l0oooo
0?ooo`190?ooo``0o`00=`3ooolb0000odd0oooo001/0?ooo`030000o`3o
ool0oooo0440oooo203o000d0?ooo`l0003oO`3oool006`0oooo00<0003o
0?ooo`3oool0?03oool50?l002/0oooo4@000?n>0?ooo`00K03oool00`00
0?l0oooo0?ooo`0h0?ooo`@0o`00:@3oool70000ocX0ooooG@3o00080?oo
o`00K03oool00`000?l0oooo0?ooo`0e0?ooo`<0o`009`3oool60000obL0
oooo6P3o001U0?ooo`00K03oool00`000?l0oooo0?ooo`0b0?ooo`<0o`00
903oool60000oah0oooo3`3o001o0?ooo`00K03oool00`000?l0oooo0?oo
o`0_0?ooo`<0o`008@3oool60000oa`0oooo203o00110?ooodD0003o203o
ool006`0oooo00<0003o0?ooo`3oool0:`3oool40?l001l0oooo1@000?lJ
0?ooo`P0o`00:03ooolQ0000odd0oooo001/0?ooo`030000o`3oool0oooo
02T0oooo0P3o000P0?ooo`<0003o6@3oool60?l001l0oooo4@000?m^0?oo
o`00K03oool00`000?l0oooo0?ooo`0W0?ooo`80o`007P3oool40000oaP0
oooo103o000I0?ooo``0003oO`3oool006`0oooo00<0003o0?ooo`3oool0
9@3oool20?l001d0oooo0`000?lH0?ooo`@0o`00603oool50000oc00oooo
D`3o00080?ooo`00K03oool00`000?l0oooo0?ooo`0S0?ooo`80o`00703o
ool30000oaL0oooo103o000F0?ooo`H0003o6@3ooolL0?l005/0oooo001/
0?ooo`030000o`3oool0oooo0240oooo0P3o000K0?ooo`<0003o5P3oool4
0?l001<0oooo1`000?lG0?ooo`P0o`00M`3oool006`0oooo00<0003o0?oo
o`3oool07`3oool20?l001/0oooo0P000?lE0?ooo`@0o`004P3oool50000
oa80oooo303o000b0?ooodD0003o203oool006`0oooo00<0003o0?ooo`3o
ool07@3oool20?l001X0oooo0`000?lD0?ooo`<0o`004P3oool40000oa<0
oooo103o000N0?ooob00003oC@3oool006`0oooo00<0003o0?ooo`3oool0
703oool00`3o0000oooo0?ooo`0G0?ooo`<0003o503oool30?l00140oooo
10000?lA0?ooo`H0o`006@3oool90000ofd0oooo001/0?ooo`030000o`3o
ool0oooo01/0oooo00<0o`000?ooo`3oool05P3oool20000oa@0oooo0`3o
000@0?ooo`@0003o3`3oool60?l001L0oooo20000?mf0?ooo`00K03oool0
0`000?l0oooo0?ooo`0J0?ooo`030?l0003oool0oooo01D0oooo0P000?lD
0?ooo`80o`00403oool30000oa00oooo0`3o000A0?ooo``0003o8`3ooomC
0?l000P0oooo001/0?ooo`030000o`3oool0oooo01T0oooo00<0o`000?oo
o`3oool0503oool20000oa@0oooo0P3o000@0?ooo`80003o403oool30?l0
0100oooo10000?lM0?oooa80o`00F`3oool006`0oooo00<0003o0?ooo`3o
ool0603oool00`3o0000oooo0?ooo`0D0?ooo`030000o`3oool0oooo0180
oooo0P3o000?0?ooo`<0003o3`3oool30?l000l0oooo10000?l@0?oooa40
o`00K@3oool006`0oooo00<0003o0?ooo`3oool05`3oool00`3o0000oooo
0?ooo`0D0?ooo`030000o`3oool0oooo0140oooo0P3o000?0?ooo`80003o
403oool20?l000h0oooo10000?l>0?ooo`H0o`00<@3ooom50000o`P0oooo
001/0?ooo`030000o`3oool0oooo01H0oooo00<0o`000?ooo`3oool04`3o
ool20000oa80oooo0P3o000?0?ooo`80003o3`3oool30?l000/0oooo1@00
0?l=0?ooo`D0o`00803ooolG0000odd0oooo001/0?ooo`030000o`3oool0
oooo01D0oooo00<0o`000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0@
0?ooo`80o`003`3oool20000o`h0oooo0`3o000:0?ooo`@0003o3P3oool4
0?l001<0oooo4P000?mT0?ooo`00K03oool00`000?l0oooo0?ooo`0D0?oo
o`030?l0003oool0oooo01<0oooo00<0003o0?ooo`3oool03`3oool20?l0
00l0oooo0P000?l>0?ooo`80o`002P3oool30000o`h0oooo103o000@0?oo
o`L0003oD03ooolN0?l000P0oooo001/0?ooo`030000o`3oool0oooo01<0
oooo00<0o`000?ooo`3oool04P3oool20000oa40oooo00<0o`000?ooo`3o
ool03@3oool20000o`d0oooo0`3o000:0?ooo`80003o3@3oool40?l000h0
oooo1P000?lR0?ooocD0o`009P3oool006`0oooo00<0003o0?ooo`3oool0
4`3oool00`3o0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00l0oooo
0P3o000>0?ooo`80003o3@3oool20?l000X0oooo0`000?l<0?ooo`<0o`00
3@3oool50000oaL0oooo4@3o001K0?ooo`00K03oool00`000?l0oooo0?oo
o`0B0?ooo`030?l0003oool0oooo0140oooo00<0003o0?ooo`3oool03`3o
ool00`3o0000oooo0?ooo`0<0?ooo`80003o3@3oool20?l000X0oooo0P00
0?l<0?ooo`<0o`00303oool40000oa<0oooo2@3o001/0?ooo`00K03oool0
0`000?l0oooo0?ooo`0B0?ooo`030?l0003oool0oooo0100oooo00<0003o
0?ooo`3oool03P3oool20?l000d0oooo0P000?l=0?ooo`80o`002P3oool2
0000o`/0oooo0`3o000;0?ooo`@0003o3`3oool80?l002T0ooooA0000?l8
0?ooo`00K03oool00`000?l0oooo0?ooo`0A0?ooo`030?l0003oool0oooo
0100oooo00<0003o0?ooo`3oool03P3oool00`3o0000oooo0?ooo`0;0?oo
o`80003o3@3oool20?l000X0oooo0P000?l;0?ooo`80o`002P3oool40000
o`d0oooo1P3o000I0?oooaP0003oC03oool006`0oooo00<0003o0?ooo`3o
ool04@3oool00`3o0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00d0
oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0;0?ooo`80
o`002P3oool20000o`X0oooo0`3o00090?ooo`<0003o3@3oool40?l000h0
oooo4@000?mT0?ooo`00K03oool00`000?l0oooo0?ooo`0@0?ooo`030?l0
003oool0oooo0100oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo
0?ooo`0;0?ooo`030000o`3oool0oooo00X0oooo0P3o000:0?ooo`80003o
2P3oool20?l000X0oooo0P000?l<0?ooo`@0o`002`3oool70000odl0oooo
7P3o00080?ooo`00K03oool00`000?l0oooo0?ooo`0@0?ooo`030?l0003o
ool0oooo00l0oooo00<0003o0?ooo`3oool03@3oool00`3o0000oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00T0oooo0P3o000;0?ooo`030000o`3o
ool0oooo00P0oooo0P3o00090?ooo`<0003o2P3oool40?l000T0oooo1P00
0?lR0?oooc@0o`009P3oool006`0oooo00<0003o0?ooo`3oool0403oool0
0`3o0000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00d0oooo00<0o`00
0?ooo`3oool02P3oool20000o`/0oooo00<0o`000?ooo`3oool02@3oool2
0000o`T0oooo0P3o00090?ooo`80003o2@3oool40?l000P0oooo1@000?lF
0?oooa80o`00FP3oool006`0oooo00<0003o0?ooo`3oool03`3oool00`3o
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
00P0oooo0P000?l:0?ooo`030?l0003oool0oooo00H0oooo0`000?l80?oo
o`<0o`00203oool40000oa<0oooo203o001/0?ooo`00K03oool00`000?l0
oooo0?ooo`0?0?ooo`030?l0003oool0oooo00h0oooo00<0003o0?ooo`3o
ool0303oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0
oooo0P3o00090?ooo`80003o2P3oool20?l000L0oooo0P000?l90?ooo`80
o`00203oool30000oa00oooo1`3o000J0?oooe80003o203oool006`0oooo
00<0003o0?ooo`3oool03`3oool00`3o0000oooo0?ooo`0=0?ooo`030000
o`3oool0oooo00`0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
203oool20?l000L0oooo0P000?l80?ooo`<0o`001P3oool40000o`d0oooo
1P3o000?0?oooa80003oFP3oool006`0oooo00<0003o0?ooo`3oool03P3o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00`0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`050?ooo`80003o203oool20?l000L0oooo0P000?l<0?ooo`D0o`003@3o
ool80000of`0oooo001/0?ooo`030000o`3oool0oooo00h0oooo00<0o`00
0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00L0oooo0P3o00070?ooo`030000o`3oool0
oooo00H0oooo0P3o00070?ooo`80003o2P3oool40?l000/0oooo1`000?lX
0?oood@0o`00203oool006`0oooo00<0003o0?ooo`3oool03P3oool00`3o
0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00`0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00L0oooo0P000?l90?ooo`030?l0003oool0oooo00D0oooo0P000?l70?oo
o`80o`001`3oool20000o`T0oooo0`3o00090?ooo`H0003o603ooolG0?l0
04`0oooo001/0?ooo`030000o`3oool0oooo00d0oooo00<0o`000?ooo`3o
ool03@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00L0oooo0P3o00060?ooo`80003o1`3oool20?l000L0
oooo0P000?l80?ooo`<0o`00203oool40000oaH0oooo203o001S0?ooo`00
K03oool00`000?l0oooo0?ooo`0=0?ooo`030?l0003oool0oooo00`0oooo
00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`090?ooo`030000
o`3oool0oooo00T0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool20?l000L0oooo0P000?l70?ooo`<0o`001`3oool40000oa40oooo
2@3o00150?oooah0003o203oool006`0oooo00<0003o0?ooo`3oool0303o
ool00`3o0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool20000o`L0oooo0P3o00070?ooo`<0003o3`3oool60?l001X0oooo=000
0?lV0?ooo`00K03oool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0
oooo00`0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00@0oooo0P000?l7
0?ooo`030?l0003oool0oooo00@0oooo0P000?l70?ooo`80o`001P3oool3
0000o``0oooo1P3o000?0?oooa40003oFP3oool006`0oooo00<0003o0?oo
o`3oool0303oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool20?l0
00H0oooo00<0003o0?ooo`3oool01@3oool20?l000H0oooo00<0003o0?oo
o`3oool01@3oool20?l000H0oooo0P000?l90?ooo`H0o`003@3oool80000
of/0oooo001/0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo0P000?l60?ooo`80
o`001P3oool20000o`H0oooo1@3o000<0?ooo`L0003o9`3ooom40?l000P0
oooo001/0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool0
303oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
103oool20?l000H0oooo0P000?l50?ooo`<0o`002`3oool60000oaL0oooo
5`3o001<0?ooo`00K03oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003o
ool0oooo00/0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool20?l000D0oooo0P000?l50?ooo`80o`001P3o
ool20000o`D0oooo0P3o000:0?ooo`@0003o3@3oool@0?l006<0oooo001/
0?ooo`030000o`3oool0oooo00/0oooo00<0o`000?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`80003o1@3oool20?l000T0oooo0`000?l;
0?ooo`H0o`00C@3ooolN0000o`P0oooo001/0?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool20?l000D0oooo0P000?l50?oo
o`80o`001`3oool40000o`P0oooo1P3o000F0?ooocd0003o9P3oool006`0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00<0oooo0P000?l50?ooo`80o`001@3oool40000o`P0
oooo103o000D0?ooo`P0003oH`3oool006`0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool20?l000D0oooo0P000?l80?ooo`@0o`00
2P3oool>0000of/0oooo001/0?ooo`030000o`3oool0oooo00X0oooo00<0
o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`80003o103o
ool20?l000D0oooo0P000?l60?ooo`@0o`002@3oool50000ob00ooooD@3o
00080?ooo`00K03oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo0P000?l50?ooo`<0o`002@3oool4
0000oa@0oooo4@3o001I0?ooo`00K03oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00`3oool20?l000P0oooo10000?l:0?ooo`h0o`00JP3oool006`0
oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool20?l000@0
oooo0P000?l50?ooo`030?l0003oool0oooo00@0oooo10000?l80?ooo`H0
o`00;03ooom40000o`P0oooo001/0?ooo`030000o`3oool0oooo00X0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo
0?ooo`030?ooo`80o`000`3oool40000o`L0oooo1@3o000D0?oooah0003o
C03oool006`0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool00`3o0000oooo0?ooo`020?ooo`80003o103oool20?l000<0oooo0P00
0?l60?ooo`D0o`004@3oool80000ofX0oooo001/0?ooo`030000o`3oool0
oooo00X0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0:
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo00@0o`000?ooo`3oool0oooo0P00
0?l40?ooo`80o`000`3oool20000o`H0oooo0P3o000;0?ooo`/0003oLP3o
ool006`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00@0oooo0P3o00030?ooo`80003o1@3o
ool30?l000P0oooo1@000?lK0?oooeX0o`00203oool006`0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0o`0000@0oooo00<0
003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo
0P3o00030?ooo`80003o1@3oool20?l000D0oooo1P000?l@0?oooa00o`00
HP3oool006`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0?l000030?ooo`050000o`3oool0oooo0?ooo`3o0000103oool00`000?l0
oooo0?ooo`030?ooo`80o`000`3oool40000o`/0oooo2`3o001b0?ooo`00
K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
0`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0o`000?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0o`0000<0
oooo00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo
0080oooo0P3o00030?ooo`80003o2P3oool50?l002@0ooooD@000?l80?oo
o`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo0080
oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`040?l0003oool0oooo
0000o`@0oooo00<0o`000?ooo`3oool00P000?l30?ooo`80o`000`3oool2
0000o`L0oooo1@3o000A0?oooaP0003oF@3oool006`0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0
oooo0?ooo`3o00000P3oool010000?l0oooo0?ooo`3oool20?l000<0oooo
0P000?l50?ooo`@0o`002`3oool;0000og40oooo001/0?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool01@3o0000oooo0?oo
o`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo0000o`030?ooo`05
0?l0003oool0oooo0?ooo`000?l00P3oool00`3o0000oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo0`3o00040?ooo`/0003o<03ooom40?l0
00P0oooo001/0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo00@0o`000?oo
o`3oool0003o103oool0103o0000oooo0?ooo`000?l20?ooo`040?l0003o
ool0oooo0?ooo`80003o0`3oool20?l000<0oooo10000?lF0?ooobD0o`00
C03oool006`0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0?l000030?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool010000?l0
oooo0?ooo`3o00020?ooo`80003o0`3oool20?l00080oooo0`000?l:0?oo
oa00o`00L@3oool006`0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103oool0103o
0000oooo0?ooo`000?l30?ooo`040?l0003oool0oooo0000o`80oooo00D0
o`000?ooo`3oool0003o0?ooo`040?l00080oooo0P000?l80?ooo`D0o`00
P@3oool006`0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0?l000030?ooo`070000o`3oool0oooo0?ooo`3o0000oooo0000o`020?oo
o`060?l0003oool0oooo0000o`3oool0o`000`3oool30000o`80oooo203o
000E0?ooofT0003o203oool006`0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`050?l0003oool0oooo0?ooo`000?l0103o
ool0103o0000oooo0?ooo`000?l30?ooo`060?l0003oool0oooo0000o`3o
ool0o`000P3oool00`000?l0oooo0?l000020?ooo`80003o0P3oool30?l0
00d0oooo40000?ma0?ooo`00K03oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`030?ooo`05
0000o`3oool0oooo0?ooo`3o0000103oool01@000?l0oooo0?ooo`3oool0
o`0000<0oooo00@0003o0?ooo`3oool0o`000P3oool010000?l0oooo0?oo
o`3o00020?ooo`030000o`3o0000oooo0080003o00@0oooo0?l0003o0000
o`000`3oool=0000oh40oooo001/0?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`3o00000P3oool01@000?l0oooo0?ooo`3oool0o`00
0080oooo00H0003o0?ooo`3oool0o`000?ooo`000?l20?l000040?ooo`00
0?l0o`000?l00080oooo10000?lM0?ooofT0o`00203oool006`0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`050?l0003o
ool0oooo0?ooo`000?l0103oool0103o0000oooo0?ooo`000?l30?ooo`0<
0?l0003oool0oooo0000o`3oool0o`000?ooo`000?l0oooo0?l0003oool0
003o0P3o00030000o`D0oooo703o001a0?ooo`00K03oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00@0003o0?ooo`3o
ool0o`000P3oool02@000?l0oooo0?ooo`3o0000oooo0000o`3oool0o`00
0000o`020?l000030000o`3oool0oooo00H0o`00S@3oool006`0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003o
ool0oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`040000
o`3oool0oooo0?l00080oooo00H0003o0?ooo`3oool0o`000?ooo`000?l2
0?l000030000o`3o0000o`0000<0o`00T`3oool006`0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo
0080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`040000o`3oool0
oooo0?l00080oooo00<0003o0?ooo`3o00000P3oool010000?l0o`000?oo
o`000?l20?l008h0003o203oool006`0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00D0
003o0?ooo`3oool0oooo0?l000020?ooo`050000o`3oool0oooo0?ooo`3o
00000P3oool00`000?l0oooo0?l000020?ooo`050000o`3o0000oooo0000
o`3o00000P000?l30?l00980oooo001/0?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o
00@0oooo00@0o`000?ooo`3oool0003o0`3oool01P3o0000oooo0?ooo`00
0?l0oooo0?l00080oooo00H0003o0?l0003o0000003o0?ooo`3o00030000
o`030?ooo`3o0000o`0000@0o`00S03oool006`0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`030?ooo`050?l0003oool0oooo0?oo
o`000?l00`3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00H0o`00
0?ooo`3oool0003o0?ooo`3o00020?ooo`060000o`3oool0o`000000o`3o
ool0o`000`3oool20000o`D0oooo203o00240?ooo`00K03oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000
oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3o
ool00P3oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o0?oo
o`3oool0oooo0?l000020?ooo`030000o`3oool0o`000080oooo00H0003o
0?ooo`3o0000oooo0000o`3oool20?l000<0oooo0P000?l;0?ooo`L0o`00
O@3oool006`0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`080?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`030?l0003oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0?l000030?ooo`050000o`3oool0oooo0?ooo`3o00000P3oool020000?l0
oooo0?ooo`3o0000oooo0000o`3oool0o`000P3oool00`000?l0oooo0?oo
o`020?l000<0oooo0`000?l?0?ooo`L0o`00MP3oool006`0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`050000o`3o
ool0oooo0?ooo`3o00000P3oool01P000?l0oooo0?ooo`3o0000oooo0000
o`80oooo00@0o`000?ooo`3oool0003o0`3oool00`3o0000oooo0?ooo`03
0?ooo`@0003o4P3oool;0?l006/0oooo001/0?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?oo
o`050000o`3oool0oooo0?ooo`3o00000`3oool01@000?l0oooo0?ooo`3o
ool0o`000080oooo00@0003o0?ooo`3oool0o`000P3oool00`000?l0oooo
0?l000030?ooo`040000o`3oool0oooo0?ooo`80o`001`3oool30000oaX0
oooo3@3o001N0?ooo`00K03oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`020?ooo`030000
o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool0o`0000<0oooo00D0003o0?ooo`3oool0oooo0?l000020?oo
o`040000o`3oool0oooo0?l00080oooo00@0003o0?ooo`3oool0o`000`3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00L0oooo1000
0?lS0?ooo`T0o`00E@3oool006`0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo0080oooo00D0003o
0?ooo`3oool0oooo0?l000030?ooo`050000o`3oool0oooo0?ooo`3o0000
0P3oool010000?l0oooo0?ooo`3o00030?ooo`040000o`3oool0oooo0?l0
00<0oooo0P000?l30?ooo`80o`002`3oool30000obT0oooo1@3o001@0?oo
o`00K03oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool00`3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`05
0?l0003oool0oooo0?ooo`000?l00`3oool0103o0000oooo0?ooo`000?l3
0?ooo`040?l0003oool0oooo0000o`<0oooo00<0o`000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020?ooo`80o`00303oool40000ogX0oooo001/
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0
0`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00D0o`00
0?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0oooo0?ooo`000?l0
0P3oool01@3o0000oooo0?ooo`3oool0003o00<0oooo00<0o`000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`030?ooo`<0o`003@3oool40000ogH0
oooo001/0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
00D0o`000?ooo`3oool0oooo0000o`030?ooo`050?l0003oool0oooo0?oo
o`000?l00P3oool00`3o0000oooo0?ooo`020?ooo`050000o`3oool0oooo
0?ooo`3o0000103oool00`000?l0oooo0?ooo`050?ooo`80o`003`3oool6
0000og00oooo001/0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`040?l0003oool0
oooo0000o`<0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool20?l001<0oooo
10000?m/0?ooo`00K03oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00`3oool01@000?l0oooo0?oo
o`3oool0o`0000@0oooo00D0003o0?ooo`3oool0oooo0?l000030?ooo`05
0000o`3oool0oooo0?ooo`3o00000`3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo0P000?l80?ooo`@0o`004`3oool60000
ofH0oooo001/0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`050000o`3oool0oooo0?oo
o`3o0000103oool01@000?l0oooo0?ooo`3oool0o`0000<0oooo00D0003o
0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080oooo00<0
o`000?ooo`3oool00`3oool20000o`X0oooo0`3o000F0?ooo`L0003oG`3o
ool006`0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0
1@3o0000oooo0?ooo`3oool0003o00<0oooo00D0o`000?ooo`3oool0oooo
0000o`040?ooo`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`3o0000oooo0?ooo`040?ooo`80003o2`3oool30?l001X0oooo
0`000?mL0?ooo`00K03oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`050?l0003oool0oooo0?ooo`000?l00`3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`80o`001P3oool20000o``0oooo
0P3o000K0?ooo`H0003oEP3oool006`0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool01@3o0000oooo0?ooo`3oool0003o00@0oooo
00D0o`000?ooo`3oool0oooo0000o`050?ooo`030?l0003oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`050?ooo`<0
003o2`3oool30?l001h0oooo10000?mB0?ooo`00K03oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00D0003o0?ooo`3oool0oooo0?l000040?ooo`030000o`3oool0oooo0080
oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0?l0003oool0oooo00L0oooo0P000?l<0?ooo`<0o`00L@3oool006`0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo
00<0003o0?ooo`3oool0103oool20?l000T0oooo00<0003o0?ooo`3oool0
303oool30?l006h0oooo001/0?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`030?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo00D0o`000?ooo`3oool0oooo0000o`040?ooo`030?l0
003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo
0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0
1`3oool20000o`l0oooo1`3o001W0?ooo`00K03oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0oooo0080oooo00<0
003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`020?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`050?ooo`80o`002@3oool20000oa@0oooo0`3o001T0?ooo`00K03oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`04
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030?l0003oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool2
0000o`L0oooo00<0o`000?ooo`3oool0203oool30000oa@0oooo0`3o001Q
0?ooo`00K03oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`3o
0000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`80o`002`3oool20000
oaD0oooo0`3o001N0?ooo`00K03oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`020?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool00P3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00X0oooo0P000?lF0?ooo`<0o`00F`3oool006`0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
1@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030?l0
003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo
0P000?l70?ooo`80o`00303oool40000oaD0oooo0`3o001H0?ooo`00K03o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0
o`000?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030?l0003o
ool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`3o0000oooo0?oo
o`030?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`80o`003P3oool20000oaH0oooo103o
001D0?ooo`00K03oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o
0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`070?ooo`80o`003P3oool2
0000of`0oooo001/0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`020?oo
o`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o
0000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool03@3oool20000ofX0oooo001/0?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00P0
oooo0P3o000?0?ooo`<0003oI`3oool006`0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo
00<0003o0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000
o`3oool0oooo0080oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo0P000?l:0?ooo`80o`00
403oool30000of@0oooo001/0?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3o
ool0oooo00<0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00T0oooo0`3o
000@0?ooo`<0003oH@3oool006`0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o
0?ooo`3oool00`3oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0
oooo0080oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo0P000?l<0?ooo`80o`004@3oool3
0000oeh0oooo001/0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00/0oooo00<0o`000?oo
o`3oool04@3oool30000oe/0oooo001/0?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`070?ooo`80003o303oool20?l001@0
oooo0`000?mH0?ooo`00K03oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`030?ooo`030000
o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0203oool20000o``0oooo0P3o000E0?ooo`80003o
EP3oool006`0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00D0oooo00<0o`000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00<0oooo00<0003o0?ooo`3oool0103o
ool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00T0oooo0P000?l<0?ooo`<0o`00JP3oool006`0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0003oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool0303oool20?l006P0oooo001/0?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00D0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`0:0?ooo`80003o3P3oool20?l0
06H0oooo001/0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00d0oooo0P3o001T0?ooo`00
K03oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030?l0
003oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo0P3o000<0?ooo`80003o
3`3oool20?l00680oooo001/0?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3o
ool20?l000`0oooo00<0003o0?ooo`3oool03P3oool20?l00600oooo001/
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool0203oool20?l000/0oooo0P000?l@
0?ooo`80o`00GP3oool006`0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?oo
o`3oool0103oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo
00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3oool03`3oool20?l0
05`0oooo001/0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3o
ool0103oool00`3o0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`0:0?ooo`80003o4@3oool20?l005X0oooo001/0?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0;0?ooo`80003o
J`3oool006`0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool0103oool00`000?l0oooo0?oo
o`050?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00`0oooo0P000?mY0?ooo`00K03oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00@0oooo00<0o`000?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`040?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00T0oooo0P3o000>0?ooo`80003oI`3oool006`0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool20000
o`/0oooo00<0o`000?ooo`3oool03@3oool00`000?l0oooo0?ooo`1T0?oo
o`00K03oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`03
0?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo0P3o000>0?ooo`03
0000o`3oool0oooo06<0oooo001/0?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00@0oooo
00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2P3oool00`3o0000oooo0?ooo`0<0?ooo`80003oH`3oool006`0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool0103oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203o
ool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo00d0oooo0P00
0?mQ0?ooo`00K03oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`07
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0
oooo00D0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool03P3oool20000oel0oooo001/0?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030?l0003oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool02P3oool20?l00100oooo00<0003o0?ooo`3oool0G03oool006`0
oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`0;0?ooo`030?l0003oool0oooo06`0
oooo001/0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030?l0003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02`3oool20?l006`0oooo
001/0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`80o`002P3o
ool00`000?l0oooo0?ooo`0<0?ooo`030?l0003oool0oooo06T0oooo001/
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`030?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool0303oool20?l006T0oooo001/0?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo
00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo0P000?l>0?ooo`030?l0003oool0oooo06H0oooo001/0?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000
oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool0303oool20?l006H0oooo001/0?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo
00<0o`000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo
0P000?l>0?ooo`80o`00I03oool006`0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003o
ool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00D0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`0=0?ooo`030?l0003oool0oooo0640oooo001/0?ooo`030000o`3oool0
oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool0
0`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00/0oooo00<0003o
0?ooo`3oool0L03oool006`0oooo00<0003o0?ooo`3oool01P3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00P0oooo00<0o`000?ooo`3oool02`3oool00`000?l0oooo0?ooo`1_0?oo
o`00K03oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool20?l000`0
oooo0P000?m_0?ooo`00K03oool00`000?l0oooo0?ooo`060?ooo`030?l0
003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo
00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`050?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo06`0oooo
001/0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00H0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00/0oooo0P000?m/0?ooo`00K03oool00`000?l0oooo0?ooo`06
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0
oooo00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`05
0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0<0?ooo`030000o`3oool0
oooo06T0oooo001/0?ooo`030000o`3oool0oooo00H0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00H0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00H0oooo00<0003o0?oo
o`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0:0?oo
o`030?l0003oool0oooo00`0oooo00<0003o0?ooo`3oool0J03oool006`0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00H0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool0303oool00`000?l0oooo0?ooo`1W0?ooo`00K03oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0
003oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo
0?ooo`060?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`1e0?ooo`00K03o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`1d0?ooo`00K03oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool01P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool0
0`3o0000oooo0?ooo`1c0?ooo`00K03oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`1b0?ooo`00K03oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00P0
oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01@3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`1a0?ooo`00
K03oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1P3oool00`3o0000oooo0?ooo`060?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo
0?ooo`1`0?ooo`00K03oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0
003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo0P000?l<0?ooo`030?l0003o
ool0oooo06l0oooo001/0?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`06
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`0:
0?ooo`80o`00K`3oool006`0oooo00<0003o0?ooo`3oool01`3oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01P3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo
07X0oooo001/0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`060?ooo`03
0000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`1j0?ooo`00
K03oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
1`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool0N@3oool006`0oooo00<0
003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`070?ooo`030?l0003oool0oooo00H0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo07P0oooo001/0?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`00
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool0
0`000?l0oooo0?ooo`1g0?ooo`00K03oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`070?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00/0oooo00<0003o0?oo
o`3oool0MP3oool006`0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0;0?ooo`030000o`3oool0oooo07D0
oooo001/0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00H0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0PP3oool006`0oooo00<0003o0?ooo`3oool01`3o
ool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`080?ooo`030?l0003o
ool0oooo00L0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`210?ooo`00K03oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0
oooo0800oooo001/0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?oo
o`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00X0oooo00<0o`000?ooo`3oool0O`3oool006`0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool01`3oool00`3o0000
oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`1n0?ooo`00
K03oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo
0?ooo`070?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0;0?ooo`030?l0
003oool0oooo07d0oooo001/0?ooo`030000o`3oool0oooo00L0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?oo
o`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00X0oooo00<0o`000?ooo`3oool0O@3oool006`0oooo00<0003o
0?ooo`3oool01`3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02`3oool00`3o0000oooo0?ooo`1l
0?ooo`00K03oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`290?oo
o`00K03oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`280?ooo`00
K03oool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`280?ooo`00K03o
ool00`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00L0oooo00<0003o0?ooo`3oool02@3o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`270?ooo`00K03oool0
0`000?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00L0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`260?ooo`00K03oool00`00
0?l0oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02P3oool00`000?l0oooo0?ooo`250?ooo`00K03oool00`000?l0
oooo0?ooo`070?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00L0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`070?ooo`03
0?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3o
ool0T@3oool006`0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0
203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`090?ooo`030?l0003oool0oooo0940oooo001/0?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool01`3oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?oo
o`2@0?ooo`00K03oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00L0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00L0oooo00<0o`000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo00T0oooo00<0o`000?ooo`3oool0T03oool006`0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`070?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`070?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o
0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo
08l0oooo001/0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3o
ool0203oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0
oooo00<0003o0?ooo`3oool01`3oool00`3o0000oooo0?ooo`090?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02P3oool00`3o0000oooo0?ooo`2>0?ooo`00K03oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`0:0?ooo`030000o`3oool0oooo09X0oooo001/0?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool0VP3oool006`0oooo00<0003o
0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0
oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`07
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool0
0`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00X0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`2I0?ooo`00K03oool00`00
0?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?oo
o`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo
00L0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo09P0oooo001/0?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool01`3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`0:0?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0V03oool006`0oooo
00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`080?ooo`030000
o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo
0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`2G0?ooo`00K03o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00P0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3o
ool00`3o0000oooo0?ooo`2S0?ooo`00K03oool00`000?l0oooo0?ooo`08
0?ooo`030?l0003oool0oooo00P0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00P0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0
oooo00P0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`2S
0?ooo`00K03oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?oo
o`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?oo
o`3oool02P3oool00`3o0000oooo0?ooo`2R0?ooo`00K03oool00`000?l0
oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool0203oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000
oooo0?ooo`2R0?ooo`00K03oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo
0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo
00<0003o0?ooo`3oool02P3oool00`3o0000oooo0?ooo`2Q0?ooo`00K03o
ool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00T0oooo00<0
003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`090?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0[P3o
ool006`0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0
oooo0:d0oooo001/0?ooo`030000o`3oool0oooo00P0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00P0oooo00<0003o0?ooo`3oool0203oool00`3o0000oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`2]0?ooo`00K03oool00`000?l0oooo0?ooo`080?ooo`03
0?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000
oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0
oooo00<0003o0?ooo`3oool0[03oool006`0oooo00<0003o0?ooo`3oool0
203oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool0203oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo0:`0oooo001/0?ooo`030000o`3o
ool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0203o
ool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0oooo00<0
o`000?ooo`3oool0^03oool006`0oooo00<0003o0?ooo`3oool0203oool0
0`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`00
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0
oooo00X0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`2h
0?ooo`00K03oool00`000?l0oooo0?ooo`080?ooo`030?l0003oool0oooo
00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`090?oo
o`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`0:0?ooo`030?l0003oool0oooo0;L0oooo001/0?ooo`03
0000o`3oool0oooo00P0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool0]`3oool006`0oooo00<0003o0?ooo`3oool0
2@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?ooo`080?ooo`030?l0
003oool0oooo00X0oooo00<0003o0?ooo`3oool0``3oool006`0oooo00<0
003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`080?ooo`030000o`3o
ool0oooo00T0oooo00<0o`000?ooo`3oool02P3oool00`000?l0oooo0?oo
o`090?ooo`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool0``3o
ool006`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`08
0?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<0003o
0?ooo`3oool0`P3oool006`0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0oooo00<0o`000?oo
o`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0003oool0oooo
00X0oooo00<0003o0?ooo`3oool0`P3oool006`0oooo00<0003o0?ooo`3o
ool02@3oool00`3o0000oooo0?ooo`090?ooo`030000o`3oool0oooo00T0
oooo00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`03
0?l0003oool0oooo0<l0oooo001/0?ooo`030000o`3oool0oooo00T0oooo
00<0o`000?ooo`3oool02@3oool00`000?l0oooo0?ooo`090?ooo`030?l0
003oool0oooo00T0oooo00<0003o0?ooo`3oool02P3oool00`3o0000oooo
0?ooo`3>0?ooo`00K03oool00`000?l0oooo0?ooo`090?ooo`030?l0003o
ool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`090?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0cP3o
ool006`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`09
0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool0
0`000?l0oooo0?ooo`3K0?ooo`00K03oool00`000?l0oooo0?ooo`090?oo
o`030?l0003oool0oooo00T0oooo00<0003o0?ooo`3oool02@3oool00`3o
0000oooo0?ooo`0:0?ooo`030000o`3oool0oooo0=X0oooo001/0?ooo`03
0000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool02@3oool00`000?l0
oooo0?ooo`090?ooo`030?l0003oool0oooo00X0oooo00<0003o0?ooo`3o
ool0fP3oool006`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo
0?ooo`090?ooo`030000o`3oool0oooo00X0oooo00<0o`000?ooo`3oool0
iP3oool006`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?oo
o`0:0?ooo`030000o`3oool0oooo00T0oooo00<0o`000?ooo`3oool0iP3o
ool006`0oooo00<0003o0?ooo`3oool02@3oool00`3o0000oooo0?ooo`0:
0?ooo`030000o`3oool0oooo0?80oooo001/0?ooo`030000o`3oool0oooo
00T0oooo00<0o`000?ooo`3oool0o`3oool00001\
\>"], "Text",
  Evaluatable->False,
  ImageSize->{378, 228},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]], "Text"],

Cell[TextData[{
  "\t\t\t",
  StyleBox[ButtonBox["Figure 11.108",
    ButtonData:>{
      URL[ 
      "http://math.fullerton.edu/mathews/c2003/sourcesink/SourceSinkFigures/\
mat11108.gif"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "  Flow from a channel  back into the first quadrant. "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[BoxData[{
    \(\(Clear[f, z];\)\ \), "\n", 
    \(\(S[z_]\  = \ 
        2 \((z + 1)\)\^\(1/2\)\ \  - \ 
          Log[\(1 - \((z + 1)\)\^\(1/2\)\)\/\(1 + \((z + 1)\)\^\(1/2\)\)];\)\ \
\), "\n", 
    \(\(Print["\<  S[z] = \>", S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<  S[0] = \>", S[0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  S[1] = \>", S[1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[1.0] = \>", S[1.0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<  S[1] = 2\!\(\@2\) - \[ImaginaryI] \[Pi] - 2 \
Log[\!\(\@2\)-1]\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[1.0] = \>", 
        N[2\ \@2 - \[ImaginaryI]\ \[Pi] - 
            2  Log[\@2 - 1]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->False],

Cell[TextData[{
  "Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to graph conformal mapping  w = S(z)."
}], "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(PolarMap[S, {0.00001, 10.00001, 0.5}, {0.0001, 3.14149, 3.14139\/24}, 
        PlotRange \[Rule] {{\(-0.001\), 10}, {0, 8.5}}, 
        PlotStyle \[Rule] {Blue, Red}, AspectRatio \[Rule] 8.5\/10, 
        Ticks \[Rule] {Range[0, 10, 2], 
            Range[0, 10, 2]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow in the upper half plane Im[z] > \
0,\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<where a source is located at \!\(z\_0\) = 0, under the\>\
\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<conformal mapping w = S[z] = \>", S[z]];\)\ \)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(eqns1\  = \ \ Table[{Re[
              S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            0, 23, 2}];\)\ \), "\n", 
    \(\(graph1 = 
        ParametricPlot[Evaluate[eqns1], {r, 0.001, 10}, 
          PlotStyle \[Rule] Blue, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(eqns2\  = \ 
        Table[{Re[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]], 
            Im[S[r\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ \[Pi]/24\)\ ]]}, {k, 
            1, 23, 2}];\)\ \), "\n", 
    \(\(graph2 = 
        ParametricPlot[Evaluate[eqns2], {r, 0.001, 10}, 
          PlotStyle \[Rule] Red, 
          DisplayFunction \[Rule] Identity];\)\ \ \), "\[IndentingNewLine]", 
    \(\(boundary = 
        Graphics[{Blue, Line[{{0, 10}, {0, 0}, {10, 0}}], 
            Line[{{4.6, \[Pi]}, {10, \[Pi]}}]}];\)\), "\[IndentingNewLine]", 
    \(\(Show[graph1, graph2, boundary, 
        PlotRange \[Rule] {{\(-0.001\), 10}, {0, 8.5}}, 
        AspectRatio \[Rule] 8.5\/10, 
        Ticks \[Rule] {Range[0, 10, 2], Range[0, 10, 2]}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<The image of the flow in the upper half plane Im[z] > \
0,\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<where a source is located at \!\(z\_0\) = 0, under the\>\
\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<conformal mapping w = S[z] = \>", 
        S[z]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Electrostatics",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ElectrostaticsBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Ideal Fluid Flow",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/FluidFlowBib.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Steady State Temperature",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/TemperaturesBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Joukowski Transformation and Airfoils",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/JoukowskiTransBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Schwarz-Christoffel Transformation",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/SchwarzChristoffelBib.html"]\
, None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Complex Potential",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexPotentialBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Green's Function",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/GreensFunctionBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{971, 634},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 759942, 13701}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 114, 2, 33, "Text"],
Cell[2219, 66, 1360, 35, 246, "Text",
  Evaluatable->False],
Cell[3582, 103, 348, 11, 33, "Text"],
Cell[3933, 116, 121, 2, 33, "Text"],
Cell[4057, 120, 1844, 59, 277, "Text",
  Evaluatable->False],
Cell[5904, 181, 840, 31, 74, "Text"],
Cell[6747, 214, 1940, 63, 138, "Text"],
Cell[8690, 279, 1251, 41, 36, "Text"],
Cell[9944, 322, 2103, 64, 113, "Text"],
Cell[12050, 388, 1274, 31, 85, "Text"],
Cell[13327, 421, 1046, 37, 177, "Text"],
Cell[14376, 460, 821, 28, 94, "Text",
  Evaluatable->False],
Cell[15200, 490, 47343, 779, 242, "Text"],
Cell[62546, 1271, 347, 11, 33, "Text"],
Cell[62896, 1284, 1772, 39, 484, "Text"],

Cell[CellGroupData[{
Cell[64693, 1327, 113, 2, 33, "Text"],
Cell[64809, 1331, 65, 0, 33, "Text"],
Cell[64877, 1333, 1698, 35, 426, "Input"],
Cell[66578, 1370, 144, 5, 33, "Text"],
Cell[66725, 1377, 777, 14, 170, "Input"],
Cell[67505, 1393, 141, 5, 33, "Text"],
Cell[67649, 1400, 1278, 25, 250, "Input"],
Cell[68930, 1427, 144, 5, 33, "Text"],
Cell[69077, 1434, 800, 14, 170, "Input"],
Cell[69880, 1450, 54, 0, 33, "Text"],
Cell[69937, 1452, 554, 11, 150, "Input"],
Cell[70494, 1465, 139, 5, 33, "Text"],
Cell[70636, 1472, 1432, 29, 298, "Input"],
Cell[72071, 1503, 119, 3, 33, "Text"],
Cell[72193, 1508, 1358, 28, 284, "Input"],
Cell[73554, 1538, 122, 3, 33, "Text"],
Cell[73679, 1543, 588, 12, 130, "Input"],
Cell[74270, 1557, 138, 3, 33, "Text"]
}, Closed]],
Cell[74423, 1563, 622, 18, 87, "Text",
  Evaluatable->False],
Cell[75048, 1583, 91336, 1500, 242, "Text"],
Cell[166387, 3085, 342, 11, 33, "Text"],
Cell[166732, 3098, 844, 21, 325, "Text"],
Cell[167579, 3121, 2546, 64, 357, "Text"],

Cell[CellGroupData[{
Cell[170150, 3189, 113, 2, 33, "Text"],
Cell[170266, 3193, 65, 0, 33, "Text"],
Cell[170334, 3195, 1464, 29, 371, "Input"],
Cell[171801, 3226, 144, 5, 33, "Text"],
Cell[171948, 3233, 817, 15, 190, "Input"],
Cell[172768, 3250, 141, 5, 33, "Text"],
Cell[172912, 3257, 1875, 35, 330, "Input"],
Cell[174790, 3294, 144, 5, 33, "Text"],
Cell[174937, 3301, 789, 14, 210, "Input"],
Cell[175729, 3317, 54, 0, 33, "Text"],
Cell[175786, 3319, 554, 11, 150, "Input"],
Cell[176343, 3332, 139, 5, 33, "Text"],
Cell[176485, 3339, 2700, 56, 562, "Input"],
Cell[179188, 3397, 138, 3, 33, "Text"],
Cell[179329, 3402, 1780, 37, 378, "Input"],
Cell[181112, 3441, 141, 3, 33, "Text"],
Cell[181256, 3446, 600, 11, 110, "Input"],
Cell[181859, 3459, 157, 3, 33, "Text"]
}, Closed]],
Cell[182031, 3465, 657, 21, 125, "Text"],
Cell[182691, 3488, 1344, 49, 204, "Text"],
Cell[184038, 3539, 906, 29, 71, "Text"],
Cell[184947, 3570, 1604, 46, 248, "Text"],
Cell[186554, 3618, 76078, 1250, 242, "Text"],
Cell[262635, 4870, 345, 11, 33, "Text"],

Cell[CellGroupData[{
Cell[263005, 4885, 113, 2, 33, "Text"],
Cell[263121, 4889, 65, 0, 33, "Text"],
Cell[263189, 4891, 1450, 29, 370, "Input"],
Cell[264642, 4922, 144, 5, 33, "Text"],
Cell[264789, 4929, 672, 12, 196, "Input"],
Cell[265464, 4943, 141, 5, 33, "Text"],
Cell[265608, 4950, 1111, 21, 250, "Input"],
Cell[266722, 4973, 144, 5, 33, "Text"],
Cell[266869, 4980, 1114, 22, 250, "Input"],
Cell[267986, 5004, 54, 0, 33, "Text"],
Cell[268043, 5006, 554, 11, 150, "Input"],
Cell[268600, 5019, 139, 5, 33, "Text"],
Cell[268742, 5026, 1944, 39, 390, "Input"],
Cell[270689, 5067, 197, 5, 36, "Text"]
}, Closed]],
Cell[270901, 5075, 2195, 61, 278, "Text"],
Cell[273099, 5138, 36838, 606, 242, "Text"],
Cell[309940, 5746, 355, 11, 33, "Text"],

Cell[CellGroupData[{
Cell[310320, 5761, 113, 2, 33, "Text"],
Cell[310436, 5765, 65, 0, 33, "Text"],
Cell[310504, 5767, 1767, 36, 427, "Input"],
Cell[312274, 5805, 144, 5, 33, "Text"],
Cell[312421, 5812, 628, 11, 144, "Input"],
Cell[313052, 5825, 141, 5, 33, "Text"],
Cell[313196, 5832, 1073, 21, 250, "Input"],
Cell[314272, 5855, 144, 5, 33, "Text"],
Cell[314419, 5862, 1082, 22, 250, "Input"],
Cell[315504, 5886, 54, 0, 33, "Text"],
Cell[315561, 5888, 580, 12, 150, "Input"],
Cell[316144, 5902, 139, 5, 33, "Text"],
Cell[316286, 5909, 1407, 29, 305, "Input"],
Cell[317696, 5940, 274, 8, 36, "Text"]
}, Closed]],
Cell[317985, 5951, 720, 21, 68, "Text"],
Cell[318708, 5974, 1195, 38, 150, "Text"],
Cell[319906, 6014, 111437, 1829, 242, "Text"],
Cell[431346, 7845, 354, 11, 33, "Text"],

Cell[CellGroupData[{
Cell[431725, 7860, 113, 2, 33, "Text"],
Cell[431841, 7864, 154, 5, 33, "Text"],
Cell[431998, 7871, 499, 10, 165, "Input"],
Cell[432500, 7883, 132, 5, 33, "Text"],
Cell[432635, 7890, 597, 10, 145, "Input"],
Cell[433235, 7902, 1712, 33, 269, "Input"]
}, Closed]],
Cell[434962, 7938, 2517, 68, 147, "Text"],
Cell[437482, 8008, 60486, 994, 242, "Text"],
Cell[497971, 9004, 349, 11, 33, "Text"],
Cell[498323, 9017, 2720, 75, 531, "Text"],

Cell[CellGroupData[{
Cell[501068, 9096, 115, 2, 33, "Text"],
Cell[501186, 9100, 487, 10, 168, "Input"],
Cell[501676, 9112, 132, 5, 33, "Text"],
Cell[501811, 9119, 1074, 20, 240, "Input"],
Cell[502888, 9141, 1680, 33, 269, "Input"],
Cell[504571, 9176, 199, 6, 71, "Text"],
Cell[504773, 9184, 1128, 20, 255, "Input"],
Cell[505904, 9206, 2669, 52, 373, "Input"]
}, Closed]],
Cell[508588, 9261, 2672, 72, 151, "Text"],
Cell[511263, 9335, 40291, 663, 242, "Text"],
Cell[551557, 10000, 369, 11, 33, "Text"],
Cell[551929, 10013, 4479, 108, 897, "Text"],

Cell[CellGroupData[{
Cell[556433, 10125, 115, 2, 33, "Text"],
Cell[556551, 10129, 567, 11, 150, "Input"],
Cell[557121, 10142, 132, 5, 33, "Text"],
Cell[557256, 10149, 976, 19, 240, "Input"],
Cell[558235, 10170, 1691, 33, 269, "Input"],
Cell[559929, 10205, 199, 6, 71, "Text"],
Cell[560131, 10213, 990, 19, 255, "Input"],
Cell[561124, 10234, 2577, 49, 373, "Input"]
}, Closed]],
Cell[563716, 10286, 732, 19, 109, "Text",
  Evaluatable->False],
Cell[564451, 10307, 95651, 1571, 242, "Text"],
Cell[660105, 11880, 344, 11, 33, "Text"],
Cell[660452, 11893, 2837, 81, 186, "Text"],
Cell[663292, 11976, 1822, 40, 448, "Text"],
Cell[665117, 12018, 1082, 21, 282, "Text"],
Cell[666202, 12041, 889, 22, 156, "Text"],

Cell[CellGroupData[{
Cell[667116, 12067, 115, 2, 33, "Text"],
Cell[667234, 12071, 482, 10, 145, "Input"],
Cell[667719, 12083, 132, 5, 33, "Text"],
Cell[667854, 12090, 709, 11, 165, "Input"],
Cell[668566, 12103, 1663, 33, 269, "Input"]
}, Closed]],
Cell[670244, 12139, 759, 19, 132, "Text"],
Cell[671006, 12160, 81234, 1334, 242, "Text"],
Cell[752243, 13496, 363, 11, 33, "Text"],

Cell[CellGroupData[{
Cell[752631, 13511, 115, 2, 33, "Text"],
Cell[752749, 13515, 894, 18, 256, "Input"],
Cell[753646, 13535, 132, 5, 33, "Text"],
Cell[753781, 13542, 753, 12, 178, "Input"],
Cell[754537, 13556, 1690, 34, 269, "Input"]
}, Closed]],
Cell[756242, 13593, 290, 7, 30, "Text"],
Cell[756535, 13602, 286, 7, 33, "Text"],
Cell[756824, 13611, 278, 6, 33, "Text"],
Cell[757105, 13619, 294, 7, 33, "Text"],
Cell[757402, 13628, 309, 7, 33, "Text"],
Cell[757714, 13637, 307, 7, 33, "Text"],
Cell[758024, 13646, 291, 7, 33, "Text"],
Cell[758318, 13655, 288, 7, 33, "Text"],
Cell[758609, 13664, 257, 5, 33, "Text"],
Cell[758869, 13671, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

