(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     38172,       1164]*)
(*NotebookOutlinePosition[     39786,       1219]*)
(*  CellTagsIndexPosition[     39710,       1213]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["Chapter 12  Fourier Series and the Laplace Transform",
  
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[StyleBox["11.1  Fourier Series",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  StyleBox["Overview",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "\n\n\t",
  "In this chapter we show how ",
  ButtonBox["Fourier",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Fourier.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " Series, the Fourier Transform, and the ",
  ButtonBox["Laplace",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Laplace.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " Transform are related to the study of complex analysis.  ",
  "We develop the Fourier series representation of a real-valued function \
U(t) of the real variable t.  We then discuss complex Fourier series and \
Fourier transforms.  Finally, we develop the Laplace transform and the \
complex variable technique for finding its inverse. In this chapter we focus \
on applying these ideas to solving problems involving real-valued functions, \
so many of the theorems throughout are stated without proof."
}], "Text"],

Cell[TextData[{
  "\tLet U(t) be a real-valued function that is periodic with period  ",
  Cell[BoxData[
      \(2  \[Pi]\)]],
  ",  that is\n\n\t\t\t",
  Cell[BoxData[
      \(U \((t + 2  \[Pi])\) = U \((t)\)\ \ for\ all\ \ t\)]],
  ".\n\nFamiliar examples of real functions that have period  ",
  Cell[BoxData[
      \(2  \[Pi]\)]],
  ",  are ",
  Cell[BoxData[
      \(cos \((nt)\)\)]],
  " and ",
  Cell[BoxData[
      \(sin \((nt)\)\)]],
  ", where n is an integer.  This raises the question whether any periodic \
function can be represented by a sum of terms involving ",
  Cell[BoxData[
      \(a\_n\ cos \((nt)\)\)]],
  " and ",
  Cell[BoxData[
      \(b\_n\ sin \((nt)\)\)]],
  ", where ",
  Cell[BoxData[
      RowBox[{\(a\_n\), "  ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], "  ", \(b\_n\)}]]],
  " are real constants.  As we shall soon see, the answer to this question is \
often yes."
}], "Text"],

Cell[TextData[{
  StyleBox["Definition 12.1 (Piecewise Continuous).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " The function ",
  Cell[BoxData[
      \(U \((t)\)\)]],
  " is ",
  StyleBox["piecewise continuous",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " on the closed interval [a,b], if there exists values ",
  Cell[BoxData[
      \(t\_0, t\_1,  ... , t\_n\)]],
  " with ",
  Cell[BoxData[
      \(a = \(\(t\_0 < t\_1 <  ... \) < t\_n = b\)\)]],
  " such that U is continuous in each of the open intervals ",
  Cell[BoxData[
      \(t\_\(k - 1\) < t < t\_k\)]],
  ", for ",
  Cell[BoxData[
      \(k = 1, 2,  ... , n\)]],
  " and has left-hand and right-hand limits at each of the values ",
  Cell[BoxData[
      \(t\_k\)]],
  ", for ",
  Cell[BoxData[
      \(k = 0, 1, 2,  ... , n\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Definition 12.2 (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Fourier Series",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/FourierSeries.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " If ",
  Cell[BoxData[
      \(U \((t)\)\)]],
  " is periodic with period ",
  Cell[BoxData[
      \(2  \[Pi]\)]],
  " and is piecewise continuous on",
  Cell[BoxData[
      \(\([\(-\[Pi]\), \[Pi]]\)\)]],
  ", then the ",
  StyleBox["Fourier Series",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " ",
  Cell[BoxData[
      \(S \((t)\)\)]],
  " for ",
  Cell[BoxData[
      \(U \((t)\)\)]],
  " is\n\n\t\t",
  Cell[BoxData[
      \(S \((t)\) = 
        a\_0\/2 + \[Sum]\+\(j = 1\)\%\[Infinity]\((\(a\_j\) 
                  cos \((j\ t)\) + \(b\_j\) sin \((j\ t)\))\)\)]],
  ",\n\nwhere the coefficients ",
  Cell[BoxData[
      RowBox[{\(a\_j\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(b\_j\)}]]],
  "  are given by the so-called ",
  StyleBox["Euler's formulae",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ":  \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(a\_j\), "=", 
          RowBox[{
            RowBox[{\(1\/\[Pi]\), 
              RowBox[{\(\[Integral]\_\(-\[Pi]\)\%\[Pi]\), 
                RowBox[{
                "U", \((t)\), "cos", \((j\ t)\), \(\[DifferentialD]t\), "  ", 
                  
                  StyleBox["for",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], " ", "j"}]}]}], "=", "0"}]}], 
        ",", "1", ",", "..."}]]],
  ",  \n\n\t\tand  \n\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(b\_j\), "=", 
          RowBox[{
            RowBox[{\(1\/\[Pi]\), 
              RowBox[{\(\[Integral]\_\(-\[Pi]\)\%\[Pi]\), 
                RowBox[{
                "U", \((t)\), "sin", \((j\ t)\), \(\[DifferentialD]t\), "  ", 
                  
                  StyleBox["for",
                    FontFamily->"Times New Roman",
                    FontSize->12,
                    FontWeight->"Plain",
                    FontSlant->"Plain",
                    FontColor->GrayLevel[0],
                    FontVariations->{"Underline"->False,
                    "StrikeThrough"->False}], " ", "j"}]}]}], "=", "1"}]}], 
        ",", "2", ",", "..."}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Theorem 12.1 (Fourier Expansion).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " Assume that ",
  Cell[BoxData[
      \(S \((t)\)\)]],
  " is the Fourier Series for ",
  Cell[BoxData[
      \(U \((t)\)\)]],
  ". If ",
  Cell[BoxData[
      RowBox[{"U", \((t)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(U'\), \((t)\)}]]],
  " are piecewise continuous on ",
  Cell[BoxData[
      \(\([\(-\[Pi]\), \[Pi]]\)\)]],
  ", then ",
  Cell[BoxData[
      \(S \((t)\)\)]],
  " is convergent for all ",
  Cell[BoxData[
      \(t\ \[Epsilon][\(-\[Pi]\), \[Pi]]\)]],
  ".  \n\nThe relation ",
  Cell[BoxData[
      \(U \((t)\) = S \((t)\)\)]],
  " holds for all ",
  Cell[BoxData[
      \(t\ \[Epsilon][\(-\[Pi]\), \[Pi]]\)]],
  "where U is continuous. If ",
  Cell[BoxData[
      \(t = a\)]],
  " is a point of discontinuity of U, then\n\n\t \t",
  Cell[BoxData[
      \(S \((a)\) = \(U \((\(a\^-\))\)\  + \ U \((\(a\^+\))\)\)\/2\)]],
  ",  \n \n where ",
  Cell[BoxData[
      RowBox[{"U", \((\(a\^-\))\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "U", \((\(a\^+\))\)}]]],
  " denote the left-hand and right-hand limits, respectively.  With this \
understanding, we have the Fourier Series expansion:\n \n\t\t",
  Cell[BoxData[
      \(U \((t)\)\  = \ 
        a\_0\/2 + \[Sum]\+\(j = 1\)\%\[Infinity]\((\(a\_j\) 
                  cos \((j\ t)\) + \(b\_j\) sin \((j\ t)\))\)\)]],
  " .  \n"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\
\tA complete discussion of the details of the proof of Theorem 12.1 can be \
found in some advanced texts.  See for example, John W. Dettman, Chapter 8 in \
\"Applied Complex Variables\", The Macmillan Company, New York, 1965.\
\>", "Text"],

Cell[TextData[StyleBox["Theorem 12.1 is mentioned in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Method I. Fourier Series - Trigonometric Polynomials.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Execute the following sells to set up the procedure S[n,t] for finding \
the Fourier Series - Trigonometric Polynomial of degree n."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[a, b, j, n, t, u];\)\ \ \), "\n", 
    \(\(a[
          j_]\  = \ \(1\/\[Pi]\) \(\[Integral]\_\(-\[Pi]\)\%\[Pi] u[t] 
              Cos[j\ t] \[DifferentialD]t\);\)\ \ \), "\n", 
    \(\(b[
          j_]\  = \ \(1\/\[Pi]\) \(\[Integral]\_\(-\[Pi]\)\%\[Pi] u[t] 
              Sin[j\ t] \[DifferentialD]t\);\)\ \ \), "\n", 
    \(\(FS[n_, t_] := 
        a[0]\/2 + \[Sum]\+\(j = 1\)\%n\((a[j] Cos[j\ t] + 
                b[j] Sin[j\ t])\);\)\ \ \), "\n", 
    \(\(Print[\*"\"\<   \!\(a\_n\) = \>\"", a[j]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<   \!\(b\_n\) = \>\"", b[j]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_n\)[t] = \!\(a[0]\/2\)+\!\(\[Sum]\+\(j = \
1\)\%n\)(a[j]Cos[j t]+b[j]Sin[j t]\>\""];\)\ \ \)}], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 12.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Fourier Series expansion of  ",
  Cell[BoxData[
      \(u \((t)\) = 
        t\/2\ \ for\ \  - \[Pi] \[LessEqual] t \[LessEqual] \[Pi]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the function u[t], and for illustration construct the Fourier Series - \
Trigonometric Polynomial of degree n = 9.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[S, S9, t, u];\)\ \ \), "\n", 
    \(\(u[t_]\  = \ t\/2;\)\ \ \), "\[IndentingNewLine]", 
    \(\(S9[t_]\  = \ FS[9, t];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\< u[t] = \>", u[t]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_9\)[t] = \>\"", 
        S9[t]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nWe can also get this result using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in procedure FourierTrigSeries.",
  StyleBox["",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Calculus`FourierTransform`\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(S9[t_]\  = \ 
        Expand[FourierTrigSeries[u[t], t, 9, 
            FourierParameters \[Rule] {0, 1\/\(2  \[Pi]\)}]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_9\)[t] = \>\"", 
        S9[t]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nA graph of  ",
  Cell[BoxData[
      \(u[t], S\_1[t], S\_2[t], and\ \ S\_3[t]\)]],
  "  is given below."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(S1[t_]\  = \ FS[1, t];\)\ \ \), "\n", 
    \(\(S2[t_]\  = \ FS[2, t];\)\ \ \), "\n", 
    \(\(S3[t_]\  = \ FS[3, t];\)\ \ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{u[t], S1[t], S2[t], S3[t]}, {t, \(-Pi\), Pi}, 
        PlotRange \[Rule] {{\(-\[Pi]\), \[Pi]}, {\(-\[Pi]\)\/2, \[Pi]\/2}}, 
        AspectRatio \[Rule] 1\/2, 
        PlotStyle \[Rule] {Magenta, Red, Green, Blue}, 
        AxesLabel \[Rule] {"\<t\>", "\<s\>"}, 
        Ticks \[Rule] {Range[\(-\[Pi]\), \[Pi], \[Pi]\/2], 
            Range[\(-\[Pi]\)\/2, \[Pi]\/2, \[Pi]\/2]}];\)\ \ \), "\n", 
    \(\(Print["\< u[t] = \>", u[t]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_1\)[t] = \>\"", S1[t]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_2\)[t] = \>\"", S2[t]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_3\)[t] = \>\"", 
        S3[t]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nThe general term for the series is  ",
  Cell[BoxData[
      \(\((\(-1\))\)\^\(n - 1\)\/n\ Sin[n\ t]\)]],
  ".  We can sum up 9 terms and see that it agrees with ",
  Cell[BoxData[
      \(S\_9[t]\)]],
  ".\nThen we can sum the infinite series  ",
  Cell[BoxData[
      \(S[
          t] = \[Sum]\+\(j = 1\)\%\[Infinity]\((\(-1\))\)\^\(j - 1\)\/j\ Sin[
              j\ t]\)]],
  "  and see if it agrees with  ",
  Cell[BoxData[
      \(u[t] = t\/2\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(s9 = \ \[Sum]\+\(j = 1\)\%9\((\(-1\))\)\^\(j - 1\)\
\/j\ Sin[j\ t];\)\ \ \), "\[IndentingNewLine]", 
    \(\(S[
          t_] = \ \[Sum]\+\(j = 1\)\%\[Infinity]\((\(-1\))\)\^\(j - 1\)\/j\ \
Sin[j\ t];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \!\(S\_9\)[t] = \!\(\[Sum]\+\(j = \
1\)\%9\)\!\(\((\(-1\))\)\^\(j - 1\)\/j\) Sin[j t] ? \>\"", 
        S9[t] \[Equal] s9];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<S[t] = \!\(\[Sum]\+\(j = \
1\)\%\[Infinity]\)\!\(\((\(-1\))\)\^\(j - 1\)\/j\) Sin[j t]\>\""];\)\ \ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<S[t] = \>", S[t]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[t] = \>", u[t]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\

We can plot  S[t]  to see what it looks like.\
\>", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{S[t], S1[t], S2[t], S3[t]}, {t, \(-3\) \[Pi], 3  \[Pi]}, \n
        PlotRange \[Rule] {{\(-3\) \[Pi], 
              3  \[Pi]}, {\(-\[Pi]\)\/2, \[Pi]\/2}}, 
        AspectRatio \[Rule] 1\/2, 
        PlotStyle \[Rule] {Magenta, Red, Green, Blue}, 
        AxesLabel \[Rule] {"\<t\>", "\<s\>"}, 
        Ticks \[Rule] {Range[\(-2\) \[Pi], 2  \[Pi], \[Pi]], 
            Range[\(-\[Pi]\)\/2, \[Pi]\/2, \[Pi]\/2]}];\)\ \ \), "\n", 
    \(\(Print["\< S[t] = \>", S[t]];\)\ \ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(S\_1\)[t] = \>\"", S1[t]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_2\)[t] = \>\"", S2[t]];\)\ \ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_3\)[t] = \>\"", 
        S3[t]];\)\ \ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nTherefore,  ",
  Cell[BoxData[
      \(S[t] = 
        1\/2\ \[ImaginaryI]\ \((Log[
                1 + \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ t\)] - 
              Log[1 + \[ExponentialE]\^\(\[ImaginaryI]\ t\)])\)\)]],
  " is the periodic extension of  ",
  Cell[BoxData[
      \(u[t] = t\/2\)],
    AspectRatioFixed->True],
  "."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 12.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(U \((t)\)\ \ and\ \ V \((t)\)\)]],
  "  have Fourier series representations, then their sum  ",
  Cell[BoxData[
      \(W \((t)\) = U \((t)\) + V \((t)\)\)]],
  "  has a Fourier series representation, and the Fourier coefficients of  W  \
are obtained by adding the corresponding coefficients of  U  and  V."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.2 is left for the reader in the \
book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 12.3 (Fourier Cosine Series).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " Assume that ",
  Cell[BoxData[
      \(U \((t)\)\)]],
  " is an even function and has period ",
  Cell[BoxData[
      \(2  \[Pi]\)]],
  ". If ",
  Cell[BoxData[
      RowBox[{"U", \((t)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(U'\), \((t)\)}]]],
  " are piecewise continuous, the Fourier series for   ",
  Cell[BoxData[
      \(U \((t)\)\)]],
  "  involves only the cosine terms,  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{
          RowBox[{"i", ".", "e", ".", "  ", 
            SubscriptBox[
              StyleBox["b",
                FontSize->14], "j"]}], "=", 
          RowBox[{"0", "  ", 
            StyleBox["for",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox[" ",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], 
            StyleBox["all",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", "j"}]}], ")"}]]],
  ",  and we write  \n\n\t\t",
  Cell[BoxData[
      \(U \((t)\) = 
        a\_0\/2 + \[Sum]\+\(j = 1\)\%\[Infinity]\( a\_j\) cos \((j\ t)\)\)]],
  ",  \n\nwhere ",
  Cell[BoxData[
      \(a\_j = \(\(2\/\[Pi]\) \(\[Integral]\_0\%\[Pi] U \((t)\) 
                cos \((j\ t)\) \[DifferentialD]t\ \ for\ \ j\) = 0\), 
      1,  ... \)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.3 is left for the reader in the \
book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 12.4 (Fourier Sine Series).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " Assume that ",
  Cell[BoxData[
      \(U \((t)\)\)]],
  " is an odd function and has period ",
  Cell[BoxData[
      \(2  \[Pi]\)]],
  ". If ",
  Cell[BoxData[
      RowBox[{"U", \((t)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", \(U'\), \((t)\)}]]],
  " are piecewise continuous, the Fourier series for   ",
  Cell[BoxData[
      \(U \((t)\)\)]],
  "  involves only the sine terms,  ",
  Cell[BoxData[
      RowBox[{"(", 
        RowBox[{
          RowBox[{"i", ".", "e", ".", "  ", 
            SubscriptBox[
              StyleBox["a",
                FontSize->14], "j"]}], "=", \(0\ \ for\ all\ \ j\)}], 
        ")"}]]],
  ",  and we write  \n\n\t\t",
  Cell[BoxData[
      \(U \((t)\) = \[Sum]\+\(j = 1\)\%\[Infinity]\( b\_j\) 
            sin \((j\ t)\)\)]],
  ",  \n\nwhere  ",
  Cell[BoxData[
      \(b\_j = \(\(2\/\[Pi]\) \(\[Integral]\_0\%\[Pi] U \((t)\) 
                sin \((j\ t)\) \[DifferentialD]t\ \ for\ \ j\) = 1\), 
      2,  ... \)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.4 is left for the reader in the \
book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 12.5  (Termwise Integration).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that  ",
  Cell[BoxData[
      \(U \((t)\)\)]],
  "  has the Fourier series representation  \n\n\t  \t",
  Cell[BoxData[
      \(U \((t)\) = 
        a\_0\/2 + \[Sum]\+\(j = 1\)\%\[Infinity]\((\(a\_j\) 
                  cos \((j\ t)\) + \(b\_j\) sin \((j\ t)\))\)\)]],
  ".  \n\nThen the integral  of  ",
  Cell[BoxData[
      \(U \((t)\)\)]],
  "  has a Fourier series representation which can be obtained by termwise \
integration of the Fourier series of  ",
  Cell[BoxData[
      \(U \((t)\)\)]],
  ",  that is  \n\n\t\t",
  Cell[BoxData[
      \(\[Integral]\_0\%t\ 
          U \((\[Tau])\) \[DifferentialD]\[Tau] = \[Sum]\+\(j = 1\)\%\
\[Infinity]\((\((a\_j\  + \ \((\(-1\))\)\^\(j + 1\)\ a\_0)\)\/j\ sin\ \((j\ \
t)\) - \(b\_j\/j\) cos\ \((j\ t)\))\)\)]],
  ",  \n\nwhere we have used the expansion  ",
  Cell[BoxData[
      \(\(\(a\_0\) t\)\/2 = \[Sum]\+\(j = \
1\)\%\[Infinity]\(\(\((\(-1\))\)\^\(j + 1\)\ a\_0\)\/j\) sin\ \((j\ t)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.5 is left for the reader in the \
book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 12.6  (Termwise Differentiation).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Assume that both  ",
  Cell[BoxData[
      \(U \((t)\)\ \ and\ \ U' \((t)\)\)]],
  "  have Fourier series representation and that  \n\n\t\t",
  Cell[BoxData[
      \(U \((t)\) = 
        a\_0\/2 + \[Sum]\+\(j = 1\)\%\[Infinity]\((\(a\_j\) 
                  cos \((j\ t)\) + \(b\_j\) sin \((j\ t)\))\)\)]],
  ".  \n\nThen  ",
  Cell[BoxData[
      \(U' \((t)\)\)]],
  "  can be obtained by termwise differentiation of  ",
  Cell[BoxData[
      \(U \((t)\)\)]],
  ",  that is  \n\n\t\t",
  Cell[BoxData[
      StyleBox[\(U' \((t)\) = \[Sum]\+\(j = 1\)\%\[Infinity]\((j\ b\_j\ cos\ \
\((j\ t)\) - j\ a\_j\ sin\ \((j\ t)\))\)\),
        ShowStringCharacters->True]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.6 is left for the reader in the \
book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["\nMethod II.  Fourier Series - Trigonometric Polynomials.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Modify procedure S[n,t] for finding the Fourier Series - Trigonometric \
Polynomial of degree n to the case of a piecewise continuous function on the \
subintervals  ",
  Cell[BoxData[
      RowBox[{"[", 
        RowBox[{
          RowBox[{\(-\ \[Pi]\), 
            RowBox[{
              StyleBox["(",
                FontColor->GrayLevel[1]], \(\(,\)\(0\)\), 
              StyleBox[")",
                FontColor->GrayLevel[0]]}], "  ", 
            StyleBox["and",
              FontFamily->"Times New Roman",
              FontSize->12,
              FontWeight->"Plain",
              FontSlant->"Plain",
              FontColor->GrayLevel[0],
              FontVariations->{"Underline"->False,
              "StrikeThrough"->False}], "  ", 
            RowBox[{"(", "0", 
              StyleBox[")",
                FontColor->GrayLevel[1]]}]}], ",", "\[Pi]"}], "]"}]]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[a, b, j, n, t, u1, u2];\)\ \), "\n", 
    \(\(a[
          j_]\  = \ \(1\/\[Pi]\) \((\[Integral]\_\(-\[Pi]\)\%0 u2[t] 
                  Cos[j\ t] \[DifferentialD]t\  + \[Integral]\_0\%\[Pi] u1[t] 
                  Cos[j\ t] \[DifferentialD]t)\)\ ;\)\ \), "\n", 
    \(\(b[
          j_]\  = \ \(1\/\[Pi]\) \((\[Integral]\_\(-\[Pi]\)\%0 u2[t] 
                  Sin[j\ t] \[DifferentialD]t\  + \[Integral]\_0\%\[Pi] u1[t] 
                  Sin[j\ t] \[DifferentialD]t)\)\ ;\)\ \), "\n", 
    \(\(TP[n_, t_] := 
        a[0]\/2 + \[Sum]\+\(j = 1\)\%n\((a[j] Cos[j\ t] + 
                b[j] Sin[j\ t])\);\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(a\_n\) = \>\"", a[j]];\)\ \), "\n", 
    \(\(Print[\*"\"\<   \!\(b\_n\) = \>\"", b[j]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(T\_n\)[t] = \!\(a[0]\/2\)+\!\(\[Sum]\+\(j = \
1\)\%n\)(a[j]Cos[j t]+b[j]Sin[j t])\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Example 12.2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  The function  ",
  Cell[BoxData[
      \(u[
          t] = \(\(|\)\(t\)\(|\)\(\ \ \)\(for\ \  - \[Pi] \[LessEqual] 
            t \[LessEqual] \[Pi]\)\)\)]],
  "  has the Fourier series representation  \n\n\t\t\t",
  Cell[BoxData[
      \(T[
          t] = \[Pi]\/2 - \(4\/\[Pi]\) \(\[Sum]\+\(j = 1\)\%\[Infinity] \
Cos[\((2  j\  - \ 1)\) t]\/\((2  j\  - \ 1)\)\^2\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the function u[t], and for illustration construct the Fourier Series - \
Trigonometric Polynomial of degree n = 9.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[T, T9, t];\)\ \), "\n", 
    \(\(u1[t_]\  = \ t;\)\ \), "\[IndentingNewLine]", 
    \(\(u2[t_]\  = \ \(-t\);\)\ \), "\[IndentingNewLine]", 
    \(\(T9[t_]\  = \ TP[9, t];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< u[t] = \>", 
        u1[t], "\<   for  0 \[LessEqual] t \[LessEqual] \[Pi]\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\< u[t] = \>", 
        u2[t], "\<  for -\[Pi] \[LessEqual] t \[LessEqual] 0\>"];\)\ \), "\n\
", 
    \(\(Print[\*"\"\<\!\(T\_9\)[t] = \>\"", 
        T9[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nWe can also get this result using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built in procedure FourierTrigSeries.",
  StyleBox["",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Calculus`FourierTransform`\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(T9[t_]\  = \ 
        Expand[FourierTrigSeries[Abs[t], t, 9, 
            FourierParameters \[Rule] {0, 1\/\(2  \[Pi]\)}]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(T\_9\)[t] = \>\"", 
        T9[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nA graph of  ",
  Cell[BoxData[
      \(u[t], T\_1[t], and\ \ T\_3[t]\)]],
  "  is given below."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(T1[t_]\  = \ TP[1, t];\)\ \), "\n", 
    \(\(T3[t_]\  = \ TP[3, t];\)\ \), "\n", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{Abs[t], T1[t], T3[t]}, {t, \(-\[Pi]\), \[Pi]}, \n
        PlotRange \[Rule] {{\(-\[Pi]\), \[Pi]}, {0, \[Pi]}}, 
        AspectRatio \[Rule] 1\/2, PlotStyle \[Rule] {Magenta, Blue, Green}, 
        AxesLabel \[Rule] {"\<t\>", "\<s\>"}, 
        Ticks \[Rule] {Range[\(-\[Pi]\), \[Pi], \[Pi]\/2], 
            Range[0, \[Pi], \[Pi]\/2]}];\)\ \), "\n", 
    \(\(Print["\< u[t] = \>", Abs[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(T\_1\)[t] = \>\"", T1[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(T\_3\)[t] = \>\"", 
        T3[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nThe general term for the series is  ",
  Cell[BoxData[
      \(Cos[\((2  j\  - \ 1)\)\ t]\/\((2  j\  - \ 1)\)\^2\)]],
  ".  We can sum up 5 terms and see that it agrees with  ",
  Cell[BoxData[
      \(T\_9[t]\)]],
  ".\nThen we can sum the infinite series  ",
  Cell[BoxData[
      \(T[
          t] = \[Pi]\/2 - \(4\/\[Pi]\) \(\[Sum]\+\(j = 1\)\%\[Infinity] \
Cos[\((2  j\  - \ 1)\) t]\/\((2  j\  - \ 1)\)\^2\)\)]],
  "  and see if it agrees with  ",
  Cell[BoxData[
      \(u[t] = \(\(|\)\(t\)\(|\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(t9 = 
        Expand[\[Pi]\/2 - \(4\/\[Pi]\) \(\[Sum]\+\(j = 1\)\%5 Cos[\((2  j - \
1)\) t]\/\((2  j - 1)\)\^2\)];\)\ \), "\[IndentingNewLine]", 
    \(\(T[
          t_] = \[Pi]\/2 - \(4\/\[Pi]\) \(\[Sum]\+\(j = 1\)\%\[Infinity] Cos[\
\((2  j - 1)\) t]\/\((2  j - 1)\)\^2\);\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Does \!\(T\_9\)[t] = \!\(\[Pi]\/2\)-\!\(4\/\[Pi]\)\!\(\
\[Sum]\+\(j = 1\)\%5\)\!\(Cos[\((2  j - 1)\) t]\/\((2  j - 1)\)\^2\) ? \>\"", 
        T9[t] \[Equal] t9];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<T[t] = \!\(\[Pi]\/2\)-\!\(4\/\[Pi]\)\!\(\[Sum]\+\(j = \
1\)\%\[Infinity]\)\!\(Cos[\((2  j - 1)\) t]\/\((2  j - 1)\)\^2\)\>\""];\)\ \
\), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<T[t] = \>", T[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<u[t] = \>", Abs[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\

We can plot  T[t]  to see what it looks like.\
\>", "Text"],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{T[t], T1[t], 
          T3[t]}, {t, \(\(-5\) \[Pi]\)\/2, \(5  \[Pi]\)\/2}, \n
        PlotRange \[Rule] {{\(\(-5\) \[Pi]\)\/2, \(5  \[Pi]\)\/2}, {0, \
\[Pi]}}, AspectRatio \[Rule] 1\/2, PlotStyle \[Rule] {Magenta, Blue, Green}, 
        AxesLabel \[Rule] {"\<t\>", "\<s\>"}, 
        Ticks \[Rule] {Range[\(-2\) \[Pi], 2  \[Pi], \[Pi]], 
            Range[0, \[Pi], \[Pi]\/2]}];\)\ \), "\n", 
    \(\(Print["\< T[t] = \>", T[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(T\_1\)[t] = \>\"", T1[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(T\_3\)[t] = \>\"", 
        T3[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nTherefore,  ",
  Cell[BoxData[
      \(T[
          t] = \[Pi]\/2 - \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ t\)\ \
\((LerchPhi[\[ExponentialE]\^\(\(-2\)\ \[ImaginaryI]\ t\), 2, 1\/2] + \
\[ExponentialE]\^\(2\ \[ImaginaryI]\ t\)\ LerchPhi[\[ExponentialE]\^\(2\ \
\[ImaginaryI]\ t\), 2, 1\/2])\)\)\/\(2\ \[Pi]\)\)]],
  " is the periodic extension of  ",
  Cell[BoxData[
      \(u[t] = \(\(|\)\(t\)\(|\)\)\)],
    AspectRatioFixed->True],
  "."
}], "Text"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Upgrade: This module is scheduled for \
revision in 2006.",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradMod.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Fourier Series and Transform",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/FourierTransformBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Dirichlet Problem",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/DirichletProblemBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Laplace Transform",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/LaplaceTransformBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1017, 621},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[11024, 349, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[18996, 581, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[22042, 679, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[24167, 753, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[26055, 814, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[27656, 869, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 39007, 1187}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 145, 3, 33, "Text"],
Cell[2250, 67, 110, 2, 33, "Text"],
Cell[2363, 71, 1059, 26, 128, "Text"],
Cell[3425, 99, 1138, 36, 128, "Text"],
Cell[4566, 137, 898, 32, 71, "Text",
  Evaluatable->False],
Cell[5467, 171, 2987, 92, 232, "Text",
  Evaluatable->False],
Cell[8457, 265, 1962, 62, 229, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[10444, 331, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[10592, 337, 250, 4, 52, "Text"],
Cell[10845, 343, 176, 4, 33, "Text",
  Evaluatable->False],
Cell[11024, 349, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[11384, 361, 340, 8, 30, "Text",
  Evaluatable->False],
Cell[11727, 371, 805, 16, 226, "Input",
  InitializationCell->True],
Cell[12535, 389, 324, 11, 36, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[12884, 404, 112, 2, 33, "Text"],
Cell[12999, 408, 192, 5, 33, "Text",
  Evaluatable->False],
Cell[13194, 415, 394, 8, 164, "Input"],
Cell[13591, 425, 281, 10, 53, "Text",
  Evaluatable->False],
Cell[13875, 437, 383, 9, 104, "Input"],
Cell[14261, 448, 185, 7, 52, "Text",
  Evaluatable->False],
Cell[14449, 457, 982, 18, 276, "Input"],
Cell[15434, 477, 494, 16, 83, "Text"],
Cell[15931, 495, 879, 16, 343, "Input"],
Cell[16813, 513, 70, 3, 52, "Text"],
Cell[16886, 518, 848, 15, 217, "Input"],
Cell[17737, 535, 364, 12, 55, "Text"]
}, Closed]],
Cell[18116, 550, 507, 14, 49, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[18648, 568, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[18796, 574, 197, 5, 33, "Text",
  Evaluatable->False],
Cell[18996, 581, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[19356, 593, 2313, 69, 131, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[21694, 666, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[21842, 672, 197, 5, 33, "Text",
  Evaluatable->False],
Cell[22042, 679, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[22402, 691, 1392, 45, 128, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[23819, 740, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[23967, 746, 197, 5, 33, "Text",
  Evaluatable->False],
Cell[24167, 753, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[24527, 765, 1155, 32, 210, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[25707, 801, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[25855, 807, 197, 5, 33, "Text",
  Evaluatable->False],
Cell[26055, 814, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[26415, 826, 868, 26, 147, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[27308, 856, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[27456, 862, 197, 5, 33, "Text",
  Evaluatable->False],
Cell[27656, 869, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[28016, 881, 1096, 30, 68, "Text",
  Evaluatable->False],
Cell[29115, 913, 999, 19, 248, "Input",
  InitializationCell->True],
Cell[30117, 934, 547, 17, 76, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[30689, 955, 112, 2, 33, "Text"],
Cell[30804, 959, 192, 5, 33, "Text",
  Evaluatable->False],
Cell[30999, 966, 606, 13, 190, "Input"],
Cell[31608, 981, 281, 10, 53, "Text",
  Evaluatable->False],
Cell[31892, 993, 381, 9, 104, "Input"],
Cell[32276, 1004, 176, 7, 52, "Text",
  Evaluatable->False],
Cell[32455, 1013, 816, 15, 257, "Input"],
Cell[33274, 1030, 549, 16, 81, "Text"],
Cell[33826, 1048, 1010, 17, 317, "Input"],
Cell[34839, 1067, 70, 3, 52, "Text"],
Cell[34912, 1072, 721, 13, 210, "Input"],
Cell[35636, 1087, 475, 13, 62, "Text"]
}, Closed]],
Cell[36126, 1103, 331, 8, 30, "Text"],
Cell[36460, 1113, 290, 7, 33, "Text"],
Cell[36753, 1122, 302, 7, 33, "Text"],
Cell[37058, 1131, 291, 7, 33, "Text"],
Cell[37352, 1140, 291, 7, 33, "Text"],
Cell[37646, 1149, 257, 5, 33, "Text"],
Cell[37906, 1156, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

