(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     43012,       1093]*)
(*NotebookOutlinePosition[     44016,       1129]*)
(*  CellTagsIndexPosition[     43940,       1123]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["12.3  Vibrations in Mechanical Systems",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tConsider a spring that resists compression as well as extension, that is \
suspended vertically from a fixed support, and a body of mass  m  that is \
attached at the lower end of the spring.  We make the assumption that the \
mass  m  is much larger than the mass of the spring so that we can neglect \
the mass of the spring.  If there is no motion then the system is in ",
  StyleBox["static equilibrium",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ".  If the mass is pulled down further and released, then it will undergo \
an oscillatory motion.\n\n\tSuppose that there is no friction to slow down \
the motion of the mass, then we say that the system is ",
  StyleBox["undamped",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ".  We will determine the ",
  ButtonBox["Simple Harmonic Motion",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/SimpleHarmonicMotion.html"], None},
    ButtonStyle->"Hyperlink"],
  " of this mechanical system by considering the forces acting on the mass \
during the motion.  This will lead to a differential equation relating the \
displacement as a function of time.  For details see Section 12.3 in the \
textbook.  The undamped mechanical system is governed by the linear \
differential equation\n\n\t\t\t",
  Cell[BoxData[
      \(m\ U'' \((t)\)\  + \ k\ U \((t)\)\  = \ 0\)]],
  ",  \n\nand the general solution to this D. E. is known to be  ",
  Cell[BoxData[
      \(U \((t)\)\  = \ 
        A\ cos \((\[Omega]\ t)\) + 
          B\ sin \((\[Omega]\ t)\), \ \ where\ \ \[Omega] = \@\(k\/m\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\tIf we consider frictional forces that slow down the motion of the mass, \
then we say that the system is ",
  StyleBox["damped",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ".  This is visualized by connecting a dashpot (or shock adsorber) to the \
mass.  For small velocities it is assumed that the frictional force is \
proportional to velocity.  The damping constant  c  must be positive.  For \
details see Section 12.3 in the textbook.  The ",
  ButtonBox["Damped Mechanical Motion",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/DampedSimpleHarmonicMotion.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  " is governed by the linear differential equation\n\n\t\t\t",
  Cell[BoxData[
      \(m\ U'' \((t)\)\  + \ c\ U' \((t)\)\  + \ k\ U \((t)\)\  = \ 0\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\tThe two cases mentioned above are called ",
  StyleBox["free vibrations",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " because all the forces that affect the motion of the system are internal \
to the system.  We extend our analysis to cover the case in which an external \
force  F(t)  acts on the mass.  Such a force might occur from vibrations of \
the support to which the top of the spring is attached, or from the effect of \
a magnetic field on a mass made of iron.  For details see Section 12.3 in the \
textbook in the textbook.  The forced motion of the mechanical system \
satisfies the nonhomogeneous linear differential equation  \n\n\t\t\t",
  Cell[BoxData[
      \(m\ U'' \((t)\)\  + \ c\ U' \((t)\)\  + \ k\ U \((t)\)\  = \ 
        F \((t)\)\)]],
  ".  \n\nThe function  F(t)  is called the ",
  StyleBox["input",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " or ",
  StyleBox["driving force",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " and the solution  U(t)  is called the ",
  StyleBox["output",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " or ",
  StyleBox["response",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ".  Of particular interest are periodic inputs  F(t)  that can be \
represented by Fourier Series. "
}], "Text"],

Cell[TextData[{
  "\tFor damped mechanical systems that are driven by a periodic input  F(t), \
 the general solution involves a transient part that vanishes as  ",
  Cell[BoxData[
      \(t\  \[Rule] \ \(+\[Infinity]\)\)]],
  ",  and a steady state part that is periodic.  The transient part of the \
solution  ",
  Cell[BoxData[
      \(\(U\_h\) \((t)\)\)]],
  "  is found by solving the homogeneous differential equation\n\n\t\t\t",
  Cell[BoxData[
      \(m\ \(U\_h\%\(\(\ \)\(''\)\)\) \((t)\)\  + \ 
          c\ \(U\_h\%\(\(\ \)\('\)\)\) \((t)\)\  + \ 
          k\ \(U\_h\) \((t)\)\  = \ 0\)]],
  ".  \n\nThis D. E.  leads to the characteristic equation  ",
  Cell[BoxData[
      \(m\ \[Lambda]\^2\  + \ c\ \[Lambda]\  + \ k\  = \ 0\)]],
  ",  which has roots  ",
  Cell[BoxData[
      \(\[Lambda]\  = \ \(\(-\ c\)\ \  \[PlusMinus] \ \ \@\(c\^2\ \  - \ \ 4  \
m\ k\)\)\/\(2  m\)\)]],
  ".  The constants  m, c, and k  are all positive, and there are three cases \
to consider.\n\n\tIf  ",
  Cell[BoxData[
      \(c\^2\ \  - \ \ 4  m\ k\  > 0\)]],
  ", then the roots are real and distinct, and since  ",
  Cell[BoxData[
      \(\@\(c\^2\ \  - \ \ 4  m\ k\) < c\)]],
  ", it follows that the roots  ",
  Cell[BoxData[
      \(\[Lambda]\_1\ \ and\ \ \[Lambda]\_2\)]],
  " are negative real numbers.  Thus for this case we have \n\n\t\t\t",
  Cell[BoxData[
      \(\(U\_h\) \((t)\)\  = \ \(A\_1\) \[ExponentialE]\^\(\(\[Lambda]\_1\) t\
\)\  + \ \(A\_2\) \[ExponentialE]\^\(\(\[Lambda]\_2\) t\)\)]],
  ",  and  ",
  Cell[BoxData[
      \(lim\+\(t\  \[Rule] \ \(+\[Infinity]\)\)\ \(U\_h\) \((t)\) = 0\)]],
  ".\n\nIf  ",
  Cell[BoxData[
      \(c\^2\ \  - \ \ 4  m\ k\  = 0\)]],
  ", then the roots are real and equal, ",
  Cell[BoxData[
      \(\[Lambda]\_1\  = \ \(\[Lambda]\_2 = \[Lambda]\)\)]],
  ",  where ",
  Cell[BoxData[
      \(\[Lambda]\)]],
  "  is a negative real number, and for this case we have \n\n\t\t\t",
  Cell[BoxData[
      \(\(U\_h\) \((t)\)\  = \ \(A\_1\) \[ExponentialE]\^\[Lambda]t\  + \ \(A\
\_2\) t\ \[ExponentialE]\^\[Lambda]t\)]],
  ",  and  ",
  Cell[BoxData[
      \(lim\+\(t\  \[Rule] \ \(+\[Infinity]\)\)\ \(U\_h\) \((t)\) = 0\)]],
  ".\n\nIf  ",
  Cell[BoxData[
      \(c\^2\ \  - \ \ 4  m\ k\  < 0\)]],
  ", then the roots are complex conjugates,  ",
  Cell[BoxData[
      \(\[Lambda] = \(-\ \[Alpha]\)\  \[PlusMinus] \ \[ImaginaryI]\ \
\[Beta]\)]],
  ",  where  ",
  Cell[BoxData[
      \(\[Alpha]\ \ and\ \ \[Beta]\)]],
  "  are positive real number, and it follows that\n\n\t\t\t",
  Cell[BoxData[
      \(\(U\_h\) \((t)\)\  = \ \(A\_1\) \(\[ExponentialE]\^\(\(-\ \[Alpha]\)\ \
t\)\) cos \((\[Beta]\ t)\)\  + \ \(A\_2\) \[ExponentialE]\^\(\(-\ \[Alpha]\)\ \
t\)\ sin \((\[Beta]\ t)\)\)]],
  ",  and  ",
  Cell[BoxData[
      \(lim\+\(t\  \[Rule] \ \(+\[Infinity]\)\)\ \(U\_h\) \((t)\) = 0\)]],
  ".\n\nIn all three cases, we see that the homogeneous solution  ",
  Cell[BoxData[
      \(\(U\_h\) \((t)\)\)]],
  "  decays to  0  as  ",
  Cell[BoxData[
      \(t\  \[Rule] \ \(+\[Infinity]\)\)]],
  ".  \n\n\tThe steady state solution  ",
  Cell[BoxData[
      \(\(U\_p\) \((t)\)\)]],
  "  can be obtained by representing  ",
  Cell[BoxData[
      \(\(U\_p\) \((t)\)\)]],
  "  by its Fourier series and substituting  ",
  Cell[BoxData[
      \(\(U\_p\%\(\(\ \)\(''\)\)\) \((t)\), \(U\_p\%\(\(\ \)\('\)\)\) \
\((t)\), \ and\ \ \(U\_p\) \((t)\)\)]],
  "  into the nonhomogeneous differential equation and solving the resulting \
system for the Fourier coefficients of  ",
  Cell[BoxData[
      \(\(U\_p\) \((t)\)\)]],
  ".  The ",
  StyleBox["general solution",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " to the nonhomogeneous linear differential equation is  \n\n\t\t\t",
  Cell[BoxData[
      \(U \((t)\)\  = \ \(U\_h\) \((t)\)\  + \ \(U\_p\) \((t)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["\n",
    FontWeight->"Bold"],
  StyleBox["Example 12.4.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the general solution to  ",
  Cell[BoxData[
      \(U'' \((t)\) + 2\ U' \((t)\) + U \((t)\) = F \((t)\)\)]],
  ",  where F(t) is given by the Fourier series  ",
  Cell[BoxData[
      \(F[
          t] = \[Sum]\+\(k = 1\)\%\[Infinity] Cos[\((2  k\  - \ 1)\) t]\/\((2 \
 k\  - \ 1)\)\^2\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.4.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
First, find the transient solution to the differential equation.\
\>", "Text"],

Cell[BoxData[{
    \(\(c = \(U = \(t = 0\)\);\)\), "\[IndentingNewLine]", 
    \(\(Remove[c, U, t];\)\ \), "\n", 
    \(\(de = \(U''\)[t] + 2\ \(U'\)[t] + U[t] \[Equal] 0;\)\ \), "\n", 
    \(\(solset = DSolve[de, U[t], t];\)\ \), "\[IndentingNewLine]", 
    \(\(Uh[t_] = 
        ReplaceAll[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), {C[1] \[Rule] c\_1, 
            C[2] \[Rule] c\_2}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The transient solution to the D.E. is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(U\_h\)[t] = \>\"", 
        Uh[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\

Next, use Fourier series to construct the steady state solution to the \
differential equation.  Enter the formula for the n-th terms T[n,t] and \
F[n,t] of the Fourier Series for U[t] and F[t], respectively.  Then form the \
equation relating the n-terms and the equations involving Cos[n t] and Sin[n \
t].  Then solve these equations for the Fourier coefficients of  U[t].\
\>", "Text"],

Cell[BoxData[{
    \(\(a = \(b = \(A = \(B = \(S = \(t = \(T = \(U = 
                      0\)\)\)\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(Remove[a, b, A, B, S, t, T, U];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[EqA, EqB, f, F, k, L, m, n];\)\ \), "\n", 
    \(\(T[n_, t_]\  = \ A\_n\ Cos[n\ t]\  + \ B\_n\ Sin[n\ t];\)\ \), "\n", 
    \(\(F[0, t_]\  = \ 0;\)\ \), "\n", 
    \(\(F[n_, t_]\  = \ \(\(1 - \((\(-1\))\)\^n\)\/2\) 
          Cos[n\ t]\/n\^2;\)\ \), "\n", 
    \(\(Print["\<T[n,t] = \>", T[n, t]];\)\ \), "\n", 
    \(\(Print["\<F[n,t] = \>", F[n, t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        Eq\  = \ \[PartialD]\_\(t, t\)T[n, t]\  + \ 
              2\ \[PartialD]\_t\ T[n, t]\  + \ T[n, t]\  \[Equal] \ 
            F[n, t]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[
        EqA\  = \ 
          ReplaceAll[
            Eq, {Cos[n\ t]\  \[Rule] \ 1, 
              Sin[n\ t]\  \[Rule] \ 0}]];\)\ \), "\n", 
    \(\(Print[
        EqB\  = \ 
          ReplaceAll[
            Eq, {Sin[n\ t]\  \[Rule] \ 1, 
              Cos[n\ t]\  \[Rule] \ 0}]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ Solve[{EqA, EqB}, \ {A\_n, B\_n}];\)\ \), "\n", 
    \(\(a\_n_\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(b\_n_\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 2, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(a\_0\ \  = \ 2\ F[0, t];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(a\_0\) = \>\"", a\_0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(a\_n\) = \>\"", a\_n];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(b\_n\) = \>\"", 
        b\_n];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

Use the Fourier coefficients of U[t] and form the n-th term of the series  \
U[n,t], and verify that it satisfies the given D.E.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(U[n_, t_]\  = \ 
        a\_n\ Cos[n\ t]\  + \ b\_n\ Sin[n\ t];\)\ \), "\n", 
    \(\(U[0, t]\ \ \  = \(\(\ \)\(a\_0\)\)\/2;\)\ \), "\n", 
    \(\(Print["\<U[0,t] = \>", U[0, t]];\)\ \), "\n", 
    \(\(Print["\<U[n,t] = \>", U[n, t]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Is the n-th term in the D.E. satisfied ?\>"];\)\ \), "\n", 
    \(\(L\  = \ \[PartialD]\_\(t, t\)U[n, t]\  + \ 
          2 \[PartialD]\_t U[n, t]\  + \ U[n, t];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[PartialD]\_\(t, t\)\)U[n,t] + \
2\!\(\[PartialD]\_t\)U[n,t] + U[n,t] = \>\"", 
        F[n, t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[L, "\< = \>", F[n, t]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[MapAll[Together, L], "\< = \>", F[n, t]];\)\ \), "\n", 
    \(\(Print[
        MapAll[Together, L \[Equal] F[n, t]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nConstruct the Trigonometric Polynomial  ",
  Cell[BoxData[
      \(S\_5[t]\)],
    AspectRatioFixed->True],
  "  of degree n = 5 and verify that it satisfies the D.E."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(S[
          t_]\  = \ \[Sum]\+\(n = 0\)\%5 U[n, t];\)\ \), "\n", 
    \(\(L\  = \ \(S''\)[t]\  + \ 2\ \(S'\)[t]\  + \ S[t];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)[t] = \!\(\[Sum]\+\(n = 0\)\%5\)U[n,t] = \
\>\"", S[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)'[t] = \>\"", \(S'\)[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)''[t] = \>\"", \(\(S'\)'\)[t]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The left and right side of the D.E. are\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)''[t] + 2 \!\(S\_5\)'[t] + \!\(S\_5\)[t] = \
\>\"", Expand[L]];\)\ \), "\n", 
    \(\(f[t_]\  = \ \[Sum]\+\(n = 0\)\%5 F[n, t];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_5\)[t] =  \!\(\[Sum]\+\(n = 0\)\%5\)F[n,t] = \
\>\"", f[t]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)''[t] + 2 \!\(S\_5\)'[t] + \!\(S\_5\)[t] \
\[Equal] \!\(f\_5\)[t]\>\""];\)\ \), "\n", 
    \(\(Print[Expand[L], "\< \[Equal] \>", f[t]];\)\ \), "\n", 
    \(\(Print[Expand[L]\  \[Equal] \ f[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nLook at the size of the coefficients  ",
  Cell[BoxData[
      \(a\_n\ \ and\ \ b\_n\)]],
  "  and observe that\n",
  Cell[BoxData[{
      \(lim\_\(n \[Rule] \[Infinity]\)\ 
          a\_n = \(lim\_\(n \[Rule] \[Infinity]\)\ \(\((\(-1\)\  + \ \
\((\(-1\))\)\^n)\)\ \((\(-1\)\  + \ n\^2)\)\)\/\(2\ n\^2\ \((1\  + \ \
n\^2)\)\^2\)\  = \ 0\)\), "\n", 
      \(lim\_\(n \[Rule] \[Infinity]\)\ 
          b\_n = \(lim\_\(n \[Rule] \[Infinity]\)\ \(1\  - \ \
\((\(-1\))\)\^n\)\/\(n\ \((1\  + \ n\^2)\)\^2\)\  = \ 0\)\)}]],
  " \nWe can investigate these sequences."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(m = 5;\)\ \), "\[IndentingNewLine]", 
    \(\(as = Table[a\_k, {k, 0, m}];\)\ \), "\[IndentingNewLine]", 
    \(\(bs = Table[b\_k, {k, 1, m}];\)\ \), "\[IndentingNewLine]", 
    \(\(as = Append[as, "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(bs = Append[bs, "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(a\_n\)} = \>\"", 
        as];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(b\_n\)} = \>\"", 
        bs];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(a\_n\)} = \>\"", 
        NumberForm[N[as], 3]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(b\_n\)} = \>\"", 
        NumberForm[N[bs], 3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nMaybe  ",
  Cell[BoxData[
      \(S\_5[t]\)]],
  " is a close approximation to the solution. A graph of  ",
  Cell[BoxData[
      \(S\_5[t]\)]],
  "  is given below."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[S[t], {t, \(-2\) Pi, 2  Pi}, PlotStyle \[Rule] Magenta, 
        PlotRange \[Rule] {{\(-2\) \[Pi], 2  \[Pi]}, {\(-0.5\), 0.5}}, 
        AxesLabel \[Rule] {"\<t\>", "\<s\>"}, 
        Ticks \[Rule] {Range[\(-2\) \[Pi], 2  \[Pi], \[Pi]], 
            Range[\(-0.5\), 0.5, 0.25]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The Trigonometric Polynomial \!\(S\_5\)[t] is an \
approximation\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<to the steady state solution \!\(U\_p\)[t] of the D.E.\>\
\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)[t] = \>\"", 
        S[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nFor illustration purposes, use the approximate solution  ",
  Cell[BoxData[
      \(U[t] = U\_h[t] + S\_5[t]\)],
    AspectRatioFixed->True],
  "  and use it so solve  ",
  Cell[BoxData[
      \(U[0] = 1, \(U'\)[0] = 0\)]],
  ", and plot the result."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(eqns = {Uh[0] + S[0] \[Equal] 
            1, \(Uh'\)[0] + \(S'\)[0] \[Equal] 0};\)\ \), "\n", 
    \(\(solset = Solve[eqns, {c\_1, c\_2}];\)\ \), "\n", 
    \(\(U[t_] = 
        S[t] + ReplaceAll[Uh[t], 
            solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Plot[{U[t], S[t]}, {t, 0, 4  Pi}, PlotStyle \[Rule] {Blue, Magenta}, 
        PlotRange \[Rule] {{0, 4  \[Pi]}, {\(-0.5\), 1.05}}, 
        AxesLabel \[Rule] {"\<t\>", "\<s\>"}, 
        Ticks \[Rule] {Range[0, 4  \[Pi], \[Pi]], 
            Range[\(-0.5\), 1.0, 0.25]}];\)\ \), "\n", 
    \(\(Print[\*"\"\<The Trigonometric Polynomial \!\(S\_5\)[t] is used to \
form\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<an approximation to the solution U[t] = \!\(U\_h\)[t] + \
\!\(S\_5\)[t]\>\""];\)\ \), "\n", 
    \(\(Print["\<with the initial conditions U[0]=1, and U'[0] = 0\>"];\)\ \
\), "\n", 
    \(\(Print["\<U[t] = \>", U[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["\n",
    FontWeight->"Bold"],
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the general solution to  ",
  Cell[BoxData[
      \(U'' \((t)\) + 3\ U' \((t)\) + U \((t)\) = F \((t)\)\)]],
  ",  where F(t) is given by the Fourier series  ",
  Cell[BoxData[
      \(F[
          t] = \[Sum]\+\(n = 1\)\%\[Infinity]\((\(-1\))\)\^\(n - 1\)\/n\ Sin[
              n\ t]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
First, find the transient solution to the differential equation.\
\>", "Text"],

Cell[BoxData[{
    \(\(c = 0;\)\), "\[IndentingNewLine]", 
    \(\(Remove[c];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[U, t];\)\ \), "\n", 
    \(\(de = \(U''\)[t] + 3\ \(U'\)[t] + U[t] \[Equal] 0;\)\ \), "\n", 
    \(\(solset = DSolve[de, U[t], t];\)\ \), "\[IndentingNewLine]", 
    \(\(Uh[t_] = 
        ReplaceAll[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), {C[1] \[Rule] c\_1, 
            C[2] \[Rule] c\_2}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The transient solution to the D.E. is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(U\_h\)[t] = \>\"", 
        Uh[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\

Next, use Fourier series to construct the steady state solution to the \
differential equation.  Enter the formula for the n-th terms T[n,t] and \
F[n,t] of the Fourier Series for U[t] and F[t], respectively.  Then form the \
equation relating the n-terms and the equations involving Cos[n t] and Sin[n \
t].  Then solve these equations for the Fourier coefficients of  U[t].\
\>", "Text"],

Cell[BoxData[{
    \(\(a = \(b = \(A = \(B = \(S = \(t = \(T = \(U = 
                      0\)\)\)\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(Remove[a, b, A, B, S, t, T, U];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[EqA, EqB, f, F, k, L, m, n];\)\ \), "\n", 
    \(\(T[n_, t_]\  = \ A\_n\ Cos[n\ t]\  + \ B\_n\ Sin[n\ t];\)\ \), "\n", 
    \(\(F[0, t_]\  = \ 0;\)\ \), "\n", 
    \(\(F[n_, 
          t_]\  = \ \(\((\(-1\))\)\^\(n - 1\)\ Sin[n\ t]\)\/n;\)\ \), "\n", 
    \(\(Print["\<T[n,t] = \>", T[n, t]];\)\ \), "\n", 
    \(\(Print["\<F[n,t] = \>", F[n, t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        Eq\  = \ \[PartialD]\_\(t, t\)T[n, t]\  + \ 
              3\ \[PartialD]\_t\ T[n, t]\  + \ T[n, t]\  \[Equal] \ 
            F[n, t]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[
        EqA\  = \ 
          ReplaceAll[
            Eq, {Cos[n\ t]\  \[Rule] \ 1, 
              Sin[n\ t]\  \[Rule] \ 0}]];\)\ \), "\n", 
    \(\(Print[
        EqB\  = \ 
          ReplaceAll[
            Eq, {Sin[n\ t]\  \[Rule] \ 1, 
              Cos[n\ t]\  \[Rule] \ 0}]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ Solve[{EqA, EqB}, \ {A\_n, B\_n}];\)\ \), "\n", 
    \(\(a\_n_\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(b\_n_\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 2, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(a\_0\ \  = \ 2\ F[0, t];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(a\_0\) = \>\"", a\_0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(a\_n\) = \>\"", a\_n];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(b\_n\) = \>\"", 
        b\_n];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

Use the Fourier coefficients of U[t] and form the n-th term of the series  \
U[n,t], and verify that it satisfies the given D.E.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(U[n_, t_]\  = \ 
        a\_n\ Cos[n\ t]\  + \ b\_n\ Sin[n\ t];\)\ \), "\n", 
    \(\(U[0, t]\ \ \  = \(\(\ \)\(a\_0\)\)\/2;\)\ \), "\n", 
    \(\(Print["\<U[0,t] = \>", U[0, t]];\)\ \), "\n", 
    \(\(Print["\<U[n,t] = \>", U[n, t]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Is the n-th term in the D.E. satisfied ?\>"];\)\ \), "\n", 
    \(\(L\  = \ \[PartialD]\_\(t, t\)U[n, t]\  + \ 
          3 \[PartialD]\_t U[n, t]\  + \ U[n, t];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(\[PartialD]\_\(t, t\)\)U[n,t] + 3 \!\(\[PartialD]\_t\
\)U[n,t] + U[n,t] = \>\"", F[n, t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[L, "\< = \>", F[n, t]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[MapAll[Together, L], "\< = \>", F[n, t]];\)\ \), "\n", 
    \(\(Print[
        MapAll[Together, L \[Equal] F[n, t]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nConstruct the Trigonometric Polynomial  ",
  Cell[BoxData[
      \(S\_5[t]\)],
    AspectRatioFixed->True],
  "  of degree n = 5 and verify that it satisfies the D.E."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(S[
          t_]\  = \ \[Sum]\+\(n = 0\)\%5 U[n, t];\)\ \), "\n", 
    \(\(L\  = \ \(\(S'\)'\)[t]\  + \ 3\ \(S'\)[t]\  + \ S[t];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)[t] = \!\(\[Sum]\+\(n = 0\)\%5\)U[n,t] = \
\>\"", S[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)'[t] = \>\"", \(S'\)[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)''[t] = \>\"", \(\(S'\)'\)[t]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The left and right side of the D.E. are\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)''[t] + 3 \!\(S\_5\)'[t] + \!\(S\_5\)[t] = \
\>\"", Expand[L]];\)\ \), "\n", 
    \(\(f[t_]\  = \ \[Sum]\+\(n = 0\)\%5 F[n, t];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_5\)[t] = \!\(\[Sum]\+\(n = 0\)\%5\)F[n,t] = \
\>\"", f[t]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)''[t] + 3 \!\(S\_5\)'[t] + \!\(S\_5\)[t] \
\[Equal] \!\(f\_5\)[t]\>\""];\)\ \), "\n", 
    \(\(Print[Expand[L], "\< \[Equal] \>", f[t]];\)\ \), "\n", 
    \(\(Print[Expand[L]\  \[Equal] \ f[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nLook at the size of the coefficients  ",
  Cell[BoxData[
      \(a\_n\ \ and\ \ b\_n\)]],
  "  and observe that\n",
  Cell[BoxData[{
      \(lim\_\(n \[Rule] \[Infinity]\)\ 
          a\_n = \(lim\_\(n \[Rule] \[Infinity]\)\ \(3\ \
\((\(-1\))\)\^n\)\/\(1 + 7\ n\^2 + n\^4\)\  = \ 0\)\), "\n", 
      \(lim\_\(n \[Rule] \[Infinity]\)\ 
          b\_n = \(lim\_\(n \[Rule] \[Infinity]\)\ \(\((\(-1\))\)\^n\ \((\(-1\
\) + n\^2)\)\)\/\(n\ \((1 + 7\ n\^2 + n\^4)\)\)\  = \ 0\)\)}]],
  " \nWe can investigate these sequences."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(m = 5;\)\ \), "\[IndentingNewLine]", 
    \(\(as = Table[a\_k, {k, 0, m}];\)\ \), "\[IndentingNewLine]", 
    \(\(bs = Table[b\_k, {k, 1, m}];\)\ \), "\[IndentingNewLine]", 
    \(\(as = Append[as, "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(bs = Append[bs, "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(a\_n\)} = \>\"", 
        as];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(b\_n\)} = \>\"", 
        bs];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(a\_n\)} = \>\"", 
        NumberForm[N[as], 3]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(b\_n\)} = \>\"", 
        NumberForm[N[bs], 3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nMaybe  ",
  Cell[BoxData[
      \(S\_5[t]\)]],
  " is a close approximation to the solution. A graph of  ",
  Cell[BoxData[
      \(S\_5[t]\)]],
  "  is given below."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[S[t], {t, \(-2\) Pi, 2  Pi}, PlotStyle \[Rule] Magenta, 
        PlotRange \[Rule] {{\(-2\) \[Pi], 2  \[Pi]}, {\(-0.3\), 0.5}}, 
        AxesLabel \[Rule] {"\<t\>", "\<s\>"}, 
        Ticks \[Rule] {Range[\(-2\) \[Pi], 2  \[Pi], \[Pi]], 
            Range[\(-0.2\), 0.4, 0.1]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The Trigonometric Polynomial \!\(S\_5\)[t] is an \
approximation\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<to the steady state solution \!\(U\_p\)[t] of the D.E.\>\
\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)[t] = \>\"", 
        S[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nFor illustration purposes, use the approximate solution  ",
  Cell[BoxData[
      \(U[t] = U\_h[t] + S\_5[t]\)],
    AspectRatioFixed->True],
  "  and use it so solve  ",
  Cell[BoxData[
      \(U[0] = 1, \(U'\)[0] = 0\)]],
  ", and plot the result."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(eqns = {Uh[0. ] + S[0. ] \[Equal] 
            1. , \(Uh'\)[0. ] + \(S'\)[0. ] \[Equal] 0. };\)\ \), "\n", 
    \(\(solset = Solve[eqns, {c\_1, c\_2}];\)\ \), "\n", 
    \(\(U[t_] = 
        S[t] + ReplaceAll[Uh[t], 
            solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{U[t], S[t]}, {t, 0, 4  Pi}, PlotStyle \[Rule] {Cyan, Magenta}, 
        PlotRange \[Rule] {{0, 4  \[Pi]}, {\(-0.3\), 1.05}}, 
        AxesLabel \[Rule] {"\<t\>", "\<s\>"}, 
        Ticks \[Rule] {Range[0, 4  \[Pi], \[Pi]], 
            Range[\(-0.5\), 1.0, 0.25]}];\)\ \), "\n", 
    \(\(Print[\*"\"\<The Trigonometric Polynomial \!\(S\_5\)[t] is used to \
form\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<an approximation to the solution U[t] = \!\(U\_h\)[t] + \
\!\(S\_5\)[t]\>\""];\)\ \), "\n", 
    \(\(Print["\<with the initial conditions U[0]=1, and U'[0] = 0\>"];\)\ \
\), "\n", 
    \(\(Print["\<U[t] = \>", U[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Extra Example 2.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the general solution to  ",
  Cell[BoxData[
      \(2  U'' \((t)\) + 2  U' \((t)\) + U \((t)\) = F \((t)\)\)]],
  ",  where F(t) is given by the Fourier series  ",
  Cell[BoxData[
      \(F[
          t] = \[Sum]\+\(n = 1\)\%\[Infinity]\((\(-1\))\)\^\(n - 1\)\/n\ Sin[
              n\ t]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Extra Solution 2.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
First, find the transient solution to the differential equation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[U, t];\)\ \), "\n", 
    \(\(de = 2 \( U''\)[t] + 2\ \(U'\)[t] + U[t] \[Equal] 0;\)\ \), "\n", 
    \(\(solset = DSolve[de, U[t], t];\)\ \), "\[IndentingNewLine]", 
    \(\(Uh[t_] = 
        ReplaceAll[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), {C[1] \[Rule] c\_1, 
            C[2] \[Rule] c\_2}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[solset];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The transient solution to the D.E. is\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(U\_h\)[t] = \>\"", 
        Uh[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\

Next, use Fourier series to construct the steady state solution to the \
differential equation.  Enter the formula for the n-th terms T[n,t] and \
F[n,t] of the Fourier Series for U[t] and F[t], respectively.  Then form the \
equation relating the n-terms and the equations involving Cos[n t] and Sin[n \
t].  Then solve these equations for the Fourier coefficients of  U[t].\
\>", "Text"]
}, Open  ]],

Cell[BoxData[{
    \(\(a = \(b = \(A = \(B = \(S = \(t = \(T = \(U = 
                      0\)\)\)\)\)\)\);\)\), "\[IndentingNewLine]", 
    \(\(Remove[a, b, A, B, S, t, T, U];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[EqA, EqB, f, F, k, L, m, n];\)\ \), "\n", 
    \(\(T[n_, t_]\  = \ A\_n\ Cos[n\ t]\  + \ B\_n\ Sin[n\ t];\)\ \), "\n", 
    \(\(F[0, t_]\  = \ 0;\)\ \), "\n", 
    \(\(F[n_, 
          t_]\  = \ \(\((\(-1\))\)\^\(n - 1\)\ Sin[n\ t]\)\/n;\)\ \), "\n", 
    \(\(Print["\<T[n,t] = \>", T[n, t]];\)\ \), "\n", 
    \(\(Print["\<F[n,t] = \>", F[n, t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        Eq\  = \ 2\ \[PartialD]\_\(t, t\)T[n, t]\  + \ 
              2\ \[PartialD]\_t\ T[n, t]\  + \ T[n, t]\  \[Equal] \ 
            F[n, t]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[
        EqA\  = \ 
          ReplaceAll[
            Eq, {Cos[n\ t]\  \[Rule] \ 1, 
              Sin[n\ t]\  \[Rule] \ 0}]];\)\ \), "\n", 
    \(\(Print[
        EqB\  = \ 
          ReplaceAll[
            Eq, {Sin[n\ t]\  \[Rule] \ 1, 
              Cos[n\ t]\  \[Rule] \ 0}]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ Solve[{EqA, EqB}, \ {A\_n, B\_n}];\)\ \), "\n", 
    \(\(a\_n_\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(b\_n_\  = \ \ solset\_\(\(\[LeftDoubleBracket]\)\(1, 2, 2\)\(\
\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(a\_0\ \  = \ 2\ F[0, t];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(a\_0\) = \>\"", a\_0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(a\_n\) = \>\"", a\_n];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(b\_n\) = \>\"", 
        b\_n];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

Use the Fourier coefficients of U[t] and form the n-th term of the series  \
U[n,t], and verify that it satisfies the given D.E.\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(U[n_, t_]\  = \ 
        a\_n\ Cos[n\ t]\  + \ b\_n\ Sin[n\ t];\)\ \), "\n", 
    \(\(U[0, t]\ \ \  = \(\(\ \)\(a\_0\)\)\/2;\)\ \), "\n", 
    \(\(Print["\<U[0,t] = \>", U[0, t]];\)\ \), "\n", 
    \(\(Print["\<U[n,t] = \>", U[n, t]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Is the n-th term in the D.E. satisfied ?\>"];\)\ \), "\n", 
    \(\(L\  = \ 
        2 \[PartialD]\_\(t, t\)U[n, t]\  + \ 2 \[PartialD]\_t U[n, t]\  + \ 
          U[n, t];\)\ \), "\n", 
    \(\(Print[\*"\"\<2 \!\(\[PartialD]\_\(t, t\)\)U[n,t] + 2 \
\!\(\[PartialD]\_t\)U[n,t] + U[n,t] = \>\"", 
        F[n, t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[L, "\< = \>", F[n, t]];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[MapAll[Together, L], "\< = \>", F[n, t]];\)\ \), "\n", 
    \(\(Print[
        MapAll[Together, L \[Equal] F[n, t]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nConstruct the Trigonometric Polynomial  ",
  Cell[BoxData[
      \(S\_5[t]\)],
    AspectRatioFixed->True],
  "  of degree n = 5 and verify that it satisfies the D.E."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(S[
          t_]\  = \ \[Sum]\+\(n = 0\)\%5 U[n, t];\)\ \), "\n", 
    \(\(L\  = \ 
        2 \(\( S'\)'\)[t]\  + \ 2\ \(S'\)[t]\  + \ S[t];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)[t] = \!\(\[Sum]\+\(n = 0\)\%5\)U[n,t] = \
\>\"", S[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)'[t] = \>\"", \(S'\)[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)''[t] = \>\"", \(\(S'\)'\)[t]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The left and right side of the D.E. are\>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<2 \!\(S\_5\)''[t] + 2 \!\(S\_5\)'[t] + \!\(S\_5\)[t] = \
\>\"", Expand[L]];\)\ \), "\n", 
    \(\(f[t_]\  = \ \[Sum]\+\(n = 0\)\%5 F[n, t];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_5\)[t] = \!\(\[Sum]\+\(n = 0\)\%5\)F[n,t] = \
\>\"", f[t]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<2 \!\(S\_5\)''[t] + 2 \!\(S\_5\)'[t] + \!\(S\_5\)[t] \
\[Equal] \!\(f\_5\)[t]\>\""];\)\ \), "\n", 
    \(\(Print[Expand[L], "\< \[Equal] \>", f[t]];\)\ \), "\n", 
    \(\(Print[Expand[L]\  \[Equal] \ f[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nLook at the size of the coefficients  ",
  Cell[BoxData[
      \(a\_n\ \ and\ \ b\_n\)]],
  "  and observe that\n",
  Cell[BoxData[{
      \(lim\_\(n \[Rule] \[Infinity]\)\ 
          a\_n = \(lim\_\(n \[Rule] \[Infinity]\)\ \(2\ \
\((\(-1\))\)\^n\)\/\(1 + 4\ n\^4\)\  = \ 0\)\), "\n", 
      \(lim\_\(n \[Rule] \[Infinity]\)\ 
          b\_n = \(lim\_\(n \[Rule] \[Infinity]\)\ \(\((\(-1\))\)\^n\ \((\(-1\
\) + 2\ n\^2)\)\)\/\(n\ \((1 + 4\ n\^4)\)\)\  = \ 0\)\)}]],
  " \nWe can investigate these sequences."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(m = 5;\)\ \), "\[IndentingNewLine]", 
    \(\(as = Table[a\_k, {k, 0, m}];\)\ \), "\[IndentingNewLine]", 
    \(\(bs = Table[b\_k, {k, 1, m}];\)\ \), "\[IndentingNewLine]", 
    \(\(as = Append[as, "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(bs = Append[bs, "\<...\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(a\_n\)} = \>\"", 
        as];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(b\_n\)} = \>\"", 
        bs];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(a\_n\)} = \>\"", 
        NumberForm[N[as], 3]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<{\!\(b\_n\)} = \>\"", 
        NumberForm[N[bs], 3]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nMaybe  ",
  Cell[BoxData[
      \(S\_5[t]\)]],
  " is a close approximation to the solution. A graph of  ",
  Cell[BoxData[
      \(S\_5[t]\)]],
  "  is given below."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[S[t], {t, \(-2\) Pi, 2  Pi}, PlotStyle \[Rule] Magenta, 
        PlotRange \[Rule] {{\(-2\) \[Pi], 2  \[Pi]}, {\(-0.4\), 0.6}}, 
        AxesLabel \[Rule] {"\<t\>", "\<s\>"}, 
        Ticks \[Rule] {Range[\(-2\) \[Pi], 2  \[Pi], \[Pi]], 
            Range[\(-0.4\), 0.6, 0.2]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<The Trigonometric Polynomial \!\(S\_5\)[t] is an \
approximation\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<to the steady state solution \!\(U\_p\)[t] of the D.E.\>\
\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(S\_5\)[t] = \>\"", 
        S[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nFor illustration purposes, use the approximate solution  ",
  Cell[BoxData[
      \(U[t] = U\_h[t] + S\_5[t]\)],
    AspectRatioFixed->True],
  "  and use it so solve  ",
  Cell[BoxData[
      \(U[0] = 1, \(U'\)[0] = 0\)]],
  ", and plot the result."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(eqns = {Uh[0. ] + S[0. ] \[Equal] 
            1. , \(Uh'\)[0. ] + \(S'\)[0. ] \[Equal] 0. };\)\ \), "\n", 
    \(\(solset = Solve[eqns, {c\_1, c\_2}];\)\ \), "\n", 
    \(\(U[t_] = 
        S[t] + ReplaceAll[Uh[t], 
            solset\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\)\
];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Plot[{U[t], S[t]}, {t, 0, 4  Pi}, PlotStyle \[Rule] {Blue, Magenta}, 
        PlotRange \[Rule] {{0, 4  \[Pi]}, {\(-0.5\), 1.05}}, 
        AxesLabel \[Rule] {"\<t\>", "\<s\>"}, 
        Ticks \[Rule] {Range[0, 4  \[Pi], \[Pi]], 
            Range[\(-0.5\), 1.0, 0.25]}];\)\ \), "\n", 
    \(\(Print[\*"\"\<The Trigonometric Polynomial \!\(S\_5\)[t] is used to \
form\>\""];\)\ \), "\n", 
    \(\(Print[\*"\"\<an approximation to the solution U[t] = \!\(U\_h\)[t] + \
\!\(S\_5\)[t]\>\""];\)\ \), "\n", 
    \(\(Print["\<with the initial conditions U[0]=1, and U'[0] = 0\>"];\)\ \
\), "\n", 
    \(\(Print["\<U[t] = \>", U[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Upgrade: This module is scheduled for \
revision in 2006.",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradMod.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Fourier Series and Transform",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/FourierTransformBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Dirichlet Problem",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/DirichletProblemBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Laplace Transform",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/LaplaceTransformBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1017, 621},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 43819, 1115}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 128, 2, 33, "Text"],
Cell[2233, 66, 1671, 35, 241, "Text",
  Evaluatable->False],
Cell[3907, 103, 840, 19, 109, "Text"],
Cell[4750, 124, 1357, 33, 166, "Text"],
Cell[6110, 159, 3832, 100, 518, "Text"],
Cell[9945, 261, 512, 17, 57, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[10482, 282, 112, 2, 33, "Text"],
Cell[10597, 286, 88, 2, 33, "Text"],
Cell[10688, 290, 881, 18, 250, "Input"],
Cell[11572, 310, 400, 7, 71, "Text"],
Cell[11975, 319, 1848, 41, 467, "Input"],
Cell[13826, 362, 153, 4, 52, "Text"],
Cell[13982, 368, 1028, 20, 322, "Input"],
Cell[15013, 390, 200, 6, 52, "Text"],
Cell[15216, 398, 1233, 22, 450, "Input"],
Cell[16452, 422, 592, 14, 131, "Text"],
Cell[17047, 438, 812, 15, 250, "Input"],
Cell[17862, 455, 247, 10, 52, "Text",
  Evaluatable->False],
Cell[18112, 467, 769, 14, 150, "Input"],
Cell[18884, 483, 283, 9, 52, "Text"],
Cell[19170, 494, 1115, 21, 250, "Input"]
}, Closed]],
Cell[20300, 518, 516, 17, 54, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20841, 539, 115, 2, 33, "Text"],
Cell[20959, 543, 88, 2, 33, "Text"],
Cell[21050, 547, 911, 19, 270, "Input"],
Cell[21964, 568, 400, 7, 71, "Text"],
Cell[22367, 577, 1843, 41, 469, "Input"],
Cell[24213, 620, 153, 4, 52, "Text"],
Cell[24369, 626, 1020, 19, 322, "Input"],
Cell[25392, 647, 200, 6, 52, "Text"],
Cell[25595, 655, 1236, 22, 450, "Input"],
Cell[26834, 679, 553, 13, 127, "Text"],
Cell[27390, 694, 812, 15, 250, "Input"],
Cell[28205, 711, 247, 10, 52, "Text",
  Evaluatable->False],
Cell[28455, 723, 768, 14, 150, "Input"],
Cell[29226, 739, 283, 9, 52, "Text"],
Cell[29512, 750, 1129, 21, 250, "Input"]
}, Closed]],
Cell[30656, 774, 485, 16, 54, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[31166, 794, 115, 2, 33, "Text"],
Cell[31284, 798, 88, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[31397, 804, 839, 17, 250, "Input"],
Cell[32239, 823, 400, 7, 71, "Text"]
}, Open  ]],
Cell[32654, 833, 1839, 40, 469, "Input"],
Cell[34496, 875, 153, 4, 52, "Text"],
Cell[34652, 881, 1042, 21, 322, "Input"],
Cell[35697, 904, 200, 6, 52, "Text"],
Cell[35900, 912, 1252, 23, 450, "Input"],
Cell[37155, 937, 542, 13, 127, "Text"],
Cell[37700, 952, 812, 15, 250, "Input"],
Cell[38515, 969, 247, 10, 52, "Text",
  Evaluatable->False],
Cell[38765, 981, 768, 14, 150, "Input"],
Cell[39536, 997, 283, 9, 52, "Text"],
Cell[39822, 1008, 1129, 21, 250, "Input"]
}, Closed]],
Cell[40966, 1032, 331, 8, 30, "Text"],
Cell[41300, 1042, 290, 7, 33, "Text"],
Cell[41593, 1051, 302, 7, 33, "Text"],
Cell[41898, 1060, 291, 7, 33, "Text"],
Cell[42192, 1069, 291, 7, 33, "Text"],
Cell[42486, 1078, 257, 5, 33, "Text"],
Cell[42746, 1085, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

