(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     37969,       1175]*)
(*NotebookOutlinePosition[     39261,       1220]*)
(*  CellTagsIndexPosition[     39185,       1214]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["12.5  The Laplace Transform",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tAlthough a function  f(t)  may be defined for all values of  t,  its ",
  ButtonBox["Laplace",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Laplace.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " transform is not influenced by values of  f(t), when  ",
  Cell[BoxData[
      \(t < 0\)]],
  ".  The Laplace transform of  f(t) is actually defined for the function  \
U(t) given by  \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{\(U \((t)\)\), "=", 
        RowBox[{"{", GridBox[{
              {\(\(f \((t)\)\ \ for\ \ t \[GreaterEqual] 0\)\(,\)\)},
              {\(0\ \ \ \ \ \ \ \ \ \ for\ \ t < 0. \)}
              }], 
          StyleBox["}",
            FontColor->GrayLevel[1]]}]}]]],
  " \n\nA sufficient condition for the existence of the Laplace transform is \
that  ",
  Cell[BoxData[
      \(\(\(|\)\(f \((t)\)\)\(|\)\)\)]],
  "  does not grow too rapidly as  ",
  Cell[BoxData[
      \(t\  \[Rule] \ \(+\[Infinity]\)\)]],
  ".  We say that the function   ",
  Cell[BoxData[
      \(f \((t)\)\)]],
  "  is of ",
  StyleBox["exponential order",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " if there exists real constants  ",
  Cell[BoxData[
      \(M > 0\ \ and\ \ K\)]],
  "  such that  \n\n\t\t\t",
  Cell[BoxData[
      \(\(\(|\)\(f \((t)\)\)\(|\)\(\(\[LessEqual]\)\(M\ \[ExponentialE]\^\(K\ \
t\)\)\)\)\)]],
  "  holds for all  ",
  Cell[BoxData[
      \(t \[GreaterEqual] 0\)]],
  ".  \n\nAll functions in this chapter are assumed to be of exponential \
order.  The next theorem shows that their Laplace transform  ",
  Cell[BoxData[
      \(F \((s)\) = F \((\[Sigma]\  + \ \[ImaginaryI]\ \[Tau])\)\)]],
  "  exists for values of  ",
  Cell[BoxData[
      \(s = \[Sigma]\  + \ \[ImaginaryI]\ \[Tau]\)]],
  "  in a domain that includes the right half-plane  ",
  Cell[BoxData[
      \(Re \((s)\) > K\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 12.10  (",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[ButtonBox["Laplace Transform",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/LaplaceTransform.html"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  StyleBox[").",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  If  ",
  Cell[BoxData[
      \(f \((t)\)\)]],
  "  is of exponential order, then its ",
  StyleBox["Laplace Transform",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["\[ScriptCapitalL]",
            FontSize->16], \((f \((t)\))\)}], "=", \(F \((s)\)\)}]]],
  " exists and is given by \n\n\t\t\t",
  Cell[BoxData[
      \(F \((s)\) = \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] 
              f \((t)\) \(\[ExponentialE]\^\(\(-s\)\ t\)\) \
\[DifferentialD]t\ \ \ where\ \ s\  = \ \[Sigma] + \[ImaginaryI]\ \
\[Tau]\)\)]],
  ".   \n\nThe defining integral for  ",
  Cell[BoxData[
      \(F \((s)\)\)]],
  "  exists at points  ",
  Cell[BoxData[
      \(s = \[Sigma] + \[ImaginaryI]\ \[Tau]\)]],
  "  in the right half plane  ",
  Cell[BoxData[
      \(\[Tau] > K\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.10 is left for the reader in the \
book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Remark 12.1.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The domain of definition of the defining integral for the Laplace \
transform ",
  Cell[BoxData[
      RowBox[{
        StyleBox["\[ScriptCapitalL]",
          FontSize->16], \((f \((t)\))\)}]]],
  " seems to be restricted to a half plane. However, the resulting formula ",
  Cell[BoxData[
      \(F \((s)\)\)]],
  " might have a domain much larger than this half plane. Later we will show \
that ",
  Cell[BoxData[
      \(F \((s)\)\)]],
  " is an analytic function of the complex variables. For most applications \
involving Laplace transforms that we will study, the Laplace transforms are \
rational functions that have the form ",
  Cell[BoxData[
      \(\(P \((s)\)\)\/\(Q \((s)\)\)\)]],
  ", where P and Q are polynomials, and some other important ones will have \
the form ",
  Cell[BoxData[
      \(\(\[ExponentialE]\^\(a\ s\)\ P \((s)\)\)\/\(Q \((s)\)\)\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 12.21  (Linearity of the Laplace Transform).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(f \((t)\)\ \ and\ \ g \((t)\)\)]],
  "  have Laplace transforms  ",
  Cell[BoxData[
      \(F \((s)\)\ \ and\ G \((s)\)\)]],
  ",  respectively.  If  a  and  b  are constants, then   \n\n\t\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["\[ScriptCapitalL]",
            FontSize->16], \((a\ f \((t)\) + b\ g \((t)\))\)}], "  ", "=", 
        "  ", \(a\ F \((s)\)\  + \ \ b\ G \((s)\)\)}]]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.11 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 12.22  (Uniqueness of the Laplace Transform).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Let  ",
  Cell[BoxData[
      \(f \((t)\)\ \ and\ \ g \((t)\)\)]],
  "  have Laplace transforms  ",
  Cell[BoxData[
      \(F \((s)\)\ \ and\ G \((s)\)\)]],
  ",  respectively.   \n\n\t\t\tIf  ",
  Cell[BoxData[
      \(F \((s)\) \[Congruent] G \((s)\)\ \ then\ \ f \((t)\) \[Congruent] 
        g \((t)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.12 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 12.7.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Laplace transform of the step function  \n\n\t\t",
  Cell[BoxData[
      \(f \((t)\) = 
        1\ \ \ for\ \ \ 0 \[LessEqual] t < c, \[IndentingNewLine]f \((t)\) = 
        0\ \ \ for\ \ \ c < \(\(t\)\(.\)\)\)]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f \((t)\)\)]],
  "  and compute the integral defining   ",
  Cell[BoxData[
      RowBox[{
        StyleBox["\[ScriptCapitalL]",
          FontSize->16], \((f \((t)\))\)}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(c = \(s = \(t = 0\)\);\)\), "\[IndentingNewLine]", 
    \(\(Remove[c, s, t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, F];\)\ \), "\n", 
    \(\(f[t_]\  = \ 1;\)\ \), "\n", 
    \(\(g[
          t_]\  = \[Integral]f[
              t] \(\[ExponentialE]\^\(\(-s\)\ t\)\) \[DifferentialD]t;\)\ \), \
"\n", 
    \(\(F[
          s_]\  = \[Integral]\_0\%c f[
              t] \(\[ExponentialE]\^\(\(-s\)\ t\)\) \[DifferentialD]t;\)\ \), \
"\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<g[t] = \[Integral] \>", 
        f[t], \*"\"\< \!\(\[ExponentialE]\^\(-st\)\)\[DifferentialD]t = \
\>\"", g[t]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<F[s] = g[c] - g[0] = \>", 
        g[c] - g[0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\<F[s] = \!\(\[Integral]\_0\%c\)\>\"", 
        f[t], \*"\"\< \!\(\[ExponentialE]\^\(-st\)\)\[DifferentialD]t = \
\>\"", F[s]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<F[s] = \>", F[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can check this with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s  result using the LaplaceTransform package."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(F[s_]\  = \ 
        LaplaceTransform[f[t], \ t, \ s];\)\ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<F[s] = \>", F[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 12.8.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Laplace transform of  ",
  Cell[BoxData[
      \(f \((t)\)\  = \ \[ExponentialE]\^\(a\ t\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f \((t)\)\)]],
  "  and compute the integral defining   ",
  Cell[BoxData[
      RowBox[{
        StyleBox["\[ScriptCapitalL]",
          FontSize->16], \((f \((t)\))\)}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(a = \(s = \(t = 0\)\);\)\), "\[IndentingNewLine]", 
    \(\(Remove[a, s, t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, F];\)\ \), "\n", 
    \(\(f[t_]\  = \ \[ExponentialE]\^\(a\ t\);\)\ \), "\n", 
    \(\(g[
          t_]\  = \ \[Integral]f[
              t] \(\[ExponentialE]\^\(\(-s\)\ t\)\) \[DifferentialD]t;\)\ \), \
"\n", 
    \(\(F[s_]\  = \ 
        Integrate[f[t] \[ExponentialE]\^\(\(-s\)\ t\), \ {t, 0, \[Infinity]}, 
          Assumptions \[Rule] {s > Re[a] && a < Re[s]}];\)\ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<g[t] = \[Integral] \>", 
        f[t], \*"\"\< \!\(\[ExponentialE]\^\(-st\)\)\[DifferentialD]t = \
\>\"", g[t]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<F[s] = \!\(\[Integral]\_0\%\[Infinity]\)\>\"", 
        f[t], \*"\"\< \!\(\[ExponentialE]\^\(-st\)\)\[DifferentialD]t = g[\
\[Infinity]] - g[0]\>\""];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<F[s] = \>", g[\[Infinity]] - g[0], "\< = \>", 
        F[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nAssuming that f(t) is of exponential order, we have  ",
  Cell[BoxData[
      \(g[t]\  \[Rule] \ \(0\ \ as\ \ t\  \[Rule] \ \[Infinity]\)\)]],
  ". Then  ",
  Cell[BoxData[
      \(\(\(g[\[Infinity]]\  = 0\)\(\ \)\)\)]],
  ",  and the Laplace transform can be computed by the calculation  ",
  Cell[BoxData[
      \(g[\[Infinity]]\  - \ g[0] = \(-\ g[0]\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<g[t] = \[Integral] \>", 
        f[t], \*"\"\< \!\(\[ExponentialE]\^\(-st\)\)\[DifferentialD]t = \
\>\"", g[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<F[s] = - g[0] = \>", 
        Simplify[\(-g[0]\)]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can check this with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s  result using the LaplaceTransform package."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(F[s_]\  = \ 
        LaplaceTransform[f[t], \ t, \ s];\)\ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<F[s] = \>", F[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 12.9.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the Laplace transform of   ",
  Cell[BoxData[
      \(f[t]\  = \ Sinh[a\ t]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell[TextData[{
  "Since  ",
  Cell[BoxData[
      \(f[
          t]\  = \ \(Sinh[
            a\ t] = \ \(\(\[ExponentialE]\^\(a\ t\) - \[ExponentialE]\^\(\(-a\
\)\ t\)\)\/2 = \(1\/2\) \[ExponentialE]\^\(a\ t\) - \(1\/2\) \
\[ExponentialE]\^\(\(-a\)\ t\)\)\)\)]],
  ",  we can apply the results of Example ",
  "12.",
  "8;   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["\[ScriptCapitalL]",
            FontSize->16], \((\[ExponentialE]\^\(a\ t\))\)}], "=", 
        RowBox[{
          RowBox[{\(1\/\(s\  - \ a\)\), "  ", "and", "   ", 
            StyleBox["\[ScriptCapitalL]",
              FontSize->16], \((\[ExponentialE]\^\(\(-a\)\ t\))\)}], 
          "=", \(1\/\(s\  + \ a\)\)}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(a = \(s = \(t = 0\)\);\)\), "\[IndentingNewLine]", 
    \(\(Remove[a, s, t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, f1, f2, f12, F, F1, F2, F12];\)\ \), "\n", 
    \(\(f1[t_]\  = \ \[ExponentialE]\^\(a\ t\);\)\ \), "\n", 
    \(\(f2[t_]\  = \ \[ExponentialE]\^\(\(-a\)\ t\);\)\ \), "\n", 
    \(\(f12[
          t_]\  = \ \(\[ExponentialE]\^\(a\ t\) - \[ExponentialE]\^\(\(-a\)\ \
t\)\)\/2;\)\ \), "\n", 
    \(\(f[t_]\  = \ Sinh[a\ t];\)\ \), "\n", 
    \(\(F1[s_]\  = \ LaplaceTransform[f1[t], \ t, \ s];\)\ \), "\n", 
    \(\(F2[s_]\  = \ LaplaceTransform[f2[t], \ t, \ s];\)\ \), "\n", 
    \(\(F12[s_]\  = \ LaplaceTransform[f[t], \ t, \ s];\)\ \), "\n", 
    \(\(F[s_]\  = \ LaplaceTransform[f[t], \ t, \ s];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(f\_1\)[t] = \>\"", f1[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(f\_2\)[t] = \>\"", f2[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_12\)[t] = \>\"", f12[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_12\)[t] = \>\"", 
        FullSimplify[f12[t]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<  f[t] = \>", FullSimplify[f[t]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(F\_1\)[s] = \>\"", F1[s]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(F\_2\)[s] = \>\"", F2[s]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\_12\)[s] = \!\(\(F\_1[s] - F\_2[s]\)\/2\) = \>\"", \
\(F1[s] - F2[s]\)\/2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\_12\)[s] = \!\(\(F\_1[s] - F\_2[s]\)\/2\) = \>\"", 
        Together[\(F1[s] - F2[s]\)\/2]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\< F[s] = \[ScriptCapitalL](Sinh[a t]) = \>", 
        F[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can check this with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s  result using the LaplaceTransform package."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(F[s_]\  = \ 
        LaplaceTransform[f[t], \ t, \ s];\)\ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<F[s] = \>", F[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell["\<\
\tWe can use the property of linearity to find new Laplace transforms from \
known transforms.\
\>", "Text"],

Cell[TextData[{
  StyleBox["Example 12.10.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Find the Laplace transform of  ",
  Cell[BoxData[
      \(f[t]\  = \ t\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f \((t)\)\)]],
  "  and compute the integral defining   ",
  Cell[BoxData[
      RowBox[{
        StyleBox["\[ScriptCapitalL]",
          FontSize->16], \((f \((t)\))\)}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(a = \(s = \(t = 0\)\);\)\), "\[IndentingNewLine]", 
    \(\(Remove[a, s, t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, F];\)\ \), "\n", 
    \(\(f[t_]\  = \ t;\)\ \), "\n", 
    \(\(g[
          t_]\  = \ \[Integral]f[
              t] \(\[ExponentialE]\^\(\(-s\)\ t\)\) \[DifferentialD]t;\)\ \), \
"\n", 
    \(\(F[s_]\  = \ 
        Integrate[f[t] \[ExponentialE]\^\(\(-s\)\ t\), \ {t, 0, \[Infinity]}, 
          Assumptions \[Rule] {Im[s] \[Equal] 0, s > 0}];\)\ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<g[t] = \[Integral] \>", 
        f[t], \*"\"\< \!\(\[ExponentialE]\^\(-st\)\)\[DifferentialD]t = \
\>\"", g[t]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<F[s] = \!\(\[Integral]\_0\%\[Infinity]\)\>\"", 
        f[t], \*"\"\< \!\(\[ExponentialE]\^\(-st\)\)\[DifferentialD]t = g[\
\[Infinity]] - g[0]\>\""];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<F[s] = \>", g[\[Infinity]] - g[0], "\< = \>", 
        F[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nAssuming that f(t) is of exponential order, we have  ",
  Cell[BoxData[
      \(g[t]\  \[Rule] \ \(0\ \ as\ \ t\  \[Rule] \ \[Infinity]\)\)]],
  ". Then  ",
  Cell[BoxData[
      \(\(\(g[\[Infinity]]\  = 0\)\(\ \)\)\)]],
  ",  and the Laplace transform can be computed by the calculation  ",
  Cell[BoxData[
      \(g[\[Infinity]]\  - \ g[0] = \(-\ g[0]\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<g[t] = \[Integral] \>", 
        f[t], \*"\"\< \!\(\[ExponentialE]\^\(-st\)\)\[DifferentialD]t = \
\>\"", g[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<F[s] = - g[0] = \>", 
        Simplify[\(-g[0]\)]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can check this with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s  result using the LaplaceTransform package."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(F[s_]\  = \ 
        LaplaceTransform[f[t], \ t, \ s];\)\ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<F[s] = \>", F[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Extra Example 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Find the Laplace transform of  ",
  Cell[BoxData[
      \(f[t]\  = \ t\^3\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution for Extra Example 1.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f \((t)\)\)]],
  "  and compute the integral defining   ",
  Cell[BoxData[
      RowBox[{
        StyleBox["\[ScriptCapitalL]",
          FontSize->16], \((f \((t)\))\)}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(a = \(s = \(t = 0\)\);\)\), "\[IndentingNewLine]", 
    \(\(Remove[a, s, t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, F];\)\ \), "\n", 
    \(\(f[t_]\  = \ t\^3;\)\ \), "\n", 
    \(\(g[
          t_]\  = \ \[Integral]f[
              t] \(\[ExponentialE]\^\(\(-s\)\ t\)\) \[DifferentialD]t;\)\ \), \
"\n", 
    \(\(F[s_]\  = \ 
        Integrate[f[t] \[ExponentialE]\^\(\(-s\)\ t\), \ {t, 0, \[Infinity]}, 
          Assumptions \[Rule] {Im[s] \[Equal] 0, s > 0}];\)\ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<g[t] = \[Integral] \>", 
        f[t], \*"\"\< \!\(\[ExponentialE]\^\(-st\)\)\[DifferentialD]t = \
\>\"", g[t]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<F[s] = \!\(\[Integral]\_0\%\[Infinity]\)\>\"", 
        f[t], \*"\"\< \!\(\[ExponentialE]\^\(-st\)\)\[DifferentialD]t = g[\
\[Infinity]] - g[0]\>\""];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<F[s] = \>", g[\[Infinity]] - g[0], "\< = \>", 
        F[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nAssuming that f(t) is of exponential order, we have  ",
  Cell[BoxData[
      \(g[t]\  \[Rule] \ \(0\ \ as\ \ t\  \[Rule] \ \[Infinity]\)\)]],
  ". Then  ",
  Cell[BoxData[
      \(\(\(g[\[Infinity]]\  = 0\)\(\ \)\)\)]],
  ",  and the Laplace transform can be computed by the calculation  ",
  Cell[BoxData[
      \(g[\[Infinity]]\  - \ g[0] = \(-\ g[0]\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<g[t] = \[Integral] \>", 
        f[t], \*"\"\< \!\(\[ExponentialE]\^\(-st\)\)\[DifferentialD]t = \
\>\"", g[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<F[s] = - g[0] = \>", 
        Simplify[\(-g[0]\)]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can check this with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s  result using the LaplaceTransform package."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(F[s_]\  = \ 
        LaplaceTransform[f[t], \ t, \ s];\)\ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<F[s] = \>", F[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 12.11.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "   Find the Laplace transform of  ",
  Cell[BoxData[
      \(f[t]\  = \ \ Cos[b\ t]\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.11.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Method 1.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  "Enter the function  ",
  Cell[BoxData[
      \(f \((t)\)\)]],
  "  and compute the integral defining   ",
  Cell[BoxData[
      RowBox[{
        StyleBox["\[ScriptCapitalL]",
          FontSize->16], \((f \((t)\))\)}]]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\(a = \(s = \(t = 0\)\);\)\), "\[IndentingNewLine]", 
    \(\(Remove[a, s, t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g, F];\)\ \), "\n", 
    \(\(f[t_]\  = \ Cos[b\ t];\)\ \), "\n", 
    \(\(g[
          t_]\  = \ \[Integral]f[
              t] \(\[ExponentialE]\^\(\(-s\)\ t\)\) \[DifferentialD]t;\)\ \), \
"\n", 
    \(\(F[s_]\  = \ 
        Integrate[f[t] \[ExponentialE]\^\(\(-s\)\ t\), \ {t, 0, \[Infinity]}, 
          Assumptions \[Rule] {Re[s] > 0, Im[b] \[Equal] 0}];\)\ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<g[t] = \[Integral] \>", 
        f[t], \*"\"\< \!\(\[ExponentialE]\^\(-st\)\)\[DifferentialD]t = \
\>\"", Simplify[g[t]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<F[s] = \!\(\[Integral]\_0\%\[Infinity]\)\>\"", 
        f[t], \*"\"\< \!\(\[ExponentialE]\^\(-st\)\)\[DifferentialD]t = g[\
\[Infinity]] - g[0]\>\""];\)\ \), "\n", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<F[s] = \>", Simplify[g[\[Infinity]] - g[0]], "\< = \>", 
        F[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nAssuming that f(t) is of exponential order, we have  ",
  Cell[BoxData[
      \(g[t]\  \[Rule] \ \(0\ \ as\ \ t\  \[Rule] \ \[Infinity]\)\)]],
  ". Then  ",
  Cell[BoxData[
      \(\(\(g[\[Infinity]]\  = 0\)\(\ \)\)\)]],
  ",  and the Laplace transform can be computed by the calculation  ",
  Cell[BoxData[
      \(g[\[Infinity]]\  - \ g[0] = \(-\ g[0]\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<g[t] = \[Integral] \>", 
        f[t], \*"\"\< \!\(\[ExponentialE]\^\(-st\)\)\[DifferentialD]t = \
\>\"", Simplify[g[t]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<F[s] = - g[0] = \>", 
        Simplify[\(-g[0]\)]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\nMethod 2",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[".",
    FontColor->RGBColor[1, 0, 1]],
  "  ",
  "Since  ",
  Cell[BoxData[
      \(f[
          t]\  = \ \(Cos[
            b\ t] = \ \(\(\[ExponentialE]\^\(\[ImaginaryI]\ b\ t\)\  + \ \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ b\ t\)\)\/2 = \(1\/2\) \[ExponentialE]\
\^\(\[ImaginaryI]\ b\ t\) + \(1\/2\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ b\
\ t\)\)\)\)]],
  ",  we can use  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["\[ScriptCapitalL]",
            FontSize->16], \((\[ExponentialE]\^\(\[ImaginaryI]\ b\ t\))\)}], 
        "=", 
        RowBox[{
          RowBox[{\(1\/\(s\  - \ \[ImaginaryI]\ b\)\), "  ", "and", "   ", 
            StyleBox["\[ScriptCapitalL]",
              
              FontSize->
                16], \((\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ b\ t\))\)}], 
          "=", \(1\/\(s\  + \ \[ImaginaryI]\ b\)\)}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(b = \(s = \(t = 0\)\);\)\), "\[IndentingNewLine]", 
    \(\(Remove[b, s, t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, f1, f2, f12, F, F1, F2, F12];\)\ \), "\n", 
    \(\(f1[t_]\  = \ \[ExponentialE]\^\(\[ImaginaryI]\ b\ t\);\)\ \), "\n", 
    \(\(f2[
          t_]\  = \ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ b\ t\);\)\ \), "\n\
", 
    \(\(f12[
          t_]\  = \ \(\[ExponentialE]\^\(\[ImaginaryI]\ b\ t\) + \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ b\ t\)\)\/2;\)\ \), "\n", 
    \(\(f[t_]\  = \ Cos[b\ t];\)\ \), "\n", 
    \(\(F1[s_]\  = \ LaplaceTransform[f1[t], \ t, \ s];\)\ \), "\n", 
    \(\(F2[s_]\  = \ LaplaceTransform[f2[t], \ t, \ s];\)\ \), "\n", 
    \(\(F12[s_]\  = \ LaplaceTransform[f[t], \ t, \ s];\)\ \), "\n", 
    \(\(F[s_]\  = \ LaplaceTransform[f[t], \ t, \ s];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(f\_1\)[t] = \>\"", f1[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(f\_2\)[t] = \>\"", f2[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_12\)[t] = \>\"", f12[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_12\)[t] = \>\"", 
        FullSimplify[f12[t]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<  f[t] = \>", FullSimplify[f[t]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(F\_1\)[s] = \>\"", F1[s]];\)\ \), "\n", 
    \(\(Print[\*"\"\< \!\(F\_2\)[s] = \>\"", F2[s]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\_12\)[s] = \!\(\(F\_1[s] + F\_2[s]\)\/2\) = \>\"", \
\(F1[s] + F2[s]\)\/2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(F\_12\)[s] = \!\(\(F\_1[s] + F\_2[s]\)\/2\) = \>\"", 
        Together[\(F1[s] + F2[s]\)\/2]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\< F[s] = \[ScriptCapitalL](Cos[b t]) = \>", 
        F[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can check this with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s  result using the LaplaceTransform package."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(F[s_]\  = \ 
        LaplaceTransform[f[t], \ t, \ s];\)\ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\(Print["\<F[s] = \>", F[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 12.12.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the inverse Laplace transform of  ",
  Cell[BoxData[
      \(F[s]\  = \ \(3  s\  + \ \ 6\)\/\(s\^2\ \  + \ \ 9\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Enter the function F[s] and find its partial fraction expansion.\
\>", "Text"],

Cell[BoxData[{
    \(\(A = \(s = \(t = 0\)\);\)\), "\[IndentingNewLine]", 
    \(\(Remove[A, s, t];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, f1, f2, F, L1, L2];\)\ \), "\n", 
    \(\(F[s_]\ \  = \ \ \(3  s\  + \ 6\)\/\(s\^2\  + \ 9\);\)\ \), "\n", 
    \(\(A\  = \ Expand[F[s]];\)\ \), "\n", 
    \(\(Print["\<F[s] = \>", F[s], "\< = \>", A];\)\ \), "\n", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

The transform F[s] is a linear combination.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(f1[t_]\  = Cos[3  t];\)\ \), "\n", 
    \(\(f2[t_]\  = Sin[3  t];\)\ \), "\n", 
    \(\(L1[s_]\  = \ s\/\(s\^2\  + \ 9\);\)\ \), "\n", 
    \(\(L2[s_]\  = \ 3\/\(s\^2\  + \ 9\);\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_1\)[t] = \>\"", f1[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_2\)[t] = \>\"", f2[t]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(L\_1\)[s] = \>\"", L1[s]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(L\_2\)[s] = \>\"", 
        L2[s]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< F[s] = \>", F[s]];\)\ \), "\n", 
    \(\(Print[\*"\"\<Is F[s] \[Equal] 3 \!\(L\_1\)[s] + 2 \!\(L\_2\)[s] \
?\>\""];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print[F[s]\  \[Equal] 3\ L1[s]\  + \ 2\ L2[s], "\<,   \>", 
        Expand[F[s]]\  \[Equal] \ 
          3\ L1[s]\  + \ 2\ L2[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nThe inverse of  ",
  Cell[BoxData[
      \(L\_1[s]\ \ is\ \ f\_1[t] = Cos[3\ t]\)]],
  "  and  the inverse of  ",
  Cell[BoxData[
      \(L\_2[s]\ \ is\ \ f\_2[t] = Sin[3\ t]\)]],
  ".  \nHence  ",
  Cell[BoxData[
      \(f[t]\  = \ 3\ f\_1[t]\  + \ 2\ f\_2[t]\)],
    AspectRatioFixed->True],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(f[t_]\  = \ 3\ f1[t]\  + \ 2\ f2[t];\)\ \), "\n", 
    \(\(Print[\*"\"\<f[t] = 3 \!\(f\_1\)[t] + 2 \!\(f\_2\)[t]\>\""];\)\ \), "\
\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can check this with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s  result using the LaplaceTransform package."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(f[t_]\  = \ 
        InverseLaplaceTransform[F[s], \ s, \ t];\)\ \), "\n", 
    \(\(Print["\<F[s] = \>", F[s]];\)\ \), "\n", 
    \(\(Print["\<f[t] = \>", f[t]];\)\ \), "\n", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Upgrade: This module is scheduled for \
revision in 2006.",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradMod.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Fourier Series and Transform",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/FourierTransformBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Dirichlet Problem",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/DirichletProblemBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Laplace Transform",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/LaplaceTransformBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{975, 619},
WindowMargins->{{15, Automatic}, {Automatic, 3}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[5865, 185, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[8235, 262, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[9473, 307, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 38776, 1197}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 117, 2, 33, "Text"],
Cell[2222, 66, 1929, 56, 250, "Text"],
Cell[4154, 124, 1337, 44, 109, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[5516, 172, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[5664, 178, 198, 5, 33, "Text",
  Evaluatable->False],
Cell[5865, 185, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[6225, 197, 994, 27, 97, "Text"],
Cell[7222, 226, 661, 20, 71, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[7908, 250, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[8056, 256, 176, 4, 33, "Text",
  Evaluatable->False],
Cell[8235, 262, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[8595, 274, 526, 17, 68, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[9146, 295, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[9294, 301, 176, 4, 33, "Text",
  Evaluatable->False],
Cell[9473, 307, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[9833, 319, 389, 11, 85, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[10247, 334, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[10410, 340, 259, 10, 33, "Text"],
Cell[10672, 352, 1186, 27, 350, "Input"],
Cell[11861, 381, 296, 11, 52, "Text",
  Evaluatable->False],
Cell[12160, 394, 274, 6, 110, "Input"]
}, Closed]],
Cell[12449, 403, 308, 11, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[12782, 418, 160, 4, 33, "Text",
  Evaluatable->False],
Cell[12945, 424, 259, 10, 33, "Text"],
Cell[13207, 436, 1161, 24, 297, "Input"],
Cell[14371, 462, 449, 13, 52, "Text",
  Evaluatable->False],
Cell[14823, 477, 428, 9, 131, "Input"],
Cell[15254, 488, 296, 11, 52, "Text",
  Evaluatable->False],
Cell[15553, 501, 274, 6, 110, "Input"]
}, Closed]],
Cell[15842, 510, 261, 10, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[16128, 524, 112, 2, 33, "Text"],
Cell[16243, 528, 786, 24, 37, "Text",
  Evaluatable->False],
Cell[17032, 554, 1781, 31, 554, "Input"],
Cell[18816, 587, 296, 11, 52, "Text",
  Evaluatable->False],
Cell[19115, 600, 274, 6, 110, "Input"]
}, Closed]],
Cell[19404, 609, 118, 3, 30, "Text"],
Cell[19525, 614, 253, 10, 33, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[19803, 628, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[19967, 634, 259, 10, 33, "Text"],
Cell[20229, 646, 1138, 24, 297, "Input"],
Cell[21370, 672, 449, 13, 52, "Text",
  Evaluatable->False],
Cell[21822, 687, 428, 9, 131, "Input"],
Cell[22253, 698, 296, 11, 52, "Text",
  Evaluatable->False],
Cell[22552, 711, 274, 6, 110, "Input"]
}, Closed]],
Cell[22841, 720, 258, 10, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[23124, 734, 175, 4, 33, "Text",
  Evaluatable->False],
Cell[23302, 740, 259, 10, 33, "Text"],
Cell[23564, 752, 1141, 24, 297, "Input"],
Cell[24708, 778, 449, 13, 52, "Text",
  Evaluatable->False],
Cell[25160, 793, 428, 9, 131, "Input"],
Cell[25591, 804, 296, 11, 52, "Text",
  Evaluatable->False],
Cell[25890, 817, 274, 6, 110, "Input"]
}, Closed]],
Cell[26179, 826, 263, 10, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[26467, 840, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[26631, 846, 350, 14, 33, "Text"],
Cell[26984, 862, 1170, 24, 297, "Input"],
Cell[28157, 888, 449, 13, 52, "Text",
  Evaluatable->False],
Cell[28609, 903, 438, 9, 131, "Input"],
Cell[29050, 914, 1051, 32, 58, "Text",
  Evaluatable->False],
Cell[30104, 948, 1852, 33, 556, "Input"],
Cell[31959, 983, 296, 11, 52, "Text",
  Evaluatable->False],
Cell[32258, 996, 274, 6, 110, "Input"]
}, Closed]],
Cell[32547, 1005, 327, 11, 34, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[32899, 1020, 161, 4, 33, "Text",
  Evaluatable->False],
Cell[33063, 1026, 88, 2, 33, "Text"],
Cell[33154, 1030, 410, 8, 164, "Input"],
Cell[33567, 1040, 116, 5, 52, "Text",
  Evaluatable->False],
Cell[33686, 1047, 979, 19, 336, "Input"],
Cell[34668, 1068, 380, 14, 71, "Text",
  Evaluatable->False],
Cell[35051, 1084, 291, 6, 110, "Input"],
Cell[35345, 1092, 296, 11, 52, "Text",
  Evaluatable->False],
Cell[35644, 1105, 264, 6, 110, "Input"]
}, Closed]],
Cell[35923, 1114, 331, 8, 30, "Text"],
Cell[36257, 1124, 290, 7, 33, "Text"],
Cell[36550, 1133, 302, 7, 33, "Text"],
Cell[36855, 1142, 291, 7, 33, "Text"],
Cell[37149, 1151, 291, 7, 33, "Text"],
Cell[37443, 1160, 257, 5, 33, "Text"],
Cell[37703, 1167, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

