(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     42375,       1257]*)
(*NotebookOutlinePosition[     43863,       1308]*)
(*  CellTagsIndexPosition[     43787,       1302]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"],

Cell[TextData[StyleBox["12.9  Inverting the Laplace Transform",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[TextData[{
  "\tSo far, most of the applications involving the Laplace transform \
involves a transform (or part of a transform) that is expressed by \n\n\t\t\t\
",
  Cell[BoxData[
      \(Y \((s)\) = \(P \((s)\)\)\/\(Q \((s)\)\)\)]],
  "  \n\nwhere  P  and  Q  are polynomials that have no common factors.  The \
inverse of  ",
  Cell[BoxData[
      \(Y \((s)\)\)]],
  "  is found by using its partial fraction representation and referring to \
Table 12.2 of Laplace Transforms.  We now show how the theory of complex \
variables can be used to systematically find the partial fraction \
representation.  The first result is an extension of Lemma 8.1 to  n  linear \
factors.  The proof is left for the reader."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 12.19 (Nonrepeated Linear Factors).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " Let ",
  Cell[BoxData[
      \(P \((s)\)\)]],
  " be a polynomial of degree at most ",
  Cell[BoxData[
      \(n - 1\)]],
  ". If ",
  Cell[BoxData[
      \(Q \((s)\)\)]],
  " has degree n, and has distinct complex roots  ",
  Cell[BoxData[
      \(a\_1, a\_2, \(\(...\) \(a\_n\)\)\)]],
  ",  then  \n\n\t\t\t",
  Cell[BoxData[
      \(Y \((s)\) = \(\(\(P \((s)\)\)\/\(Q \((s)\)\)\)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \(\(P \((s)\)\)\/\(\(\((s - a\_1)\) \((s - a\_2)\) ... \) \((s - \
a\_n)\)\) = \[Sum]\+\(k = 1\)\%n Res[Y, a\_k]\/\((s - a\_k)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.19 is left for the reader in the \
book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 12.20 (A Repeated Linear Factors).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " If ",
  Cell[BoxData[
      RowBox[{"P", \((s)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "Q", \((s)\)}]]],
  " are polynomials of degree ",
  Cell[BoxData[
      RowBox[{"\[Mu]", " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "\[Nu]"}]]],
  ", respectively and ",
  Cell[BoxData[
      \(\[Mu] < \[Nu] + n\)]],
  "  and  ",
  Cell[BoxData[
      \(Q \((a)\) \[NotEqual] 0\)]],
  ",  then  \n\n\t\t\t",
  Cell[BoxData[
      \(Y \((s)\) = \(P \((s)\)\)\/\(\(\((s\  - \ a)\)\^n\) Q \((s)\)\)\)]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\[Sum]\+\(k = 1\)\%n A\_k\/\((s\  - \ a)\)\^k\ \
 + \ R \((s)\)\)\)\)\)]],
  ",  \n\nwhere  ",
  Cell[BoxData[
      \(R \((s)\)\)]],
  "  is the sum of all partial fractions that do not involve factors of the \
form  ",
  Cell[BoxData[
      StyleBox[
        SuperscriptBox[
          RowBox[{"(", 
            RowBox[{"s", " ", "-", 
              StyleBox[" ",
                FontSize->12], "a"}], ")"}], "j"],
        FontSize->12]]],
  ".  Furthermore, the coefficients  ",
  Cell[BoxData[
      SubscriptBox[
        StyleBox["A",
          FontSize->14], "k"]]],
  "  can be computed with the formula  ",
  Cell[BoxData[
      \(A\_k = \(\(1\/\(\((n - 
                      k)\)!\)\) \(lim\+\(s\  \[Rule] \ a\)\ \ d\^\(n - \
k\)\/\(d\ s\^\(n - k\)\)\ \(P \((s)\)\)\/\(Q \((s)\)\)\ \ for\ \ k\) = 1\), 
      2,  ... , n\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.20 is  left for the reader in the \
book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 12.24.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the inverse Laplace transform of  ",
  Cell[BoxData[
      \(Y[s] = \(s\^3\  - \ 4  s\  + \ \ 1\)\/\(s \((s\  - \ 1)\)\^3\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.24.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter Y[s] and find its partial fraction expansion.", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[a, b, s, t, Y, PQ, PR];\)\ \), "\n", 
    \(\(Y[
          s_]\  = \ \(s\^3\  - \ 4  s\  + \ 1\)\/\(s \((s - 1)\)\^3\);\)\ \), \
"\n", 
    \(\(Print["\<Y[s] = \>", Y[s]];\)\ \), "\n", 
    \(\(Print["\<Y[s] = \>", Apart[Y[s]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Traditionally.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The partial fraction expansion can be obtained with the residue calculus. \
\n",
  Cell[BoxData[
      \(Y[
          s]\  = \(\(\ \)\(a\_3\)\)\/\((s\  - \ 1)\)\^3\  + \(\(\ \
\)\(a\_2\)\)\/\((s\  - \ 1)\)\^2 + \ 
          a\_1\/\(s\  - \ 1\)\  + \(\(\ \)\(b\_1\)\)\/s\)]],
  "  \nAt  s = 1, we compute  ",
  Cell[BoxData[
      \(a\_1, a\_2, \ and\ \ a\_3\)]],
  "  as follows."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(PQ\  = \ \(s\^3\  - \ 4  s\  + \ 1\)\/s;\)\ \), "\n\
", 
    \(\(a\_3\  = \ Limit[PQ, s \[Rule] 1];\)\ \), "\n", 
    \(\(a\_2\  = \ Limit[\[PartialD]\_s\ PQ, s \[Rule] 1];\)\ \), "\n", 
    \(\(a\_1\  = 
        1\/\(2!\)\ Limit[\[PartialD]\_\(s, s\)PQ, s \[Rule] 1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(a\_3\) = \!\(lim\+\(s \[Rule] 1\)\) \>\"", 
        PQ, "\< = \>", a\_3];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(a\_2\) = \!\(lim\+\(s \[Rule] 1\)\) \>\"", 
        Together[\[PartialD]\_s\ PQ], "\< = \>", a\_2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(a\_1\) = \!\(lim\+\(s \[Rule] 1\)\) \>\"", 
        Together[\[PartialD]\_\(s, s\)PQ], "\< = \>", 
        a\_1];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nAt  s = 0, we compute  ",
  Cell[BoxData[
      \(b\_1\)]],
  "  as follows."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(PR\  = \ \(s\^3\  - \ 4  s\  + \ 1\)\/\((s - \
1)\)\^3;\)\ \), "\n", 
    \(\(b\_1\  = \ Limit[PR, s \[Rule] 0];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(b\_1\) = \!\(lim\+\(s \[Rule] 0\)\)\>\"", 
        PR, "\< = \>", b\_1];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

Using the residue calculus, we construct the partial fraction expansion.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Y[
          s_]\  = \(\(\ \)\(a\_3\)\)\/\((s\  - \ 1)\)\^3\  + \(\(\ \)\(a\_2\)\
\)\/\((s\  - \ 1)\)\^2 + \ 
          a\_1\/\(s\  - \ 1\)\  + \(\(\ \)\(b\_1\)\)\/s;\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<Y[s] = \>", Y[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nUse a table of Laplace transforms to solve for  ",
  Cell[BoxData[
      RowBox[{\(y[t]\), "=", 
        RowBox[{
          StyleBox[\(\[ScriptCapitalL]\^\(-1\)\),
            FontSize->16], \((Y[s])\)}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Ys = 
        Table[0, {i, Length[Y[s]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(For[i = 1, i \[LessEqual] Length[Y[s]], \(i++\), 
        Ys\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ \
\(Y[s]\)\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)];\)\ \), \
"\[IndentingNewLine]", 
    \(\(yt = 
        InverseLaplaceTransform[Ys, \ s, \ t];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Transpose[{yt, Ys}];\)\ \), "\[IndentingNewLine]", 
    \(\(y[t_]\  = \ 
        InverseLaplaceTransform[Y[s], \ s, \ 
          t];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[table, 
          TableHeadings \[Rule] {None, {"\<f[t]\>", \
"\<\[ScriptCapitalL](f[t])\>"}}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Y[s] = \>", Y[s]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", y[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can check this with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s  result using the LaplaceTransform package."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(y[t_]\  = \ 
        InverseLaplaceTransform[Y[s], \ s, \ t];\)\ \), "\n", 
    \(\(Print["\<Y[s] = \>", Apart[Y[s]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", Expand[y[t]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 12.21 (Irreducible Quadratic Factors).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " Let ",
  Cell[BoxData[
      RowBox[{"P", \((s)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "Q", \((s)\)}]]],
  " be polynomials with real coefficients such that the degree of ",
  Cell[BoxData[
      \(P \((s)\)\)]],
  " is at most 1 larger than the degree of ",
  Cell[BoxData[
      \(Q \((s)\)\)]],
  ".   If  ",
  Cell[BoxData[
      \(T \((s)\)\)]],
  "  does not have a factor of the form  ",
  Cell[BoxData[
      \(\((s - a)\)\^2 + b\^2\)]],
  ",  then  \n\n\t\t\t",
  Cell[BoxData[
      \(Y \((s)\) = \(\(P \((s)\)\)\/\(Q \((s)\)\) = \(P \((s)\)\)\/\(\((\((s\
\  - \ a)\)\^2\  + \ b\^2)\) T \((s)\)\)\)\)]],
  Cell[BoxData[
      \(\(\(=\)\(\(2  A \((s\  - \ a)\)\  - \ 2  B\ b\)\/\(\((s\  - \ a)\)\^2\
\  + \ b\^2\) + R \((s)\)\)\)\)]],
  ",  where  ",
  Cell[BoxData[
      \(A\  + \ \[ImaginaryI]\ B = \(P \((a\  + \ \[ImaginaryI]\ b)\)\)\/\(Q' \
\((a\  + \ \[ImaginaryI]\ b)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.21 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 12.25.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the inverse Laplace transform of  ",
  Cell[BoxData[
      \(Y[s] = \(5  s\)\/\(\((s\^2\  + \ 4)\) \((s\^2\  + \ 9)\)\)\)],
    AspectRatioFixed->True],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.25.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter Y[s] and find its partial fraction expansion.", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[a, A, b, B, s, t, Y, z, i, res1, res2, 
        Yi];\)\ \), "\n", 
    \(\(Y[
          s_]\  = \ \(5  s\)\/\(\((s\^2 + 4)\) \((s\^2 + 9)\)\);\)\ \), "\n", \

    \(\(Print["\<Y[s] = \>", Y[s]];\)\ \), "\n", 
    \(\(Print["\<Y[s] = \>", Apart[Y[s]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Traditionally.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " The partial fraction expansion can be obtained with the residue calculus. \
\nThe simple poles in the upper half plane occur at  ",
  Cell[BoxData[
      \(z\_1 = \(2  \[ImaginaryI]\ and\ \ z\_2 = 3  \[ImaginaryI]\)\)]],
  ".  First determine their residues."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(z\_1\  = \ 2  \[ImaginaryI];\)\ \), "\n", 
    \(\(z\_2\  = \ 3  \[ImaginaryI];\)\ \), "\n", 
    \(\(res1\  = \ Residue[Y[s], {s, z\_1}];\)\ \), "\n", 
    \(\(res2\  = \ Residue[Y[s], {s, z\_2}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Y[s] = \>", Y[s]];\)\ \), "\n", 
    \(\(Print["\<Res[Y[s],\>", z\_1, "\<] = \>", res1];\)\ \), "\n", 
    \(\(Print["\<Res[Y[s],\>", z\_2, "\<] = \>", 
        res2];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell["\<\

Using the residue calculus, we construct the partial fraction expansion.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(a\_1\  = \ Re[z\_1];\)\ \), "\n", 
    \(\(b\_1\  = \ Im[z\_1];\)\ \), "\n", 
    \(\(A\_1\  = \ Re[res1];\)\ \), "\n", 
    \(\(B\_1\  = \ Im[res1];\)\ \), "\n", 
    \(\(a\_2\  = \ Re[z\_2];\)\ \), "\n", 
    \(\(b\_2\  = \ Im[z\_2];\)\ \), "\n", 
    \(\(A\_2 = \ Re[res2];\)\ \), "\n", 
    \(\(B\_2\  = \ Im[res2];\)\ \), "\n", 
    \(\(Y1[
          s_]\  = \((2\ \(A\_1\) \((s\  - \ a\_1)\)\  - \ 2\ B\_1\ \
b\_1)\)\/\((\((s\  - \ a\_1)\)\^2\  + \ b\_1\^2)\);\)\ \), "\n", 
    \(\(Y2[
          s_]\  = \((2\ \(A\_2\) \((s\  - \ a\_2)\)\  - \ 2\ B\_2\ \
b\_2)\)\/\((\((s\  - \ a\_2)\)\^2\  + \ b\_2\^2)\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(Y[s_] = Y1[s]\  + \ Y2[s];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(Y\_1\)[s] = \>\"", Y1[s]];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(Y\_2\)[s] = \>\"", 
        Y2[s]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\< Y[s] = \>", Y[s]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nUse a table of Laplace transforms to solve for  ",
  Cell[BoxData[
      RowBox[{\(y[t]\), "=", 
        RowBox[{
          StyleBox[\(\[ScriptCapitalL]\^\(-1\)\),
            FontSize->16], \((Y[s])\)}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Ys = 
        Table[0, {i, Length[Y[s]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(For[i = 1, i \[LessEqual] Length[Y[s]], \(i++\), 
        Ys\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ \
\(Y[s]\)\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)];\)\ \), \
"\[IndentingNewLine]", 
    \(\(yt = 
        InverseLaplaceTransform[Ys, \ s, \ t];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Transpose[{yt, Ys}];\)\ \), "\[IndentingNewLine]", 
    \(\(y[t_]\  = \ 
        InverseLaplaceTransform[Y[s], \ s, \ 
          t];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[table, 
          TableHeadings \[Rule] {None, {"\<f[t]\>", \
"\<\[ScriptCapitalL](f[t])\>"}}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Y[s] = \>", Y[s]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", y[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can check this with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s  result using the LaplaceTransform package."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(y[t_]\  = \ 
        InverseLaplaceTransform[Y[s], \ s, \ t];\)\ \), "\n", 
    \(\(Print["\<Y[s] = \>", Apart[Y[s]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", y[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 12.26.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the inverse Laplace transform of  ",
  Cell[BoxData[
      \(Y[
          s] = \(s\^3\  + \ 3  s\^2\  - \ s\  + \ 1\)\/\(s \(\((s\  + \ \
1)\)\^2\) \((s\^2\  + \ 1)\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.26.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["Enter Y[s] and find its partial fraction expansion.", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[i, s, t, y, Y, Yi];\)\ \), "\n", 
    \(\(Y[
          s_]\  = \ \(s\^3 + 3  s\^2 - s + 1\)\/\(s \(\((s + 1)\)\^2\) \
\((s\^2 + 1)\)\);\)\ \), "\n", 
    \(\(Print["\<Y[s] = \>", Y[s]];\)\ \), "\[IndentingNewLine]", 
    \(\(Y[s_]\  = Apart[Y[s]];\)\ \), "\n", 
    \(\(Print["\<Y[s] = \>", Y[s]];\)\ \), "\[IndentingNewLine]", 
    \(\(Y[s_]\  = 
        Map[Simplify, ExpandAll[Y[s]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Y[s] = \>", Y[s]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\nUse a table of Laplace transforms to solve for  ",
  Cell[BoxData[
      RowBox[{\(y[t]\), "=", 
        RowBox[{
          StyleBox[\(\[ScriptCapitalL]\^\(-1\)\),
            FontSize->16], \((Y[s])\)}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Ys = 
        Table[0, {i, Length[Y[s]]}];\)\ \), "\[IndentingNewLine]", 
    \(\(For[i = 1, i \[LessEqual] Length[Y[s]], \(i++\), 
        Ys\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)\  = \ \
\(Y[s]\)\_\(\(\[LeftDoubleBracket]\)\(i\)\(\[RightDoubleBracket]\)\)];\)\ \), \
"\[IndentingNewLine]", 
    \(\(yt = 
        InverseLaplaceTransform[Ys, \ s, \ t];\)\ \), "\[IndentingNewLine]", 
    \(\(table = Transpose[{yt, Ys}];\)\ \), "\[IndentingNewLine]", 
    \(\(y[t_]\  = \ 
        InverseLaplaceTransform[Y[s], \ s, \ 
          t];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[table, 
          TableHeadings \[Rule] {None, {"\<f[t]\>", \
"\<\[ScriptCapitalL](f[t])\>"}}]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Y[s] = \>", Y[s]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", y[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can check this with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s  result using the LaplaceTransform package."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(y[t_]\  = \ 
        InverseLaplaceTransform[Y[s], \ s, \ t];\)\ \), "\n", 
    \(\(Print["\<Y[s] = \>", Y[s]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", y[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 12.27.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "\t Solve the initial value problem  \n\n\t\t",
  Cell[BoxData[
      \(y' \((t)\) = \ \ \ \(y \((t)\)\  - \ \ x \
\((t)\)\ \ \ \ \ \ with\ \ \ y \((0)\) = 
          1\), \[IndentingNewLine]x' \((t)\) = \(5  y \((t)\) - 
            3  x \((t)\)\ \ \ \ \ \ \ \ and\ \ \ x \((0)\) = 2. \)\)]],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Explore Solution 12.27.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter the initial conditions and the system of  D.E.s.  Then Laplace \
transform the D.E.s and solve for the transforms Y[s] any X[s] and the \
functions y[t] and x[t].\
\>", "Text"],

Cell[BoxData[{
    \(\n\(Clear[eqn1, eqn2, solset, s, t, x, X, y, Y, x0, 
        y0];\)\ \), "\[IndentingNewLine]", 
    \(\(de1\  = \ \(y'\)[
            t]\  \[Equal] \ \ \ y[t]\ \  - \ \ x[
              t]\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(de2\  = \ \(x'\)[t]\  \[Equal] \ 
          5  y[t]\  - \ 3  x[t]\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(y0\  = \ 1;\)\ \), "\[IndentingNewLine]", 
    \(\(x0\  = \ 2;\)\ \), "\[IndentingNewLine]", 
    \(\(eqn1 = 
        ReplaceAll[
          de1, {x[t] \[Rule] X[s], 
            y[t] \[Rule] Y[s], \(y'\)[t] \[Rule] 
              s\ Y[s] - y0}];\)\ \), "\[IndentingNewLine]", 
    \(\(eqn2 = 
        ReplaceAll[
          de2, {x[t] \[Rule] X[s], 
            y[t] \[Rule] Y[s], \(x'\)[t] \[Rule] 
              s\ X[s] - x0}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[de2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y[0] = \>", y0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x[0] = \>", x0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[eqn2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ Solve[{eqn1, eqn2}, \ {X[s], Y[s]}];\)\ \), "\n", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(X[s_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Y[s_]\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 2, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(y[t_]\  = \ 
        InverseLaplaceTransform[Y[s], \ s, \ 
          t];\)\ \), "\[IndentingNewLine]", 
    \(\(y[t_]\  = FullSimplify[y[t]];\)\ \), "\n", 
    \(\(x[t_]\  = \ 
        InverseLaplaceTransform[X[s], \ s, \ 
          t];\)\ \), "\[IndentingNewLine]", 
    \(\(x[t_]\  = FullSimplify[x[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Y[s] = \>", Y[s]];\)\ \), "\n", 
    \(\(Print["\<X[s] = \>", X[s]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", y[t]];\)\ \), "\n", 
    \(\(Print["\<x[t] = \>", x[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can substitute y[t] and x[t] into the D.E.'s and verify that they are \
the solution."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<        y'[t] = \>", \(y'\)[t]];\)\ \), "\n", 
    \(\(Print["\<  y[t] - x[t] = \>", 
        Expand[y[t] - x[t]]\ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<  Does  y'[t] = y[t] - x[t] ? \>", 
        ExpandAll[\(y'\)[t] \[Equal] y[t] - x[t]]];\)\ \), "\n", 
    \(\(Print["\< \>"];\)\ \), "\n", 
    \(\(Print["\<        x'[t] = \>", \(x'\)[
          t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<        x'[t] = \>", Expand[\(x'\)[t]]];\)\ \), "\n", 
    \(\(Print["\<5y[t] - 3x[t] = \>", 
        Expand[5  y[t]\  - \ 3  x[t]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Does    x'[t] = 5y[t] - 3x[t] ? \>", 
        ExpandAll[\(x'\)[t] \[Equal] 
            5  y[t]\  - \ 3  x[t]]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "/s DSolve package to solve the system of D.E.'s and plot the solution."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[eqn1, eqn2, solset, t, x, y];\)\ \), "\n", 
    \(\(eqn1\  = \ \(y'\)[t]\  \[Equal] \ \ y[t]\  - \ x[t];\)\ \), "\n", 
    \(\(eqn2\  = \ \(x'\)[t]\  \[Equal] \ 
          5  y[t]\  - \ 3  x[t];\)\ \), "\n", 
    \(\(Print[eqn1];\)\ \), "\n", 
    \(\(Print[eqn2];\)\ \), "\n", 
    \(\(solset\  = \ 
        DSolve[{eqn1, eqn2, \ x[0] \[Equal] 2, \ 
            y[0] \[Equal] 1}, \ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ {y[t], \ 
            x[t]}, \ t];\)\ \), "\n", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(y[t_]\  = \ 
        FullSimplify[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\n", 
    \(\(x[t_]\  = \ 
        FullSimplify[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 2, \
2\)\(\[RightDoubleBracket]\)\)];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(ParametricPlot[{x[t], y[t]}, {t, 0, 5}, 
        PlotRange \[Rule] {{\(-0.1\), 2}, {\(-0.1\), 1}}, 
        PlotStyle \[Rule] Magenta, AxesLabel \[Rule] {"\<x\>", "\<y\>"}, 
        Ticks \[Rule] {Range[0, 2, 0.5], Range[0, 1, 0.25]}];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", y[t]];\)\ \), "\n", 
    \(\(Print["\<x[t] = \>", x[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y[0] = \>", y0];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<x[0] = \>", x0];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"]
}, Closed]],

Cell[TextData[{
  StyleBox["Theorem 12.22 (Inverse Laplace Transform).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " Let ",
  Cell[BoxData[
      \(Y \((s)\) = \(P \((s)\)\)\/\(Q \((s)\)\)\)]],
  ", where ",
  Cell[BoxData[
      RowBox[{"P", \((s)\), " ", 
        StyleBox["and",
          FontFamily->"Times New Roman",
          FontSize->12,
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontColor->GrayLevel[0],
          FontVariations->{"Underline"->False,
          "StrikeThrough"->False}], " ", "Q", \((s)\)}]]],
  " are polynomials of degree m and n, respectively, and  ",
  Cell[BoxData[
      \(n > m\)]],
  ".  The inverse Laplace transform of  ",
  Cell[BoxData[
      \(Y \((s)\)\)]],
  "  is given by  \n\n\t\t",
  Cell[BoxData[
      RowBox[{\(y \((t)\)\), " ", "=", " ", 
        RowBox[{
          StyleBox[\(\[ScriptCapitalL]\^\(-1\)\),
            FontSize->16], \((Y \((s)\))\)}]}]]],
  Cell[BoxData[
      \(\(\(\ \)\(\(=\)\(\ \)\(\[Sum]\ 
          Res[F \((s)\) \[ExponentialE]\^\(s\ t\), s\_k]\)\)\)\)]],
  ",  \n\nwhere the sum is taken over all the residues of the complex \
function  ",
  Cell[BoxData[
      \(F \((s)\) \[ExponentialE]\^\(s\ t\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.22 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  "\n\tUsing the residue calculus, the English mathematician ",
  ButtonBox["Oliver Heaviside",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Heaviside.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " discovered a method for inverting the Laplace transform."
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 12.23 (Heaviside Expansion Theorem).",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " Let ",
  Cell[BoxData[
      \(P \((s)\)\)]],
  " and ",
  Cell[BoxData[
      \(Q \((s)\)\)]],
  " be polynomials of degree m and n, respectively, where ",
  Cell[BoxData[
      \(n > m\)]],
  ". If ",
  Cell[BoxData[
      \(Q \((s)\)\)]],
  " has n distinct simple zeros at the points  ",
  Cell[BoxData[
      RowBox[{
        SubscriptBox[
          StyleBox["s",
            FontSize->14], "1"], ",", 
        SubscriptBox[
          StyleBox["s",
            FontSize->14], "2"], 
        StyleBox[",",
          FontSize->14], "\[CenterEllipsis]", 
        StyleBox[",",
          FontSize->14], 
        SubscriptBox[
          StyleBox["s",
            FontSize->14], "n"]}]]],
  ",  then  ",
  Cell[BoxData[
      FractionBox[
        StyleBox[\(P \((s)\)\),
          FontSize->12], 
        StyleBox[\(Q \((s)\)\),
          FontSize->12]]]],
  "  is the Laplace transform of the function  ",
  Cell[BoxData[
      \(y \((t)\)\)]],
  "  given by\n\n\t\t",
  Cell[BoxData[
      RowBox[{\(y \((t)\)\), "=", 
        RowBox[{
          RowBox[{
            StyleBox[\(\[ScriptCapitalL]\^\(-1\)\),
              FontSize->16], \((\(P \((s)\)\)\/\(Q \((s)\)\))\)}], 
          "=", \(\[Sum]\+\(k = 1\)\%n\(\( 
                    P \((s\_k)\)\)\/\(Q' \((s\_k)\)\)\) \
\[ExponentialE]\^\(s\_k\ t\)\)}]}]]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Proof.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[StyleBox["Proof of Theorem 12.23 is in the book.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[ButtonBox["Complex Analysis for Mathematics and \
Engineering",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/books/cbook.htm"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 1"]
}, Closed]],

Cell[TextData[{
  StyleBox["Example 12.28.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Find the inverse Laplace transform of  ",
  Cell[BoxData[
      \(Y[
          s] = \(4  s\  + \ 3\)\/\(\(\ \)\(s\^3\  + \ 2  s\^2\  + \ s\  + \ 2\
\)\)\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 12.28.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text"],

Cell["\<\
Enter Y[s] and use the Heaviside Expansion Theorem to find y[t].\
\>", "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Clear[P, Q, solset, s, t, y, Y];\)\ \), "\n", 
    \(\(P[s_]\  = \ 4  s\  + \ 3;\)\ \), "\n", 
    \(\(Q[s_]\  = \ s\^3\  + \ 2  s\^2\  + \ s\  + \ 2;\)\ \), "\n", 
    \(\(Y[s_]\  = \ P[s]\/Q[s];\)\ \), "\[IndentingNewLine]", 
    \(\(solset\  = \ Solve[Q[s] \[Equal] 0, s];\)\ \), "\n", 
    \(\(s\_1\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(s\_2\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(s\_3\  = \ 
        solset\_\(\(\[LeftDoubleBracket]\)\(3, 1, \
2\)\(\[RightDoubleBracket]\)\);\)\ \), "\n", 
    \(\(Print["\<P[s] = \>", P[s]];\)\ \), "\n", 
    \(\(Print["\<Q[s] = \>", Q[s]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Y[s] = \>", Y[s]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<Solve the equation Q[s] = 0\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[Q[s]\  \[Equal] 0\ ];\)\ \), "\n", 
    \(\(Print[Factor[Q[s]] \[Equal] 0];\)\ \), "\n", 
    \(\(Print[solset];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(s\_1\) = \>\"", s\_1];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(s\_2\) = \>\"", s\_2];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(s\_3\) = \>\"", 
        s\_3];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "\nQ[s] has simple zeros at the points  ",
  Cell[BoxData[
      \(s\_1\  = \(-2\), \ s\_2\  = \(-\[ImaginaryI]\), \ 
      and\ \ s\_3\  = \[ImaginaryI]\)]],
  ".  Construct the three terms  ",
  Cell[BoxData[
      \(\(P[s\_k]\/\(Q'\)[
                s\_k]\) \[ExponentialE]\^\(\(s\_k\) t\)\ \ for\ \ k\  = \ 1, 
      2, 3\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Print["\<P[\>", s\_1, "\<]/Q'[\>", 
        s\_1, "\<] = (\>", P[s\_1], "\<)/(\>", \(Q'\)[s\_1], "\<) = \>", 
        P[s\_1]\/\(Q'\)[s\_1]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<P[\>", s\_2, "\<]/Q'[\>", s\_2, "\<] = (\>", 
        P[s\_2], "\<)/(\>", \(Q'\)[s\_2], "\<) = \>", 
        P[s\_2]\/\(Q'\)[s\_2]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<P[\>", s\_3, "\<]/Q'[\>", s\_3, "\<] = (\>", 
        P[s\_3], "\<)/(\>", \(Q'\)[s\_3], "\<) = \>", 
        P[s\_3]\/\(Q'\)[s\_3]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<P[\>", s\_1, "\<]/Q'[\>", 
        s\_1, "\<] \>", \[ExponentialE]\^\(\(s\_1\) t\), "\< = \>", \(P[
                s\_1]\/\(Q'\)[
                s\_1]\) \[ExponentialE]\^\(\(s\_1\) t\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<P[\>", s\_2, "\<]/Q'[\>", 
        s\_2, "\<] \>", \[ExponentialE]\^\(\(s\_2\) t\), "\< = \>", \(P[
                s\_2]\/\(Q'\)[
                s\_2]\) \[ExponentialE]\^\(\(s\_2\) t\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<P[\>", s\_2, "\<]/Q'[\>", 
        s\_2, "\<] \>", \[ExponentialE]\^\(\(s\_2\) t\), "\< = \>", 
        ComplexExpand[\(P[s\_2]\/\(Q'\)[
                  s\_2]\) \[ExponentialE]\^\(\(s\_2\) t\)]];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<P[\>", s\_3, "\<]/Q'[\>", 
        s\_3, "\<] \>", \[ExponentialE]\^\(\(s\_3\) t\), "\< = \>", \(P[
                s\_3]\/\(Q'\)[
                s\_3]\) \[ExponentialE]\^\(\(s\_3\) t\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<P[\>", s\_3, "\<]/Q'[\>", 
        s\_3, "\<] \>", \[ExponentialE]\^\(\(s\_3\) t\), "\< = \>", 
        ComplexExpand[\(P[s\_3]\/\(Q'\)[
                  s\_3]\) \[ExponentialE]\^\(\(s\_3\) t\)]];\)\ \), "\
\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell["\<\

Use the Heaviside Expansion Theorem to construct y[t].\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(y[
          t_]\  = \(P[s\_1]\/\(Q'\)[
                  s\_1]\) \[ExponentialE]\^\(\(s\_1\) t\) + \(P[s\_2]\/\(Q'\)[
                  s\_2]\) \[ExponentialE]\^\(\(s\_2\) t\) + \(P[s\_3]\/\(Q'\)[
                  s\_3]\) \[ExponentialE]\^\(\(s\_3\) t\);\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<y[t] = P[\>", s\_1, "\<]/Q'[\>", 
        s\_1, "\<] \>", \[ExponentialE]\^\(\(s\_1\) t\), "\< + \>", "\<P[\>", 
        s\_2, "\<]/Q'[\>", 
        s\_2, "\<] \>", \[ExponentialE]\^\(\(s\_2\) t\), "\< + \>", "\<P[\>", 
        s\_3, "\<]/Q'[\>", 
        s\_3, "\<] \>", \[ExponentialE]\^\(\(s\_3\) t\)];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<y[t] = (\>", \(P[s\_1]\/\(Q'\)[
                s\_1]\) \[ExponentialE]\^\(\(s\_1\) t\), "\<) + (\>", \(P[
                s\_2]\/\(Q'\)[
                s\_2]\) \[ExponentialE]\^\(\(s\_2\) t\), "\<) + (\>", \(P[
                s\_3]\/\(Q'\)[
                s\_3]\) \[ExponentialE]\^\(\(s\_3\) t\), "\<)\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print["\<y[t] = (\>", 
        ComplexExpand[\(P[s\_1]\/\(Q'\)[
                  s\_1]\) \[ExponentialE]\^\(\(s\_1\) t\)], "\<)\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<     + (\>", 
        ComplexExpand[\(P[s\_2]\/\(Q'\)[
                  s\_2]\) \[ExponentialE]\^\(\(s\_2\) t\)], "\<)\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print["\<     + (\>", 
        ComplexExpand[\(P[s\_3]\/\(Q'\)[
                  s\_3]\) \[ExponentialE]\^\(\(s\_3\) t\)], "\<)\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(y[t_]\  = ComplexExpand[y[t]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<y[t] = \>", y[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input"],

Cell[TextData[{
  "\n",
  StyleBox["Aside.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  " We can check this with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s  result using the LaplaceTransform package."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(y[t_]\  = \ 
        InverseLaplaceTransform[Y[s], \ s, \ t];\)\ \), "\n", 
    \(\(Print["\<F[s] = \>", 
        Map[Expand, Apart[Y[s]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<y[t] = \>", y[t]];\)\ \), "\[IndentingNewLine]", 
    \(\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[StyleBox[ButtonBox["Upgrade: This module is scheduled for \
revision in 2006.",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradMod.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Library Research Experience for \
Undergraduates",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/ComplexUndergradRes.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Fourier Series and Transform",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/FourierTransformBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Dirichlet Problem",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/DirichletProblemBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Laplace Transform",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/c2003/LaplaceTransformBib.html"], 
    None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1],
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["Return to the Complex Analysis Project",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/complex.html"], None},
  ButtonStyle->"Hyperlink"],
  FontWeight->"Bold",
  FontVariations->{"Underline"->True}]], "Text"],

Cell[TextData[StyleBox[ButtonBox["(c) 2006 John H. Mathews, Russell W. \
Howell",
  ButtonData:>{
    URL[ "http://math.fullerton.edu/mathews/"], None},
  ButtonStyle->"Hyperlink"],
  FontColor->RGBColor[0, 1, 0],
  FontVariations->{"Underline"->True}]], "Text"]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1014, 621},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 1"->{
    Cell[1754, 51, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[4099, 125, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[6886, 219, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[14210, 448, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[30419, 910, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"],
    Cell[32993, 1004, 345, 9, 33, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 1", 43182, 1279}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"],
Cell[2102, 62, 127, 2, 33, "Text"],
Cell[2232, 66, 729, 15, 152, "Text"],
Cell[2964, 83, 761, 25, 77, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3750, 112, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[3898, 118, 198, 5, 33, "Text",
  Evaluatable->False],
Cell[4099, 125, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[4459, 137, 2052, 65, 136, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[6536, 206, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[6684, 212, 199, 5, 33, "Text",
  Evaluatable->False],
Cell[6886, 219, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[7246, 231, 338, 11, 36, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[7609, 246, 113, 2, 33, "Text"],
Cell[7725, 250, 67, 0, 33, "Text"],
Cell[7795, 252, 354, 8, 150, "Input"],
Cell[8152, 262, 556, 18, 95, "Text",
  Evaluatable->False],
Cell[8711, 282, 793, 15, 245, "Input"],
Cell[9507, 299, 158, 7, 52, "Text",
  Evaluatable->False],
Cell[9668, 308, 344, 7, 138, "Input"],
Cell[10015, 317, 145, 5, 52, "Text",
  Evaluatable->False],
Cell[10163, 324, 329, 7, 106, "Input"],
Cell[10495, 333, 297, 10, 52, "Text",
  Evaluatable->False],
Cell[10795, 345, 1052, 21, 251, "Input"],
Cell[11850, 368, 296, 11, 52, "Text",
  Evaluatable->False],
Cell[12149, 381, 350, 7, 130, "Input"]
}, Closed]],
Cell[12514, 391, 1344, 41, 93, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[13883, 436, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[14031, 442, 176, 4, 33, "Text",
  Evaluatable->False],
Cell[14210, 448, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[14570, 460, 334, 11, 36, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[14929, 475, 113, 2, 33, "Text"],
Cell[15045, 479, 67, 0, 33, "Text"],
Cell[15115, 481, 377, 9, 146, "Input"],
Cell[15495, 492, 435, 12, 71, "Text",
  Evaluatable->False],
Cell[15933, 506, 533, 10, 190, "Input"],
Cell[16469, 518, 145, 5, 52, "Text",
  Evaluatable->False],
Cell[16617, 525, 1049, 23, 382, "Input"],
Cell[17669, 550, 297, 10, 52, "Text",
  Evaluatable->False],
Cell[17969, 562, 1052, 21, 251, "Input"],
Cell[19024, 585, 296, 11, 52, "Text",
  Evaluatable->False],
Cell[19323, 598, 342, 7, 130, "Input"]
}, Closed]],
Cell[19680, 608, 355, 12, 37, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20060, 624, 113, 2, 33, "Text"],
Cell[20176, 628, 67, 0, 33, "Text"],
Cell[20246, 630, 554, 11, 210, "Input"],
Cell[20803, 643, 297, 10, 52, "Text",
  Evaluatable->False],
Cell[21103, 655, 1052, 21, 251, "Input"],
Cell[22158, 678, 296, 11, 52, "Text",
  Evaluatable->False],
Cell[22457, 691, 335, 7, 130, "Input"]
}, Closed]],
Cell[22807, 701, 466, 13, 85, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[23298, 718, 113, 2, 33, "Text"],
Cell[23414, 722, 192, 4, 33, "Text"],
Cell[23609, 728, 2249, 49, 610, "Input"],
Cell[25861, 779, 257, 9, 52, "Text",
  Evaluatable->False],
Cell[26121, 790, 876, 17, 230, "Input"],
Cell[27000, 809, 304, 11, 52, "Text",
  Evaluatable->False],
Cell[27307, 822, 1451, 29, 390, "Input"]
}, Closed]],
Cell[28773, 854, 1294, 40, 130, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[30092, 898, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[30240, 904, 176, 4, 33, "Text",
  Evaluatable->False],
Cell[30419, 910, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[30779, 922, 339, 9, 49, "Text"],
Cell[31121, 933, 1520, 55, 102, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[32666, 992, 145, 4, 33, "Text",
  Evaluatable->False],
Cell[32814, 998, 176, 4, 33, "Text",
  Evaluatable->False],
Cell[32993, 1004, 345, 9, 33, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 1"]
}, Closed]],
Cell[33353, 1016, 334, 12, 34, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[33712, 1032, 105, 2, 33, "Text"],
Cell[33820, 1036, 88, 2, 33, "Text"],
Cell[33911, 1040, 1426, 30, 466, "Input"],
Cell[35340, 1072, 415, 13, 58, "Text",
  Evaluatable->False],
Cell[35758, 1087, 1972, 38, 398, "Input"],
Cell[37733, 1127, 127, 5, 52, "Text",
  Evaluatable->False],
Cell[37863, 1134, 1785, 36, 310, "Input"],
Cell[39651, 1172, 296, 11, 52, "Text",
  Evaluatable->False],
Cell[39950, 1185, 364, 8, 130, "Input"]
}, Closed]],
Cell[40329, 1196, 331, 8, 30, "Text"],
Cell[40663, 1206, 290, 7, 33, "Text"],
Cell[40956, 1215, 302, 7, 33, "Text"],
Cell[41261, 1224, 291, 7, 33, "Text"],
Cell[41555, 1233, 291, 7, 33, "Text"],
Cell[41849, 1242, 257, 5, 33, "Text"],
Cell[42109, 1249, 262, 6, 33, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

